Class: SDM::SSHCert
- Inherits:
-
Object
- Object
- SDM::SSHCert
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#key_type ⇒ Object
Returns the value of attribute key_type.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
-
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCert
constructor
A new instance of SSHCert.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCert
Returns a new instance of SSHCert.
7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 7046 7047 7048 |
# File 'lib/models/porcelain.rb', line 7014 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_type = key_type == nil ? "" : key_type @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
6982 6983 6984 |
# File 'lib/models/porcelain.rb', line 6982 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
Bind interface
6984 6985 6986 |
# File 'lib/models/porcelain.rb', line 6984 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6986 6987 6988 |
# File 'lib/models/porcelain.rb', line 6986 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6988 6989 6990 |
# File 'lib/models/porcelain.rb', line 6988 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6990 6991 6992 |
# File 'lib/models/porcelain.rb', line 6990 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6992 6993 6994 |
# File 'lib/models/porcelain.rb', line 6992 def id @id end |
#key_type ⇒ Object
Returns the value of attribute key_type.
6994 6995 6996 |
# File 'lib/models/porcelain.rb', line 6994 def key_type @key_type end |
#name ⇒ Object
Unique human-readable name of the Resource.
6996 6997 6998 |
# File 'lib/models/porcelain.rb', line 6996 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
6998 6999 7000 |
# File 'lib/models/porcelain.rb', line 6998 def port @port end |
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
7000 7001 7002 |
# File 'lib/models/porcelain.rb', line 7000 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7002 7003 7004 |
# File 'lib/models/porcelain.rb', line 7002 def port_override @port_override end |
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
7004 7005 7006 |
# File 'lib/models/porcelain.rb', line 7004 def remote_identity_group_id @remote_identity_group_id end |
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
7006 7007 7008 |
# File 'lib/models/porcelain.rb', line 7006 def remote_identity_healthcheck_username @remote_identity_healthcheck_username end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7008 7009 7010 |
# File 'lib/models/porcelain.rb', line 7008 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7010 7011 7012 |
# File 'lib/models/porcelain.rb', line 7010 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7012 7013 7014 |
# File 'lib/models/porcelain.rb', line 7012 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7050 7051 7052 7053 7054 7055 7056 |
# File 'lib/models/porcelain.rb', line 7050 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |