Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
# File 'lib/models/porcelain.rb', line 6138

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



6106
6107
6108
# File 'lib/models/porcelain.rb', line 6106

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



6108
6109
6110
# File 'lib/models/porcelain.rb', line 6108

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6110
6111
6112
# File 'lib/models/porcelain.rb', line 6110

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6112
6113
6114
# File 'lib/models/porcelain.rb', line 6112

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6114
6115
6116
# File 'lib/models/porcelain.rb', line 6114

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6116
6117
6118
# File 'lib/models/porcelain.rb', line 6116

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



6118
6119
6120
# File 'lib/models/porcelain.rb', line 6118

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



6120
6121
6122
# File 'lib/models/porcelain.rb', line 6120

def name
  @name
end

#portObject

Returns the value of attribute port.



6122
6123
6124
# File 'lib/models/porcelain.rb', line 6122

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



6124
6125
6126
# File 'lib/models/porcelain.rb', line 6124

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



6126
6127
6128
# File 'lib/models/porcelain.rb', line 6126

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



6128
6129
6130
# File 'lib/models/porcelain.rb', line 6128

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



6130
6131
6132
# File 'lib/models/porcelain.rb', line 6130

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6132
6133
6134
# File 'lib/models/porcelain.rb', line 6132

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6134
6135
6136
# File 'lib/models/porcelain.rb', line 6134

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6136
6137
6138
# File 'lib/models/porcelain.rb', line 6136

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6174
6175
6176
6177
6178
6179
6180
# File 'lib/models/porcelain.rb', line 6174

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end