Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



6018
6019
6020
6021
6022
6023
6024
6025
6026
6027
6028
6029
6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
6043
6044
6045
6046
6047
6048
6049
6050
6051
6052
# File 'lib/models/porcelain.rb', line 6018

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



5986
5987
5988
# File 'lib/models/porcelain.rb', line 5986

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



5988
5989
5990
# File 'lib/models/porcelain.rb', line 5988

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5990
5991
5992
# File 'lib/models/porcelain.rb', line 5990

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5992
5993
5994
# File 'lib/models/porcelain.rb', line 5992

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5994
5995
5996
# File 'lib/models/porcelain.rb', line 5994

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5996
5997
5998
# File 'lib/models/porcelain.rb', line 5996

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



5998
5999
6000
# File 'lib/models/porcelain.rb', line 5998

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



6000
6001
6002
# File 'lib/models/porcelain.rb', line 6000

def name
  @name
end

#portObject

Returns the value of attribute port.



6002
6003
6004
# File 'lib/models/porcelain.rb', line 6002

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



6004
6005
6006
# File 'lib/models/porcelain.rb', line 6004

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



6006
6007
6008
# File 'lib/models/porcelain.rb', line 6006

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



6008
6009
6010
# File 'lib/models/porcelain.rb', line 6008

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



6010
6011
6012
# File 'lib/models/porcelain.rb', line 6010

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6012
6013
6014
# File 'lib/models/porcelain.rb', line 6012

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6014
6015
6016
# File 'lib/models/porcelain.rb', line 6014

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6016
6017
6018
# File 'lib/models/porcelain.rb', line 6016

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6054
6055
6056
6057
6058
6059
6060
# File 'lib/models/porcelain.rb', line 6054

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end