Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
# File 'lib/models/porcelain.rb', line 5984

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



5952
5953
5954
# File 'lib/models/porcelain.rb', line 5952

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



5954
5955
5956
# File 'lib/models/porcelain.rb', line 5954

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5956
5957
5958
# File 'lib/models/porcelain.rb', line 5956

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5958
5959
5960
# File 'lib/models/porcelain.rb', line 5958

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5960
5961
5962
# File 'lib/models/porcelain.rb', line 5960

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5962
5963
5964
# File 'lib/models/porcelain.rb', line 5962

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



5964
5965
5966
# File 'lib/models/porcelain.rb', line 5964

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



5966
5967
5968
# File 'lib/models/porcelain.rb', line 5966

def name
  @name
end

#portObject

Returns the value of attribute port.



5968
5969
5970
# File 'lib/models/porcelain.rb', line 5968

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



5970
5971
5972
# File 'lib/models/porcelain.rb', line 5970

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



5972
5973
5974
# File 'lib/models/porcelain.rb', line 5972

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



5974
5975
5976
# File 'lib/models/porcelain.rb', line 5974

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



5976
5977
5978
# File 'lib/models/porcelain.rb', line 5976

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5978
5979
5980
# File 'lib/models/porcelain.rb', line 5978

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



5980
5981
5982
# File 'lib/models/porcelain.rb', line 5980

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



5982
5983
5984
# File 'lib/models/porcelain.rb', line 5982

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6020
6021
6022
6023
6024
6025
6026
# File 'lib/models/porcelain.rb', line 6020

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end