Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
5893
5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
# File 'lib/models/porcelain.rb', line 5880

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



5848
5849
5850
# File 'lib/models/porcelain.rb', line 5848

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



5850
5851
5852
# File 'lib/models/porcelain.rb', line 5850

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5852
5853
5854
# File 'lib/models/porcelain.rb', line 5852

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5854
5855
5856
# File 'lib/models/porcelain.rb', line 5854

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5856
5857
5858
# File 'lib/models/porcelain.rb', line 5856

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5858
5859
5860
# File 'lib/models/porcelain.rb', line 5858

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



5860
5861
5862
# File 'lib/models/porcelain.rb', line 5860

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



5862
5863
5864
# File 'lib/models/porcelain.rb', line 5862

def name
  @name
end

#portObject

Returns the value of attribute port.



5864
5865
5866
# File 'lib/models/porcelain.rb', line 5864

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



5866
5867
5868
# File 'lib/models/porcelain.rb', line 5866

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



5868
5869
5870
# File 'lib/models/porcelain.rb', line 5868

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



5870
5871
5872
# File 'lib/models/porcelain.rb', line 5870

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



5872
5873
5874
# File 'lib/models/porcelain.rb', line 5872

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5874
5875
5876
# File 'lib/models/porcelain.rb', line 5874

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



5876
5877
5878
# File 'lib/models/porcelain.rb', line 5876

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



5878
5879
5880
# File 'lib/models/porcelain.rb', line 5878

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5916
5917
5918
5919
5920
5921
5922
# File 'lib/models/porcelain.rb', line 5916

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end