Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
# File 'lib/models/porcelain.rb', line 6813

def initialize(
  allow_deprecated_key_exchanges: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  if allow_deprecated_key_exchanges != nil
    @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges
  end
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if healthy != nil
    @healthy = healthy
  end
  if hostname != nil
    @hostname = hostname
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if port != nil
    @port = port
  end
  if port_forwarding != nil
    @port_forwarding = port_forwarding
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if tags != nil
    @tags = tags
  end
  if username != nil
    @username = username
  end
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



6791
6792
6793
# File 'lib/models/porcelain.rb', line 6791

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6793
6794
6795
# File 'lib/models/porcelain.rb', line 6793

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6795
6796
6797
# File 'lib/models/porcelain.rb', line 6795

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6797
6798
6799
# File 'lib/models/porcelain.rb', line 6797

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6799
6800
6801
# File 'lib/models/porcelain.rb', line 6799

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6801
6802
6803
# File 'lib/models/porcelain.rb', line 6801

def name
  @name
end

#portObject

Returns the value of attribute port.



6803
6804
6805
# File 'lib/models/porcelain.rb', line 6803

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



6805
6806
6807
# File 'lib/models/porcelain.rb', line 6805

def port_forwarding
  @port_forwarding
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6807
6808
6809
# File 'lib/models/porcelain.rb', line 6807

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6809
6810
6811
# File 'lib/models/porcelain.rb', line 6809

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6811
6812
6813
# File 'lib/models/porcelain.rb', line 6811

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6861
6862
6863
6864
6865
6866
6867
# File 'lib/models/porcelain.rb', line 6861

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end