Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, key_type: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



16900
16901
16902
16903
16904
16905
16906
16907
16908
16909
16910
16911
16912
16913
16914
16915
16916
16917
16918
16919
16920
16921
16922
16923
16924
16925
16926
16927
16928
16929
16930
16931
16932
16933
16934
16935
16936
16937
16938
16939
16940
# File 'lib/models/porcelain.rb', line 16900

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  key_type: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @key_type = key_type == nil ? "" : key_type
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchanges ⇒ Object

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16862
16863
16864
# File 'lib/models/porcelain.rb', line 16862

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16864
16865
16866
# File 'lib/models/porcelain.rb', line 16864

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



16866
16867
16868
# File 'lib/models/porcelain.rb', line 16866

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



16868
16869
16870
# File 'lib/models/porcelain.rb', line 16868

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



16870
16871
16872
# File 'lib/models/porcelain.rb', line 16870

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



16872
16873
16874
# File 'lib/models/porcelain.rb', line 16872

def id
  @id
end

#identity_alias_healthcheck_username ⇒ Object

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



16874
16875
16876
# File 'lib/models/porcelain.rb', line 16874

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_id ⇒ Object

The ID of the identity set to use for identity connections.



16876
16877
16878
# File 'lib/models/porcelain.rb', line 16876

def identity_set_id
  @identity_set_id
end

#key_type ⇒ Object

The key type to use e.g. rsa-2048 or ed25519



16878
16879
16880
# File 'lib/models/porcelain.rb', line 16878

def key_type
  @key_type
end

#lock_required ⇒ Object

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16880
16881
16882
# File 'lib/models/porcelain.rb', line 16880

def lock_required
  @lock_required
end

#name ⇒ Object

Unique human-readable name of the Resource.



16882
16883
16884
# File 'lib/models/porcelain.rb', line 16882

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



16884
16885
16886
# File 'lib/models/porcelain.rb', line 16884

def port
  @port
end

#port_forwarding ⇒ Object

Whether port forwarding is allowed through this server.



16886
16887
16888
# File 'lib/models/porcelain.rb', line 16886

def port_forwarding
  @port_forwarding
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16888
16889
16890
# File 'lib/models/porcelain.rb', line 16888

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



16890
16891
16892
# File 'lib/models/porcelain.rb', line 16890

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



16892
16893
16894
# File 'lib/models/porcelain.rb', line 16892

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16894
16895
16896
# File 'lib/models/porcelain.rb', line 16894

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



16896
16897
16898
# File 'lib/models/porcelain.rb', line 16896

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



16898
16899
16900
# File 'lib/models/porcelain.rb', line 16898

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16942
16943
16944
16945
16946
16947
16948
# File 'lib/models/porcelain.rb', line 16942

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end