Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



16931
16932
16933
16934
16935
16936
16937
16938
16939
16940
16941
16942
16943
16944
16945
16946
16947
16948
16949
16950
16951
16952
16953
16954
16955
16956
16957
16958
16959
16960
16961
16962
16963
16964
16965
16966
16967
16968
16969
16970
16971
# File 'lib/models/porcelain.rb', line 16931

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16893
16894
16895
# File 'lib/models/porcelain.rb', line 16893

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16895
16896
16897
# File 'lib/models/porcelain.rb', line 16895

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16897
16898
16899
# File 'lib/models/porcelain.rb', line 16897

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16899
16900
16901
# File 'lib/models/porcelain.rb', line 16899

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16901
16902
16903
# File 'lib/models/porcelain.rb', line 16901

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16903
16904
16905
# File 'lib/models/porcelain.rb', line 16903

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



16905
16906
16907
# File 'lib/models/porcelain.rb', line 16905

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



16907
16908
16909
# File 'lib/models/porcelain.rb', line 16907

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16909
16910
16911
# File 'lib/models/porcelain.rb', line 16909

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16911
16912
16913
# File 'lib/models/porcelain.rb', line 16911

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16913
16914
16915
# File 'lib/models/porcelain.rb', line 16913

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



16915
16916
16917
# File 'lib/models/porcelain.rb', line 16915

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16917
16918
16919
# File 'lib/models/porcelain.rb', line 16917

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



16919
16920
16921
# File 'lib/models/porcelain.rb', line 16919

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16921
16922
16923
# File 'lib/models/porcelain.rb', line 16921

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16923
16924
16925
# File 'lib/models/porcelain.rb', line 16923

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16925
16926
16927
# File 'lib/models/porcelain.rb', line 16925

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16927
16928
16929
# File 'lib/models/porcelain.rb', line 16927

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16929
16930
16931
# File 'lib/models/porcelain.rb', line 16929

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16973
16974
16975
16976
16977
16978
16979
# File 'lib/models/porcelain.rb', line 16973

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end