Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



16799
16800
16801
16802
16803
16804
16805
16806
16807
16808
16809
16810
16811
16812
16813
16814
16815
16816
16817
16818
16819
16820
16821
16822
16823
16824
16825
16826
16827
16828
16829
16830
16831
16832
16833
16834
16835
16836
16837
16838
16839
# File 'lib/models/porcelain.rb', line 16799

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16761
16762
16763
# File 'lib/models/porcelain.rb', line 16761

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16763
16764
16765
# File 'lib/models/porcelain.rb', line 16763

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16765
16766
16767
# File 'lib/models/porcelain.rb', line 16765

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16767
16768
16769
# File 'lib/models/porcelain.rb', line 16767

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16769
16770
16771
# File 'lib/models/porcelain.rb', line 16769

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16771
16772
16773
# File 'lib/models/porcelain.rb', line 16771

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



16773
16774
16775
# File 'lib/models/porcelain.rb', line 16773

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



16775
16776
16777
# File 'lib/models/porcelain.rb', line 16775

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16777
16778
16779
# File 'lib/models/porcelain.rb', line 16777

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16779
16780
16781
# File 'lib/models/porcelain.rb', line 16779

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16781
16782
16783
# File 'lib/models/porcelain.rb', line 16781

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



16783
16784
16785
# File 'lib/models/porcelain.rb', line 16783

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16785
16786
16787
# File 'lib/models/porcelain.rb', line 16785

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



16787
16788
16789
# File 'lib/models/porcelain.rb', line 16787

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16789
16790
16791
# File 'lib/models/porcelain.rb', line 16789

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16791
16792
16793
# File 'lib/models/porcelain.rb', line 16791

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16793
16794
16795
# File 'lib/models/porcelain.rb', line 16793

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16795
16796
16797
# File 'lib/models/porcelain.rb', line 16795

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16797
16798
16799
# File 'lib/models/porcelain.rb', line 16797

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16841
16842
16843
16844
16845
16846
16847
# File 'lib/models/porcelain.rb', line 16841

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end