Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



16572
16573
16574
16575
16576
16577
16578
16579
16580
16581
16582
16583
16584
16585
16586
16587
16588
16589
16590
16591
16592
16593
16594
16595
16596
16597
16598
16599
16600
16601
16602
16603
16604
16605
16606
16607
16608
16609
16610
16611
16612
# File 'lib/models/porcelain.rb', line 16572

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16534
16535
16536
# File 'lib/models/porcelain.rb', line 16534

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16536
16537
16538
# File 'lib/models/porcelain.rb', line 16536

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16538
16539
16540
# File 'lib/models/porcelain.rb', line 16538

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16540
16541
16542
# File 'lib/models/porcelain.rb', line 16540

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16542
16543
16544
# File 'lib/models/porcelain.rb', line 16542

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16544
16545
16546
# File 'lib/models/porcelain.rb', line 16544

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



16546
16547
16548
# File 'lib/models/porcelain.rb', line 16546

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



16548
16549
16550
# File 'lib/models/porcelain.rb', line 16548

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16550
16551
16552
# File 'lib/models/porcelain.rb', line 16550

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16552
16553
16554
# File 'lib/models/porcelain.rb', line 16552

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16554
16555
16556
# File 'lib/models/porcelain.rb', line 16554

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



16556
16557
16558
# File 'lib/models/porcelain.rb', line 16556

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16558
16559
16560
# File 'lib/models/porcelain.rb', line 16558

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



16560
16561
16562
# File 'lib/models/porcelain.rb', line 16560

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16562
16563
16564
# File 'lib/models/porcelain.rb', line 16562

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16564
16565
16566
# File 'lib/models/porcelain.rb', line 16564

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16566
16567
16568
# File 'lib/models/porcelain.rb', line 16566

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16568
16569
16570
# File 'lib/models/porcelain.rb', line 16568

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16570
16571
16572
# File 'lib/models/porcelain.rb', line 16570

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16614
16615
16616
16617
16618
16619
16620
# File 'lib/models/porcelain.rb', line 16614

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end