Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



16449
16450
16451
16452
16453
16454
16455
16456
16457
16458
16459
16460
16461
16462
16463
16464
16465
16466
16467
16468
16469
16470
16471
16472
16473
16474
16475
16476
16477
16478
16479
16480
16481
16482
16483
16484
16485
16486
16487
16488
16489
# File 'lib/models/porcelain.rb', line 16449

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16411
16412
16413
# File 'lib/models/porcelain.rb', line 16411

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16413
16414
16415
# File 'lib/models/porcelain.rb', line 16413

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16415
16416
16417
# File 'lib/models/porcelain.rb', line 16415

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16417
16418
16419
# File 'lib/models/porcelain.rb', line 16417

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16419
16420
16421
# File 'lib/models/porcelain.rb', line 16419

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16421
16422
16423
# File 'lib/models/porcelain.rb', line 16421

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



16423
16424
16425
# File 'lib/models/porcelain.rb', line 16423

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



16425
16426
16427
# File 'lib/models/porcelain.rb', line 16425

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16427
16428
16429
# File 'lib/models/porcelain.rb', line 16427

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16429
16430
16431
# File 'lib/models/porcelain.rb', line 16429

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16431
16432
16433
# File 'lib/models/porcelain.rb', line 16431

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



16433
16434
16435
# File 'lib/models/porcelain.rb', line 16433

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16435
16436
16437
# File 'lib/models/porcelain.rb', line 16435

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



16437
16438
16439
# File 'lib/models/porcelain.rb', line 16437

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16439
16440
16441
# File 'lib/models/porcelain.rb', line 16439

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16441
16442
16443
# File 'lib/models/porcelain.rb', line 16441

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16443
16444
16445
# File 'lib/models/porcelain.rb', line 16443

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16445
16446
16447
# File 'lib/models/porcelain.rb', line 16445

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16447
16448
16449
# File 'lib/models/porcelain.rb', line 16447

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16491
16492
16493
16494
16495
16496
16497
# File 'lib/models/porcelain.rb', line 16491

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end