Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



16150
16151
16152
16153
16154
16155
16156
16157
16158
16159
16160
16161
16162
16163
16164
16165
16166
16167
16168
16169
16170
16171
16172
16173
16174
16175
16176
16177
16178
16179
16180
16181
16182
16183
16184
16185
16186
16187
16188
16189
16190
# File 'lib/models/porcelain.rb', line 16150

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16112
16113
16114
# File 'lib/models/porcelain.rb', line 16112

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16114
16115
16116
# File 'lib/models/porcelain.rb', line 16114

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16116
16117
16118
# File 'lib/models/porcelain.rb', line 16116

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16118
16119
16120
# File 'lib/models/porcelain.rb', line 16118

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16120
16121
16122
# File 'lib/models/porcelain.rb', line 16120

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16122
16123
16124
# File 'lib/models/porcelain.rb', line 16122

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



16124
16125
16126
# File 'lib/models/porcelain.rb', line 16124

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



16126
16127
16128
# File 'lib/models/porcelain.rb', line 16126

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16128
16129
16130
# File 'lib/models/porcelain.rb', line 16128

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16130
16131
16132
# File 'lib/models/porcelain.rb', line 16130

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16132
16133
16134
# File 'lib/models/porcelain.rb', line 16132

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



16134
16135
16136
# File 'lib/models/porcelain.rb', line 16134

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16136
16137
16138
# File 'lib/models/porcelain.rb', line 16136

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



16138
16139
16140
# File 'lib/models/porcelain.rb', line 16138

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16140
16141
16142
# File 'lib/models/porcelain.rb', line 16140

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16142
16143
16144
# File 'lib/models/porcelain.rb', line 16142

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16144
16145
16146
# File 'lib/models/porcelain.rb', line 16144

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16146
16147
16148
# File 'lib/models/porcelain.rb', line 16146

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16148
16149
16150
# File 'lib/models/porcelain.rb', line 16148

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16192
16193
16194
16195
16196
16197
16198
# File 'lib/models/porcelain.rb', line 16192

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end