Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



15774
15775
15776
15777
15778
15779
15780
15781
15782
15783
15784
15785
15786
15787
15788
15789
15790
15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
15811
15812
15813
15814
# File 'lib/models/porcelain.rb', line 15774

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



15736
15737
15738
# File 'lib/models/porcelain.rb', line 15736

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15738
15739
15740
# File 'lib/models/porcelain.rb', line 15738

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15740
15741
15742
# File 'lib/models/porcelain.rb', line 15740

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15742
15743
15744
# File 'lib/models/porcelain.rb', line 15742

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15744
15745
15746
# File 'lib/models/porcelain.rb', line 15744

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15746
15747
15748
# File 'lib/models/porcelain.rb', line 15746

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



15748
15749
15750
# File 'lib/models/porcelain.rb', line 15748

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



15750
15751
15752
# File 'lib/models/porcelain.rb', line 15750

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



15752
15753
15754
# File 'lib/models/porcelain.rb', line 15752

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



15754
15755
15756
# File 'lib/models/porcelain.rb', line 15754

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15756
15757
15758
# File 'lib/models/porcelain.rb', line 15756

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



15758
15759
15760
# File 'lib/models/porcelain.rb', line 15758

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15760
15761
15762
# File 'lib/models/porcelain.rb', line 15760

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



15762
15763
15764
# File 'lib/models/porcelain.rb', line 15762

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15764
15765
15766
# File 'lib/models/porcelain.rb', line 15764

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15766
15767
15768
# File 'lib/models/porcelain.rb', line 15766

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15768
15769
15770
# File 'lib/models/porcelain.rb', line 15768

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15770
15771
15772
# File 'lib/models/porcelain.rb', line 15770

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15772
15773
15774
# File 'lib/models/porcelain.rb', line 15772

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15816
15817
15818
15819
15820
15821
15822
# File 'lib/models/porcelain.rb', line 15816

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end