Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



14878
14879
14880
14881
14882
14883
14884
14885
14886
14887
14888
14889
14890
14891
14892
14893
14894
14895
14896
14897
14898
14899
14900
14901
14902
14903
14904
14905
14906
14907
14908
14909
14910
14911
14912
14913
14914
14915
14916
# File 'lib/models/porcelain.rb', line 14878

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



14842
14843
14844
# File 'lib/models/porcelain.rb', line 14842

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14844
14845
14846
# File 'lib/models/porcelain.rb', line 14844

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14846
14847
14848
# File 'lib/models/porcelain.rb', line 14846

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14848
14849
14850
# File 'lib/models/porcelain.rb', line 14848

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14850
14851
14852
# File 'lib/models/porcelain.rb', line 14850

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14852
14853
14854
# File 'lib/models/porcelain.rb', line 14852

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



14854
14855
14856
# File 'lib/models/porcelain.rb', line 14854

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



14856
14857
14858
# File 'lib/models/porcelain.rb', line 14856

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



14858
14859
14860
# File 'lib/models/porcelain.rb', line 14858

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14860
14861
14862
# File 'lib/models/porcelain.rb', line 14860

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



14862
14863
14864
# File 'lib/models/porcelain.rb', line 14862

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14864
14865
14866
# File 'lib/models/porcelain.rb', line 14864

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



14866
14867
14868
# File 'lib/models/porcelain.rb', line 14866

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14868
14869
14870
# File 'lib/models/porcelain.rb', line 14868

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14870
14871
14872
# File 'lib/models/porcelain.rb', line 14870

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14872
14873
14874
# File 'lib/models/porcelain.rb', line 14872

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14874
14875
14876
# File 'lib/models/porcelain.rb', line 14874

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14876
14877
14878
# File 'lib/models/porcelain.rb', line 14876

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14918
14919
14920
14921
14922
14923
14924
# File 'lib/models/porcelain.rb', line 14918

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end