Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
13613
13614
13615
13616
13617
13618
13619
13620
13621
13622
13623
13624
13625
13626
13627
13628
13629
13630
13631
13632
13633
13634
13635
13636
# File 'lib/models/porcelain.rb', line 13598

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



13562
13563
13564
# File 'lib/models/porcelain.rb', line 13562

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13564
13565
13566
# File 'lib/models/porcelain.rb', line 13564

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13566
13567
13568
# File 'lib/models/porcelain.rb', line 13566

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13568
13569
13570
# File 'lib/models/porcelain.rb', line 13568

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13570
13571
13572
# File 'lib/models/porcelain.rb', line 13570

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13572
13573
13574
# File 'lib/models/porcelain.rb', line 13572

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



13574
13575
13576
# File 'lib/models/porcelain.rb', line 13574

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



13576
13577
13578
# File 'lib/models/porcelain.rb', line 13576

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



13578
13579
13580
# File 'lib/models/porcelain.rb', line 13578

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13580
13581
13582
# File 'lib/models/porcelain.rb', line 13580

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



13582
13583
13584
# File 'lib/models/porcelain.rb', line 13582

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



13584
13585
13586
# File 'lib/models/porcelain.rb', line 13584

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



13586
13587
13588
# File 'lib/models/porcelain.rb', line 13586

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13588
13589
13590
# File 'lib/models/porcelain.rb', line 13588

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13590
13591
13592
# File 'lib/models/porcelain.rb', line 13590

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13592
13593
13594
# File 'lib/models/porcelain.rb', line 13592

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13594
13595
13596
# File 'lib/models/porcelain.rb', line 13594

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13596
13597
13598
# File 'lib/models/porcelain.rb', line 13596

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13638
13639
13640
13641
13642
13643
13644
# File 'lib/models/porcelain.rb', line 13638

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end