Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



13336
13337
13338
13339
13340
13341
13342
13343
13344
13345
13346
13347
13348
13349
13350
13351
13352
13353
13354
13355
13356
13357
13358
13359
13360
13361
13362
13363
13364
13365
13366
13367
13368
13369
13370
13371
13372
13373
13374
# File 'lib/models/porcelain.rb', line 13336

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



13300
13301
13302
# File 'lib/models/porcelain.rb', line 13300

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13302
13303
13304
# File 'lib/models/porcelain.rb', line 13302

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13304
13305
13306
# File 'lib/models/porcelain.rb', line 13304

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13306
13307
13308
# File 'lib/models/porcelain.rb', line 13306

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13308
13309
13310
# File 'lib/models/porcelain.rb', line 13308

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13310
13311
13312
# File 'lib/models/porcelain.rb', line 13310

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



13312
13313
13314
# File 'lib/models/porcelain.rb', line 13312

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



13314
13315
13316
# File 'lib/models/porcelain.rb', line 13314

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



13316
13317
13318
# File 'lib/models/porcelain.rb', line 13316

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13318
13319
13320
# File 'lib/models/porcelain.rb', line 13318

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



13320
13321
13322
# File 'lib/models/porcelain.rb', line 13320

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



13322
13323
13324
# File 'lib/models/porcelain.rb', line 13322

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



13324
13325
13326
# File 'lib/models/porcelain.rb', line 13324

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13326
13327
13328
# File 'lib/models/porcelain.rb', line 13326

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13328
13329
13330
# File 'lib/models/porcelain.rb', line 13328

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13330
13331
13332
# File 'lib/models/porcelain.rb', line 13330

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13332
13333
13334
# File 'lib/models/porcelain.rb', line 13332

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13334
13335
13336
# File 'lib/models/porcelain.rb', line 13334

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13376
13377
13378
13379
13380
13381
13382
# File 'lib/models/porcelain.rb', line 13376

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end