Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



13263
13264
13265
13266
13267
13268
13269
13270
13271
13272
13273
13274
13275
13276
13277
13278
13279
13280
13281
13282
13283
13284
13285
13286
13287
13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
# File 'lib/models/porcelain.rb', line 13263

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



13227
13228
13229
# File 'lib/models/porcelain.rb', line 13227

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13229
13230
13231
# File 'lib/models/porcelain.rb', line 13229

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13231
13232
13233
# File 'lib/models/porcelain.rb', line 13231

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13233
13234
13235
# File 'lib/models/porcelain.rb', line 13233

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13235
13236
13237
# File 'lib/models/porcelain.rb', line 13235

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13237
13238
13239
# File 'lib/models/porcelain.rb', line 13237

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



13239
13240
13241
# File 'lib/models/porcelain.rb', line 13239

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



13241
13242
13243
# File 'lib/models/porcelain.rb', line 13241

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



13243
13244
13245
# File 'lib/models/porcelain.rb', line 13243

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13245
13246
13247
# File 'lib/models/porcelain.rb', line 13245

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



13247
13248
13249
# File 'lib/models/porcelain.rb', line 13247

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



13249
13250
13251
# File 'lib/models/porcelain.rb', line 13249

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



13251
13252
13253
# File 'lib/models/porcelain.rb', line 13251

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13253
13254
13255
# File 'lib/models/porcelain.rb', line 13253

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13255
13256
13257
# File 'lib/models/porcelain.rb', line 13255

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13257
13258
13259
# File 'lib/models/porcelain.rb', line 13257

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13259
13260
13261
# File 'lib/models/porcelain.rb', line 13259

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13261
13262
13263
# File 'lib/models/porcelain.rb', line 13261

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13303
13304
13305
13306
13307
13308
13309
# File 'lib/models/porcelain.rb', line 13303

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end