Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



13195
13196
13197
13198
13199
13200
13201
13202
13203
13204
13205
13206
13207
13208
13209
13210
13211
13212
13213
13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
13233
# File 'lib/models/porcelain.rb', line 13195

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



13159
13160
13161
# File 'lib/models/porcelain.rb', line 13159

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13161
13162
13163
# File 'lib/models/porcelain.rb', line 13161

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13163
13164
13165
# File 'lib/models/porcelain.rb', line 13163

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13165
13166
13167
# File 'lib/models/porcelain.rb', line 13165

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13167
13168
13169
# File 'lib/models/porcelain.rb', line 13167

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13169
13170
13171
# File 'lib/models/porcelain.rb', line 13169

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



13171
13172
13173
# File 'lib/models/porcelain.rb', line 13171

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



13173
13174
13175
# File 'lib/models/porcelain.rb', line 13173

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



13175
13176
13177
# File 'lib/models/porcelain.rb', line 13175

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13177
13178
13179
# File 'lib/models/porcelain.rb', line 13177

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



13179
13180
13181
# File 'lib/models/porcelain.rb', line 13179

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



13181
13182
13183
# File 'lib/models/porcelain.rb', line 13181

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



13183
13184
13185
# File 'lib/models/porcelain.rb', line 13183

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13185
13186
13187
# File 'lib/models/porcelain.rb', line 13185

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13187
13188
13189
# File 'lib/models/porcelain.rb', line 13187

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13189
13190
13191
# File 'lib/models/porcelain.rb', line 13189

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13191
13192
13193
# File 'lib/models/porcelain.rb', line 13191

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13193
13194
13195
# File 'lib/models/porcelain.rb', line 13193

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13235
13236
13237
13238
13239
13240
13241
# File 'lib/models/porcelain.rb', line 13235

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end