Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
12350
12351
12352
12353
12354
12355
12356
12357
12358
12359
12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
# File 'lib/models/porcelain.rb', line 12340

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



12308
12309
12310
# File 'lib/models/porcelain.rb', line 12308

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12310
12311
12312
# File 'lib/models/porcelain.rb', line 12310

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12312
12313
12314
# File 'lib/models/porcelain.rb', line 12312

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12314
12315
12316
# File 'lib/models/porcelain.rb', line 12314

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12316
12317
12318
# File 'lib/models/porcelain.rb', line 12316

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12318
12319
12320
# File 'lib/models/porcelain.rb', line 12318

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12320
12321
12322
# File 'lib/models/porcelain.rb', line 12320

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12322
12323
12324
# File 'lib/models/porcelain.rb', line 12322

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



12324
12325
12326
# File 'lib/models/porcelain.rb', line 12324

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



12326
12327
12328
# File 'lib/models/porcelain.rb', line 12326

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



12328
12329
12330
# File 'lib/models/porcelain.rb', line 12328

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12330
12331
12332
# File 'lib/models/porcelain.rb', line 12330

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12332
12333
12334
# File 'lib/models/porcelain.rb', line 12332

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12334
12335
12336
# File 'lib/models/porcelain.rb', line 12334

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12336
12337
12338
# File 'lib/models/porcelain.rb', line 12336

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12338
12339
12340
# File 'lib/models/porcelain.rb', line 12338

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12376
12377
12378
12379
12380
12381
12382
# File 'lib/models/porcelain.rb', line 12376

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end