Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



12018
12019
12020
12021
12022
12023
12024
12025
12026
12027
12028
12029
12030
12031
12032
12033
12034
12035
12036
12037
12038
12039
12040
12041
12042
12043
12044
12045
12046
12047
12048
12049
12050
12051
12052
# File 'lib/models/porcelain.rb', line 12018

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11986
11987
11988
# File 'lib/models/porcelain.rb', line 11986

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11988
11989
11990
# File 'lib/models/porcelain.rb', line 11988

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11990
11991
11992
# File 'lib/models/porcelain.rb', line 11990

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11992
11993
11994
# File 'lib/models/porcelain.rb', line 11992

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11994
11995
11996
# File 'lib/models/porcelain.rb', line 11994

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11996
11997
11998
# File 'lib/models/porcelain.rb', line 11996

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11998
11999
12000
# File 'lib/models/porcelain.rb', line 11998

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12000
12001
12002
# File 'lib/models/porcelain.rb', line 12000

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



12002
12003
12004
# File 'lib/models/porcelain.rb', line 12002

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



12004
12005
12006
# File 'lib/models/porcelain.rb', line 12004

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



12006
12007
12008
# File 'lib/models/porcelain.rb', line 12006

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12008
12009
12010
# File 'lib/models/porcelain.rb', line 12008

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12010
12011
12012
# File 'lib/models/porcelain.rb', line 12010

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12012
12013
12014
# File 'lib/models/porcelain.rb', line 12012

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12014
12015
12016
# File 'lib/models/porcelain.rb', line 12014

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12016
12017
12018
# File 'lib/models/porcelain.rb', line 12016

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12054
12055
12056
12057
12058
12059
12060
# File 'lib/models/porcelain.rb', line 12054

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end