Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



11504
11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
# File 'lib/models/porcelain.rb', line 11504

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11472
11473
11474
# File 'lib/models/porcelain.rb', line 11472

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11474
11475
11476
# File 'lib/models/porcelain.rb', line 11474

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11476
11477
11478
# File 'lib/models/porcelain.rb', line 11476

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11478
11479
11480
# File 'lib/models/porcelain.rb', line 11478

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11480
11481
11482
# File 'lib/models/porcelain.rb', line 11480

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11482
11483
11484
# File 'lib/models/porcelain.rb', line 11482

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11484
11485
11486
# File 'lib/models/porcelain.rb', line 11484

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11486
11487
11488
# File 'lib/models/porcelain.rb', line 11486

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11488
11489
11490
# File 'lib/models/porcelain.rb', line 11488

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11490
11491
11492
# File 'lib/models/porcelain.rb', line 11490

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



11492
11493
11494
# File 'lib/models/porcelain.rb', line 11492

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11494
11495
11496
# File 'lib/models/porcelain.rb', line 11494

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11496
11497
11498
# File 'lib/models/porcelain.rb', line 11496

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11498
11499
11500
# File 'lib/models/porcelain.rb', line 11498

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11500
11501
11502
# File 'lib/models/porcelain.rb', line 11500

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11502
11503
11504
# File 'lib/models/porcelain.rb', line 11502

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11540
11541
11542
11543
11544
11545
11546
# File 'lib/models/porcelain.rb', line 11540

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end