Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
11191
11192
11193
11194
11195
11196
11197
11198
11199
11200
11201
11202
11203
11204
11205
11206
11207
11208
11209
11210
11211
11212
# File 'lib/models/porcelain.rb', line 11178

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11146
11147
11148
# File 'lib/models/porcelain.rb', line 11146

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11148
11149
11150
# File 'lib/models/porcelain.rb', line 11148

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11150
11151
11152
# File 'lib/models/porcelain.rb', line 11150

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11152
11153
11154
# File 'lib/models/porcelain.rb', line 11152

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11154
11155
11156
# File 'lib/models/porcelain.rb', line 11154

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11156
11157
11158
# File 'lib/models/porcelain.rb', line 11156

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11158
11159
11160
# File 'lib/models/porcelain.rb', line 11158

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11160
11161
11162
# File 'lib/models/porcelain.rb', line 11160

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11162
11163
11164
# File 'lib/models/porcelain.rb', line 11162

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11164
11165
11166
# File 'lib/models/porcelain.rb', line 11164

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



11166
11167
11168
# File 'lib/models/porcelain.rb', line 11166

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11168
11169
11170
# File 'lib/models/porcelain.rb', line 11168

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11170
11171
11172
# File 'lib/models/porcelain.rb', line 11170

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11172
11173
11174
# File 'lib/models/porcelain.rb', line 11172

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11174
11175
11176
# File 'lib/models/porcelain.rb', line 11174

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11176
11177
11178
# File 'lib/models/porcelain.rb', line 11176

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11214
11215
11216
11217
11218
11219
11220
# File 'lib/models/porcelain.rb', line 11214

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end