Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



10787
10788
10789
10790
10791
10792
10793
10794
10795
10796
10797
10798
10799
10800
10801
10802
10803
10804
10805
10806
10807
10808
10809
10810
10811
10812
10813
10814
10815
10816
10817
10818
10819
# File 'lib/models/porcelain.rb', line 10787

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



10757
10758
10759
# File 'lib/models/porcelain.rb', line 10757

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10759
10760
10761
# File 'lib/models/porcelain.rb', line 10759

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10761
10762
10763
# File 'lib/models/porcelain.rb', line 10761

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10763
10764
10765
# File 'lib/models/porcelain.rb', line 10763

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10765
10766
10767
# File 'lib/models/porcelain.rb', line 10765

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10767
10768
10769
# File 'lib/models/porcelain.rb', line 10767

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10769
10770
10771
# File 'lib/models/porcelain.rb', line 10769

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10771
10772
10773
# File 'lib/models/porcelain.rb', line 10771

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



10773
10774
10775
# File 'lib/models/porcelain.rb', line 10773

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



10775
10776
10777
# File 'lib/models/porcelain.rb', line 10775

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



10777
10778
10779
# File 'lib/models/porcelain.rb', line 10777

def private_key
  @private_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10779
10780
10781
# File 'lib/models/porcelain.rb', line 10779

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10781
10782
10783
# File 'lib/models/porcelain.rb', line 10781

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10783
10784
10785
# File 'lib/models/porcelain.rb', line 10783

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10785
10786
10787
# File 'lib/models/porcelain.rb', line 10785

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10821
10822
10823
10824
10825
10826
10827
# File 'lib/models/porcelain.rb', line 10821

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end