Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



10449
10450
10451
10452
10453
10454
10455
10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
# File 'lib/models/porcelain.rb', line 10449

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



10419
10420
10421
# File 'lib/models/porcelain.rb', line 10419

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10421
10422
10423
# File 'lib/models/porcelain.rb', line 10421

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10423
10424
10425
# File 'lib/models/porcelain.rb', line 10423

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10425
10426
10427
# File 'lib/models/porcelain.rb', line 10425

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10427
10428
10429
# File 'lib/models/porcelain.rb', line 10427

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10429
10430
10431
# File 'lib/models/porcelain.rb', line 10429

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10431
10432
10433
# File 'lib/models/porcelain.rb', line 10431

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10433
10434
10435
# File 'lib/models/porcelain.rb', line 10433

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



10435
10436
10437
# File 'lib/models/porcelain.rb', line 10435

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



10437
10438
10439
# File 'lib/models/porcelain.rb', line 10437

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



10439
10440
10441
# File 'lib/models/porcelain.rb', line 10439

def private_key
  @private_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10441
10442
10443
# File 'lib/models/porcelain.rb', line 10441

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10443
10444
10445
# File 'lib/models/porcelain.rb', line 10443

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10445
10446
10447
# File 'lib/models/porcelain.rb', line 10445

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10447
10448
10449
# File 'lib/models/porcelain.rb', line 10447

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10483
10484
10485
10486
10487
10488
10489
# File 'lib/models/porcelain.rb', line 10483

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end