Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



9119
9120
9121
9122
9123
9124
9125
9126
9127
9128
9129
9130
9131
9132
9133
9134
9135
9136
9137
9138
9139
9140
9141
9142
9143
9144
9145
9146
9147
9148
9149
9150
9151
# File 'lib/models/porcelain.rb', line 9119

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



9089
9090
9091
# File 'lib/models/porcelain.rb', line 9089

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9091
9092
9093
# File 'lib/models/porcelain.rb', line 9091

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9093
9094
9095
# File 'lib/models/porcelain.rb', line 9093

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9095
9096
9097
# File 'lib/models/porcelain.rb', line 9095

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9097
9098
9099
# File 'lib/models/porcelain.rb', line 9097

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9099
9100
9101
# File 'lib/models/porcelain.rb', line 9099

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9101
9102
9103
# File 'lib/models/porcelain.rb', line 9101

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9103
9104
9105
# File 'lib/models/porcelain.rb', line 9103

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



9105
9106
9107
# File 'lib/models/porcelain.rb', line 9105

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



9107
9108
9109
# File 'lib/models/porcelain.rb', line 9107

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



9109
9110
9111
# File 'lib/models/porcelain.rb', line 9109

def private_key
  @private_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9111
9112
9113
# File 'lib/models/porcelain.rb', line 9111

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9113
9114
9115
# File 'lib/models/porcelain.rb', line 9113

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9115
9116
9117
# File 'lib/models/porcelain.rb', line 9115

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9117
9118
9119
# File 'lib/models/porcelain.rb', line 9117

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9153
9154
9155
9156
9157
9158
9159
# File 'lib/models/porcelain.rb', line 9153

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end