Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
8010
8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
# File 'lib/models/porcelain.rb', line 7999

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



7969
7970
7971
# File 'lib/models/porcelain.rb', line 7969

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7971
7972
7973
# File 'lib/models/porcelain.rb', line 7971

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7973
7974
7975
# File 'lib/models/porcelain.rb', line 7973

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7975
7976
7977
# File 'lib/models/porcelain.rb', line 7975

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7977
7978
7979
# File 'lib/models/porcelain.rb', line 7977

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7979
7980
7981
# File 'lib/models/porcelain.rb', line 7979

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7981
7982
7983
# File 'lib/models/porcelain.rb', line 7981

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7983
7984
7985
# File 'lib/models/porcelain.rb', line 7983

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



7985
7986
7987
# File 'lib/models/porcelain.rb', line 7985

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



7987
7988
7989
# File 'lib/models/porcelain.rb', line 7987

def port_override
  @port_override
end

#private_keyObject

The private key used to authenticate with the server.



7989
7990
7991
# File 'lib/models/porcelain.rb', line 7989

def private_key
  @private_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7991
7992
7993
# File 'lib/models/porcelain.rb', line 7991

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7993
7994
7995
# File 'lib/models/porcelain.rb', line 7993

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7995
7996
7997
# File 'lib/models/porcelain.rb', line 7995

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7997
7998
7999
# File 'lib/models/porcelain.rb', line 7997

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8033
8034
8035
8036
8037
8038
8039
# File 'lib/models/porcelain.rb', line 8033

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end