Class: SDM::SSHCustomerKey
- Inherits:
-
Object
- Object
- SDM::SSHCustomerKey
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#private_key ⇒ Object
Returns the value of attribute private_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey
constructor
A new instance of SSHCustomerKey.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey
Returns a new instance of SSHCustomerKey.
7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/models/porcelain.rb', line 7813 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @private_key = private_key == nil ? "" : private_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
7783 7784 7785 |
# File 'lib/models/porcelain.rb', line 7783 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
Bind interface
7785 7786 7787 |
# File 'lib/models/porcelain.rb', line 7785 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7787 7788 7789 |
# File 'lib/models/porcelain.rb', line 7787 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7789 7790 7791 |
# File 'lib/models/porcelain.rb', line 7789 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7791 7792 7793 |
# File 'lib/models/porcelain.rb', line 7791 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7793 7794 7795 |
# File 'lib/models/porcelain.rb', line 7793 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7795 7796 7797 |
# File 'lib/models/porcelain.rb', line 7795 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
7797 7798 7799 |
# File 'lib/models/porcelain.rb', line 7797 def port @port end |
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
7799 7800 7801 |
# File 'lib/models/porcelain.rb', line 7799 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7801 7802 7803 |
# File 'lib/models/porcelain.rb', line 7801 def port_override @port_override end |
#private_key ⇒ Object
Returns the value of attribute private_key.
7803 7804 7805 |
# File 'lib/models/porcelain.rb', line 7803 def private_key @private_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7805 7806 7807 |
# File 'lib/models/porcelain.rb', line 7805 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7807 7808 7809 |
# File 'lib/models/porcelain.rb', line 7807 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7809 7810 7811 |
# File 'lib/models/porcelain.rb', line 7809 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7811 7812 7813 |
# File 'lib/models/porcelain.rb', line 7811 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7847 7848 7849 7850 7851 7852 7853 |
# File 'lib/models/porcelain.rb', line 7847 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |