Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
7784
7785
7786
7787
7788
7789
# File 'lib/models/porcelain.rb', line 7757

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



7727
7728
7729
# File 'lib/models/porcelain.rb', line 7727

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



7729
7730
7731
# File 'lib/models/porcelain.rb', line 7729

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7731
7732
7733
# File 'lib/models/porcelain.rb', line 7731

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7733
7734
7735
# File 'lib/models/porcelain.rb', line 7733

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7735
7736
7737
# File 'lib/models/porcelain.rb', line 7735

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7737
7738
7739
# File 'lib/models/porcelain.rb', line 7737

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7739
7740
7741
# File 'lib/models/porcelain.rb', line 7739

def name
  @name
end

#portObject

Returns the value of attribute port.



7741
7742
7743
# File 'lib/models/porcelain.rb', line 7741

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



7743
7744
7745
# File 'lib/models/porcelain.rb', line 7743

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



7745
7746
7747
# File 'lib/models/porcelain.rb', line 7745

def port_override
  @port_override
end

#private_keyObject

Returns the value of attribute private_key.



7747
7748
7749
# File 'lib/models/porcelain.rb', line 7747

def private_key
  @private_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7749
7750
7751
# File 'lib/models/porcelain.rb', line 7749

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7751
7752
7753
# File 'lib/models/porcelain.rb', line 7751

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7753
7754
7755
# File 'lib/models/porcelain.rb', line 7753

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7755
7756
7757
# File 'lib/models/porcelain.rb', line 7755

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7791
7792
7793
7794
7795
7796
7797
# File 'lib/models/porcelain.rb', line 7791

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end