Class: SDM::SSHCustomerKey
- Inherits:
-
Object
- Object
- SDM::SSHCustomerKey
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#private_key ⇒ Object
Returns the value of attribute private_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey
constructor
A new instance of SSHCustomerKey.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey
Returns a new instance of SSHCustomerKey.
7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 |
# File 'lib/models/porcelain.rb', line 7583 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @private_key = private_key == nil ? "" : private_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
7553 7554 7555 |
# File 'lib/models/porcelain.rb', line 7553 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
Bind interface
7555 7556 7557 |
# File 'lib/models/porcelain.rb', line 7555 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7557 7558 7559 |
# File 'lib/models/porcelain.rb', line 7557 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7559 7560 7561 |
# File 'lib/models/porcelain.rb', line 7559 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7561 7562 7563 |
# File 'lib/models/porcelain.rb', line 7561 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7563 7564 7565 |
# File 'lib/models/porcelain.rb', line 7563 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7565 7566 7567 |
# File 'lib/models/porcelain.rb', line 7565 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
7567 7568 7569 |
# File 'lib/models/porcelain.rb', line 7567 def port @port end |
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
7569 7570 7571 |
# File 'lib/models/porcelain.rb', line 7569 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7571 7572 7573 |
# File 'lib/models/porcelain.rb', line 7571 def port_override @port_override end |
#private_key ⇒ Object
Returns the value of attribute private_key.
7573 7574 7575 |
# File 'lib/models/porcelain.rb', line 7573 def private_key @private_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7575 7576 7577 |
# File 'lib/models/porcelain.rb', line 7575 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7577 7578 7579 |
# File 'lib/models/porcelain.rb', line 7577 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7579 7580 7581 |
# File 'lib/models/porcelain.rb', line 7579 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7581 7582 7583 |
# File 'lib/models/porcelain.rb', line 7581 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/models/porcelain.rb', line 7617 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |