Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



7530
7531
7532
7533
7534
7535
7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
# File 'lib/models/porcelain.rb', line 7530

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



7500
7501
7502
# File 'lib/models/porcelain.rb', line 7500

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



7502
7503
7504
# File 'lib/models/porcelain.rb', line 7502

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7504
7505
7506
# File 'lib/models/porcelain.rb', line 7504

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7506
7507
7508
# File 'lib/models/porcelain.rb', line 7506

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7508
7509
7510
# File 'lib/models/porcelain.rb', line 7508

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7510
7511
7512
# File 'lib/models/porcelain.rb', line 7510

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7512
7513
7514
# File 'lib/models/porcelain.rb', line 7512

def name
  @name
end

#portObject

Returns the value of attribute port.



7514
7515
7516
# File 'lib/models/porcelain.rb', line 7514

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



7516
7517
7518
# File 'lib/models/porcelain.rb', line 7516

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



7518
7519
7520
# File 'lib/models/porcelain.rb', line 7518

def port_override
  @port_override
end

#private_keyObject

Returns the value of attribute private_key.



7520
7521
7522
# File 'lib/models/porcelain.rb', line 7520

def private_key
  @private_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7522
7523
7524
# File 'lib/models/porcelain.rb', line 7522

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7524
7525
7526
# File 'lib/models/porcelain.rb', line 7524

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7526
7527
7528
# File 'lib/models/porcelain.rb', line 7526

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7528
7529
7530
# File 'lib/models/porcelain.rb', line 7528

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7564
7565
7566
7567
7568
7569
7570
# File 'lib/models/porcelain.rb', line 7564

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end