Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
# File 'lib/models/porcelain.rb', line 7088

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



7060
7061
7062
# File 'lib/models/porcelain.rb', line 7060

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



7062
7063
7064
# File 'lib/models/porcelain.rb', line 7062

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7064
7065
7066
# File 'lib/models/porcelain.rb', line 7064

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7066
7067
7068
# File 'lib/models/porcelain.rb', line 7066

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7068
7069
7070
# File 'lib/models/porcelain.rb', line 7068

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7070
7071
7072
# File 'lib/models/porcelain.rb', line 7070

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7072
7073
7074
# File 'lib/models/porcelain.rb', line 7072

def name
  @name
end

#portObject

Returns the value of attribute port.



7074
7075
7076
# File 'lib/models/porcelain.rb', line 7074

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



7076
7077
7078
# File 'lib/models/porcelain.rb', line 7076

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



7078
7079
7080
# File 'lib/models/porcelain.rb', line 7078

def port_override
  @port_override
end

#private_keyObject

Returns the value of attribute private_key.



7080
7081
7082
# File 'lib/models/porcelain.rb', line 7080

def private_key
  @private_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7082
7083
7084
# File 'lib/models/porcelain.rb', line 7082

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



7084
7085
7086
# File 'lib/models/porcelain.rb', line 7084

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7086
7087
7088
# File 'lib/models/porcelain.rb', line 7086

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7120
7121
7122
7123
7124
7125
7126
# File 'lib/models/porcelain.rb', line 7120

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end