Class: SDM::SSHCustomerKey
- Inherits:
-
Object
- Object
- SDM::SSHCustomerKey
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#private_key ⇒ Object
Returns the value of attribute private_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCustomerKey
constructor
A new instance of SSHCustomerKey.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCustomerKey
Returns a new instance of SSHCustomerKey.
6211 6212 6213 6214 6215 6216 6217 6218 6219 6220 6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 6234 6235 6236 6237 6238 6239 6240 6241 |
# File 'lib/models/porcelain.rb', line 6211 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @private_key = private_key == nil ? "" : private_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
6183 6184 6185 |
# File 'lib/models/porcelain.rb', line 6183 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
Bind interface
6185 6186 6187 |
# File 'lib/models/porcelain.rb', line 6185 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6187 6188 6189 |
# File 'lib/models/porcelain.rb', line 6187 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6189 6190 6191 |
# File 'lib/models/porcelain.rb', line 6189 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6191 6192 6193 |
# File 'lib/models/porcelain.rb', line 6191 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6193 6194 6195 |
# File 'lib/models/porcelain.rb', line 6193 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6195 6196 6197 |
# File 'lib/models/porcelain.rb', line 6195 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
6197 6198 6199 |
# File 'lib/models/porcelain.rb', line 6197 def port @port end |
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
6199 6200 6201 |
# File 'lib/models/porcelain.rb', line 6199 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6201 6202 6203 |
# File 'lib/models/porcelain.rb', line 6201 def port_override @port_override end |
#private_key ⇒ Object
Returns the value of attribute private_key.
6203 6204 6205 |
# File 'lib/models/porcelain.rb', line 6203 def private_key @private_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6205 6206 6207 |
# File 'lib/models/porcelain.rb', line 6205 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6207 6208 6209 |
# File 'lib/models/porcelain.rb', line 6207 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6209 6210 6211 |
# File 'lib/models/porcelain.rb', line 6209 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6243 6244 6245 6246 6247 6248 6249 |
# File 'lib/models/porcelain.rb', line 6243 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |