Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



6212
6213
6214
6215
6216
6217
6218
6219
6220
6221
6222
6223
6224
6225
6226
6227
6228
6229
6230
6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
6241
6242
# File 'lib/models/porcelain.rb', line 6212

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



6184
6185
6186
# File 'lib/models/porcelain.rb', line 6184

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



6186
6187
6188
# File 'lib/models/porcelain.rb', line 6186

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6188
6189
6190
# File 'lib/models/porcelain.rb', line 6188

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6190
6191
6192
# File 'lib/models/porcelain.rb', line 6190

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6192
6193
6194
# File 'lib/models/porcelain.rb', line 6192

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6194
6195
6196
# File 'lib/models/porcelain.rb', line 6194

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6196
6197
6198
# File 'lib/models/porcelain.rb', line 6196

def name
  @name
end

#portObject

Returns the value of attribute port.



6198
6199
6200
# File 'lib/models/porcelain.rb', line 6198

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



6200
6201
6202
# File 'lib/models/porcelain.rb', line 6200

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



6202
6203
6204
# File 'lib/models/porcelain.rb', line 6202

def port_override
  @port_override
end

#private_keyObject

Returns the value of attribute private_key.



6204
6205
6206
# File 'lib/models/porcelain.rb', line 6204

def private_key
  @private_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6206
6207
6208
# File 'lib/models/porcelain.rb', line 6206

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6208
6209
6210
# File 'lib/models/porcelain.rb', line 6208

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6210
6211
6212
# File 'lib/models/porcelain.rb', line 6210

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6244
6245
6246
6247
6248
6249
6250
# File 'lib/models/porcelain.rb', line 6244

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end