Class: SDM::SSHCustomerKey
- Inherits:
-
Object
- Object
- SDM::SSHCustomerKey
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#private_key ⇒ Object
Returns the value of attribute private_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCustomerKey
constructor
A new instance of SSHCustomerKey.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCustomerKey
Returns a new instance of SSHCustomerKey.
6135 6136 6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 |
# File 'lib/models/porcelain.rb', line 6135 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @private_key = private_key == nil ? "" : private_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
6107 6108 6109 |
# File 'lib/models/porcelain.rb', line 6107 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
Bind interface
6109 6110 6111 |
# File 'lib/models/porcelain.rb', line 6109 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6111 6112 6113 |
# File 'lib/models/porcelain.rb', line 6111 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6113 6114 6115 |
# File 'lib/models/porcelain.rb', line 6113 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6115 6116 6117 |
# File 'lib/models/porcelain.rb', line 6115 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6117 6118 6119 |
# File 'lib/models/porcelain.rb', line 6117 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6119 6120 6121 |
# File 'lib/models/porcelain.rb', line 6119 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
6121 6122 6123 |
# File 'lib/models/porcelain.rb', line 6121 def port @port end |
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
6123 6124 6125 |
# File 'lib/models/porcelain.rb', line 6123 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6125 6126 6127 |
# File 'lib/models/porcelain.rb', line 6125 def port_override @port_override end |
#private_key ⇒ Object
Returns the value of attribute private_key.
6127 6128 6129 |
# File 'lib/models/porcelain.rb', line 6127 def private_key @private_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6129 6130 6131 |
# File 'lib/models/porcelain.rb', line 6129 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6131 6132 6133 |
# File 'lib/models/porcelain.rb', line 6131 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6133 6134 6135 |
# File 'lib/models/porcelain.rb', line 6133 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6167 6168 6169 6170 6171 6172 6173 |
# File 'lib/models/porcelain.rb', line 6167 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |