Class: SDM::SSHCustomerKey
- Inherits:
-
Object
- Object
- SDM::SSHCustomerKey
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#private_key ⇒ Object
Returns the value of attribute private_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCustomerKey
constructor
A new instance of SSHCustomerKey.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCustomerKey
Returns a new instance of SSHCustomerKey.
6104 6105 6106 6107 6108 6109 6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/models/porcelain.rb', line 6104 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @private_key = private_key == nil ? "" : private_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
6076 6077 6078 |
# File 'lib/models/porcelain.rb', line 6076 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
Bind interface
6078 6079 6080 |
# File 'lib/models/porcelain.rb', line 6078 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6080 6081 6082 |
# File 'lib/models/porcelain.rb', line 6080 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6082 6083 6084 |
# File 'lib/models/porcelain.rb', line 6082 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6084 6085 6086 |
# File 'lib/models/porcelain.rb', line 6084 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6086 6087 6088 |
# File 'lib/models/porcelain.rb', line 6086 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6088 6089 6090 |
# File 'lib/models/porcelain.rb', line 6088 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
6090 6091 6092 |
# File 'lib/models/porcelain.rb', line 6090 def port @port end |
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
6092 6093 6094 |
# File 'lib/models/porcelain.rb', line 6092 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6094 6095 6096 |
# File 'lib/models/porcelain.rb', line 6094 def port_override @port_override end |
#private_key ⇒ Object
Returns the value of attribute private_key.
6096 6097 6098 |
# File 'lib/models/porcelain.rb', line 6096 def private_key @private_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6098 6099 6100 |
# File 'lib/models/porcelain.rb', line 6098 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6100 6101 6102 |
# File 'lib/models/porcelain.rb', line 6100 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6102 6103 6104 |
# File 'lib/models/porcelain.rb', line 6102 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6136 6137 6138 6139 6140 6141 6142 |
# File 'lib/models/porcelain.rb', line 6136 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |