Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
6073
6074
6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
6088
# File 'lib/models/porcelain.rb', line 6058

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



6030
6031
6032
# File 'lib/models/porcelain.rb', line 6030

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



6032
6033
6034
# File 'lib/models/porcelain.rb', line 6032

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6034
6035
6036
# File 'lib/models/porcelain.rb', line 6034

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6036
6037
6038
# File 'lib/models/porcelain.rb', line 6036

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6038
6039
6040
# File 'lib/models/porcelain.rb', line 6038

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6040
6041
6042
# File 'lib/models/porcelain.rb', line 6040

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6042
6043
6044
# File 'lib/models/porcelain.rb', line 6042

def name
  @name
end

#portObject

Returns the value of attribute port.



6044
6045
6046
# File 'lib/models/porcelain.rb', line 6044

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



6046
6047
6048
# File 'lib/models/porcelain.rb', line 6046

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



6048
6049
6050
# File 'lib/models/porcelain.rb', line 6048

def port_override
  @port_override
end

#private_keyObject

Returns the value of attribute private_key.



6050
6051
6052
# File 'lib/models/porcelain.rb', line 6050

def private_key
  @private_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6052
6053
6054
# File 'lib/models/porcelain.rb', line 6052

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6054
6055
6056
# File 'lib/models/porcelain.rb', line 6054

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6056
6057
6058
# File 'lib/models/porcelain.rb', line 6056

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6090
6091
6092
6093
6094
6095
6096
# File 'lib/models/porcelain.rb', line 6090

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end