Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_forwarding: nil, private_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



6895
6896
6897
6898
6899
6900
6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
6932
6933
6934
6935
6936
6937
6938
6939
6940
6941
6942
6943
6944
6945
# File 'lib/models/porcelain.rb', line 6895

def initialize(
  allow_deprecated_key_exchanges: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  private_key: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  if allow_deprecated_key_exchanges != nil
    @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges
  end
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if healthy != nil
    @healthy = healthy
  end
  if hostname != nil
    @hostname = hostname
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if port != nil
    @port = port
  end
  if port_forwarding != nil
    @port_forwarding = port_forwarding
  end
  if private_key != nil
    @private_key = private_key
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if tags != nil
    @tags = tags
  end
  if username != nil
    @username = username
  end
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



6871
6872
6873
# File 'lib/models/porcelain.rb', line 6871

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6873
6874
6875
# File 'lib/models/porcelain.rb', line 6873

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6875
6876
6877
# File 'lib/models/porcelain.rb', line 6875

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6877
6878
6879
# File 'lib/models/porcelain.rb', line 6877

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6879
6880
6881
# File 'lib/models/porcelain.rb', line 6879

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6881
6882
6883
# File 'lib/models/porcelain.rb', line 6881

def name
  @name
end

#portObject

Returns the value of attribute port.



6883
6884
6885
# File 'lib/models/porcelain.rb', line 6883

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



6885
6886
6887
# File 'lib/models/porcelain.rb', line 6885

def port_forwarding
  @port_forwarding
end

#private_keyObject

Returns the value of attribute private_key.



6887
6888
6889
# File 'lib/models/porcelain.rb', line 6887

def private_key
  @private_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6889
6890
6891
# File 'lib/models/porcelain.rb', line 6889

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6891
6892
6893
# File 'lib/models/porcelain.rb', line 6891

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6893
6894
6895
# File 'lib/models/porcelain.rb', line 6893

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6947
6948
6949
6950
6951
6952
6953
# File 'lib/models/porcelain.rb', line 6947

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end