Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



17018
17019
17020
17021
17022
17023
17024
17025
17026
17027
17028
17029
17030
17031
17032
17033
17034
17035
17036
17037
17038
17039
17040
17041
17042
17043
17044
17045
17046
17047
17048
17049
17050
17051
17052
17053
17054
# File 'lib/models/porcelain.rb', line 17018

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16984
16985
16986
# File 'lib/models/porcelain.rb', line 16984

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16986
16987
16988
# File 'lib/models/porcelain.rb', line 16986

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16988
16989
16990
# File 'lib/models/porcelain.rb', line 16988

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16990
16991
16992
# File 'lib/models/porcelain.rb', line 16990

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16992
16993
16994
# File 'lib/models/porcelain.rb', line 16992

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16994
16995
16996
# File 'lib/models/porcelain.rb', line 16994

def id
  @id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16996
16997
16998
# File 'lib/models/porcelain.rb', line 16996

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16998
16999
17000
# File 'lib/models/porcelain.rb', line 16998

def name
  @name
end

#passwordObject

The password to authenticate with.



17000
17001
17002
# File 'lib/models/porcelain.rb', line 17000

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17002
17003
17004
# File 'lib/models/porcelain.rb', line 17002

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



17004
17005
17006
# File 'lib/models/porcelain.rb', line 17004

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17006
17007
17008
# File 'lib/models/porcelain.rb', line 17006

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17008
17009
17010
# File 'lib/models/porcelain.rb', line 17008

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17010
17011
17012
# File 'lib/models/porcelain.rb', line 17010

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17012
17013
17014
# File 'lib/models/porcelain.rb', line 17012

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17014
17015
17016
# File 'lib/models/porcelain.rb', line 17014

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17016
17017
17018
# File 'lib/models/porcelain.rb', line 17016

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17056
17057
17058
17059
17060
17061
17062
# File 'lib/models/porcelain.rb', line 17056

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end