Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
16900
16901
16902
16903
16904
16905
16906
16907
16908
16909
16910
16911
16912
16913
16914
16915
16916
16917
16918
16919
16920
16921
16922
16923
16924
16925
16926
# File 'lib/models/porcelain.rb', line 16890

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16856
16857
16858
# File 'lib/models/porcelain.rb', line 16856

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16858
16859
16860
# File 'lib/models/porcelain.rb', line 16858

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16860
16861
16862
# File 'lib/models/porcelain.rb', line 16860

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16862
16863
16864
# File 'lib/models/porcelain.rb', line 16862

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16864
16865
16866
# File 'lib/models/porcelain.rb', line 16864

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16866
16867
16868
# File 'lib/models/porcelain.rb', line 16866

def id
  @id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16868
16869
16870
# File 'lib/models/porcelain.rb', line 16868

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16870
16871
16872
# File 'lib/models/porcelain.rb', line 16870

def name
  @name
end

#passwordObject

The password to authenticate with.



16872
16873
16874
# File 'lib/models/porcelain.rb', line 16872

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16874
16875
16876
# File 'lib/models/porcelain.rb', line 16874

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



16876
16877
16878
# File 'lib/models/porcelain.rb', line 16876

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16878
16879
16880
# File 'lib/models/porcelain.rb', line 16878

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16880
16881
16882
# File 'lib/models/porcelain.rb', line 16880

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16882
16883
16884
# File 'lib/models/porcelain.rb', line 16882

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16884
16885
16886
# File 'lib/models/porcelain.rb', line 16884

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16886
16887
16888
# File 'lib/models/porcelain.rb', line 16886

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16888
16889
16890
# File 'lib/models/porcelain.rb', line 16888

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16928
16929
16930
16931
16932
16933
16934
# File 'lib/models/porcelain.rb', line 16928

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end