Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



16652
16653
16654
16655
16656
16657
16658
16659
16660
16661
16662
16663
16664
16665
16666
16667
16668
16669
16670
16671
16672
16673
16674
16675
16676
16677
16678
16679
16680
16681
16682
16683
16684
16685
16686
16687
16688
# File 'lib/models/porcelain.rb', line 16652

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16618
16619
16620
# File 'lib/models/porcelain.rb', line 16618

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16620
16621
16622
# File 'lib/models/porcelain.rb', line 16620

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16622
16623
16624
# File 'lib/models/porcelain.rb', line 16622

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16624
16625
16626
# File 'lib/models/porcelain.rb', line 16624

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16626
16627
16628
# File 'lib/models/porcelain.rb', line 16626

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16628
16629
16630
# File 'lib/models/porcelain.rb', line 16628

def id
  @id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16630
16631
16632
# File 'lib/models/porcelain.rb', line 16630

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16632
16633
16634
# File 'lib/models/porcelain.rb', line 16632

def name
  @name
end

#passwordObject

The password to authenticate with.



16634
16635
16636
# File 'lib/models/porcelain.rb', line 16634

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16636
16637
16638
# File 'lib/models/porcelain.rb', line 16636

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



16638
16639
16640
# File 'lib/models/porcelain.rb', line 16638

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16640
16641
16642
# File 'lib/models/porcelain.rb', line 16640

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16642
16643
16644
# File 'lib/models/porcelain.rb', line 16642

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16644
16645
16646
# File 'lib/models/porcelain.rb', line 16644

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16646
16647
16648
# File 'lib/models/porcelain.rb', line 16646

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16648
16649
16650
# File 'lib/models/porcelain.rb', line 16648

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16650
16651
16652
# File 'lib/models/porcelain.rb', line 16650

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16690
16691
16692
16693
16694
16695
16696
# File 'lib/models/porcelain.rb', line 16690

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end