Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



16236
16237
16238
16239
16240
16241
16242
16243
16244
16245
16246
16247
16248
16249
16250
16251
16252
16253
16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
16264
16265
16266
16267
16268
16269
16270
16271
16272
# File 'lib/models/porcelain.rb', line 16236

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16202
16203
16204
# File 'lib/models/porcelain.rb', line 16202

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16204
16205
16206
# File 'lib/models/porcelain.rb', line 16204

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16206
16207
16208
# File 'lib/models/porcelain.rb', line 16206

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16208
16209
16210
# File 'lib/models/porcelain.rb', line 16208

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16210
16211
16212
# File 'lib/models/porcelain.rb', line 16210

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16212
16213
16214
# File 'lib/models/porcelain.rb', line 16212

def id
  @id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16214
16215
16216
# File 'lib/models/porcelain.rb', line 16214

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16216
16217
16218
# File 'lib/models/porcelain.rb', line 16216

def name
  @name
end

#passwordObject

The password to authenticate with.



16218
16219
16220
# File 'lib/models/porcelain.rb', line 16218

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16220
16221
16222
# File 'lib/models/porcelain.rb', line 16220

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



16222
16223
16224
# File 'lib/models/porcelain.rb', line 16222

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16224
16225
16226
# File 'lib/models/porcelain.rb', line 16224

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16226
16227
16228
# File 'lib/models/porcelain.rb', line 16226

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16228
16229
16230
# File 'lib/models/porcelain.rb', line 16228

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16230
16231
16232
# File 'lib/models/porcelain.rb', line 16230

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16232
16233
16234
# File 'lib/models/porcelain.rb', line 16232

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16234
16235
16236
# File 'lib/models/porcelain.rb', line 16234

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16274
16275
16276
16277
16278
16279
16280
# File 'lib/models/porcelain.rb', line 16274

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end