Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



14961
14962
14963
14964
14965
14966
14967
14968
14969
14970
14971
14972
14973
14974
14975
14976
14977
14978
14979
14980
14981
14982
14983
14984
14985
14986
14987
14988
14989
14990
14991
14992
14993
14994
14995
# File 'lib/models/porcelain.rb', line 14961

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



14929
14930
14931
# File 'lib/models/porcelain.rb', line 14929

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14931
14932
14933
# File 'lib/models/porcelain.rb', line 14931

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14933
14934
14935
# File 'lib/models/porcelain.rb', line 14933

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14935
14936
14937
# File 'lib/models/porcelain.rb', line 14935

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14937
14938
14939
# File 'lib/models/porcelain.rb', line 14937

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14939
14940
14941
# File 'lib/models/porcelain.rb', line 14939

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14941
14942
14943
# File 'lib/models/porcelain.rb', line 14941

def name
  @name
end

#passwordObject

The password to authenticate with.



14943
14944
14945
# File 'lib/models/porcelain.rb', line 14943

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14945
14946
14947
# File 'lib/models/porcelain.rb', line 14945

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



14947
14948
14949
# File 'lib/models/porcelain.rb', line 14947

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14949
14950
14951
# File 'lib/models/porcelain.rb', line 14949

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14951
14952
14953
# File 'lib/models/porcelain.rb', line 14951

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14953
14954
14955
# File 'lib/models/porcelain.rb', line 14953

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14955
14956
14957
# File 'lib/models/porcelain.rb', line 14955

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14957
14958
14959
# File 'lib/models/porcelain.rb', line 14957

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14959
14960
14961
# File 'lib/models/porcelain.rb', line 14959

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14997
14998
14999
15000
15001
15002
15003
# File 'lib/models/porcelain.rb', line 14997

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end