Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



13666
13667
13668
13669
13670
13671
13672
13673
13674
13675
13676
13677
13678
13679
13680
13681
13682
13683
13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
13694
13695
13696
13697
13698
13699
13700
# File 'lib/models/porcelain.rb', line 13666

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



13634
13635
13636
# File 'lib/models/porcelain.rb', line 13634

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13636
13637
13638
# File 'lib/models/porcelain.rb', line 13636

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13638
13639
13640
# File 'lib/models/porcelain.rb', line 13638

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13640
13641
13642
# File 'lib/models/porcelain.rb', line 13640

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13642
13643
13644
# File 'lib/models/porcelain.rb', line 13642

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13644
13645
13646
# File 'lib/models/porcelain.rb', line 13644

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13646
13647
13648
# File 'lib/models/porcelain.rb', line 13646

def name
  @name
end

#passwordObject

The password to authenticate with.



13648
13649
13650
# File 'lib/models/porcelain.rb', line 13648

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13650
13651
13652
# File 'lib/models/porcelain.rb', line 13650

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



13652
13653
13654
# File 'lib/models/porcelain.rb', line 13652

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



13654
13655
13656
# File 'lib/models/porcelain.rb', line 13654

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13656
13657
13658
# File 'lib/models/porcelain.rb', line 13656

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13658
13659
13660
# File 'lib/models/porcelain.rb', line 13658

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13660
13661
13662
# File 'lib/models/porcelain.rb', line 13660

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13662
13663
13664
# File 'lib/models/porcelain.rb', line 13662

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13664
13665
13666
# File 'lib/models/porcelain.rb', line 13664

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13702
13703
13704
13705
13706
13707
13708
# File 'lib/models/porcelain.rb', line 13702

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end