Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



13278
13279
13280
13281
13282
13283
13284
13285
13286
13287
13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
13309
13310
13311
13312
# File 'lib/models/porcelain.rb', line 13278

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



13246
13247
13248
# File 'lib/models/porcelain.rb', line 13246

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13248
13249
13250
# File 'lib/models/porcelain.rb', line 13248

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13250
13251
13252
# File 'lib/models/porcelain.rb', line 13250

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13252
13253
13254
# File 'lib/models/porcelain.rb', line 13252

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13254
13255
13256
# File 'lib/models/porcelain.rb', line 13254

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13256
13257
13258
# File 'lib/models/porcelain.rb', line 13256

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13258
13259
13260
# File 'lib/models/porcelain.rb', line 13258

def name
  @name
end

#passwordObject

The password to authenticate with.



13260
13261
13262
# File 'lib/models/porcelain.rb', line 13260

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13262
13263
13264
# File 'lib/models/porcelain.rb', line 13262

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



13264
13265
13266
# File 'lib/models/porcelain.rb', line 13264

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



13266
13267
13268
# File 'lib/models/porcelain.rb', line 13266

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13268
13269
13270
# File 'lib/models/porcelain.rb', line 13268

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13270
13271
13272
# File 'lib/models/porcelain.rb', line 13270

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13272
13273
13274
# File 'lib/models/porcelain.rb', line 13272

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13274
13275
13276
# File 'lib/models/porcelain.rb', line 13274

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13276
13277
13278
# File 'lib/models/porcelain.rb', line 13276

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13314
13315
13316
13317
13318
13319
13320
# File 'lib/models/porcelain.rb', line 13314

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end