Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
12440
12441
12442
12443
12444
12445
12446
12447
12448
12449
12450
12451
12452
12453
12454
12455
12456
12457
12458
12459
12460
12461
# File 'lib/models/porcelain.rb', line 12427

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



12395
12396
12397
# File 'lib/models/porcelain.rb', line 12395

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12397
12398
12399
# File 'lib/models/porcelain.rb', line 12397

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12399
12400
12401
# File 'lib/models/porcelain.rb', line 12399

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12401
12402
12403
# File 'lib/models/porcelain.rb', line 12401

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12403
12404
12405
# File 'lib/models/porcelain.rb', line 12403

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12405
12406
12407
# File 'lib/models/porcelain.rb', line 12405

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12407
12408
12409
# File 'lib/models/porcelain.rb', line 12407

def name
  @name
end

#passwordObject

The password to authenticate with.



12409
12410
12411
# File 'lib/models/porcelain.rb', line 12409

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12411
12412
12413
# File 'lib/models/porcelain.rb', line 12411

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



12413
12414
12415
# File 'lib/models/porcelain.rb', line 12413

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



12415
12416
12417
# File 'lib/models/porcelain.rb', line 12415

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12417
12418
12419
# File 'lib/models/porcelain.rb', line 12417

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12419
12420
12421
# File 'lib/models/porcelain.rb', line 12419

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12421
12422
12423
# File 'lib/models/porcelain.rb', line 12421

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12423
12424
12425
# File 'lib/models/porcelain.rb', line 12423

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12425
12426
12427
# File 'lib/models/porcelain.rb', line 12425

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12463
12464
12465
12466
12467
12468
12469
# File 'lib/models/porcelain.rb', line 12463

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end