Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



12017
12018
12019
12020
12021
12022
12023
12024
12025
12026
12027
12028
12029
12030
12031
12032
12033
12034
12035
12036
12037
12038
12039
12040
12041
12042
12043
12044
12045
12046
12047
12048
12049
12050
12051
# File 'lib/models/porcelain.rb', line 12017

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11985
11986
11987
# File 'lib/models/porcelain.rb', line 11985

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11987
11988
11989
# File 'lib/models/porcelain.rb', line 11987

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11989
11990
11991
# File 'lib/models/porcelain.rb', line 11989

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11991
11992
11993
# File 'lib/models/porcelain.rb', line 11991

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11993
11994
11995
# File 'lib/models/porcelain.rb', line 11993

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11995
11996
11997
# File 'lib/models/porcelain.rb', line 11995

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11997
11998
11999
# File 'lib/models/porcelain.rb', line 11997

def name
  @name
end

#passwordObject

The password to authenticate with.



11999
12000
12001
# File 'lib/models/porcelain.rb', line 11999

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12001
12002
12003
# File 'lib/models/porcelain.rb', line 12001

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



12003
12004
12005
# File 'lib/models/porcelain.rb', line 12003

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



12005
12006
12007
# File 'lib/models/porcelain.rb', line 12005

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12007
12008
12009
# File 'lib/models/porcelain.rb', line 12007

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12009
12010
12011
# File 'lib/models/porcelain.rb', line 12009

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12011
12012
12013
# File 'lib/models/porcelain.rb', line 12011

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12013
12014
12015
# File 'lib/models/porcelain.rb', line 12013

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12015
12016
12017
# File 'lib/models/porcelain.rb', line 12015

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12053
12054
12055
12056
12057
12058
12059
# File 'lib/models/porcelain.rb', line 12053

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end