Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



11946
11947
11948
11949
11950
11951
11952
11953
11954
11955
11956
11957
11958
11959
11960
11961
11962
11963
11964
11965
11966
11967
11968
11969
11970
11971
11972
11973
11974
11975
11976
11977
11978
11979
11980
# File 'lib/models/porcelain.rb', line 11946

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11914
11915
11916
# File 'lib/models/porcelain.rb', line 11914

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11916
11917
11918
# File 'lib/models/porcelain.rb', line 11916

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11918
11919
11920
# File 'lib/models/porcelain.rb', line 11918

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11920
11921
11922
# File 'lib/models/porcelain.rb', line 11920

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11922
11923
11924
# File 'lib/models/porcelain.rb', line 11922

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11924
11925
11926
# File 'lib/models/porcelain.rb', line 11924

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11926
11927
11928
# File 'lib/models/porcelain.rb', line 11926

def name
  @name
end

#passwordObject

The password to authenticate with.



11928
11929
11930
# File 'lib/models/porcelain.rb', line 11928

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11930
11931
11932
# File 'lib/models/porcelain.rb', line 11930

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11932
11933
11934
# File 'lib/models/porcelain.rb', line 11932

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11934
11935
11936
# File 'lib/models/porcelain.rb', line 11934

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11936
11937
11938
# File 'lib/models/porcelain.rb', line 11936

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11938
11939
11940
# File 'lib/models/porcelain.rb', line 11938

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11940
11941
11942
# File 'lib/models/porcelain.rb', line 11940

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11942
11943
11944
# File 'lib/models/porcelain.rb', line 11942

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11944
11945
11946
# File 'lib/models/porcelain.rb', line 11944

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11982
11983
11984
11985
11986
11987
11988
# File 'lib/models/porcelain.rb', line 11982

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end