Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



11880
11881
11882
11883
11884
11885
11886
11887
11888
11889
11890
11891
11892
11893
11894
11895
11896
11897
11898
11899
11900
11901
11902
11903
11904
11905
11906
11907
11908
11909
11910
11911
11912
11913
11914
# File 'lib/models/porcelain.rb', line 11880

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11848
11849
11850
# File 'lib/models/porcelain.rb', line 11848

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11850
11851
11852
# File 'lib/models/porcelain.rb', line 11850

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11852
11853
11854
# File 'lib/models/porcelain.rb', line 11852

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11854
11855
11856
# File 'lib/models/porcelain.rb', line 11854

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11856
11857
11858
# File 'lib/models/porcelain.rb', line 11856

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11858
11859
11860
# File 'lib/models/porcelain.rb', line 11858

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11860
11861
11862
# File 'lib/models/porcelain.rb', line 11860

def name
  @name
end

#passwordObject

The password to authenticate with.



11862
11863
11864
# File 'lib/models/porcelain.rb', line 11862

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11864
11865
11866
# File 'lib/models/porcelain.rb', line 11864

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11866
11867
11868
# File 'lib/models/porcelain.rb', line 11866

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11868
11869
11870
# File 'lib/models/porcelain.rb', line 11868

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11870
11871
11872
# File 'lib/models/porcelain.rb', line 11870

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11872
11873
11874
# File 'lib/models/porcelain.rb', line 11872

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11874
11875
11876
# File 'lib/models/porcelain.rb', line 11874

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11876
11877
11878
# File 'lib/models/porcelain.rb', line 11876

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11878
11879
11880
# File 'lib/models/porcelain.rb', line 11878

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11916
11917
11918
11919
11920
11921
11922
# File 'lib/models/porcelain.rb', line 11916

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end