Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
# File 'lib/models/porcelain.rb', line 11497

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11465
11466
11467
# File 'lib/models/porcelain.rb', line 11465

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11467
11468
11469
# File 'lib/models/porcelain.rb', line 11467

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11469
11470
11471
# File 'lib/models/porcelain.rb', line 11469

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11471
11472
11473
# File 'lib/models/porcelain.rb', line 11471

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11473
11474
11475
# File 'lib/models/porcelain.rb', line 11473

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11475
11476
11477
# File 'lib/models/porcelain.rb', line 11475

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11477
11478
11479
# File 'lib/models/porcelain.rb', line 11477

def name
  @name
end

#passwordObject

The password to authenticate with.



11479
11480
11481
# File 'lib/models/porcelain.rb', line 11479

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11481
11482
11483
# File 'lib/models/porcelain.rb', line 11481

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11483
11484
11485
# File 'lib/models/porcelain.rb', line 11483

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11485
11486
11487
# File 'lib/models/porcelain.rb', line 11485

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11487
11488
11489
# File 'lib/models/porcelain.rb', line 11487

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11489
11490
11491
# File 'lib/models/porcelain.rb', line 11489

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11491
11492
11493
# File 'lib/models/porcelain.rb', line 11491

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11493
11494
11495
# File 'lib/models/porcelain.rb', line 11493

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11495
11496
11497
# File 'lib/models/porcelain.rb', line 11495

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11533
11534
11535
11536
11537
11538
11539
# File 'lib/models/porcelain.rb', line 11533

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end