Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
11346
11347
11348
11349
11350
11351
11352
11353
11354
11355
11356
11357
11358
11359
11360
11361
11362
# File 'lib/models/porcelain.rb', line 11328

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11296
11297
11298
# File 'lib/models/porcelain.rb', line 11296

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11298
11299
11300
# File 'lib/models/porcelain.rb', line 11298

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11300
11301
11302
# File 'lib/models/porcelain.rb', line 11300

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11302
11303
11304
# File 'lib/models/porcelain.rb', line 11302

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11304
11305
11306
# File 'lib/models/porcelain.rb', line 11304

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11306
11307
11308
# File 'lib/models/porcelain.rb', line 11306

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11308
11309
11310
# File 'lib/models/porcelain.rb', line 11308

def name
  @name
end

#passwordObject

The password to authenticate with.



11310
11311
11312
# File 'lib/models/porcelain.rb', line 11310

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11312
11313
11314
# File 'lib/models/porcelain.rb', line 11312

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11314
11315
11316
# File 'lib/models/porcelain.rb', line 11314

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11316
11317
11318
# File 'lib/models/porcelain.rb', line 11316

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11318
11319
11320
# File 'lib/models/porcelain.rb', line 11318

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11320
11321
11322
# File 'lib/models/porcelain.rb', line 11320

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11322
11323
11324
# File 'lib/models/porcelain.rb', line 11322

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11324
11325
11326
# File 'lib/models/porcelain.rb', line 11324

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11326
11327
11328
# File 'lib/models/porcelain.rb', line 11326

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11364
11365
11366
11367
11368
11369
11370
# File 'lib/models/porcelain.rb', line 11364

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end