Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SSHPassword is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
11191
11192
11193
11194
11195
11196
11197
11198
11199
11200
11201
11202
11203
11204
11205
11206
11207
11208
11209
11210
11211
11212
11213
11214
11215
# File 'lib/models/porcelain.rb', line 11181

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11149
11150
11151
# File 'lib/models/porcelain.rb', line 11149

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11151
11152
11153
# File 'lib/models/porcelain.rb', line 11151

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11153
11154
11155
# File 'lib/models/porcelain.rb', line 11153

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11155
11156
11157
# File 'lib/models/porcelain.rb', line 11155

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11157
11158
11159
# File 'lib/models/porcelain.rb', line 11157

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11159
11160
11161
# File 'lib/models/porcelain.rb', line 11159

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11161
11162
11163
# File 'lib/models/porcelain.rb', line 11161

def name
  @name
end

#passwordObject

The password to authenticate with.



11163
11164
11165
# File 'lib/models/porcelain.rb', line 11163

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11165
11166
11167
# File 'lib/models/porcelain.rb', line 11165

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11167
11168
11169
# File 'lib/models/porcelain.rb', line 11167

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11169
11170
11171
# File 'lib/models/porcelain.rb', line 11169

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11171
11172
11173
# File 'lib/models/porcelain.rb', line 11171

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11173
11174
11175
# File 'lib/models/porcelain.rb', line 11173

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11175
11176
11177
# File 'lib/models/porcelain.rb', line 11175

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11177
11178
11179
# File 'lib/models/porcelain.rb', line 11177

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11179
11180
11181
# File 'lib/models/porcelain.rb', line 11179

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11217
11218
11219
11220
11221
11222
11223
# File 'lib/models/porcelain.rb', line 11217

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end