Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SSHPassword is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



10694
10695
10696
10697
10698
10699
10700
10701
10702
10703
10704
10705
10706
10707
10708
10709
10710
10711
10712
10713
10714
10715
10716
10717
10718
10719
10720
10721
10722
10723
10724
10725
10726
# File 'lib/models/porcelain.rb', line 10694

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



10664
10665
10666
# File 'lib/models/porcelain.rb', line 10664

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10666
10667
10668
# File 'lib/models/porcelain.rb', line 10666

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10668
10669
10670
# File 'lib/models/porcelain.rb', line 10668

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10670
10671
10672
# File 'lib/models/porcelain.rb', line 10670

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10672
10673
10674
# File 'lib/models/porcelain.rb', line 10672

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10674
10675
10676
# File 'lib/models/porcelain.rb', line 10674

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10676
10677
10678
# File 'lib/models/porcelain.rb', line 10676

def name
  @name
end

#passwordObject

The password to authenticate with.



10678
10679
10680
# File 'lib/models/porcelain.rb', line 10678

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10680
10681
10682
# File 'lib/models/porcelain.rb', line 10680

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



10682
10683
10684
# File 'lib/models/porcelain.rb', line 10682

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



10684
10685
10686
# File 'lib/models/porcelain.rb', line 10684

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10686
10687
10688
# File 'lib/models/porcelain.rb', line 10686

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10688
10689
10690
# File 'lib/models/porcelain.rb', line 10688

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10690
10691
10692
# File 'lib/models/porcelain.rb', line 10690

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10692
10693
10694
# File 'lib/models/porcelain.rb', line 10692

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10728
10729
10730
10731
10732
10733
10734
# File 'lib/models/porcelain.rb', line 10728

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end