Class: SDM::SecretEngineDeleteRequest
- Inherits:
-
Object
- Object
- SDM::SecretEngineDeleteRequest
- Defined in:
- lib/models/porcelain.rb
Overview
SecretEngineDeleteRequest specified the ID of a Secret Engine to be deleted.
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Secret Engine to delete.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ SecretEngineDeleteRequest
constructor
A new instance of SecretEngineDeleteRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ SecretEngineDeleteRequest
Returns a new instance of SecretEngineDeleteRequest.
13779 13780 13781 13782 13783 |
# File 'lib/models/porcelain.rb', line 13779 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Secret Engine to delete.
13777 13778 13779 |
# File 'lib/models/porcelain.rb', line 13777 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13785 13786 13787 13788 13789 13790 13791 |
# File 'lib/models/porcelain.rb', line 13785 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |