Class: SDM::SecretEngineDeleteRequest
- Inherits:
-
Object
- Object
- SDM::SecretEngineDeleteRequest
- Defined in:
- lib/models/porcelain.rb
Overview
SecretEngineDeleteRequest specified the ID of a Secret Engine to be deleted.
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Secret Engine to delete.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ SecretEngineDeleteRequest
constructor
A new instance of SecretEngineDeleteRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ SecretEngineDeleteRequest
Returns a new instance of SecretEngineDeleteRequest.
13776 13777 13778 13779 13780 |
# File 'lib/models/porcelain.rb', line 13776 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Secret Engine to delete.
13774 13775 13776 |
# File 'lib/models/porcelain.rb', line 13774 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13782 13783 13784 13785 13786 13787 13788 |
# File 'lib/models/porcelain.rb', line 13782 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |