Class: SDM::SecretEngineDeleteRequest
- Inherits:
-
Object
- Object
- SDM::SecretEngineDeleteRequest
- Defined in:
- lib/models/porcelain.rb
Overview
SecretEngineDeleteRequest specified the ID of a Secret Engine to be deleted.
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Secret Engine to delete.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ SecretEngineDeleteRequest
constructor
A new instance of SecretEngineDeleteRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ SecretEngineDeleteRequest
Returns a new instance of SecretEngineDeleteRequest.
13764 13765 13766 13767 13768 |
# File 'lib/models/porcelain.rb', line 13764 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Secret Engine to delete.
13762 13763 13764 |
# File 'lib/models/porcelain.rb', line 13762 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13770 13771 13772 13773 13774 13775 13776 |
# File 'lib/models/porcelain.rb', line 13770 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |