Class: SDM::SecretEngineDeleteRequest
- Inherits:
-
Object
- Object
- SDM::SecretEngineDeleteRequest
- Defined in:
- lib/models/porcelain.rb
Overview
SecretEngineDeleteRequest specified the ID of a Secret Engine to be deleted.
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Secret Engine to delete.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ SecretEngineDeleteRequest
constructor
A new instance of SecretEngineDeleteRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ SecretEngineDeleteRequest
Returns a new instance of SecretEngineDeleteRequest.
13517 13518 13519 13520 13521 |
# File 'lib/models/porcelain.rb', line 13517 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Secret Engine to delete.
13515 13516 13517 |
# File 'lib/models/porcelain.rb', line 13515 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13523 13524 13525 13526 13527 13528 13529 |
# File 'lib/models/porcelain.rb', line 13523 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |