Class: SDM::SecretEngineGetRequest
- Inherits:
-
Object
- Object
- SDM::SecretEngineGetRequest
- Defined in:
- lib/models/porcelain.rb
Overview
SecretEngineGetRequest specifies which Secret Engine to retrieve
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Secret Engine to retrieve.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ SecretEngineGetRequest
constructor
A new instance of SecretEngineGetRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ SecretEngineGetRequest
Returns a new instance of SecretEngineGetRequest.
17110 17111 17112 17113 17114 |
# File 'lib/models/porcelain.rb', line 17110 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Secret Engine to retrieve.
17108 17109 17110 |
# File 'lib/models/porcelain.rb', line 17108 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17116 17117 17118 17119 17120 17121 17122 |
# File 'lib/models/porcelain.rb', line 17116 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |