Class: SDM::SecretEngineGetRequest
- Inherits:
-
Object
- Object
- SDM::SecretEngineGetRequest
- Defined in:
- lib/models/porcelain.rb
Overview
SecretEngineGetRequest specifies which Secret Engine to retrieve
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Secret Engine to retrieve.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ SecretEngineGetRequest
constructor
A new instance of SecretEngineGetRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ SecretEngineGetRequest
Returns a new instance of SecretEngineGetRequest.
16799 16800 16801 16802 16803 |
# File 'lib/models/porcelain.rb', line 16799 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Secret Engine to retrieve.
16797 16798 16799 |
# File 'lib/models/porcelain.rb', line 16797 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16805 16806 16807 16808 16809 16810 16811 |
# File 'lib/models/porcelain.rb', line 16805 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |