Class: SDM::SecretEngineGetRequest
- Inherits:
-
Object
- Object
- SDM::SecretEngineGetRequest
- Defined in:
- lib/models/porcelain.rb
Overview
SecretEngineGetRequest specifies which Secret Engine to retrieve
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Secret Engine to retrieve.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ SecretEngineGetRequest
constructor
A new instance of SecretEngineGetRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ SecretEngineGetRequest
Returns a new instance of SecretEngineGetRequest.
16676 16677 16678 16679 16680 |
# File 'lib/models/porcelain.rb', line 16676 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Secret Engine to retrieve.
16674 16675 16676 |
# File 'lib/models/porcelain.rb', line 16674 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16682 16683 16684 16685 16686 16687 16688 |
# File 'lib/models/porcelain.rb', line 16682 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |