Class: SDM::SecretEngineGetRequest
- Inherits:
-
Object
- Object
- SDM::SecretEngineGetRequest
- Defined in:
- lib/models/porcelain.rb
Overview
SecretEngineGetRequest specifies which Secret Engine to retrieve
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Secret Engine to retrieve.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ SecretEngineGetRequest
constructor
A new instance of SecretEngineGetRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ SecretEngineGetRequest
Returns a new instance of SecretEngineGetRequest.
16001 16002 16003 16004 16005 |
# File 'lib/models/porcelain.rb', line 16001 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Secret Engine to retrieve.
15999 16000 16001 |
# File 'lib/models/porcelain.rb', line 15999 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16007 16008 16009 16010 16011 16012 16013 |
# File 'lib/models/porcelain.rb', line 16007 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |