Class: SDM::SecretEngineGetRequest
- Inherits:
-
Object
- Object
- SDM::SecretEngineGetRequest
- Defined in:
- lib/models/porcelain.rb
Overview
SecretEngineGetRequest specifies which Secret Engine to retrieve
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Secret Engine to retrieve.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ SecretEngineGetRequest
constructor
A new instance of SecretEngineGetRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ SecretEngineGetRequest
Returns a new instance of SecretEngineGetRequest.
13483 13484 13485 13486 13487 |
# File 'lib/models/porcelain.rb', line 13483 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Secret Engine to retrieve.
13481 13482 13483 |
# File 'lib/models/porcelain.rb', line 13481 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13489 13490 13491 13492 13493 13494 13495 |
# File 'lib/models/porcelain.rb', line 13489 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |