Class: SDM::SecretEnginePasswordPolicy
- Inherits:
-
Object
- Object
- SDM::SecretEnginePasswordPolicy
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_repeat ⇒ Object
If set to true allows for consecutive characters to repeat itself.
-
#exclude_characters ⇒ Object
Characters to exclude when generating password.
-
#exclude_upper_case ⇒ Object
If set to true do not include upper case letters when generating password.
-
#length ⇒ Object
Password length.
-
#num_digits ⇒ Object
Numbers of digits to use when generating password.
-
#num_symbols ⇒ Object
Number of symbols to use when generating password.
Instance Method Summary collapse
-
#initialize(allow_repeat: nil, exclude_characters: nil, exclude_upper_case: nil, length: nil, num_digits: nil, num_symbols: nil) ⇒ SecretEnginePasswordPolicy
constructor
A new instance of SecretEnginePasswordPolicy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_repeat: nil, exclude_characters: nil, exclude_upper_case: nil, length: nil, num_digits: nil, num_symbols: nil) ⇒ SecretEnginePasswordPolicy
Returns a new instance of SecretEnginePasswordPolicy.
17255 17256 17257 17258 17259 17260 17261 17262 17263 17264 17265 17266 17267 17268 17269 |
# File 'lib/models/porcelain.rb', line 17255 def initialize( allow_repeat: nil, exclude_characters: nil, exclude_upper_case: nil, length: nil, num_digits: nil, num_symbols: nil ) @allow_repeat = allow_repeat == nil ? false : allow_repeat @exclude_characters = exclude_characters == nil ? "" : exclude_characters @exclude_upper_case = exclude_upper_case == nil ? false : exclude_upper_case @length = length == nil ? 0 : length @num_digits = num_digits == nil ? 0 : num_digits @num_symbols = num_symbols == nil ? 0 : num_symbols end |
Instance Attribute Details
#allow_repeat ⇒ Object
If set to true allows for consecutive characters to repeat itself
17243 17244 17245 |
# File 'lib/models/porcelain.rb', line 17243 def allow_repeat @allow_repeat end |
#exclude_characters ⇒ Object
Characters to exclude when generating password
17245 17246 17247 |
# File 'lib/models/porcelain.rb', line 17245 def exclude_characters @exclude_characters end |
#exclude_upper_case ⇒ Object
If set to true do not include upper case letters when generating password
17247 17248 17249 |
# File 'lib/models/porcelain.rb', line 17247 def exclude_upper_case @exclude_upper_case end |
#length ⇒ Object
Password length.
17249 17250 17251 |
# File 'lib/models/porcelain.rb', line 17249 def length @length end |
#num_digits ⇒ Object
Numbers of digits to use when generating password
17251 17252 17253 |
# File 'lib/models/porcelain.rb', line 17251 def num_digits @num_digits end |
#num_symbols ⇒ Object
Number of symbols to use when generating password
17253 17254 17255 |
# File 'lib/models/porcelain.rb', line 17253 def num_symbols @num_symbols end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17271 17272 17273 17274 17275 17276 17277 |
# File 'lib/models/porcelain.rb', line 17271 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |