Class: SDM::SecretEngineRotateRequest
- Inherits:
-
Object
- Object
- SDM::SecretEngineRotateRequest
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Secret Engine to rotate credentials for.
-
#password_policy ⇒ Object
Optional password policy to use when generating a password If not provided it will use secret engine's password_policy.
Instance Method Summary collapse
-
#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest
constructor
A new instance of SecretEngineRotateRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest
Returns a new instance of SecretEngineRotateRequest.
17178 17179 17180 17181 17182 17183 17184 |
# File 'lib/models/porcelain.rb', line 17178 def initialize( id: nil, password_policy: nil ) @id = id == nil ? "" : id @password_policy = password_policy == nil ? nil : password_policy end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Secret Engine to rotate credentials for.
17173 17174 17175 |
# File 'lib/models/porcelain.rb', line 17173 def id @id end |
#password_policy ⇒ Object
Optional password policy to use when generating a password If not provided it will use secret engine's password_policy
17176 17177 17178 |
# File 'lib/models/porcelain.rb', line 17176 def password_policy @password_policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17186 17187 17188 17189 17190 17191 17192 |
# File 'lib/models/porcelain.rb', line 17186 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |