Class: SDM::SecretEngineRotateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest

Returns a new instance of SecretEngineRotateRequest.



17174
17175
17176
17177
17178
17179
17180
# File 'lib/models/porcelain.rb', line 17174

def initialize(
  id: nil,
  password_policy: nil
)
  @id = id == nil ? "" : id
  @password_policy = password_policy == nil ? nil : password_policy
end

Instance Attribute Details

#idObject

The unique identifier of the Secret Engine to rotate credentials for.



17169
17170
17171
# File 'lib/models/porcelain.rb', line 17169

def id
  @id
end

#password_policyObject

Optional password policy to use when generating a password If not provided it will use secret engine's password_policy



17172
17173
17174
# File 'lib/models/porcelain.rb', line 17172

def password_policy
  @password_policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17182
17183
17184
17185
17186
17187
17188
# File 'lib/models/porcelain.rb', line 17182

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end