Class: SDM::SecretEngineRotateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest

Returns a new instance of SecretEngineRotateRequest.



16947
16948
16949
16950
16951
16952
16953
# File 'lib/models/porcelain.rb', line 16947

def initialize(
  id: nil,
  password_policy: nil
)
  @id = id == nil ? "" : id
  @password_policy = password_policy == nil ? nil : password_policy
end

Instance Attribute Details

#idObject

The unique identifier of the Secret Engine to rotate credentials for.



16942
16943
16944
# File 'lib/models/porcelain.rb', line 16942

def id
  @id
end

#password_policyObject

Optional password policy to use when generating a password If not provided it will use secret engine's password_policy



16945
16946
16947
# File 'lib/models/porcelain.rb', line 16945

def password_policy
  @password_policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16955
16956
16957
16958
16959
16960
16961
# File 'lib/models/porcelain.rb', line 16955

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end