Class: SDM::SecretEngineRotateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest

Returns a new instance of SecretEngineRotateRequest.



16940
16941
16942
16943
16944
16945
16946
# File 'lib/models/porcelain.rb', line 16940

def initialize(
  id: nil,
  password_policy: nil
)
  @id = id == nil ? "" : id
  @password_policy = password_policy == nil ? nil : password_policy
end

Instance Attribute Details

#idObject

The unique identifier of the Secret Engine to rotate credentials for.



16935
16936
16937
# File 'lib/models/porcelain.rb', line 16935

def id
  @id
end

#password_policyObject

Optional password policy to use when generating a password If not provided it will use secret engine's password_policy



16938
16939
16940
# File 'lib/models/porcelain.rb', line 16938

def password_policy
  @password_policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16948
16949
16950
16951
16952
16953
16954
# File 'lib/models/porcelain.rb', line 16948

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end