Class: SDM::SecretEngineRotateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest

Returns a new instance of SecretEngineRotateRequest.



16824
16825
16826
16827
16828
16829
16830
# File 'lib/models/porcelain.rb', line 16824

def initialize(
  id: nil,
  password_policy: nil
)
  @id = id == nil ? "" : id
  @password_policy = password_policy == nil ? nil : password_policy
end

Instance Attribute Details

#idObject

The unique identifier of the Secret Engine to rotate credentials for.



16819
16820
16821
# File 'lib/models/porcelain.rb', line 16819

def id
  @id
end

#password_policyObject

Optional password policy to use when generating a password If not provided it will use secret engine's password_policy



16822
16823
16824
# File 'lib/models/porcelain.rb', line 16822

def password_policy
  @password_policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16832
16833
16834
16835
16836
16837
16838
# File 'lib/models/porcelain.rb', line 16832

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end