Class: SDM::SecretEngineRotateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest

Returns a new instance of SecretEngineRotateRequest.



16525
16526
16527
16528
16529
16530
16531
# File 'lib/models/porcelain.rb', line 16525

def initialize(
  id: nil,
  password_policy: nil
)
  @id = id == nil ? "" : id
  @password_policy = password_policy == nil ? nil : password_policy
end

Instance Attribute Details

#idObject

The unique identifier of the Secret Engine to rotate credentials for.



16520
16521
16522
# File 'lib/models/porcelain.rb', line 16520

def id
  @id
end

#password_policyObject

Optional password policy to use when generating a password If not provided it will use secret engine's password_policy



16523
16524
16525
# File 'lib/models/porcelain.rb', line 16523

def password_policy
  @password_policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16533
16534
16535
16536
16537
16538
16539
# File 'lib/models/porcelain.rb', line 16533

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end