Class: SDM::SecretEngineRotateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest

Returns a new instance of SecretEngineRotateRequest.



16149
16150
16151
16152
16153
16154
16155
# File 'lib/models/porcelain.rb', line 16149

def initialize(
  id: nil,
  password_policy: nil
)
  @id = id == nil ? "" : id
  @password_policy = password_policy == nil ? nil : password_policy
end

Instance Attribute Details

#idObject

The unique identifier of the Secret Engine to rotate credentials for.



16144
16145
16146
# File 'lib/models/porcelain.rb', line 16144

def id
  @id
end

#password_policyObject

Optional password policy to use when generating a password If not provided it will use secret engine's password_policy



16147
16148
16149
# File 'lib/models/porcelain.rb', line 16147

def password_policy
  @password_policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16157
16158
16159
16160
16161
16162
16163
# File 'lib/models/porcelain.rb', line 16157

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end