Class: SDM::SecretEngineRotateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest

Returns a new instance of SecretEngineRotateRequest.



16085
16086
16087
16088
16089
16090
16091
# File 'lib/models/porcelain.rb', line 16085

def initialize(
  id: nil,
  password_policy: nil
)
  @id = id == nil ? "" : id
  @password_policy = password_policy == nil ? nil : password_policy
end

Instance Attribute Details

#idObject

The unique identifier of the Secret Engine to rotate credentials for.



16080
16081
16082
# File 'lib/models/porcelain.rb', line 16080

def id
  @id
end

#password_policyObject

Optional password policy to use when generating a password If not provided it will use secret engine's password_policy



16083
16084
16085
# File 'lib/models/porcelain.rb', line 16083

def password_policy
  @password_policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16093
16094
16095
16096
16097
16098
16099
# File 'lib/models/porcelain.rb', line 16093

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end