Class: SDM::SecretEngineRotateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest

Returns a new instance of SecretEngineRotateRequest.



15247
15248
15249
15250
15251
15252
15253
# File 'lib/models/porcelain.rb', line 15247

def initialize(
  id: nil,
  password_policy: nil
)
  @id = id == nil ? "" : id
  @password_policy = password_policy == nil ? nil : password_policy
end

Instance Attribute Details

#idObject

The unique identifier of the Secret Engine to rotate credentials for.



15242
15243
15244
# File 'lib/models/porcelain.rb', line 15242

def id
  @id
end

#password_policyObject

Optional password policy to use when generating a password If not provided it will use secret engine's password_policy



15245
15246
15247
# File 'lib/models/porcelain.rb', line 15245

def password_policy
  @password_policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15255
15256
15257
15258
15259
15260
15261
# File 'lib/models/porcelain.rb', line 15255

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end