Class: SDM::SecretEngineRotateRequest
- Inherits:
-
Object
- Object
- SDM::SecretEngineRotateRequest
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Secret Engine to rotate credentials for.
-
#password_policy ⇒ Object
Optional password policy to use when generating a password If not provided it will use secret engine's password_policy.
Instance Method Summary collapse
-
#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest
constructor
A new instance of SecretEngineRotateRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest
Returns a new instance of SecretEngineRotateRequest.
13564 13565 13566 13567 13568 13569 13570 |
# File 'lib/models/porcelain.rb', line 13564 def initialize( id: nil, password_policy: nil ) @id = id == nil ? "" : id @password_policy = password_policy == nil ? nil : password_policy end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Secret Engine to rotate credentials for.
13559 13560 13561 |
# File 'lib/models/porcelain.rb', line 13559 def id @id end |
#password_policy ⇒ Object
Optional password policy to use when generating a password If not provided it will use secret engine's password_policy
13562 13563 13564 |
# File 'lib/models/porcelain.rb', line 13562 def password_policy @password_policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13572 13573 13574 13575 13576 13577 13578 |
# File 'lib/models/porcelain.rb', line 13572 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |