Class: SDM::SecretStoreHealth
- Inherits:
-
Object
- Object
- SDM::SecretStoreHealth
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.
Instance Attribute Summary collapse
-
#changed_at ⇒ Object
The time when the status last changed.
-
#checked_at ⇒ Object
The time when the status was last checked by the node.
-
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
-
#flags ⇒ Object
Any specific status or error flags associated with this health check.
-
#node_id ⇒ Object
Associated node id for this health.
-
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
-
#secret_store_id ⇒ Object
Associated secret store for this health.
-
#status ⇒ Object
The status of the link between the node and secret store.
Instance Method Summary collapse
-
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
constructor
A new instance of SecretStoreHealth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
Returns a new instance of SecretStoreHealth.
17491 17492 17493 17494 17495 17496 17497 17498 17499 17500 17501 17502 17503 17504 17505 17506 17507 17508 17509 |
# File 'lib/models/porcelain.rb', line 17491 def initialize( changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil ) @changed_at = changed_at == nil ? nil : changed_at @checked_at = checked_at == nil ? nil : checked_at @error = error == nil ? "" : error @flags = flags == nil ? [] : flags @node_id = node_id == nil ? "" : node_id @reachability = reachability == nil ? "" : reachability @secret_store_id = secret_store_id == nil ? "" : secret_store_id @status = status == nil ? "" : status end |
Instance Attribute Details
#changed_at ⇒ Object
The time when the status last changed
17475 17476 17477 |
# File 'lib/models/porcelain.rb', line 17475 def changed_at @changed_at end |
#checked_at ⇒ Object
The time when the status was last checked by the node
17477 17478 17479 |
# File 'lib/models/porcelain.rb', line 17477 def checked_at @checked_at end |
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
17479 17480 17481 |
# File 'lib/models/porcelain.rb', line 17479 def error @error end |
#flags ⇒ Object
Any specific status or error flags associated with this health check.
17481 17482 17483 |
# File 'lib/models/porcelain.rb', line 17481 def flags @flags end |
#node_id ⇒ Object
Associated node id for this health
17483 17484 17485 |
# File 'lib/models/porcelain.rb', line 17483 def node_id @node_id end |
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
17485 17486 17487 |
# File 'lib/models/porcelain.rb', line 17485 def reachability @reachability end |
#secret_store_id ⇒ Object
Associated secret store for this health
17487 17488 17489 |
# File 'lib/models/porcelain.rb', line 17487 def secret_store_id @secret_store_id end |
#status ⇒ Object
The status of the link between the node and secret store
17489 17490 17491 |
# File 'lib/models/porcelain.rb', line 17489 def status @status end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17511 17512 17513 17514 17515 17516 17517 |
# File 'lib/models/porcelain.rb', line 17511 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |