Class: SDM::SecretStoreHealth
- Inherits:
-
Object
- Object
- SDM::SecretStoreHealth
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.
Instance Attribute Summary collapse
-
#changed_at ⇒ Object
The time when the status last changed.
-
#checked_at ⇒ Object
The time when the status was last checked by the node.
-
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
-
#flags ⇒ Object
Any specific status or error flags associated with this health check.
-
#node_id ⇒ Object
Associated node id for this health.
-
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
-
#secret_store_id ⇒ Object
Associated secret store for this health.
-
#status ⇒ Object
The status of the link between the node and secret store.
Instance Method Summary collapse
-
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
constructor
A new instance of SecretStoreHealth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
Returns a new instance of SecretStoreHealth.
17443 17444 17445 17446 17447 17448 17449 17450 17451 17452 17453 17454 17455 17456 17457 17458 17459 17460 17461 |
# File 'lib/models/porcelain.rb', line 17443 def initialize( changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil ) @changed_at = changed_at == nil ? nil : changed_at @checked_at = checked_at == nil ? nil : checked_at @error = error == nil ? "" : error @flags = flags == nil ? [] : flags @node_id = node_id == nil ? "" : node_id @reachability = reachability == nil ? "" : reachability @secret_store_id = secret_store_id == nil ? "" : secret_store_id @status = status == nil ? "" : status end |
Instance Attribute Details
#changed_at ⇒ Object
The time when the status last changed
17427 17428 17429 |
# File 'lib/models/porcelain.rb', line 17427 def changed_at @changed_at end |
#checked_at ⇒ Object
The time when the status was last checked by the node
17429 17430 17431 |
# File 'lib/models/porcelain.rb', line 17429 def checked_at @checked_at end |
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
17431 17432 17433 |
# File 'lib/models/porcelain.rb', line 17431 def error @error end |
#flags ⇒ Object
Any specific status or error flags associated with this health check.
17433 17434 17435 |
# File 'lib/models/porcelain.rb', line 17433 def flags @flags end |
#node_id ⇒ Object
Associated node id for this health
17435 17436 17437 |
# File 'lib/models/porcelain.rb', line 17435 def node_id @node_id end |
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
17437 17438 17439 |
# File 'lib/models/porcelain.rb', line 17437 def reachability @reachability end |
#secret_store_id ⇒ Object
Associated secret store for this health
17439 17440 17441 |
# File 'lib/models/porcelain.rb', line 17439 def secret_store_id @secret_store_id end |
#status ⇒ Object
The status of the link between the node and secret store
17441 17442 17443 |
# File 'lib/models/porcelain.rb', line 17441 def status @status end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17463 17464 17465 17466 17467 17468 17469 |
# File 'lib/models/porcelain.rb', line 17463 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |