Class: SDM::SecretStoreHealth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth

Returns a new instance of SecretStoreHealth.



17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
17373
17374
17375
17376
17377
# File 'lib/models/porcelain.rb', line 17359

def initialize(
  changed_at: nil,
  checked_at: nil,
  error: nil,
  flags: nil,
  node_id: nil,
  reachability: nil,
  secret_store_id: nil,
  status: nil
)
  @changed_at = changed_at == nil ? nil : changed_at
  @checked_at = checked_at == nil ? nil : checked_at
  @error = error == nil ? "" : error
  @flags = flags == nil ? [] : flags
  @node_id = node_id == nil ? "" : node_id
  @reachability = reachability == nil ? "" : reachability
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @status = status == nil ? "" : status
end

Instance Attribute Details

#changed_atObject

The time when the status last changed



17343
17344
17345
# File 'lib/models/porcelain.rb', line 17343

def changed_at
  @changed_at
end

#checked_atObject

The time when the status was last checked by the node



17345
17346
17347
# File 'lib/models/porcelain.rb', line 17345

def checked_at
  @checked_at
end

#errorObject

The error associated with this health check, if it occurred after reachability checks succeeded.



17347
17348
17349
# File 'lib/models/porcelain.rb', line 17347

def error
  @error
end

#flagsObject

Any specific status or error flags associated with this health check.



17349
17350
17351
# File 'lib/models/porcelain.rb', line 17349

def flags
  @flags
end

#node_idObject

Associated node id for this health



17351
17352
17353
# File 'lib/models/porcelain.rb', line 17351

def node_id
  @node_id
end

#reachabilityObject

The error associated with this health check, if it occurred during reachability checks.



17353
17354
17355
# File 'lib/models/porcelain.rb', line 17353

def reachability
  @reachability
end

#secret_store_idObject

Associated secret store for this health



17355
17356
17357
# File 'lib/models/porcelain.rb', line 17355

def secret_store_id
  @secret_store_id
end

#statusObject

The status of the link between the node and secret store



17357
17358
17359
# File 'lib/models/porcelain.rb', line 17357

def status
  @status
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17379
17380
17381
17382
17383
17384
17385
# File 'lib/models/porcelain.rb', line 17379

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end