Class: SDM::SecretStoreHealth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth

Returns a new instance of SecretStoreHealth.



17009
17010
17011
17012
17013
17014
17015
17016
17017
17018
17019
17020
17021
17022
17023
17024
17025
17026
17027
# File 'lib/models/porcelain.rb', line 17009

def initialize(
  changed_at: nil,
  checked_at: nil,
  error: nil,
  flags: nil,
  node_id: nil,
  reachability: nil,
  secret_store_id: nil,
  status: nil
)
  @changed_at = changed_at == nil ? nil : changed_at
  @checked_at = checked_at == nil ? nil : checked_at
  @error = error == nil ? "" : error
  @flags = flags == nil ? [] : flags
  @node_id = node_id == nil ? "" : node_id
  @reachability = reachability == nil ? "" : reachability
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @status = status == nil ? "" : status
end

Instance Attribute Details

#changed_atObject

The time when the status last changed



16993
16994
16995
# File 'lib/models/porcelain.rb', line 16993

def changed_at
  @changed_at
end

#checked_atObject

The time when the status was last checked by the node



16995
16996
16997
# File 'lib/models/porcelain.rb', line 16995

def checked_at
  @checked_at
end

#errorObject

The error associated with this health check, if it occurred after reachability checks succeeded.



16997
16998
16999
# File 'lib/models/porcelain.rb', line 16997

def error
  @error
end

#flagsObject

Any specific status or error flags associated with this health check.



16999
17000
17001
# File 'lib/models/porcelain.rb', line 16999

def flags
  @flags
end

#node_idObject

Associated node id for this health



17001
17002
17003
# File 'lib/models/porcelain.rb', line 17001

def node_id
  @node_id
end

#reachabilityObject

The error associated with this health check, if it occurred during reachability checks.



17003
17004
17005
# File 'lib/models/porcelain.rb', line 17003

def reachability
  @reachability
end

#secret_store_idObject

Associated secret store for this health



17005
17006
17007
# File 'lib/models/porcelain.rb', line 17005

def secret_store_id
  @secret_store_id
end

#statusObject

The status of the link between the node and secret store



17007
17008
17009
# File 'lib/models/porcelain.rb', line 17007

def status
  @status
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17029
17030
17031
17032
17033
17034
17035
# File 'lib/models/porcelain.rb', line 17029

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end