Class: SDM::SecretStoreHealth
- Inherits:
-
Object
- Object
- SDM::SecretStoreHealth
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.
Instance Attribute Summary collapse
-
#changed_at ⇒ Object
The time when the status last changed.
-
#checked_at ⇒ Object
The time when the status was last checked by the node.
-
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
-
#flags ⇒ Object
Any specific status or error flags associated with this health check.
-
#node_id ⇒ Object
Associated node id for this health.
-
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
-
#secret_store_id ⇒ Object
Associated secret store for this health.
-
#status ⇒ Object
The status of the link between the node and secret store.
Instance Method Summary collapse
-
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
constructor
A new instance of SecretStoreHealth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
Returns a new instance of SecretStoreHealth.
16334 16335 16336 16337 16338 16339 16340 16341 16342 16343 16344 16345 16346 16347 16348 16349 16350 16351 16352 |
# File 'lib/models/porcelain.rb', line 16334 def initialize( changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil ) @changed_at = changed_at == nil ? nil : changed_at @checked_at = checked_at == nil ? nil : checked_at @error = error == nil ? "" : error @flags = flags == nil ? [] : flags @node_id = node_id == nil ? "" : node_id @reachability = reachability == nil ? "" : reachability @secret_store_id = secret_store_id == nil ? "" : secret_store_id @status = status == nil ? "" : status end |
Instance Attribute Details
#changed_at ⇒ Object
The time when the status last changed
16318 16319 16320 |
# File 'lib/models/porcelain.rb', line 16318 def changed_at @changed_at end |
#checked_at ⇒ Object
The time when the status was last checked by the node
16320 16321 16322 |
# File 'lib/models/porcelain.rb', line 16320 def checked_at @checked_at end |
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
16322 16323 16324 |
# File 'lib/models/porcelain.rb', line 16322 def error @error end |
#flags ⇒ Object
Any specific status or error flags associated with this health check.
16324 16325 16326 |
# File 'lib/models/porcelain.rb', line 16324 def flags @flags end |
#node_id ⇒ Object
Associated node id for this health
16326 16327 16328 |
# File 'lib/models/porcelain.rb', line 16326 def node_id @node_id end |
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
16328 16329 16330 |
# File 'lib/models/porcelain.rb', line 16328 def reachability @reachability end |
#secret_store_id ⇒ Object
Associated secret store for this health
16330 16331 16332 |
# File 'lib/models/porcelain.rb', line 16330 def secret_store_id @secret_store_id end |
#status ⇒ Object
The status of the link between the node and secret store
16332 16333 16334 |
# File 'lib/models/porcelain.rb', line 16332 def status @status end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16354 16355 16356 16357 16358 16359 16360 |
# File 'lib/models/porcelain.rb', line 16354 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |