Class: SDM::SecretStoreHealth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth

Returns a new instance of SecretStoreHealth.



15432
15433
15434
15435
15436
15437
15438
15439
15440
15441
15442
15443
15444
15445
15446
15447
15448
15449
15450
# File 'lib/models/porcelain.rb', line 15432

def initialize(
  changed_at: nil,
  checked_at: nil,
  error: nil,
  flags: nil,
  node_id: nil,
  reachability: nil,
  secret_store_id: nil,
  status: nil
)
  @changed_at = changed_at == nil ? nil : changed_at
  @checked_at = checked_at == nil ? nil : checked_at
  @error = error == nil ? "" : error
  @flags = flags == nil ? [] : flags
  @node_id = node_id == nil ? "" : node_id
  @reachability = reachability == nil ? "" : reachability
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @status = status == nil ? "" : status
end

Instance Attribute Details

#changed_atObject

The time when the status last changed



15416
15417
15418
# File 'lib/models/porcelain.rb', line 15416

def changed_at
  @changed_at
end

#checked_atObject

The time when the status was last checked by the node



15418
15419
15420
# File 'lib/models/porcelain.rb', line 15418

def checked_at
  @checked_at
end

#errorObject

The error associated with this health check, if it occurred after reachability checks succeeded.



15420
15421
15422
# File 'lib/models/porcelain.rb', line 15420

def error
  @error
end

#flagsObject

Any specific status or error flags associated with this health check.



15422
15423
15424
# File 'lib/models/porcelain.rb', line 15422

def flags
  @flags
end

#node_idObject

Associated node id for this health



15424
15425
15426
# File 'lib/models/porcelain.rb', line 15424

def node_id
  @node_id
end

#reachabilityObject

The error associated with this health check, if it occurred during reachability checks.



15426
15427
15428
# File 'lib/models/porcelain.rb', line 15426

def reachability
  @reachability
end

#secret_store_idObject

Associated secret store for this health



15428
15429
15430
# File 'lib/models/porcelain.rb', line 15428

def secret_store_id
  @secret_store_id
end

#statusObject

The status of the link between the node and secret store



15430
15431
15432
# File 'lib/models/porcelain.rb', line 15430

def status
  @status
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15452
15453
15454
15455
15456
15457
15458
# File 'lib/models/porcelain.rb', line 15452

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end