Class: SDM::SecretStoreHealth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth

Returns a new instance of SecretStoreHealth.



14137
14138
14139
14140
14141
14142
14143
14144
14145
14146
14147
14148
14149
14150
14151
14152
14153
14154
14155
# File 'lib/models/porcelain.rb', line 14137

def initialize(
  changed_at: nil,
  checked_at: nil,
  error: nil,
  flags: nil,
  node_id: nil,
  reachability: nil,
  secret_store_id: nil,
  status: nil
)
  @changed_at = changed_at == nil ? nil : changed_at
  @checked_at = checked_at == nil ? nil : checked_at
  @error = error == nil ? "" : error
  @flags = flags == nil ? [] : flags
  @node_id = node_id == nil ? "" : node_id
  @reachability = reachability == nil ? "" : reachability
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @status = status == nil ? "" : status
end

Instance Attribute Details

#changed_atObject

The time when the status last changed



14121
14122
14123
# File 'lib/models/porcelain.rb', line 14121

def changed_at
  @changed_at
end

#checked_atObject

The time when the status was last checked by the node



14123
14124
14125
# File 'lib/models/porcelain.rb', line 14123

def checked_at
  @checked_at
end

#errorObject

The error associated with this health check, if it occurred after reachability checks succeeded.



14125
14126
14127
# File 'lib/models/porcelain.rb', line 14125

def error
  @error
end

#flagsObject

Any specific status or error flags associated with this health check.



14127
14128
14129
# File 'lib/models/porcelain.rb', line 14127

def flags
  @flags
end

#node_idObject

Associated node id for this health



14129
14130
14131
# File 'lib/models/porcelain.rb', line 14129

def node_id
  @node_id
end

#reachabilityObject

The error associated with this health check, if it occurred during reachability checks.



14131
14132
14133
# File 'lib/models/porcelain.rb', line 14131

def reachability
  @reachability
end

#secret_store_idObject

Associated secret store for this health



14133
14134
14135
# File 'lib/models/porcelain.rb', line 14133

def secret_store_id
  @secret_store_id
end

#statusObject

The status of the link between the node and secret store



14135
14136
14137
# File 'lib/models/porcelain.rb', line 14135

def status
  @status
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14157
14158
14159
14160
14161
14162
14163
# File 'lib/models/porcelain.rb', line 14157

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end