Class: SDM::SecretStoreHealth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth

Returns a new instance of SecretStoreHealth.



13969
13970
13971
13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
13986
13987
# File 'lib/models/porcelain.rb', line 13969

def initialize(
  changed_at: nil,
  checked_at: nil,
  error: nil,
  flags: nil,
  node_id: nil,
  reachability: nil,
  secret_store_id: nil,
  status: nil
)
  @changed_at = changed_at == nil ? nil : changed_at
  @checked_at = checked_at == nil ? nil : checked_at
  @error = error == nil ? "" : error
  @flags = flags == nil ? [] : flags
  @node_id = node_id == nil ? "" : node_id
  @reachability = reachability == nil ? "" : reachability
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @status = status == nil ? "" : status
end

Instance Attribute Details

#changed_atObject

The time when the status last changed



13953
13954
13955
# File 'lib/models/porcelain.rb', line 13953

def changed_at
  @changed_at
end

#checked_atObject

The time when the status was last checked by the node



13955
13956
13957
# File 'lib/models/porcelain.rb', line 13955

def checked_at
  @checked_at
end

#errorObject

The error associated with this health check, if it occurred after reachability checks succeeded.



13957
13958
13959
# File 'lib/models/porcelain.rb', line 13957

def error
  @error
end

#flagsObject

Any specific status or error flags associated with this health check.



13959
13960
13961
# File 'lib/models/porcelain.rb', line 13959

def flags
  @flags
end

#node_idObject

Associated node id for this health



13961
13962
13963
# File 'lib/models/porcelain.rb', line 13961

def node_id
  @node_id
end

#reachabilityObject

The error associated with this health check, if it occurred during reachability checks.



13963
13964
13965
# File 'lib/models/porcelain.rb', line 13963

def reachability
  @reachability
end

#secret_store_idObject

Associated secret store for this health



13965
13966
13967
# File 'lib/models/porcelain.rb', line 13965

def secret_store_id
  @secret_store_id
end

#statusObject

The status of the link between the node and secret store



13967
13968
13969
# File 'lib/models/porcelain.rb', line 13967

def status
  @status
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13989
13990
13991
13992
13993
13994
13995
# File 'lib/models/porcelain.rb', line 13989

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end