Class: SDM::SecretStoreHealth
- Inherits:
-
Object
- Object
- SDM::SecretStoreHealth
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.
Instance Attribute Summary collapse
-
#changed_at ⇒ Object
The time when the status last changed.
-
#checked_at ⇒ Object
The time when the status was last checked by the node.
-
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
-
#flags ⇒ Object
Any specific status or error flags associated with this health check.
-
#node_id ⇒ Object
Associated node id for this health.
-
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
-
#secret_store_id ⇒ Object
Associated secret store for this health.
-
#status ⇒ Object
The status of the link between the node and secret store.
Instance Method Summary collapse
-
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
constructor
A new instance of SecretStoreHealth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
Returns a new instance of SecretStoreHealth.
13749 13750 13751 13752 13753 13754 13755 13756 13757 13758 13759 13760 13761 13762 13763 13764 13765 13766 13767 |
# File 'lib/models/porcelain.rb', line 13749 def initialize( changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil ) @changed_at = changed_at == nil ? nil : changed_at @checked_at = checked_at == nil ? nil : checked_at @error = error == nil ? "" : error @flags = flags == nil ? [] : flags @node_id = node_id == nil ? "" : node_id @reachability = reachability == nil ? "" : reachability @secret_store_id = secret_store_id == nil ? "" : secret_store_id @status = status == nil ? "" : status end |
Instance Attribute Details
#changed_at ⇒ Object
The time when the status last changed
13733 13734 13735 |
# File 'lib/models/porcelain.rb', line 13733 def changed_at @changed_at end |
#checked_at ⇒ Object
The time when the status was last checked by the node
13735 13736 13737 |
# File 'lib/models/porcelain.rb', line 13735 def checked_at @checked_at end |
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
13737 13738 13739 |
# File 'lib/models/porcelain.rb', line 13737 def error @error end |
#flags ⇒ Object
Any specific status or error flags associated with this health check.
13739 13740 13741 |
# File 'lib/models/porcelain.rb', line 13739 def flags @flags end |
#node_id ⇒ Object
Associated node id for this health
13741 13742 13743 |
# File 'lib/models/porcelain.rb', line 13741 def node_id @node_id end |
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
13743 13744 13745 |
# File 'lib/models/porcelain.rb', line 13743 def reachability @reachability end |
#secret_store_id ⇒ Object
Associated secret store for this health
13745 13746 13747 |
# File 'lib/models/porcelain.rb', line 13745 def secret_store_id @secret_store_id end |
#status ⇒ Object
The status of the link between the node and secret store
13747 13748 13749 |
# File 'lib/models/porcelain.rb', line 13747 def status @status end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13769 13770 13771 13772 13773 13774 13775 |
# File 'lib/models/porcelain.rb', line 13769 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |