Class: SDM::SecretStoreHealth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth

Returns a new instance of SecretStoreHealth.



12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
12500
# File 'lib/models/porcelain.rb', line 12482

def initialize(
  changed_at: nil,
  checked_at: nil,
  error: nil,
  flags: nil,
  node_id: nil,
  reachability: nil,
  secret_store_id: nil,
  status: nil
)
  @changed_at = changed_at == nil ? nil : changed_at
  @checked_at = checked_at == nil ? nil : checked_at
  @error = error == nil ? "" : error
  @flags = flags == nil ? [] : flags
  @node_id = node_id == nil ? "" : node_id
  @reachability = reachability == nil ? "" : reachability
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @status = status == nil ? "" : status
end

Instance Attribute Details

#changed_atObject

The time when the status last changed



12466
12467
12468
# File 'lib/models/porcelain.rb', line 12466

def changed_at
  @changed_at
end

#checked_atObject

The time when the status was last checked by the node



12468
12469
12470
# File 'lib/models/porcelain.rb', line 12468

def checked_at
  @checked_at
end

#errorObject

The error associated with this health check, if it occurred after reachability checks succeeded.



12470
12471
12472
# File 'lib/models/porcelain.rb', line 12470

def error
  @error
end

#flagsObject

Any specific status or error flags associated with this health check.



12472
12473
12474
# File 'lib/models/porcelain.rb', line 12472

def flags
  @flags
end

#node_idObject

Associated node id for this health



12474
12475
12476
# File 'lib/models/porcelain.rb', line 12474

def node_id
  @node_id
end

#reachabilityObject

The error associated with this health check, if it occurred during reachability checks.



12476
12477
12478
# File 'lib/models/porcelain.rb', line 12476

def reachability
  @reachability
end

#secret_store_idObject

Associated secret store for this health



12478
12479
12480
# File 'lib/models/porcelain.rb', line 12478

def secret_store_id
  @secret_store_id
end

#statusObject

The status of the link between the node and secret store



12480
12481
12482
# File 'lib/models/porcelain.rb', line 12480

def status
  @status
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12502
12503
12504
12505
12506
12507
12508
# File 'lib/models/porcelain.rb', line 12502

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end