Class: SDM::SecretStoreHealth
- Inherits:
-
Object
- Object
- SDM::SecretStoreHealth
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.
Instance Attribute Summary collapse
-
#changed_at ⇒ Object
The time when the status last changed.
-
#checked_at ⇒ Object
The time when the status was last checked by the node.
-
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
-
#flags ⇒ Object
Any specific status or error flags associated with this health check.
-
#node_id ⇒ Object
Associated node id for this health.
-
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
-
#secret_store_id ⇒ Object
Associated secret store for this health.
-
#status ⇒ Object
The status of the link between the node and secret store.
Instance Method Summary collapse
-
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
constructor
A new instance of SecretStoreHealth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
Returns a new instance of SecretStoreHealth.
12246 12247 12248 12249 12250 12251 12252 12253 12254 12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 |
# File 'lib/models/porcelain.rb', line 12246 def initialize( changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil ) @changed_at = changed_at == nil ? nil : changed_at @checked_at = checked_at == nil ? nil : checked_at @error = error == nil ? "" : error @flags = flags == nil ? [] : flags @node_id = node_id == nil ? "" : node_id @reachability = reachability == nil ? "" : reachability @secret_store_id = secret_store_id == nil ? "" : secret_store_id @status = status == nil ? "" : status end |
Instance Attribute Details
#changed_at ⇒ Object
The time when the status last changed
12230 12231 12232 |
# File 'lib/models/porcelain.rb', line 12230 def changed_at @changed_at end |
#checked_at ⇒ Object
The time when the status was last checked by the node
12232 12233 12234 |
# File 'lib/models/porcelain.rb', line 12232 def checked_at @checked_at end |
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
12234 12235 12236 |
# File 'lib/models/porcelain.rb', line 12234 def error @error end |
#flags ⇒ Object
Any specific status or error flags associated with this health check.
12236 12237 12238 |
# File 'lib/models/porcelain.rb', line 12236 def flags @flags end |
#node_id ⇒ Object
Associated node id for this health
12238 12239 12240 |
# File 'lib/models/porcelain.rb', line 12238 def node_id @node_id end |
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
12240 12241 12242 |
# File 'lib/models/porcelain.rb', line 12240 def reachability @reachability end |
#secret_store_id ⇒ Object
Associated secret store for this health
12242 12243 12244 |
# File 'lib/models/porcelain.rb', line 12242 def secret_store_id @secret_store_id end |
#status ⇒ Object
The status of the link between the node and secret store
12244 12245 12246 |
# File 'lib/models/porcelain.rb', line 12244 def status @status end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12266 12267 12268 12269 12270 12271 12272 |
# File 'lib/models/porcelain.rb', line 12266 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |