Class: SDM::SecretStoreHealth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth

Returns a new instance of SecretStoreHealth.



12247
12248
12249
12250
12251
12252
12253
12254
12255
12256
12257
12258
12259
12260
12261
12262
12263
12264
12265
# File 'lib/models/porcelain.rb', line 12247

def initialize(
  changed_at: nil,
  checked_at: nil,
  error: nil,
  flags: nil,
  node_id: nil,
  reachability: nil,
  secret_store_id: nil,
  status: nil
)
  @changed_at = changed_at == nil ? nil : changed_at
  @checked_at = checked_at == nil ? nil : checked_at
  @error = error == nil ? "" : error
  @flags = flags == nil ? [] : flags
  @node_id = node_id == nil ? "" : node_id
  @reachability = reachability == nil ? "" : reachability
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @status = status == nil ? "" : status
end

Instance Attribute Details

#changed_atObject

The time when the status last changed



12231
12232
12233
# File 'lib/models/porcelain.rb', line 12231

def changed_at
  @changed_at
end

#checked_atObject

The time when the status was last checked by the node



12233
12234
12235
# File 'lib/models/porcelain.rb', line 12233

def checked_at
  @checked_at
end

#errorObject

The error associated with this health check, if it occurred after reachability checks succeeded.



12235
12236
12237
# File 'lib/models/porcelain.rb', line 12235

def error
  @error
end

#flagsObject

Any specific status or error flags associated with this health check.



12237
12238
12239
# File 'lib/models/porcelain.rb', line 12237

def flags
  @flags
end

#node_idObject

Associated node id for this health



12239
12240
12241
# File 'lib/models/porcelain.rb', line 12239

def node_id
  @node_id
end

#reachabilityObject

The error associated with this health check, if it occurred during reachability checks.



12241
12242
12243
# File 'lib/models/porcelain.rb', line 12241

def reachability
  @reachability
end

#secret_store_idObject

Associated secret store for this health



12243
12244
12245
# File 'lib/models/porcelain.rb', line 12243

def secret_store_id
  @secret_store_id
end

#statusObject

The status of the link between the node and secret store



12245
12246
12247
# File 'lib/models/porcelain.rb', line 12245

def status
  @status
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12267
12268
12269
12270
12271
12272
12273
# File 'lib/models/porcelain.rb', line 12267

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end