Class: SDM::SecretStoreHealth
- Inherits:
-
Object
- Object
- SDM::SecretStoreHealth
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.
Instance Attribute Summary collapse
-
#changed_at ⇒ Object
The time when the status last changed.
-
#checked_at ⇒ Object
The time when the status was last checked by the node.
-
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
-
#flags ⇒ Object
Any specific status or error flags associated with this health check.
-
#node_id ⇒ Object
Associated node id for this health.
-
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
-
#secret_store_id ⇒ Object
Associated secret store for this health.
-
#status ⇒ Object
The status of the link between the node and secret store.
Instance Method Summary collapse
-
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
constructor
A new instance of SecretStoreHealth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
Returns a new instance of SecretStoreHealth.
12167 12168 12169 12170 12171 12172 12173 12174 12175 12176 12177 12178 12179 12180 12181 12182 12183 12184 12185 |
# File 'lib/models/porcelain.rb', line 12167 def initialize( changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil ) @changed_at = changed_at == nil ? nil : changed_at @checked_at = checked_at == nil ? nil : checked_at @error = error == nil ? "" : error @flags = flags == nil ? [] : flags @node_id = node_id == nil ? "" : node_id @reachability = reachability == nil ? "" : reachability @secret_store_id = secret_store_id == nil ? "" : secret_store_id @status = status == nil ? "" : status end |
Instance Attribute Details
#changed_at ⇒ Object
The time when the status last changed
12151 12152 12153 |
# File 'lib/models/porcelain.rb', line 12151 def changed_at @changed_at end |
#checked_at ⇒ Object
The time when the status was last checked by the node
12153 12154 12155 |
# File 'lib/models/porcelain.rb', line 12153 def checked_at @checked_at end |
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
12155 12156 12157 |
# File 'lib/models/porcelain.rb', line 12155 def error @error end |
#flags ⇒ Object
Any specific status or error flags associated with this health check.
12157 12158 12159 |
# File 'lib/models/porcelain.rb', line 12157 def flags @flags end |
#node_id ⇒ Object
Associated node id for this health
12159 12160 12161 |
# File 'lib/models/porcelain.rb', line 12159 def node_id @node_id end |
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
12161 12162 12163 |
# File 'lib/models/porcelain.rb', line 12161 def reachability @reachability end |
#secret_store_id ⇒ Object
Associated secret store for this health
12163 12164 12165 |
# File 'lib/models/porcelain.rb', line 12163 def secret_store_id @secret_store_id end |
#status ⇒ Object
The status of the link between the node and secret store
12165 12166 12167 |
# File 'lib/models/porcelain.rb', line 12165 def status @status end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12187 12188 12189 12190 12191 12192 12193 |
# File 'lib/models/porcelain.rb', line 12187 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |