Class: SDM::SecretStoreHealth
- Inherits:
-
Object
- Object
- SDM::SecretStoreHealth
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.
Instance Attribute Summary collapse
-
#changed_at ⇒ Object
The time when the status last changed.
-
#checked_at ⇒ Object
The time when the status was last checked by the node.
-
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
-
#flags ⇒ Object
Any specific status or error flags associated with this health check.
-
#node_id ⇒ Object
Associated node id for this health.
-
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
-
#secret_store_id ⇒ Object
Associated secret store for this health.
-
#status ⇒ Object
The status of the link between the node and secret store.
Instance Method Summary collapse
-
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
constructor
A new instance of SecretStoreHealth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
Returns a new instance of SecretStoreHealth.
12093 12094 12095 12096 12097 12098 12099 12100 12101 12102 12103 12104 12105 12106 12107 12108 12109 12110 12111 |
# File 'lib/models/porcelain.rb', line 12093 def initialize( changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil ) @changed_at = changed_at == nil ? nil : changed_at @checked_at = checked_at == nil ? nil : checked_at @error = error == nil ? "" : error @flags = flags == nil ? [] : flags @node_id = node_id == nil ? "" : node_id @reachability = reachability == nil ? "" : reachability @secret_store_id = secret_store_id == nil ? "" : secret_store_id @status = status == nil ? "" : status end |
Instance Attribute Details
#changed_at ⇒ Object
The time when the status last changed
12077 12078 12079 |
# File 'lib/models/porcelain.rb', line 12077 def changed_at @changed_at end |
#checked_at ⇒ Object
The time when the status was last checked by the node
12079 12080 12081 |
# File 'lib/models/porcelain.rb', line 12079 def checked_at @checked_at end |
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
12081 12082 12083 |
# File 'lib/models/porcelain.rb', line 12081 def error @error end |
#flags ⇒ Object
Any specific status or error flags associated with this health check.
12083 12084 12085 |
# File 'lib/models/porcelain.rb', line 12083 def flags @flags end |
#node_id ⇒ Object
Associated node id for this health
12085 12086 12087 |
# File 'lib/models/porcelain.rb', line 12085 def node_id @node_id end |
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
12087 12088 12089 |
# File 'lib/models/porcelain.rb', line 12087 def reachability @reachability end |
#secret_store_id ⇒ Object
Associated secret store for this health
12089 12090 12091 |
# File 'lib/models/porcelain.rb', line 12089 def secret_store_id @secret_store_id end |
#status ⇒ Object
The status of the link between the node and secret store
12091 12092 12093 |
# File 'lib/models/porcelain.rb', line 12091 def status @status end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12113 12114 12115 12116 12117 12118 12119 |
# File 'lib/models/porcelain.rb', line 12113 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |