Class: SDM::SecretStoreHealth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth

Returns a new instance of SecretStoreHealth.



11729
11730
11731
11732
11733
11734
11735
11736
11737
11738
11739
11740
11741
11742
11743
11744
11745
11746
11747
# File 'lib/models/porcelain.rb', line 11729

def initialize(
  changed_at: nil,
  checked_at: nil,
  error: nil,
  flags: nil,
  node_id: nil,
  reachability: nil,
  secret_store_id: nil,
  status: nil
)
  @changed_at = changed_at == nil ? nil : changed_at
  @checked_at = checked_at == nil ? nil : checked_at
  @error = error == nil ? "" : error
  @flags = flags == nil ? [] : flags
  @node_id = node_id == nil ? "" : node_id
  @reachability = reachability == nil ? "" : reachability
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @status = status == nil ? "" : status
end

Instance Attribute Details

#changed_atObject

The time when the status last changed



11713
11714
11715
# File 'lib/models/porcelain.rb', line 11713

def changed_at
  @changed_at
end

#checked_atObject

The time when the status was last checked by the node



11715
11716
11717
# File 'lib/models/porcelain.rb', line 11715

def checked_at
  @checked_at
end

#errorObject

The error associated with this health check, if it occurred after reachability checks succeeded.



11717
11718
11719
# File 'lib/models/porcelain.rb', line 11717

def error
  @error
end

#flagsObject

Any specific status or error flags associated with this health check.



11719
11720
11721
# File 'lib/models/porcelain.rb', line 11719

def flags
  @flags
end

#node_idObject

Associated node id for this health



11721
11722
11723
# File 'lib/models/porcelain.rb', line 11721

def node_id
  @node_id
end

#reachabilityObject

The error associated with this health check, if it occurred during reachability checks.



11723
11724
11725
# File 'lib/models/porcelain.rb', line 11723

def reachability
  @reachability
end

#secret_store_idObject

Associated secret store for this health



11725
11726
11727
# File 'lib/models/porcelain.rb', line 11725

def secret_store_id
  @secret_store_id
end

#statusObject

The status of the link between the node and secret store



11727
11728
11729
# File 'lib/models/porcelain.rb', line 11727

def status
  @status
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11749
11750
11751
11752
11753
11754
11755
# File 'lib/models/porcelain.rb', line 11749

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end