Class: SDM::SecretStoreHealth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth

Returns a new instance of SecretStoreHealth.



11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
# File 'lib/models/porcelain.rb', line 11474

def initialize(
  changed_at: nil,
  checked_at: nil,
  error: nil,
  flags: nil,
  node_id: nil,
  reachability: nil,
  secret_store_id: nil,
  status: nil
)
  @changed_at = changed_at == nil ? nil : changed_at
  @checked_at = checked_at == nil ? nil : checked_at
  @error = error == nil ? "" : error
  @flags = flags == nil ? [] : flags
  @node_id = node_id == nil ? "" : node_id
  @reachability = reachability == nil ? "" : reachability
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @status = status == nil ? "" : status
end

Instance Attribute Details

#changed_atObject

The time when the status last changed



11458
11459
11460
# File 'lib/models/porcelain.rb', line 11458

def changed_at
  @changed_at
end

#checked_atObject

The time when the status was last checked by the node



11460
11461
11462
# File 'lib/models/porcelain.rb', line 11460

def checked_at
  @checked_at
end

#errorObject

The error associated with this health check, if it occurred after reachability checks succeeded.



11462
11463
11464
# File 'lib/models/porcelain.rb', line 11462

def error
  @error
end

#flagsObject

Any specific status or error flags associated with this health check.



11464
11465
11466
# File 'lib/models/porcelain.rb', line 11464

def flags
  @flags
end

#node_idObject

Associated node id for this health



11466
11467
11468
# File 'lib/models/porcelain.rb', line 11466

def node_id
  @node_id
end

#reachabilityObject

The error associated with this health check, if it occurred during reachability checks.



11468
11469
11470
# File 'lib/models/porcelain.rb', line 11468

def reachability
  @reachability
end

#secret_store_idObject

Associated secret store for this health



11470
11471
11472
# File 'lib/models/porcelain.rb', line 11470

def secret_store_id
  @secret_store_id
end

#statusObject

The status of the link between the node and secret store



11472
11473
11474
# File 'lib/models/porcelain.rb', line 11472

def status
  @status
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11494
11495
11496
11497
11498
11499
11500
# File 'lib/models/porcelain.rb', line 11494

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end