Class: SDM::SecretStoreHealth
- Inherits:
-
Object
- Object
- SDM::SecretStoreHealth
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.
Instance Attribute Summary collapse
-
#changed_at ⇒ Object
The time when the status last changed.
-
#checked_at ⇒ Object
The time when the status was last checked by the node.
-
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
-
#flags ⇒ Object
Any specific status or error flags associated with this health check.
-
#node_id ⇒ Object
Associated node id for this health.
-
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
-
#secret_store_id ⇒ Object
Associated secret store for this health.
-
#status ⇒ Object
The status of the link between the node and secret store.
Instance Method Summary collapse
-
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
constructor
A new instance of SecretStoreHealth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
Returns a new instance of SecretStoreHealth.
11007 11008 11009 11010 11011 11012 11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 |
# File 'lib/models/porcelain.rb', line 11007 def initialize( changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil ) @changed_at = changed_at == nil ? nil : changed_at @checked_at = checked_at == nil ? nil : checked_at @error = error == nil ? "" : error @flags = flags == nil ? [] : flags @node_id = node_id == nil ? "" : node_id @reachability = reachability == nil ? "" : reachability @secret_store_id = secret_store_id == nil ? "" : secret_store_id @status = status == nil ? "" : status end |
Instance Attribute Details
#changed_at ⇒ Object
The time when the status last changed
10991 10992 10993 |
# File 'lib/models/porcelain.rb', line 10991 def changed_at @changed_at end |
#checked_at ⇒ Object
The time when the status was last checked by the node
10993 10994 10995 |
# File 'lib/models/porcelain.rb', line 10993 def checked_at @checked_at end |
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
10995 10996 10997 |
# File 'lib/models/porcelain.rb', line 10995 def error @error end |
#flags ⇒ Object
Any specific status or error flags associated with this health check.
10997 10998 10999 |
# File 'lib/models/porcelain.rb', line 10997 def flags @flags end |
#node_id ⇒ Object
Associated node id for this health
10999 11000 11001 |
# File 'lib/models/porcelain.rb', line 10999 def node_id @node_id end |
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
11001 11002 11003 |
# File 'lib/models/porcelain.rb', line 11001 def reachability @reachability end |
#secret_store_id ⇒ Object
Associated secret store for this health
11003 11004 11005 |
# File 'lib/models/porcelain.rb', line 11003 def secret_store_id @secret_store_id end |
#status ⇒ Object
The status of the link between the node and secret store
11005 11006 11007 |
# File 'lib/models/porcelain.rb', line 11005 def status @status end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11027 11028 11029 11030 11031 11032 11033 |
# File 'lib/models/porcelain.rb', line 11027 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |