Class: SDM::SecretStoreHealth
- Inherits:
-
Object
- Object
- SDM::SecretStoreHealth
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.
Instance Attribute Summary collapse
-
#changed_at ⇒ Object
The time when the status last changed.
-
#checked_at ⇒ Object
The time when the status was last checked by the node.
-
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
-
#flags ⇒ Object
Any specific status or error flags associated with this health check.
-
#node_id ⇒ Object
Associated node id for this health.
-
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
-
#secret_store_id ⇒ Object
Associated secret store for this health.
-
#status ⇒ Object
The status of the link between the node and secret store.
Instance Method Summary collapse
-
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
constructor
A new instance of SecretStoreHealth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
Returns a new instance of SecretStoreHealth.
10838 10839 10840 10841 10842 10843 10844 10845 10846 10847 10848 10849 10850 10851 10852 10853 10854 10855 10856 |
# File 'lib/models/porcelain.rb', line 10838 def initialize( changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil ) @changed_at = changed_at == nil ? nil : changed_at @checked_at = checked_at == nil ? nil : checked_at @error = error == nil ? "" : error @flags = flags == nil ? [] : flags @node_id = node_id == nil ? "" : node_id @reachability = reachability == nil ? "" : reachability @secret_store_id = secret_store_id == nil ? "" : secret_store_id @status = status == nil ? "" : status end |
Instance Attribute Details
#changed_at ⇒ Object
The time when the status last changed
10822 10823 10824 |
# File 'lib/models/porcelain.rb', line 10822 def changed_at @changed_at end |
#checked_at ⇒ Object
The time when the status was last checked by the node
10824 10825 10826 |
# File 'lib/models/porcelain.rb', line 10824 def checked_at @checked_at end |
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
10826 10827 10828 |
# File 'lib/models/porcelain.rb', line 10826 def error @error end |
#flags ⇒ Object
Any specific status or error flags associated with this health check.
10828 10829 10830 |
# File 'lib/models/porcelain.rb', line 10828 def flags @flags end |
#node_id ⇒ Object
Associated node id for this health
10830 10831 10832 |
# File 'lib/models/porcelain.rb', line 10830 def node_id @node_id end |
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
10832 10833 10834 |
# File 'lib/models/porcelain.rb', line 10832 def reachability @reachability end |
#secret_store_id ⇒ Object
Associated secret store for this health
10834 10835 10836 |
# File 'lib/models/porcelain.rb', line 10834 def secret_store_id @secret_store_id end |
#status ⇒ Object
The status of the link between the node and secret store
10836 10837 10838 |
# File 'lib/models/porcelain.rb', line 10836 def status @status end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10858 10859 10860 10861 10862 10863 10864 |
# File 'lib/models/porcelain.rb', line 10858 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |