Class: SDM::SecretStoreHealth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth

Returns a new instance of SecretStoreHealth.



10834
10835
10836
10837
10838
10839
10840
10841
10842
10843
10844
10845
10846
10847
10848
10849
10850
10851
10852
# File 'lib/models/porcelain.rb', line 10834

def initialize(
  changed_at: nil,
  checked_at: nil,
  error: nil,
  flags: nil,
  node_id: nil,
  reachability: nil,
  secret_store_id: nil,
  status: nil
)
  @changed_at = changed_at == nil ? nil : changed_at
  @checked_at = checked_at == nil ? nil : checked_at
  @error = error == nil ? "" : error
  @flags = flags == nil ? [] : flags
  @node_id = node_id == nil ? "" : node_id
  @reachability = reachability == nil ? "" : reachability
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @status = status == nil ? "" : status
end

Instance Attribute Details

#changed_atObject

The time when the status last changed



10818
10819
10820
# File 'lib/models/porcelain.rb', line 10818

def changed_at
  @changed_at
end

#checked_atObject

The time when the status was last checked by the node



10820
10821
10822
# File 'lib/models/porcelain.rb', line 10820

def checked_at
  @checked_at
end

#errorObject

The error associated with this health check, if it occurred after reachability checks succeeded.



10822
10823
10824
# File 'lib/models/porcelain.rb', line 10822

def error
  @error
end

#flagsObject

Any specific status or error flags associated with this health check.



10824
10825
10826
# File 'lib/models/porcelain.rb', line 10824

def flags
  @flags
end

#node_idObject

Associated node id for this health



10826
10827
10828
# File 'lib/models/porcelain.rb', line 10826

def node_id
  @node_id
end

#reachabilityObject

The error associated with this health check, if it occurred during reachability checks.



10828
10829
10830
# File 'lib/models/porcelain.rb', line 10828

def reachability
  @reachability
end

#secret_store_idObject

Associated secret store for this health



10830
10831
10832
# File 'lib/models/porcelain.rb', line 10830

def secret_store_id
  @secret_store_id
end

#statusObject

The status of the link between the node and secret store



10832
10833
10834
# File 'lib/models/porcelain.rb', line 10832

def status
  @status
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10854
10855
10856
10857
10858
10859
10860
# File 'lib/models/porcelain.rb', line 10854

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end