Class: SDM::SecretStoreHealth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth

Returns a new instance of SecretStoreHealth.



10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
# File 'lib/models/porcelain.rb', line 10669

def initialize(
  changed_at: nil,
  checked_at: nil,
  error: nil,
  flags: nil,
  node_id: nil,
  reachability: nil,
  secret_store_id: nil,
  status: nil
)
  @changed_at = changed_at == nil ? nil : changed_at
  @checked_at = checked_at == nil ? nil : checked_at
  @error = error == nil ? "" : error
  @flags = flags == nil ? [] : flags
  @node_id = node_id == nil ? "" : node_id
  @reachability = reachability == nil ? "" : reachability
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @status = status == nil ? "" : status
end

Instance Attribute Details

#changed_atObject

The time when the status last changed



10653
10654
10655
# File 'lib/models/porcelain.rb', line 10653

def changed_at
  @changed_at
end

#checked_atObject

The time when the status was last checked by the node



10655
10656
10657
# File 'lib/models/porcelain.rb', line 10655

def checked_at
  @checked_at
end

#errorObject

The error associated with this health check, if it occurred after reachability checks succeeded.



10657
10658
10659
# File 'lib/models/porcelain.rb', line 10657

def error
  @error
end

#flagsObject

Any specific status or error flags associated with this health check.



10659
10660
10661
# File 'lib/models/porcelain.rb', line 10659

def flags
  @flags
end

#node_idObject

Associated node id for this health



10661
10662
10663
# File 'lib/models/porcelain.rb', line 10661

def node_id
  @node_id
end

#reachabilityObject

The error associated with this health check, if it occurred during reachability checks.



10663
10664
10665
# File 'lib/models/porcelain.rb', line 10663

def reachability
  @reachability
end

#secret_store_idObject

Associated secret store for this health



10665
10666
10667
# File 'lib/models/porcelain.rb', line 10665

def secret_store_id
  @secret_store_id
end

#statusObject

The status of the link between the node and secret store



10667
10668
10669
# File 'lib/models/porcelain.rb', line 10667

def status
  @status
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10689
10690
10691
10692
10693
10694
10695
# File 'lib/models/porcelain.rb', line 10689

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end