Class: SDM::SecretStoreHealth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth

Returns a new instance of SecretStoreHealth.



9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
9317
9318
# File 'lib/models/porcelain.rb', line 9300

def initialize(
  changed_at: nil,
  checked_at: nil,
  error: nil,
  flags: nil,
  node_id: nil,
  reachability: nil,
  secret_store_id: nil,
  status: nil
)
  @changed_at = changed_at == nil ? nil : changed_at
  @checked_at = checked_at == nil ? nil : checked_at
  @error = error == nil ? "" : error
  @flags = flags == nil ? [] : flags
  @node_id = node_id == nil ? "" : node_id
  @reachability = reachability == nil ? "" : reachability
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @status = status == nil ? "" : status
end

Instance Attribute Details

#changed_atObject

The time when the status last changed



9284
9285
9286
# File 'lib/models/porcelain.rb', line 9284

def changed_at
  @changed_at
end

#checked_atObject

The time when the status was last checked by the node



9286
9287
9288
# File 'lib/models/porcelain.rb', line 9286

def checked_at
  @checked_at
end

#errorObject

The error associated with this health check, if it occurred after reachability checks succeeded.



9288
9289
9290
# File 'lib/models/porcelain.rb', line 9288

def error
  @error
end

#flagsObject

Any specific status or error flags associated with this health check.



9290
9291
9292
# File 'lib/models/porcelain.rb', line 9290

def flags
  @flags
end

#node_idObject

Associated node id for this health



9292
9293
9294
# File 'lib/models/porcelain.rb', line 9292

def node_id
  @node_id
end

#reachabilityObject

The error associated with this health check, if it occurred during reachability checks.



9294
9295
9296
# File 'lib/models/porcelain.rb', line 9294

def reachability
  @reachability
end

#secret_store_idObject

Associated secret store for this health



9296
9297
9298
# File 'lib/models/porcelain.rb', line 9296

def secret_store_id
  @secret_store_id
end

#statusObject

The status of the link between the node and secret store



9298
9299
9300
# File 'lib/models/porcelain.rb', line 9298

def status
  @status
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9320
9321
9322
9323
9324
9325
9326
# File 'lib/models/porcelain.rb', line 9320

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end