Class: SDM::SecretStoreHealth
- Inherits:
-
Object
- Object
- SDM::SecretStoreHealth
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHealth denotes a secret store's health status. Note a secret store is not healthy in terms of a simple boolean, but rather healthy with respect to a particular node or set of nodes.
Instance Attribute Summary collapse
-
#changed_at ⇒ Object
The time when the status last changed.
-
#checked_at ⇒ Object
The time when the status was last checked by the node.
-
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
-
#flags ⇒ Object
Any specific status or error flags associated with this health check.
-
#node_id ⇒ Object
Associated node id for this health.
-
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
-
#secret_store_id ⇒ Object
Associated secret store for this health.
-
#status ⇒ Object
The status of the link between the node and secret store.
Instance Method Summary collapse
-
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
constructor
A new instance of SecretStoreHealth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil) ⇒ SecretStoreHealth
Returns a new instance of SecretStoreHealth.
9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 9184 9185 9186 9187 9188 9189 |
# File 'lib/models/porcelain.rb', line 9171 def initialize( changed_at: nil, checked_at: nil, error: nil, flags: nil, node_id: nil, reachability: nil, secret_store_id: nil, status: nil ) @changed_at = changed_at == nil ? nil : changed_at @checked_at = checked_at == nil ? nil : checked_at @error = error == nil ? "" : error @flags = flags == nil ? [] : flags @node_id = node_id == nil ? "" : node_id @reachability = reachability == nil ? "" : reachability @secret_store_id = secret_store_id == nil ? "" : secret_store_id @status = status == nil ? "" : status end |
Instance Attribute Details
#changed_at ⇒ Object
The time when the status last changed
9155 9156 9157 |
# File 'lib/models/porcelain.rb', line 9155 def changed_at @changed_at end |
#checked_at ⇒ Object
The time when the status was last checked by the node
9157 9158 9159 |
# File 'lib/models/porcelain.rb', line 9157 def checked_at @checked_at end |
#error ⇒ Object
The error associated with this health check, if it occurred after reachability checks succeeded.
9159 9160 9161 |
# File 'lib/models/porcelain.rb', line 9159 def error @error end |
#flags ⇒ Object
Any specific status or error flags associated with this health check.
9161 9162 9163 |
# File 'lib/models/porcelain.rb', line 9161 def flags @flags end |
#node_id ⇒ Object
Associated node id for this health
9163 9164 9165 |
# File 'lib/models/porcelain.rb', line 9163 def node_id @node_id end |
#reachability ⇒ Object
The error associated with this health check, if it occurred during reachability checks.
9165 9166 9167 |
# File 'lib/models/porcelain.rb', line 9165 def reachability @reachability end |
#secret_store_id ⇒ Object
Associated secret store for this health
9167 9168 9169 |
# File 'lib/models/porcelain.rb', line 9167 def secret_store_id @secret_store_id end |
#status ⇒ Object
The status of the link between the node and secret store
9169 9170 9171 |
# File 'lib/models/porcelain.rb', line 9169 def status @status end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9191 9192 9193 9194 9195 9196 9197 |
# File 'lib/models/porcelain.rb', line 9191 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |