Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



17572
17573
17574
17575
17576
17577
17578
17579
17580
17581
17582
# File 'lib/models/porcelain.rb', line 17572

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



17564
17565
17566
# File 'lib/models/porcelain.rb', line 17564

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



17566
17567
17568
# File 'lib/models/porcelain.rb', line 17566

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



17568
17569
17570
# File 'lib/models/porcelain.rb', line 17568

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



17570
17571
17572
# File 'lib/models/porcelain.rb', line 17570

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17584
17585
17586
17587
17588
17589
17590
# File 'lib/models/porcelain.rb', line 17584

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end