Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



17440
17441
17442
17443
17444
17445
17446
17447
17448
17449
17450
# File 'lib/models/porcelain.rb', line 17440

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



17432
17433
17434
# File 'lib/models/porcelain.rb', line 17432

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



17434
17435
17436
# File 'lib/models/porcelain.rb', line 17434

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



17436
17437
17438
# File 'lib/models/porcelain.rb', line 17436

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



17438
17439
17440
# File 'lib/models/porcelain.rb', line 17438

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17452
17453
17454
17455
17456
17457
17458
# File 'lib/models/porcelain.rb', line 17452

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end