Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



17214
17215
17216
17217
17218
17219
17220
17221
17222
17223
17224
# File 'lib/models/porcelain.rb', line 17214

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



17206
17207
17208
# File 'lib/models/porcelain.rb', line 17206

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



17208
17209
17210
# File 'lib/models/porcelain.rb', line 17208

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



17210
17211
17212
# File 'lib/models/porcelain.rb', line 17210

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



17212
17213
17214
# File 'lib/models/porcelain.rb', line 17212

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17226
17227
17228
17229
17230
17231
17232
# File 'lib/models/porcelain.rb', line 17226

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end