Class: SDM::SecretStoreHistory
- Inherits:
-
Object
- Object
- SDM::SecretStoreHistory
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the SecretStore.
-
#deleted_at ⇒ Object
If this SecretStore was deleted, the time it was deleted.
-
#secret_store ⇒ Object
The complete SecretStore state at this time.
-
#timestamp ⇒ Object
The time at which the SecretStore state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory
constructor
A new instance of SecretStoreHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory
Returns a new instance of SecretStoreHistory.
17206 17207 17208 17209 17210 17211 17212 17213 17214 17215 17216 |
# File 'lib/models/porcelain.rb', line 17206 def initialize( activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @secret_store = secret_store == nil ? nil : secret_store @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.
17198 17199 17200 |
# File 'lib/models/porcelain.rb', line 17198 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this SecretStore was deleted, the time it was deleted.
17200 17201 17202 |
# File 'lib/models/porcelain.rb', line 17200 def deleted_at @deleted_at end |
#secret_store ⇒ Object
The complete SecretStore state at this time.
17202 17203 17204 |
# File 'lib/models/porcelain.rb', line 17202 def secret_store @secret_store end |
#timestamp ⇒ Object
The time at which the SecretStore state was recorded.
17204 17205 17206 |
# File 'lib/models/porcelain.rb', line 17204 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17218 17219 17220 17221 17222 17223 17224 |
# File 'lib/models/porcelain.rb', line 17218 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |