Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



17090
17091
17092
17093
17094
17095
17096
17097
17098
17099
17100
# File 'lib/models/porcelain.rb', line 17090

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



17082
17083
17084
# File 'lib/models/porcelain.rb', line 17082

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



17084
17085
17086
# File 'lib/models/porcelain.rb', line 17084

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



17086
17087
17088
# File 'lib/models/porcelain.rb', line 17086

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



17088
17089
17090
# File 'lib/models/porcelain.rb', line 17088

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17102
17103
17104
17105
17106
17107
17108
# File 'lib/models/porcelain.rb', line 17102

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end