Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



16717
16718
16719
16720
16721
16722
16723
16724
16725
16726
16727
# File 'lib/models/porcelain.rb', line 16717

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



16709
16710
16711
# File 'lib/models/porcelain.rb', line 16709

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



16711
16712
16713
# File 'lib/models/porcelain.rb', line 16711

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



16713
16714
16715
# File 'lib/models/porcelain.rb', line 16713

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



16715
16716
16717
# File 'lib/models/porcelain.rb', line 16715

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16729
16730
16731
16732
16733
16734
16735
# File 'lib/models/porcelain.rb', line 16729

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end