Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



14311
14312
14313
14314
14315
14316
14317
14318
14319
14320
14321
# File 'lib/models/porcelain.rb', line 14311

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



14303
14304
14305
# File 'lib/models/porcelain.rb', line 14303

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



14305
14306
14307
# File 'lib/models/porcelain.rb', line 14305

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



14307
14308
14309
# File 'lib/models/porcelain.rb', line 14307

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



14309
14310
14311
# File 'lib/models/porcelain.rb', line 14309

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14323
14324
14325
14326
14327
14328
14329
# File 'lib/models/porcelain.rb', line 14323

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end