Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



14039
14040
14041
14042
14043
14044
14045
14046
14047
14048
14049
# File 'lib/models/porcelain.rb', line 14039

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



14031
14032
14033
# File 'lib/models/porcelain.rb', line 14031

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



14033
14034
14035
# File 'lib/models/porcelain.rb', line 14033

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



14035
14036
14037
# File 'lib/models/porcelain.rb', line 14035

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



14037
14038
14039
# File 'lib/models/porcelain.rb', line 14037

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14051
14052
14053
14054
14055
14056
14057
# File 'lib/models/porcelain.rb', line 14051

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end