Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



13971
13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
# File 'lib/models/porcelain.rb', line 13971

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



13963
13964
13965
# File 'lib/models/porcelain.rb', line 13963

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



13965
13966
13967
# File 'lib/models/porcelain.rb', line 13965

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



13967
13968
13969
# File 'lib/models/porcelain.rb', line 13967

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



13969
13970
13971
# File 'lib/models/porcelain.rb', line 13969

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13983
13984
13985
13986
13987
13988
13989
# File 'lib/models/porcelain.rb', line 13983

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end