Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



12646
12647
12648
12649
12650
12651
12652
12653
12654
12655
12656
# File 'lib/models/porcelain.rb', line 12646

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



12638
12639
12640
# File 'lib/models/porcelain.rb', line 12638

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



12640
12641
12642
# File 'lib/models/porcelain.rb', line 12640

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



12642
12643
12644
# File 'lib/models/porcelain.rb', line 12642

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



12644
12645
12646
# File 'lib/models/porcelain.rb', line 12644

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12658
12659
12660
12661
12662
12663
12664
# File 'lib/models/porcelain.rb', line 12658

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end