Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



12571
12572
12573
12574
12575
12576
12577
12578
12579
12580
12581
# File 'lib/models/porcelain.rb', line 12571

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



12563
12564
12565
# File 'lib/models/porcelain.rb', line 12563

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



12565
12566
12567
# File 'lib/models/porcelain.rb', line 12565

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



12567
12568
12569
# File 'lib/models/porcelain.rb', line 12567

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



12569
12570
12571
# File 'lib/models/porcelain.rb', line 12569

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12583
12584
12585
12586
12587
12588
12589
# File 'lib/models/porcelain.rb', line 12583

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end