Class: SDM::SecretStoreHistory
- Inherits:
-
Object
- Object
- SDM::SecretStoreHistory
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the SecretStore.
-
#deleted_at ⇒ Object
If this SecretStore was deleted, the time it was deleted.
-
#secret_store ⇒ Object
The complete SecretStore state at this time.
-
#timestamp ⇒ Object
The time at which the SecretStore state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory
constructor
A new instance of SecretStoreHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory
Returns a new instance of SecretStoreHistory.
12395 12396 12397 12398 12399 12400 12401 12402 12403 12404 12405 |
# File 'lib/models/porcelain.rb', line 12395 def initialize( activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @secret_store = secret_store == nil ? nil : secret_store @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.
12387 12388 12389 |
# File 'lib/models/porcelain.rb', line 12387 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this SecretStore was deleted, the time it was deleted.
12389 12390 12391 |
# File 'lib/models/porcelain.rb', line 12389 def deleted_at @deleted_at end |
#secret_store ⇒ Object
The complete SecretStore state at this time.
12391 12392 12393 |
# File 'lib/models/porcelain.rb', line 12391 def secret_store @secret_store end |
#timestamp ⇒ Object
The time at which the SecretStore state was recorded.
12393 12394 12395 |
# File 'lib/models/porcelain.rb', line 12393 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12407 12408 12409 12410 12411 12412 12413 |
# File 'lib/models/porcelain.rb', line 12407 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |