Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
# File 'lib/models/porcelain.rb', line 12327

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



12319
12320
12321
# File 'lib/models/porcelain.rb', line 12319

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



12321
12322
12323
# File 'lib/models/porcelain.rb', line 12321

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



12323
12324
12325
# File 'lib/models/porcelain.rb', line 12323

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



12325
12326
12327
# File 'lib/models/porcelain.rb', line 12325

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12339
12340
12341
12342
12343
12344
12345
# File 'lib/models/porcelain.rb', line 12339

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end