Class: SDM::SecretStoreHistory
- Inherits:
-
Object
- Object
- SDM::SecretStoreHistory
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the SecretStore.
-
#deleted_at ⇒ Object
If this SecretStore was deleted, the time it was deleted.
-
#secret_store ⇒ Object
The complete SecretStore state at this time.
-
#timestamp ⇒ Object
The time at which the SecretStore state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory
constructor
A new instance of SecretStoreHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory
Returns a new instance of SecretStoreHistory.
12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 |
# File 'lib/models/porcelain.rb', line 12328 def initialize( activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @secret_store = secret_store == nil ? nil : secret_store @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.
12320 12321 12322 |
# File 'lib/models/porcelain.rb', line 12320 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this SecretStore was deleted, the time it was deleted.
12322 12323 12324 |
# File 'lib/models/porcelain.rb', line 12322 def deleted_at @deleted_at end |
#secret_store ⇒ Object
The complete SecretStore state at this time.
12324 12325 12326 |
# File 'lib/models/porcelain.rb', line 12324 def secret_store @secret_store end |
#timestamp ⇒ Object
The time at which the SecretStore state was recorded.
12326 12327 12328 |
# File 'lib/models/porcelain.rb', line 12326 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12340 12341 12342 12343 12344 12345 12346 |
# File 'lib/models/porcelain.rb', line 12340 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |