Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



10915
10916
10917
10918
10919
10920
10921
10922
10923
10924
10925
# File 'lib/models/porcelain.rb', line 10915

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



10907
10908
10909
# File 'lib/models/porcelain.rb', line 10907

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



10909
10910
10911
# File 'lib/models/porcelain.rb', line 10909

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



10911
10912
10913
# File 'lib/models/porcelain.rb', line 10911

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



10913
10914
10915
# File 'lib/models/porcelain.rb', line 10913

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10927
10928
10929
10930
10931
10932
10933
# File 'lib/models/porcelain.rb', line 10927

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end