Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



9896
9897
9898
9899
9900
9901
9902
9903
9904
9905
9906
# File 'lib/models/porcelain.rb', line 9896

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



9888
9889
9890
# File 'lib/models/porcelain.rb', line 9888

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



9890
9891
9892
# File 'lib/models/porcelain.rb', line 9890

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



9892
9893
9894
# File 'lib/models/porcelain.rb', line 9892

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



9894
9895
9896
# File 'lib/models/porcelain.rb', line 9894

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9908
9909
9910
9911
9912
9913
9914
# File 'lib/models/porcelain.rb', line 9908

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end