Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
# File 'lib/models/porcelain.rb', line 7894

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



7886
7887
7888
# File 'lib/models/porcelain.rb', line 7886

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



7888
7889
7890
# File 'lib/models/porcelain.rb', line 7888

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



7890
7891
7892
# File 'lib/models/porcelain.rb', line 7890

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



7892
7893
7894
# File 'lib/models/porcelain.rb', line 7892

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7906
7907
7908
7909
7910
7911
7912
# File 'lib/models/porcelain.rb', line 7906

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end