Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
# File 'lib/models/porcelain.rb', line 7667

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



7659
7660
7661
# File 'lib/models/porcelain.rb', line 7659

def activity_id
  @activity_id
end

#deleted_atObject

If this SecretStore was deleted, the time it was deleted.



7661
7662
7663
# File 'lib/models/porcelain.rb', line 7661

def deleted_at
  @deleted_at
end

#secret_storeObject

The complete SecretStore state at this time.



7663
7664
7665
# File 'lib/models/porcelain.rb', line 7663

def secret_store
  @secret_store
end

#timestampObject

The time at which the SecretStore state was recorded.



7665
7666
7667
# File 'lib/models/porcelain.rb', line 7665

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7679
7680
7681
7682
7683
7684
7685
# File 'lib/models/porcelain.rb', line 7679

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end