Class: SDM::SecretStoreHistory
- Inherits:
-
Object
- Object
- SDM::SecretStoreHistory
- Defined in:
- lib/models/porcelain.rb
Overview
SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the SecretStore.
-
#deleted_at ⇒ Object
If this SecretStore was deleted, the time it was deleted.
-
#secret_store ⇒ Object
The complete SecretStore state at this time.
-
#timestamp ⇒ Object
The time at which the SecretStore state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory
constructor
A new instance of SecretStoreHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory
Returns a new instance of SecretStoreHistory.
7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 |
# File 'lib/models/porcelain.rb', line 7223 def initialize( activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @secret_store = secret_store == nil ? nil : secret_store @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.
7215 7216 7217 |
# File 'lib/models/porcelain.rb', line 7215 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this SecretStore was deleted, the time it was deleted.
7217 7218 7219 |
# File 'lib/models/porcelain.rb', line 7217 def deleted_at @deleted_at end |
#secret_store ⇒ Object
The complete SecretStore state at this time.
7219 7220 7221 |
# File 'lib/models/porcelain.rb', line 7219 def secret_store @secret_store end |
#timestamp ⇒ Object
The time at which the SecretStore state was recorded.
7221 7222 7223 |
# File 'lib/models/porcelain.rb', line 7221 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7235 7236 7237 7238 7239 7240 7241 |
# File 'lib/models/porcelain.rb', line 7235 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |