Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
# File 'lib/models/porcelain.rb', line 17588

def initialize(
  created_at: nil,
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#created_atObject

CreatedAt is the timestamp when the service was created



17578
17579
17580
# File 'lib/models/porcelain.rb', line 17578

def created_at
  @created_at
end

#idObject

Unique identifier of the Service.



17580
17581
17582
# File 'lib/models/porcelain.rb', line 17580

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



17582
17583
17584
# File 'lib/models/porcelain.rb', line 17582

def name
  @name
end

#suspendedObject

The Service's suspended state.



17584
17585
17586
# File 'lib/models/porcelain.rb', line 17584

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



17586
17587
17588
# File 'lib/models/porcelain.rb', line 17586

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17602
17603
17604
17605
17606
17607
17608
# File 'lib/models/porcelain.rb', line 17602

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end