Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



17504
17505
17506
17507
17508
17509
17510
17511
17512
17513
17514
17515
17516
# File 'lib/models/porcelain.rb', line 17504

def initialize(
  created_at: nil,
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#created_atObject

CreatedAt is the timestamp when the service was created



17494
17495
17496
# File 'lib/models/porcelain.rb', line 17494

def created_at
  @created_at
end

#idObject

Unique identifier of the Service.



17496
17497
17498
# File 'lib/models/porcelain.rb', line 17496

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



17498
17499
17500
# File 'lib/models/porcelain.rb', line 17498

def name
  @name
end

#suspendedObject

The Service's suspended state.



17500
17501
17502
# File 'lib/models/porcelain.rb', line 17500

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



17502
17503
17504
# File 'lib/models/porcelain.rb', line 17502

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17518
17519
17520
17521
17522
17523
17524
# File 'lib/models/porcelain.rb', line 17518

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end