Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#created_at ⇒ Object
CreatedAt is the timestamp when the service was created.
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(created_at: nil, id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(created_at: nil, id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
17270 17271 17272 17273 17274 17275 17276 17277 17278 17279 17280 17281 17282 |
# File 'lib/models/porcelain.rb', line 17270 def initialize( created_at: nil, id: nil, name: nil, suspended: nil, tags: nil ) @created_at = created_at == nil ? nil : created_at @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#created_at ⇒ Object
CreatedAt is the timestamp when the service was created
17260 17261 17262 |
# File 'lib/models/porcelain.rb', line 17260 def created_at @created_at end |
#id ⇒ Object
Unique identifier of the Service.
17262 17263 17264 |
# File 'lib/models/porcelain.rb', line 17262 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
17264 17265 17266 |
# File 'lib/models/porcelain.rb', line 17264 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
17266 17267 17268 |
# File 'lib/models/porcelain.rb', line 17266 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17268 17269 17270 |
# File 'lib/models/porcelain.rb', line 17268 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17284 17285 17286 17287 17288 17289 17290 |
# File 'lib/models/porcelain.rb', line 17284 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |