Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#created_at ⇒ Object
CreatedAt is the timestamp when the service was created.
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(created_at: nil, id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(created_at: nil, id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
16415 16416 16417 16418 16419 16420 16421 16422 16423 16424 16425 16426 16427 |
# File 'lib/models/porcelain.rb', line 16415 def initialize( created_at: nil, id: nil, name: nil, suspended: nil, tags: nil ) @created_at = created_at == nil ? nil : created_at @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#created_at ⇒ Object
CreatedAt is the timestamp when the service was created
16405 16406 16407 |
# File 'lib/models/porcelain.rb', line 16405 def created_at @created_at end |
#id ⇒ Object
Unique identifier of the Service.
16407 16408 16409 |
# File 'lib/models/porcelain.rb', line 16407 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
16409 16410 16411 |
# File 'lib/models/porcelain.rb', line 16409 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
16411 16412 16413 |
# File 'lib/models/porcelain.rb', line 16411 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
16413 16414 16415 |
# File 'lib/models/porcelain.rb', line 16413 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16429 16430 16431 16432 16433 16434 16435 |
# File 'lib/models/porcelain.rb', line 16429 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |