Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
15575 15576 15577 15578 15579 15580 15581 15582 15583 15584 15585 |
# File 'lib/models/porcelain.rb', line 15575 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
15567 15568 15569 |
# File 'lib/models/porcelain.rb', line 15567 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
15569 15570 15571 |
# File 'lib/models/porcelain.rb', line 15569 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
15571 15572 15573 |
# File 'lib/models/porcelain.rb', line 15571 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
15573 15574 15575 |
# File 'lib/models/porcelain.rb', line 15573 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15587 15588 15589 15590 15591 15592 15593 |
# File 'lib/models/porcelain.rb', line 15587 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |