Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



14292
14293
14294
14295
14296
14297
14298
14299
14300
14301
14302
# File 'lib/models/porcelain.rb', line 14292

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



14284
14285
14286
# File 'lib/models/porcelain.rb', line 14284

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



14286
14287
14288
# File 'lib/models/porcelain.rb', line 14286

def name
  @name
end

#suspendedObject

The Service's suspended state.



14288
14289
14290
# File 'lib/models/porcelain.rb', line 14288

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



14290
14291
14292
# File 'lib/models/porcelain.rb', line 14290

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14304
14305
14306
14307
14308
14309
14310
# File 'lib/models/porcelain.rb', line 14304

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end