Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
14280 14281 14282 14283 14284 14285 14286 14287 14288 14289 14290 |
# File 'lib/models/porcelain.rb', line 14280 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
14272 14273 14274 |
# File 'lib/models/porcelain.rb', line 14272 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
14274 14275 14276 |
# File 'lib/models/porcelain.rb', line 14274 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
14276 14277 14278 |
# File 'lib/models/porcelain.rb', line 14276 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14278 14279 14280 |
# File 'lib/models/porcelain.rb', line 14278 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14292 14293 14294 14295 14296 14297 14298 |
# File 'lib/models/porcelain.rb', line 14292 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |