Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
13892 13893 13894 13895 13896 13897 13898 13899 13900 13901 13902 |
# File 'lib/models/porcelain.rb', line 13892 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
13884 13885 13886 |
# File 'lib/models/porcelain.rb', line 13884 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
13886 13887 13888 |
# File 'lib/models/porcelain.rb', line 13886 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
13888 13889 13890 |
# File 'lib/models/porcelain.rb', line 13888 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13890 13891 13892 |
# File 'lib/models/porcelain.rb', line 13890 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13904 13905 13906 13907 13908 13909 13910 |
# File 'lib/models/porcelain.rb', line 13904 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |