Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
12708 12709 12710 12711 12712 12713 12714 12715 12716 12717 12718 |
# File 'lib/models/porcelain.rb', line 12708 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
12700 12701 12702 |
# File 'lib/models/porcelain.rb', line 12700 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
12702 12703 12704 |
# File 'lib/models/porcelain.rb', line 12702 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
12704 12705 12706 |
# File 'lib/models/porcelain.rb', line 12704 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12706 12707 12708 |
# File 'lib/models/porcelain.rb', line 12706 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12720 12721 12722 12723 12724 12725 12726 |
# File 'lib/models/porcelain.rb', line 12720 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |