Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



12633
12634
12635
12636
12637
12638
12639
12640
12641
12642
12643
# File 'lib/models/porcelain.rb', line 12633

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



12625
12626
12627
# File 'lib/models/porcelain.rb', line 12625

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



12627
12628
12629
# File 'lib/models/porcelain.rb', line 12627

def name
  @name
end

#suspendedObject

The Service's suspended state.



12629
12630
12631
# File 'lib/models/porcelain.rb', line 12629

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



12631
12632
12633
# File 'lib/models/porcelain.rb', line 12631

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12645
12646
12647
12648
12649
12650
12651
# File 'lib/models/porcelain.rb', line 12645

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end