Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
12633 12634 12635 12636 12637 12638 12639 12640 12641 12642 12643 |
# File 'lib/models/porcelain.rb', line 12633 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
12625 12626 12627 |
# File 'lib/models/porcelain.rb', line 12625 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
12627 12628 12629 |
# File 'lib/models/porcelain.rb', line 12627 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
12629 12630 12631 |
# File 'lib/models/porcelain.rb', line 12629 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12631 12632 12633 |
# File 'lib/models/porcelain.rb', line 12631 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12645 12646 12647 12648 12649 12650 12651 |
# File 'lib/models/porcelain.rb', line 12645 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |