Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
12390 12391 12392 12393 12394 12395 12396 12397 12398 12399 12400 |
# File 'lib/models/porcelain.rb', line 12390 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
12382 12383 12384 |
# File 'lib/models/porcelain.rb', line 12382 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
12384 12385 12386 |
# File 'lib/models/porcelain.rb', line 12384 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
12386 12387 12388 |
# File 'lib/models/porcelain.rb', line 12386 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12388 12389 12390 |
# File 'lib/models/porcelain.rb', line 12388 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12402 12403 12404 12405 12406 12407 12408 |
# File 'lib/models/porcelain.rb', line 12402 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |