Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 |
# File 'lib/models/porcelain.rb', line 12310 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
12302 12303 12304 |
# File 'lib/models/porcelain.rb', line 12302 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
12304 12305 12306 |
# File 'lib/models/porcelain.rb', line 12304 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
12306 12307 12308 |
# File 'lib/models/porcelain.rb', line 12306 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12308 12309 12310 |
# File 'lib/models/porcelain.rb', line 12308 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12322 12323 12324 12325 12326 12327 12328 |
# File 'lib/models/porcelain.rb', line 12322 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |