Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



12235
12236
12237
12238
12239
12240
12241
12242
12243
12244
12245
# File 'lib/models/porcelain.rb', line 12235

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



12227
12228
12229
# File 'lib/models/porcelain.rb', line 12227

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



12229
12230
12231
# File 'lib/models/porcelain.rb', line 12229

def name
  @name
end

#suspendedObject

The Service's suspended state.



12231
12232
12233
# File 'lib/models/porcelain.rb', line 12231

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



12233
12234
12235
# File 'lib/models/porcelain.rb', line 12233

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12247
12248
12249
12250
12251
12252
12253
# File 'lib/models/porcelain.rb', line 12247

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end