Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



11872
11873
11874
11875
11876
11877
11878
11879
11880
11881
11882
# File 'lib/models/porcelain.rb', line 11872

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



11864
11865
11866
# File 'lib/models/porcelain.rb', line 11864

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



11866
11867
11868
# File 'lib/models/porcelain.rb', line 11866

def name
  @name
end

#suspendedObject

The Service's suspended state.



11868
11869
11870
# File 'lib/models/porcelain.rb', line 11868

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



11870
11871
11872
# File 'lib/models/porcelain.rb', line 11870

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11884
11885
11886
11887
11888
11889
11890
# File 'lib/models/porcelain.rb', line 11884

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end