Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
11874 11875 11876 11877 11878 11879 11880 11881 11882 11883 11884 |
# File 'lib/models/porcelain.rb', line 11874 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
11866 11867 11868 |
# File 'lib/models/porcelain.rb', line 11866 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
11868 11869 11870 |
# File 'lib/models/porcelain.rb', line 11868 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
11870 11871 11872 |
# File 'lib/models/porcelain.rb', line 11870 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11872 11873 11874 |
# File 'lib/models/porcelain.rb', line 11872 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11886 11887 11888 11889 11890 11891 11892 |
# File 'lib/models/porcelain.rb', line 11886 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |