Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 |
# File 'lib/models/porcelain.rb', line 11617 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
11609 11610 11611 |
# File 'lib/models/porcelain.rb', line 11609 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
11611 11612 11613 |
# File 'lib/models/porcelain.rb', line 11611 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
11613 11614 11615 |
# File 'lib/models/porcelain.rb', line 11613 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11615 11616 11617 |
# File 'lib/models/porcelain.rb', line 11615 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11629 11630 11631 11632 11633 11634 11635 |
# File 'lib/models/porcelain.rb', line 11629 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |