Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



11546
11547
11548
11549
11550
11551
11552
11553
11554
11555
11556
# File 'lib/models/porcelain.rb', line 11546

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



11538
11539
11540
# File 'lib/models/porcelain.rb', line 11538

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



11540
11541
11542
# File 'lib/models/porcelain.rb', line 11540

def name
  @name
end

#suspendedObject

The Service's suspended state.



11542
11543
11544
# File 'lib/models/porcelain.rb', line 11542

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



11544
11545
11546
# File 'lib/models/porcelain.rb', line 11544

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11558
11559
11560
11561
11562
11563
11564
# File 'lib/models/porcelain.rb', line 11558

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end