Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
11470 11471 11472 11473 11474 11475 11476 11477 11478 11479 11480 |
# File 'lib/models/porcelain.rb', line 11470 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
11462 11463 11464 |
# File 'lib/models/porcelain.rb', line 11462 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
11464 11465 11466 |
# File 'lib/models/porcelain.rb', line 11464 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
11466 11467 11468 |
# File 'lib/models/porcelain.rb', line 11466 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11468 11469 11470 |
# File 'lib/models/porcelain.rb', line 11468 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11482 11483 11484 11485 11486 11487 11488 |
# File 'lib/models/porcelain.rb', line 11482 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |