Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
# File 'lib/models/porcelain.rb', line 11150

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



11142
11143
11144
# File 'lib/models/porcelain.rb', line 11142

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



11144
11145
11146
# File 'lib/models/porcelain.rb', line 11144

def name
  @name
end

#suspendedObject

The Service's suspended state.



11146
11147
11148
# File 'lib/models/porcelain.rb', line 11146

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



11148
11149
11150
# File 'lib/models/porcelain.rb', line 11148

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11162
11163
11164
11165
11166
11167
11168
# File 'lib/models/porcelain.rb', line 11162

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end