Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 |
# File 'lib/models/porcelain.rb', line 10981 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
10973 10974 10975 |
# File 'lib/models/porcelain.rb', line 10973 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
10975 10976 10977 |
# File 'lib/models/porcelain.rb', line 10975 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
10977 10978 10979 |
# File 'lib/models/porcelain.rb', line 10977 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10979 10980 10981 |
# File 'lib/models/porcelain.rb', line 10979 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10993 10994 10995 10996 10997 10998 10999 |
# File 'lib/models/porcelain.rb', line 10993 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |