Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
10812 10813 10814 10815 10816 10817 10818 10819 10820 10821 10822 |
# File 'lib/models/porcelain.rb', line 10812 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
10804 10805 10806 |
# File 'lib/models/porcelain.rb', line 10804 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
10806 10807 10808 |
# File 'lib/models/porcelain.rb', line 10806 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
10808 10809 10810 |
# File 'lib/models/porcelain.rb', line 10808 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10810 10811 10812 |
# File 'lib/models/porcelain.rb', line 10810 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10824 10825 10826 10827 10828 10829 10830 |
# File 'lib/models/porcelain.rb', line 10824 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |