Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



10810
10811
10812
10813
10814
10815
10816
10817
10818
10819
10820
# File 'lib/models/porcelain.rb', line 10810

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



10802
10803
10804
# File 'lib/models/porcelain.rb', line 10802

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



10804
10805
10806
# File 'lib/models/porcelain.rb', line 10804

def name
  @name
end

#suspendedObject

The Service's suspended state.



10806
10807
10808
# File 'lib/models/porcelain.rb', line 10806

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



10808
10809
10810
# File 'lib/models/porcelain.rb', line 10808

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10822
10823
10824
10825
10826
10827
10828
# File 'lib/models/porcelain.rb', line 10822

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end