Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
# File 'lib/models/porcelain.rb', line 10039

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



10031
10032
10033
# File 'lib/models/porcelain.rb', line 10031

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



10033
10034
10035
# File 'lib/models/porcelain.rb', line 10033

def name
  @name
end

#suspendedObject

The Service's suspended state.



10035
10036
10037
# File 'lib/models/porcelain.rb', line 10035

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



10037
10038
10039
# File 'lib/models/porcelain.rb', line 10037

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10051
10052
10053
10054
10055
10056
10057
# File 'lib/models/porcelain.rb', line 10051

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end