Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 |
# File 'lib/models/porcelain.rb', line 9406 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
9398 9399 9400 |
# File 'lib/models/porcelain.rb', line 9398 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
9400 9401 9402 |
# File 'lib/models/porcelain.rb', line 9400 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
9402 9403 9404 |
# File 'lib/models/porcelain.rb', line 9402 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9404 9405 9406 |
# File 'lib/models/porcelain.rb', line 9404 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9418 9419 9420 9421 9422 9423 9424 |
# File 'lib/models/porcelain.rb', line 9418 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |