Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



9314
9315
9316
9317
9318
9319
9320
9321
9322
9323
9324
# File 'lib/models/porcelain.rb', line 9314

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



9306
9307
9308
# File 'lib/models/porcelain.rb', line 9306

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



9308
9309
9310
# File 'lib/models/porcelain.rb', line 9308

def name
  @name
end

#suspendedObject

The Service's suspended state.



9310
9311
9312
# File 'lib/models/porcelain.rb', line 9310

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



9312
9313
9314
# File 'lib/models/porcelain.rb', line 9312

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9326
9327
9328
9329
9330
9331
9332
# File 'lib/models/porcelain.rb', line 9326

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end