Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 |
# File 'lib/models/porcelain.rb', line 8788 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
8780 8781 8782 |
# File 'lib/models/porcelain.rb', line 8780 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
8782 8783 8784 |
# File 'lib/models/porcelain.rb', line 8782 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
8784 8785 8786 |
# File 'lib/models/porcelain.rb', line 8784 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8786 8787 8788 |
# File 'lib/models/porcelain.rb', line 8786 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8800 8801 8802 8803 8804 8805 8806 |
# File 'lib/models/porcelain.rb', line 8800 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |