Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
# File 'lib/models/porcelain.rb', line 8193

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



8185
8186
8187
# File 'lib/models/porcelain.rb', line 8185

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



8187
8188
8189
# File 'lib/models/porcelain.rb', line 8187

def name
  @name
end

#suspendedObject

The Service's suspended state.



8189
8190
8191
# File 'lib/models/porcelain.rb', line 8189

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



8191
8192
8193
# File 'lib/models/porcelain.rb', line 8191

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8205
8206
8207
8208
8209
8210
8211
# File 'lib/models/porcelain.rb', line 8205

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end