Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 |
# File 'lib/models/porcelain.rb', line 8012 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
8004 8005 8006 |
# File 'lib/models/porcelain.rb', line 8004 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
8006 8007 8008 |
# File 'lib/models/porcelain.rb', line 8006 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
8008 8009 8010 |
# File 'lib/models/porcelain.rb', line 8008 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8010 8011 8012 |
# File 'lib/models/porcelain.rb', line 8010 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8024 8025 8026 8027 8028 8029 8030 |
# File 'lib/models/porcelain.rb', line 8024 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |