Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



7782
7783
7784
7785
7786
7787
7788
7789
7790
7791
7792
# File 'lib/models/porcelain.rb', line 7782

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



7774
7775
7776
# File 'lib/models/porcelain.rb', line 7774

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



7776
7777
7778
# File 'lib/models/porcelain.rb', line 7776

def name
  @name
end

#suspendedObject

The Service's suspended state.



7778
7779
7780
# File 'lib/models/porcelain.rb', line 7778

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



7780
7781
7782
# File 'lib/models/porcelain.rb', line 7780

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7794
7795
7796
7797
7798
7799
7800
# File 'lib/models/porcelain.rb', line 7794

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end