Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 |
# File 'lib/models/porcelain.rb', line 7782 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
7774 7775 7776 |
# File 'lib/models/porcelain.rb', line 7774 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
7776 7777 7778 |
# File 'lib/models/porcelain.rb', line 7776 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
7778 7779 7780 |
# File 'lib/models/porcelain.rb', line 7778 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7780 7781 7782 |
# File 'lib/models/porcelain.rb', line 7780 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7794 7795 7796 7797 7798 7799 7800 |
# File 'lib/models/porcelain.rb', line 7794 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |