Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



7729
7730
7731
7732
7733
7734
7735
7736
7737
7738
7739
# File 'lib/models/porcelain.rb', line 7729

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



7721
7722
7723
# File 'lib/models/porcelain.rb', line 7721

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



7723
7724
7725
# File 'lib/models/porcelain.rb', line 7723

def name
  @name
end

#suspendedObject

The Service's suspended state.



7725
7726
7727
# File 'lib/models/porcelain.rb', line 7725

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



7727
7728
7729
# File 'lib/models/porcelain.rb', line 7727

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7741
7742
7743
7744
7745
7746
7747
# File 'lib/models/porcelain.rb', line 7741

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end