Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 |
# File 'lib/models/porcelain.rb', line 7729 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
7721 7722 7723 |
# File 'lib/models/porcelain.rb', line 7721 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
7723 7724 7725 |
# File 'lib/models/porcelain.rb', line 7723 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
7725 7726 7727 |
# File 'lib/models/porcelain.rb', line 7725 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7727 7728 7729 |
# File 'lib/models/porcelain.rb', line 7727 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7741 7742 7743 7744 7745 7746 7747 |
# File 'lib/models/porcelain.rb', line 7741 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |