Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
# File 'lib/models/porcelain.rb', line 7655

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



7647
7648
7649
# File 'lib/models/porcelain.rb', line 7647

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



7649
7650
7651
# File 'lib/models/porcelain.rb', line 7649

def name
  @name
end

#suspendedObject

The Service's suspended state.



7651
7652
7653
# File 'lib/models/porcelain.rb', line 7651

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



7653
7654
7655
# File 'lib/models/porcelain.rb', line 7653

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7667
7668
7669
7670
7671
7672
7673
# File 'lib/models/porcelain.rb', line 7667

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end