Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
6374 6375 6376 6377 6378 6379 6380 6381 6382 6383 6384 |
# File 'lib/models/porcelain.rb', line 6374 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
6366 6367 6368 |
# File 'lib/models/porcelain.rb', line 6366 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
6368 6369 6370 |
# File 'lib/models/porcelain.rb', line 6368 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
6370 6371 6372 |
# File 'lib/models/porcelain.rb', line 6370 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6372 6373 6374 |
# File 'lib/models/porcelain.rb', line 6372 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6386 6387 6388 6389 6390 6391 6392 |
# File 'lib/models/porcelain.rb', line 6386 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |