Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 6276 |
# File 'lib/models/porcelain.rb', line 6266 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
6258 6259 6260 |
# File 'lib/models/porcelain.rb', line 6258 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
6260 6261 6262 |
# File 'lib/models/porcelain.rb', line 6260 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
6262 6263 6264 |
# File 'lib/models/porcelain.rb', line 6262 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6264 6265 6266 |
# File 'lib/models/porcelain.rb', line 6264 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6278 6279 6280 6281 6282 6283 6284 |
# File 'lib/models/porcelain.rb', line 6278 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |