Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
6220 6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 |
# File 'lib/models/porcelain.rb', line 6220 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
6212 6213 6214 |
# File 'lib/models/porcelain.rb', line 6212 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
6214 6215 6216 |
# File 'lib/models/porcelain.rb', line 6214 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
6216 6217 6218 |
# File 'lib/models/porcelain.rb', line 6216 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6218 6219 6220 |
# File 'lib/models/porcelain.rb', line 6218 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6232 6233 6234 6235 6236 6237 6238 |
# File 'lib/models/porcelain.rb', line 6232 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |