Class: SDM::Service
- Inherits:
-
Object
- Object
- SDM::Service
- Defined in:
- lib/models/porcelain.rb
Overview
A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Service.
-
#name ⇒ Object
Unique human-readable name of the Service.
-
#suspended ⇒ Object
The Service's suspended state.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
constructor
A new instance of Service.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service
Returns a new instance of Service.
6116 6117 6118 6119 6120 6121 6122 6123 6124 6125 6126 |
# File 'lib/models/porcelain.rb', line 6116 def initialize( id: nil, name: nil, suspended: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Service.
6108 6109 6110 |
# File 'lib/models/porcelain.rb', line 6108 def id @id end |
#name ⇒ Object
Unique human-readable name of the Service.
6110 6111 6112 |
# File 'lib/models/porcelain.rb', line 6110 def name @name end |
#suspended ⇒ Object
The Service's suspended state.
6112 6113 6114 |
# File 'lib/models/porcelain.rb', line 6112 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6114 6115 6116 |
# File 'lib/models/porcelain.rb', line 6114 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/models/porcelain.rb', line 6128 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |