Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



7099
7100
7101
7102
7103
7104
7105
7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
# File 'lib/models/porcelain.rb', line 7099

def initialize(
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if suspended != nil
    @suspended = suspended
  end
  if tags != nil
    @tags = tags
  end
end

Instance Attribute Details

#idObject

Unique identifier of the Service.



7091
7092
7093
# File 'lib/models/porcelain.rb', line 7091

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



7093
7094
7095
# File 'lib/models/porcelain.rb', line 7093

def name
  @name
end

#suspendedObject

The Service's suspended state.



7095
7096
7097
# File 'lib/models/porcelain.rb', line 7095

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



7097
7098
7099
# File 'lib/models/porcelain.rb', line 7097

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7119
7120
7121
7122
7123
7124
7125
# File 'lib/models/porcelain.rb', line 7119

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end