Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



17213
17214
17215
17216
17217
17218
17219
17220
17221
17222
17223
17224
17225
17226
17227
17228
17229
17230
17231
17232
17233
17234
17235
17236
17237
17238
17239
17240
17241
17242
17243
17244
17245
17246
17247
17248
17249
# File 'lib/models/porcelain.rb', line 17213

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17179
17180
17181
# File 'lib/models/porcelain.rb', line 17179

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



17181
17182
17183
# File 'lib/models/porcelain.rb', line 17181

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17183
17184
17185
# File 'lib/models/porcelain.rb', line 17183

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17185
17186
17187
# File 'lib/models/porcelain.rb', line 17185

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17187
17188
17189
# File 'lib/models/porcelain.rb', line 17187

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17189
17190
17191
# File 'lib/models/porcelain.rb', line 17189

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17191
17192
17193
# File 'lib/models/porcelain.rb', line 17191

def name
  @name
end

#passwordObject

The password to authenticate with.



17193
17194
17195
# File 'lib/models/porcelain.rb', line 17193

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17195
17196
17197
# File 'lib/models/porcelain.rb', line 17195

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17197
17198
17199
# File 'lib/models/porcelain.rb', line 17197

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17199
17200
17201
# File 'lib/models/porcelain.rb', line 17199

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



17201
17202
17203
# File 'lib/models/porcelain.rb', line 17201

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17203
17204
17205
# File 'lib/models/porcelain.rb', line 17203

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17205
17206
17207
# File 'lib/models/porcelain.rb', line 17205

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17207
17208
17209
# File 'lib/models/porcelain.rb', line 17207

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



17209
17210
17211
# File 'lib/models/porcelain.rb', line 17209

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



17211
17212
17213
# File 'lib/models/porcelain.rb', line 17211

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17251
17252
17253
17254
17255
17256
17257
# File 'lib/models/porcelain.rb', line 17251

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end