Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



16914
16915
16916
16917
16918
16919
16920
16921
16922
16923
16924
16925
16926
16927
16928
16929
16930
16931
16932
16933
16934
16935
16936
16937
16938
16939
16940
16941
16942
16943
16944
16945
16946
16947
16948
16949
16950
# File 'lib/models/porcelain.rb', line 16914

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16880
16881
16882
# File 'lib/models/porcelain.rb', line 16880

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



16882
16883
16884
# File 'lib/models/porcelain.rb', line 16882

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16884
16885
16886
# File 'lib/models/porcelain.rb', line 16884

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16886
16887
16888
# File 'lib/models/porcelain.rb', line 16886

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16888
16889
16890
# File 'lib/models/porcelain.rb', line 16888

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16890
16891
16892
# File 'lib/models/porcelain.rb', line 16890

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



16892
16893
16894
# File 'lib/models/porcelain.rb', line 16892

def name
  @name
end

#passwordObject

The password to authenticate with.



16894
16895
16896
# File 'lib/models/porcelain.rb', line 16894

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16896
16897
16898
# File 'lib/models/porcelain.rb', line 16896

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16898
16899
16900
# File 'lib/models/porcelain.rb', line 16898

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16900
16901
16902
# File 'lib/models/porcelain.rb', line 16900

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



16902
16903
16904
# File 'lib/models/porcelain.rb', line 16902

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16904
16905
16906
# File 'lib/models/porcelain.rb', line 16904

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16906
16907
16908
# File 'lib/models/porcelain.rb', line 16906

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16908
16909
16910
# File 'lib/models/porcelain.rb', line 16908

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



16910
16911
16912
# File 'lib/models/porcelain.rb', line 16910

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



16912
16913
16914
# File 'lib/models/porcelain.rb', line 16912

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16952
16953
16954
16955
16956
16957
16958
# File 'lib/models/porcelain.rb', line 16952

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end