Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



16840
16841
16842
16843
16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
16870
16871
16872
16873
16874
16875
16876
# File 'lib/models/porcelain.rb', line 16840

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16806
16807
16808
# File 'lib/models/porcelain.rb', line 16806

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



16808
16809
16810
# File 'lib/models/porcelain.rb', line 16808

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16810
16811
16812
# File 'lib/models/porcelain.rb', line 16810

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16812
16813
16814
# File 'lib/models/porcelain.rb', line 16812

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16814
16815
16816
# File 'lib/models/porcelain.rb', line 16814

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16816
16817
16818
# File 'lib/models/porcelain.rb', line 16816

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



16818
16819
16820
# File 'lib/models/porcelain.rb', line 16818

def name
  @name
end

#passwordObject

The password to authenticate with.



16820
16821
16822
# File 'lib/models/porcelain.rb', line 16820

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16822
16823
16824
# File 'lib/models/porcelain.rb', line 16822

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16824
16825
16826
# File 'lib/models/porcelain.rb', line 16824

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16826
16827
16828
# File 'lib/models/porcelain.rb', line 16826

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



16828
16829
16830
# File 'lib/models/porcelain.rb', line 16828

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16830
16831
16832
# File 'lib/models/porcelain.rb', line 16830

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16832
16833
16834
# File 'lib/models/porcelain.rb', line 16832

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16834
16835
16836
# File 'lib/models/porcelain.rb', line 16834

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



16836
16837
16838
# File 'lib/models/porcelain.rb', line 16836

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



16838
16839
16840
# File 'lib/models/porcelain.rb', line 16838

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16878
16879
16880
16881
16882
16883
16884
# File 'lib/models/porcelain.rb', line 16878

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end