Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



16538
16539
16540
16541
16542
16543
16544
16545
16546
16547
16548
16549
16550
16551
16552
16553
16554
16555
16556
16557
16558
16559
16560
16561
16562
16563
16564
16565
16566
16567
16568
16569
16570
16571
16572
16573
16574
# File 'lib/models/porcelain.rb', line 16538

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16504
16505
16506
# File 'lib/models/porcelain.rb', line 16504

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



16506
16507
16508
# File 'lib/models/porcelain.rb', line 16506

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16508
16509
16510
# File 'lib/models/porcelain.rb', line 16508

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16510
16511
16512
# File 'lib/models/porcelain.rb', line 16510

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16512
16513
16514
# File 'lib/models/porcelain.rb', line 16512

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16514
16515
16516
# File 'lib/models/porcelain.rb', line 16514

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



16516
16517
16518
# File 'lib/models/porcelain.rb', line 16516

def name
  @name
end

#passwordObject

The password to authenticate with.



16518
16519
16520
# File 'lib/models/porcelain.rb', line 16518

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16520
16521
16522
# File 'lib/models/porcelain.rb', line 16520

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16522
16523
16524
# File 'lib/models/porcelain.rb', line 16522

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16524
16525
16526
# File 'lib/models/porcelain.rb', line 16524

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



16526
16527
16528
# File 'lib/models/porcelain.rb', line 16526

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16528
16529
16530
# File 'lib/models/porcelain.rb', line 16528

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16530
16531
16532
# File 'lib/models/porcelain.rb', line 16530

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16532
16533
16534
# File 'lib/models/porcelain.rb', line 16532

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



16534
16535
16536
# File 'lib/models/porcelain.rb', line 16534

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



16536
16537
16538
# File 'lib/models/porcelain.rb', line 16536

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16576
16577
16578
16579
16580
16581
16582
# File 'lib/models/porcelain.rb', line 16576

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end