Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



14352
14353
14354
14355
14356
14357
14358
14359
14360
14361
14362
14363
14364
14365
14366
14367
14368
14369
14370
14371
14372
14373
14374
14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
# File 'lib/models/porcelain.rb', line 14352

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14318
14319
14320
# File 'lib/models/porcelain.rb', line 14318

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



14320
14321
14322
# File 'lib/models/porcelain.rb', line 14320

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14322
14323
14324
# File 'lib/models/porcelain.rb', line 14322

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14324
14325
14326
# File 'lib/models/porcelain.rb', line 14324

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14326
14327
14328
# File 'lib/models/porcelain.rb', line 14326

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14328
14329
14330
# File 'lib/models/porcelain.rb', line 14328

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14330
14331
14332
# File 'lib/models/porcelain.rb', line 14330

def name
  @name
end

#passwordObject

The password to authenticate with.



14332
14333
14334
# File 'lib/models/porcelain.rb', line 14332

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14334
14335
14336
# File 'lib/models/porcelain.rb', line 14334

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14336
14337
14338
# File 'lib/models/porcelain.rb', line 14336

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14338
14339
14340
# File 'lib/models/porcelain.rb', line 14338

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



14340
14341
14342
# File 'lib/models/porcelain.rb', line 14340

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14342
14343
14344
# File 'lib/models/porcelain.rb', line 14342

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14344
14345
14346
# File 'lib/models/porcelain.rb', line 14344

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14346
14347
14348
# File 'lib/models/porcelain.rb', line 14346

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



14348
14349
14350
# File 'lib/models/porcelain.rb', line 14348

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



14350
14351
14352
# File 'lib/models/porcelain.rb', line 14350

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14390
14391
14392
14393
14394
14395
14396
# File 'lib/models/porcelain.rb', line 14390

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end