Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



14090
14091
14092
14093
14094
14095
14096
14097
14098
14099
14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'lib/models/porcelain.rb', line 14090

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14056
14057
14058
# File 'lib/models/porcelain.rb', line 14056

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



14058
14059
14060
# File 'lib/models/porcelain.rb', line 14058

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14060
14061
14062
# File 'lib/models/porcelain.rb', line 14060

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14062
14063
14064
# File 'lib/models/porcelain.rb', line 14062

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14064
14065
14066
# File 'lib/models/porcelain.rb', line 14064

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14066
14067
14068
# File 'lib/models/porcelain.rb', line 14066

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14068
14069
14070
# File 'lib/models/porcelain.rb', line 14068

def name
  @name
end

#passwordObject

The password to authenticate with.



14070
14071
14072
# File 'lib/models/porcelain.rb', line 14070

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14072
14073
14074
# File 'lib/models/porcelain.rb', line 14072

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14074
14075
14076
# File 'lib/models/porcelain.rb', line 14074

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14076
14077
14078
# File 'lib/models/porcelain.rb', line 14076

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



14078
14079
14080
# File 'lib/models/porcelain.rb', line 14078

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14080
14081
14082
# File 'lib/models/porcelain.rb', line 14080

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14082
14083
14084
# File 'lib/models/porcelain.rb', line 14082

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14084
14085
14086
# File 'lib/models/porcelain.rb', line 14084

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



14086
14087
14088
# File 'lib/models/porcelain.rb', line 14086

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



14088
14089
14090
# File 'lib/models/porcelain.rb', line 14088

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14128
14129
14130
14131
14132
14133
14134
# File 'lib/models/porcelain.rb', line 14128

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end