Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



14017
14018
14019
14020
14021
14022
14023
14024
14025
14026
14027
14028
14029
14030
14031
14032
14033
14034
14035
14036
14037
14038
14039
14040
14041
14042
14043
14044
14045
14046
14047
14048
14049
14050
14051
14052
14053
# File 'lib/models/porcelain.rb', line 14017

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13983
13984
13985
# File 'lib/models/porcelain.rb', line 13983

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



13985
13986
13987
# File 'lib/models/porcelain.rb', line 13985

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13987
13988
13989
# File 'lib/models/porcelain.rb', line 13987

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13989
13990
13991
# File 'lib/models/porcelain.rb', line 13989

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13991
13992
13993
# File 'lib/models/porcelain.rb', line 13991

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13993
13994
13995
# File 'lib/models/porcelain.rb', line 13993

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13995
13996
13997
# File 'lib/models/porcelain.rb', line 13995

def name
  @name
end

#passwordObject

The password to authenticate with.



13997
13998
13999
# File 'lib/models/porcelain.rb', line 13997

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13999
14000
14001
# File 'lib/models/porcelain.rb', line 13999

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14001
14002
14003
# File 'lib/models/porcelain.rb', line 14001

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14003
14004
14005
# File 'lib/models/porcelain.rb', line 14003

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



14005
14006
14007
# File 'lib/models/porcelain.rb', line 14005

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14007
14008
14009
# File 'lib/models/porcelain.rb', line 14007

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14009
14010
14011
# File 'lib/models/porcelain.rb', line 14009

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14011
14012
14013
# File 'lib/models/porcelain.rb', line 14011

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



14013
14014
14015
# File 'lib/models/porcelain.rb', line 14013

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



14015
14016
14017
# File 'lib/models/porcelain.rb', line 14015

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14055
14056
14057
14058
14059
14060
14061
# File 'lib/models/porcelain.rb', line 14055

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end