Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



13949
13950
13951
13952
13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
13966
13967
13968
13969
13970
13971
13972
13973
13974
13975
13976
13977
13978
13979
13980
13981
13982
13983
13984
13985
# File 'lib/models/porcelain.rb', line 13949

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13915
13916
13917
# File 'lib/models/porcelain.rb', line 13915

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



13917
13918
13919
# File 'lib/models/porcelain.rb', line 13917

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13919
13920
13921
# File 'lib/models/porcelain.rb', line 13919

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13921
13922
13923
# File 'lib/models/porcelain.rb', line 13921

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13923
13924
13925
# File 'lib/models/porcelain.rb', line 13923

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13925
13926
13927
# File 'lib/models/porcelain.rb', line 13925

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13927
13928
13929
# File 'lib/models/porcelain.rb', line 13927

def name
  @name
end

#passwordObject

The password to authenticate with.



13929
13930
13931
# File 'lib/models/porcelain.rb', line 13929

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13931
13932
13933
# File 'lib/models/porcelain.rb', line 13931

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



13933
13934
13935
# File 'lib/models/porcelain.rb', line 13933

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13935
13936
13937
# File 'lib/models/porcelain.rb', line 13935

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



13937
13938
13939
# File 'lib/models/porcelain.rb', line 13937

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13939
13940
13941
# File 'lib/models/porcelain.rb', line 13939

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13941
13942
13943
# File 'lib/models/porcelain.rb', line 13941

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13943
13944
13945
# File 'lib/models/porcelain.rb', line 13943

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



13945
13946
13947
# File 'lib/models/porcelain.rb', line 13945

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



13947
13948
13949
# File 'lib/models/porcelain.rb', line 13947

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13987
13988
13989
13990
13991
13992
13993
# File 'lib/models/porcelain.rb', line 13987

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end