Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



12443
12444
12445
12446
12447
12448
12449
12450
12451
12452
12453
12454
12455
12456
12457
12458
12459
12460
12461
12462
12463
12464
12465
12466
12467
12468
12469
12470
12471
12472
12473
12474
12475
12476
12477
12478
12479
# File 'lib/models/porcelain.rb', line 12443

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12409
12410
12411
# File 'lib/models/porcelain.rb', line 12409

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



12411
12412
12413
# File 'lib/models/porcelain.rb', line 12411

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12413
12414
12415
# File 'lib/models/porcelain.rb', line 12413

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12415
12416
12417
# File 'lib/models/porcelain.rb', line 12415

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12417
12418
12419
# File 'lib/models/porcelain.rb', line 12417

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12419
12420
12421
# File 'lib/models/porcelain.rb', line 12419

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12421
12422
12423
# File 'lib/models/porcelain.rb', line 12421

def name
  @name
end

#passwordObject

The password to authenticate with.



12423
12424
12425
# File 'lib/models/porcelain.rb', line 12423

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12425
12426
12427
# File 'lib/models/porcelain.rb', line 12425

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12427
12428
12429
# File 'lib/models/porcelain.rb', line 12427

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12429
12430
12431
# File 'lib/models/porcelain.rb', line 12429

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



12431
12432
12433
# File 'lib/models/porcelain.rb', line 12431

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12433
12434
12435
# File 'lib/models/porcelain.rb', line 12433

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12435
12436
12437
# File 'lib/models/porcelain.rb', line 12435

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12437
12438
12439
# File 'lib/models/porcelain.rb', line 12437

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



12439
12440
12441
# File 'lib/models/porcelain.rb', line 12439

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



12441
12442
12443
# File 'lib/models/porcelain.rb', line 12441

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12481
12482
12483
12484
12485
12486
12487
# File 'lib/models/porcelain.rb', line 12481

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end