Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
# File 'lib/models/porcelain.rb', line 12363

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12329
12330
12331
# File 'lib/models/porcelain.rb', line 12329

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



12331
12332
12333
# File 'lib/models/porcelain.rb', line 12331

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12333
12334
12335
# File 'lib/models/porcelain.rb', line 12333

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12335
12336
12337
# File 'lib/models/porcelain.rb', line 12335

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12337
12338
12339
# File 'lib/models/porcelain.rb', line 12337

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12339
12340
12341
# File 'lib/models/porcelain.rb', line 12339

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12341
12342
12343
# File 'lib/models/porcelain.rb', line 12341

def name
  @name
end

#passwordObject

The password to authenticate with.



12343
12344
12345
# File 'lib/models/porcelain.rb', line 12343

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12345
12346
12347
# File 'lib/models/porcelain.rb', line 12345

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12347
12348
12349
# File 'lib/models/porcelain.rb', line 12347

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12349
12350
12351
# File 'lib/models/porcelain.rb', line 12349

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



12351
12352
12353
# File 'lib/models/porcelain.rb', line 12351

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12353
12354
12355
# File 'lib/models/porcelain.rb', line 12353

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12355
12356
12357
# File 'lib/models/porcelain.rb', line 12355

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12357
12358
12359
# File 'lib/models/porcelain.rb', line 12357

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



12359
12360
12361
# File 'lib/models/porcelain.rb', line 12359

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



12361
12362
12363
# File 'lib/models/porcelain.rb', line 12361

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12401
12402
12403
12404
12405
12406
12407
# File 'lib/models/porcelain.rb', line 12401

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end