Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



12226
12227
12228
12229
12230
12231
12232
12233
12234
12235
12236
12237
12238
12239
12240
12241
12242
12243
12244
12245
12246
12247
12248
12249
12250
12251
12252
12253
12254
12255
12256
12257
12258
12259
12260
12261
12262
# File 'lib/models/porcelain.rb', line 12226

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12192
12193
12194
# File 'lib/models/porcelain.rb', line 12192

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



12194
12195
12196
# File 'lib/models/porcelain.rb', line 12194

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12196
12197
12198
# File 'lib/models/porcelain.rb', line 12196

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12198
12199
12200
# File 'lib/models/porcelain.rb', line 12198

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12200
12201
12202
# File 'lib/models/porcelain.rb', line 12200

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12202
12203
12204
# File 'lib/models/porcelain.rb', line 12202

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12204
12205
12206
# File 'lib/models/porcelain.rb', line 12204

def name
  @name
end

#passwordObject

The password to authenticate with.



12206
12207
12208
# File 'lib/models/porcelain.rb', line 12206

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12208
12209
12210
# File 'lib/models/porcelain.rb', line 12208

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12210
12211
12212
# File 'lib/models/porcelain.rb', line 12210

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12212
12213
12214
# File 'lib/models/porcelain.rb', line 12212

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



12214
12215
12216
# File 'lib/models/porcelain.rb', line 12214

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12216
12217
12218
# File 'lib/models/porcelain.rb', line 12216

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12218
12219
12220
# File 'lib/models/porcelain.rb', line 12218

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12220
12221
12222
# File 'lib/models/porcelain.rb', line 12220

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



12222
12223
12224
# File 'lib/models/porcelain.rb', line 12222

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



12224
12225
12226
# File 'lib/models/porcelain.rb', line 12224

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12264
12265
12266
12267
12268
12269
12270
# File 'lib/models/porcelain.rb', line 12264

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end