Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



11674
11675
11676
11677
11678
11679
11680
11681
11682
11683
11684
11685
11686
11687
11688
11689
11690
11691
11692
11693
11694
11695
11696
11697
11698
11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
11709
11710
# File 'lib/models/porcelain.rb', line 11674

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11640
11641
11642
# File 'lib/models/porcelain.rb', line 11640

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



11642
11643
11644
# File 'lib/models/porcelain.rb', line 11642

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11644
11645
11646
# File 'lib/models/porcelain.rb', line 11644

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11646
11647
11648
# File 'lib/models/porcelain.rb', line 11646

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11648
11649
11650
# File 'lib/models/porcelain.rb', line 11648

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11650
11651
11652
# File 'lib/models/porcelain.rb', line 11650

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11652
11653
11654
# File 'lib/models/porcelain.rb', line 11652

def name
  @name
end

#passwordObject

The password to authenticate with.



11654
11655
11656
# File 'lib/models/porcelain.rb', line 11654

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11656
11657
11658
# File 'lib/models/porcelain.rb', line 11656

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11658
11659
11660
# File 'lib/models/porcelain.rb', line 11658

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11660
11661
11662
# File 'lib/models/porcelain.rb', line 11660

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



11662
11663
11664
# File 'lib/models/porcelain.rb', line 11662

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11664
11665
11666
# File 'lib/models/porcelain.rb', line 11664

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11666
11667
11668
# File 'lib/models/porcelain.rb', line 11666

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11668
11669
11670
# File 'lib/models/porcelain.rb', line 11668

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



11670
11671
11672
# File 'lib/models/porcelain.rb', line 11670

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



11672
11673
11674
# File 'lib/models/porcelain.rb', line 11672

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11712
11713
11714
11715
11716
11717
11718
# File 'lib/models/porcelain.rb', line 11712

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end