Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



11603
11604
11605
11606
11607
11608
11609
11610
11611
11612
11613
11614
11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
11626
11627
11628
11629
11630
11631
11632
11633
11634
11635
11636
11637
11638
11639
# File 'lib/models/porcelain.rb', line 11603

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11569
11570
11571
# File 'lib/models/porcelain.rb', line 11569

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



11571
11572
11573
# File 'lib/models/porcelain.rb', line 11571

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11573
11574
11575
# File 'lib/models/porcelain.rb', line 11573

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11575
11576
11577
# File 'lib/models/porcelain.rb', line 11575

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11577
11578
11579
# File 'lib/models/porcelain.rb', line 11577

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11579
11580
11581
# File 'lib/models/porcelain.rb', line 11579

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11581
11582
11583
# File 'lib/models/porcelain.rb', line 11581

def name
  @name
end

#passwordObject

The password to authenticate with.



11583
11584
11585
# File 'lib/models/porcelain.rb', line 11583

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11585
11586
11587
# File 'lib/models/porcelain.rb', line 11585

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11587
11588
11589
# File 'lib/models/porcelain.rb', line 11587

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11589
11590
11591
# File 'lib/models/porcelain.rb', line 11589

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



11591
11592
11593
# File 'lib/models/porcelain.rb', line 11591

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11593
11594
11595
# File 'lib/models/porcelain.rb', line 11593

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11595
11596
11597
# File 'lib/models/porcelain.rb', line 11595

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11597
11598
11599
# File 'lib/models/porcelain.rb', line 11597

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



11599
11600
11601
# File 'lib/models/porcelain.rb', line 11599

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



11601
11602
11603
# File 'lib/models/porcelain.rb', line 11601

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11641
11642
11643
11644
11645
11646
11647
# File 'lib/models/porcelain.rb', line 11641

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end