Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



11205
11206
11207
11208
11209
11210
11211
11212
11213
11214
11215
11216
11217
11218
11219
11220
11221
11222
11223
11224
11225
11226
11227
11228
11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
11239
# File 'lib/models/porcelain.rb', line 11205

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11173
11174
11175
# File 'lib/models/porcelain.rb', line 11173

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



11175
11176
11177
# File 'lib/models/porcelain.rb', line 11175

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11177
11178
11179
# File 'lib/models/porcelain.rb', line 11177

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11179
11180
11181
# File 'lib/models/porcelain.rb', line 11179

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11181
11182
11183
# File 'lib/models/porcelain.rb', line 11181

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11183
11184
11185
# File 'lib/models/porcelain.rb', line 11183

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11185
11186
11187
# File 'lib/models/porcelain.rb', line 11185

def name
  @name
end

#passwordObject

The password to authenticate with.



11187
11188
11189
# File 'lib/models/porcelain.rb', line 11187

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11189
11190
11191
# File 'lib/models/porcelain.rb', line 11189

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11191
11192
11193
# File 'lib/models/porcelain.rb', line 11191

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



11193
11194
11195
# File 'lib/models/porcelain.rb', line 11193

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11195
11196
11197
# File 'lib/models/porcelain.rb', line 11195

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11197
11198
11199
# File 'lib/models/porcelain.rb', line 11197

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11199
11200
11201
# File 'lib/models/porcelain.rb', line 11199

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



11201
11202
11203
# File 'lib/models/porcelain.rb', line 11201

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



11203
11204
11205
# File 'lib/models/porcelain.rb', line 11203

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11241
11242
11243
11244
11245
11246
11247
# File 'lib/models/porcelain.rb', line 11241

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end