Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



11032
11033
11034
11035
11036
11037
11038
11039
11040
11041
11042
11043
11044
11045
11046
11047
11048
11049
11050
11051
11052
11053
11054
11055
11056
11057
11058
11059
11060
11061
11062
11063
11064
11065
11066
# File 'lib/models/porcelain.rb', line 11032

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11000
11001
11002
# File 'lib/models/porcelain.rb', line 11000

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



11002
11003
11004
# File 'lib/models/porcelain.rb', line 11002

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11004
11005
11006
# File 'lib/models/porcelain.rb', line 11004

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11006
11007
11008
# File 'lib/models/porcelain.rb', line 11006

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11008
11009
11010
# File 'lib/models/porcelain.rb', line 11008

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11010
11011
11012
# File 'lib/models/porcelain.rb', line 11010

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11012
11013
11014
# File 'lib/models/porcelain.rb', line 11012

def name
  @name
end

#passwordObject

The password to authenticate with.



11014
11015
11016
# File 'lib/models/porcelain.rb', line 11014

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11016
11017
11018
# File 'lib/models/porcelain.rb', line 11016

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11018
11019
11020
# File 'lib/models/porcelain.rb', line 11018

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



11020
11021
11022
# File 'lib/models/porcelain.rb', line 11020

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11022
11023
11024
# File 'lib/models/porcelain.rb', line 11022

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11024
11025
11026
# File 'lib/models/porcelain.rb', line 11024

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11026
11027
11028
# File 'lib/models/porcelain.rb', line 11026

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



11028
11029
11030
# File 'lib/models/porcelain.rb', line 11028

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



11030
11031
11032
# File 'lib/models/porcelain.rb', line 11030

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11068
11069
11070
11071
11072
11073
11074
# File 'lib/models/porcelain.rb', line 11068

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end