Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



10867
10868
10869
10870
10871
10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
10900
10901
# File 'lib/models/porcelain.rb', line 10867

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10835
10836
10837
# File 'lib/models/porcelain.rb', line 10835

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



10837
10838
10839
# File 'lib/models/porcelain.rb', line 10837

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10839
10840
10841
# File 'lib/models/porcelain.rb', line 10839

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10841
10842
10843
# File 'lib/models/porcelain.rb', line 10841

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10843
10844
10845
# File 'lib/models/porcelain.rb', line 10843

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10845
10846
10847
# File 'lib/models/porcelain.rb', line 10845

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10847
10848
10849
# File 'lib/models/porcelain.rb', line 10847

def name
  @name
end

#passwordObject

The password to authenticate with.



10849
10850
10851
# File 'lib/models/porcelain.rb', line 10849

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10851
10852
10853
# File 'lib/models/porcelain.rb', line 10851

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10853
10854
10855
# File 'lib/models/porcelain.rb', line 10853

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10855
10856
10857
# File 'lib/models/porcelain.rb', line 10855

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10857
10858
10859
# File 'lib/models/porcelain.rb', line 10857

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10859
10860
10861
# File 'lib/models/porcelain.rb', line 10859

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10861
10862
10863
# File 'lib/models/porcelain.rb', line 10861

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



10863
10864
10865
# File 'lib/models/porcelain.rb', line 10863

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



10865
10866
10867
# File 'lib/models/porcelain.rb', line 10865

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10903
10904
10905
10906
10907
10908
10909
# File 'lib/models/porcelain.rb', line 10903

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end