Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



10648
10649
10650
10651
10652
10653
10654
10655
10656
10657
10658
10659
10660
10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
# File 'lib/models/porcelain.rb', line 10648

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10616
10617
10618
# File 'lib/models/porcelain.rb', line 10616

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



10618
10619
10620
# File 'lib/models/porcelain.rb', line 10618

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10620
10621
10622
# File 'lib/models/porcelain.rb', line 10620

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10622
10623
10624
# File 'lib/models/porcelain.rb', line 10622

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10624
10625
10626
# File 'lib/models/porcelain.rb', line 10624

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10626
10627
10628
# File 'lib/models/porcelain.rb', line 10626

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10628
10629
10630
# File 'lib/models/porcelain.rb', line 10628

def name
  @name
end

#passwordObject

The password to authenticate with.



10630
10631
10632
# File 'lib/models/porcelain.rb', line 10630

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10632
10633
10634
# File 'lib/models/porcelain.rb', line 10632

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10634
10635
10636
# File 'lib/models/porcelain.rb', line 10634

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10636
10637
10638
# File 'lib/models/porcelain.rb', line 10636

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10638
10639
10640
# File 'lib/models/porcelain.rb', line 10638

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10640
10641
10642
# File 'lib/models/porcelain.rb', line 10640

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10642
10643
10644
# File 'lib/models/porcelain.rb', line 10642

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



10644
10645
10646
# File 'lib/models/porcelain.rb', line 10644

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



10646
10647
10648
# File 'lib/models/porcelain.rb', line 10646

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10684
10685
10686
10687
10688
10689
10690
# File 'lib/models/porcelain.rb', line 10684

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end