Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



10564
10565
10566
10567
10568
10569
10570
10571
10572
10573
10574
10575
10576
10577
10578
10579
10580
10581
10582
10583
10584
10585
10586
10587
10588
10589
10590
10591
10592
10593
10594
10595
10596
10597
10598
# File 'lib/models/porcelain.rb', line 10564

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10532
10533
10534
# File 'lib/models/porcelain.rb', line 10532

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



10534
10535
10536
# File 'lib/models/porcelain.rb', line 10534

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10536
10537
10538
# File 'lib/models/porcelain.rb', line 10536

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10538
10539
10540
# File 'lib/models/porcelain.rb', line 10538

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10540
10541
10542
# File 'lib/models/porcelain.rb', line 10540

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10542
10543
10544
# File 'lib/models/porcelain.rb', line 10542

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10544
10545
10546
# File 'lib/models/porcelain.rb', line 10544

def name
  @name
end

#passwordObject

The password to authenticate with.



10546
10547
10548
# File 'lib/models/porcelain.rb', line 10546

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10548
10549
10550
# File 'lib/models/porcelain.rb', line 10548

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10550
10551
10552
# File 'lib/models/porcelain.rb', line 10550

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10552
10553
10554
# File 'lib/models/porcelain.rb', line 10552

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10554
10555
10556
# File 'lib/models/porcelain.rb', line 10554

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10556
10557
10558
# File 'lib/models/porcelain.rb', line 10556

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10558
10559
10560
# File 'lib/models/porcelain.rb', line 10558

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



10560
10561
10562
# File 'lib/models/porcelain.rb', line 10560

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



10562
10563
10564
# File 'lib/models/porcelain.rb', line 10562

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10600
10601
10602
10603
10604
10605
10606
# File 'lib/models/porcelain.rb', line 10600

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end