Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



9461
9462
9463
9464
9465
9466
9467
9468
9469
9470
9471
9472
9473
9474
9475
9476
9477
9478
9479
9480
9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
# File 'lib/models/porcelain.rb', line 9461

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9429
9430
9431
# File 'lib/models/porcelain.rb', line 9429

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



9431
9432
9433
# File 'lib/models/porcelain.rb', line 9431

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9433
9434
9435
# File 'lib/models/porcelain.rb', line 9433

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9435
9436
9437
# File 'lib/models/porcelain.rb', line 9435

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9437
9438
9439
# File 'lib/models/porcelain.rb', line 9437

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9439
9440
9441
# File 'lib/models/porcelain.rb', line 9439

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9441
9442
9443
# File 'lib/models/porcelain.rb', line 9441

def name
  @name
end

#passwordObject

The password to authenticate with.



9443
9444
9445
# File 'lib/models/porcelain.rb', line 9443

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9445
9446
9447
# File 'lib/models/porcelain.rb', line 9445

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9447
9448
9449
# File 'lib/models/porcelain.rb', line 9447

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



9449
9450
9451
# File 'lib/models/porcelain.rb', line 9449

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9451
9452
9453
# File 'lib/models/porcelain.rb', line 9451

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9453
9454
9455
# File 'lib/models/porcelain.rb', line 9453

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9455
9456
9457
# File 'lib/models/porcelain.rb', line 9455

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



9457
9458
9459
# File 'lib/models/porcelain.rb', line 9457

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



9459
9460
9461
# File 'lib/models/porcelain.rb', line 9459

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9497
9498
9499
9500
9501
9502
9503
# File 'lib/models/porcelain.rb', line 9497

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end