Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
8708
8709
8710
8711
8712
8713
# File 'lib/models/porcelain.rb', line 8679

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8647
8648
8649
# File 'lib/models/porcelain.rb', line 8647

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8649
8650
8651
# File 'lib/models/porcelain.rb', line 8649

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8651
8652
8653
# File 'lib/models/porcelain.rb', line 8651

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8653
8654
8655
# File 'lib/models/porcelain.rb', line 8653

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8655
8656
8657
# File 'lib/models/porcelain.rb', line 8655

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8657
8658
8659
# File 'lib/models/porcelain.rb', line 8657

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8659
8660
8661
# File 'lib/models/porcelain.rb', line 8659

def name
  @name
end

#passwordObject

The password to authenticate with.



8661
8662
8663
# File 'lib/models/porcelain.rb', line 8661

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8663
8664
8665
# File 'lib/models/porcelain.rb', line 8663

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8665
8666
8667
# File 'lib/models/porcelain.rb', line 8665

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



8667
8668
8669
# File 'lib/models/porcelain.rb', line 8667

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8669
8670
8671
# File 'lib/models/porcelain.rb', line 8669

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8671
8672
8673
# File 'lib/models/porcelain.rb', line 8671

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8673
8674
8675
# File 'lib/models/porcelain.rb', line 8673

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



8675
8676
8677
# File 'lib/models/porcelain.rb', line 8675

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



8677
8678
8679
# File 'lib/models/porcelain.rb', line 8677

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8715
8716
8717
8718
8719
8720
8721
# File 'lib/models/porcelain.rb', line 8715

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end