Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



8242
8243
8244
8245
8246
8247
8248
8249
8250
8251
8252
8253
8254
8255
8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
# File 'lib/models/porcelain.rb', line 8242

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8210
8211
8212
# File 'lib/models/porcelain.rb', line 8210

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8212
8213
8214
# File 'lib/models/porcelain.rb', line 8212

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8214
8215
8216
# File 'lib/models/porcelain.rb', line 8214

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8216
8217
8218
# File 'lib/models/porcelain.rb', line 8216

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8218
8219
8220
# File 'lib/models/porcelain.rb', line 8218

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8220
8221
8222
# File 'lib/models/porcelain.rb', line 8220

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8222
8223
8224
# File 'lib/models/porcelain.rb', line 8222

def name
  @name
end

#passwordObject

The password to authenticate with.



8224
8225
8226
# File 'lib/models/porcelain.rb', line 8224

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8226
8227
8228
# File 'lib/models/porcelain.rb', line 8226

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8228
8229
8230
# File 'lib/models/porcelain.rb', line 8228

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



8230
8231
8232
# File 'lib/models/porcelain.rb', line 8230

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8232
8233
8234
# File 'lib/models/porcelain.rb', line 8232

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8234
8235
8236
# File 'lib/models/porcelain.rb', line 8234

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8236
8237
8238
# File 'lib/models/porcelain.rb', line 8236

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



8238
8239
8240
# File 'lib/models/porcelain.rb', line 8238

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



8240
8241
8242
# File 'lib/models/porcelain.rb', line 8240

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8278
8279
8280
8281
8282
8283
8284
# File 'lib/models/porcelain.rb', line 8278

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end