Class: SDM::SingleStore
- Inherits:
-
Object
- Object
- SDM::SingleStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#require_native_auth ⇒ Object
Returns the value of attribute require_native_auth.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_azure_single_server_usernames ⇒ Object
Returns the value of attribute use_azure_single_server_usernames.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore
constructor
A new instance of SingleStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore
Returns a new instance of SingleStore.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 8092 8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/models/porcelain.rb', line 8067 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @require_native_auth = require_native_auth == nil ? false : require_native_auth @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
8035 8036 8037 |
# File 'lib/models/porcelain.rb', line 8035 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
8037 8038 8039 |
# File 'lib/models/porcelain.rb', line 8037 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8039 8040 8041 |
# File 'lib/models/porcelain.rb', line 8039 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8041 8042 8043 |
# File 'lib/models/porcelain.rb', line 8041 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
8043 8044 8045 |
# File 'lib/models/porcelain.rb', line 8043 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8045 8046 8047 |
# File 'lib/models/porcelain.rb', line 8045 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8047 8048 8049 |
# File 'lib/models/porcelain.rb', line 8047 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
8049 8050 8051 |
# File 'lib/models/porcelain.rb', line 8049 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
8051 8052 8053 |
# File 'lib/models/porcelain.rb', line 8051 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
8053 8054 8055 |
# File 'lib/models/porcelain.rb', line 8053 def port_override @port_override end |
#require_native_auth ⇒ Object
Returns the value of attribute require_native_auth.
8055 8056 8057 |
# File 'lib/models/porcelain.rb', line 8055 def require_native_auth @require_native_auth end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8057 8058 8059 |
# File 'lib/models/porcelain.rb', line 8057 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8059 8060 8061 |
# File 'lib/models/porcelain.rb', line 8059 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8061 8062 8063 |
# File 'lib/models/porcelain.rb', line 8061 def @tags end |
#use_azure_single_server_usernames ⇒ Object
Returns the value of attribute use_azure_single_server_usernames.
8063 8064 8065 |
# File 'lib/models/porcelain.rb', line 8063 def use_azure_single_server_usernames @use_azure_single_server_usernames end |
#username ⇒ Object
Returns the value of attribute username.
8065 8066 8067 |
# File 'lib/models/porcelain.rb', line 8065 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8103 8104 8105 8106 8107 8108 8109 |
# File 'lib/models/porcelain.rb', line 8103 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |