Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



8007
8008
8009
8010
8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
8037
# File 'lib/models/porcelain.rb', line 8007

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



7979
7980
7981
# File 'lib/models/porcelain.rb', line 7979

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



7981
7982
7983
# File 'lib/models/porcelain.rb', line 7981

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7983
7984
7985
# File 'lib/models/porcelain.rb', line 7983

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7985
7986
7987
# File 'lib/models/porcelain.rb', line 7985

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7987
7988
7989
# File 'lib/models/porcelain.rb', line 7987

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7989
7990
7991
# File 'lib/models/porcelain.rb', line 7989

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7991
7992
7993
# File 'lib/models/porcelain.rb', line 7991

def name
  @name
end

#passwordObject

Returns the value of attribute password.



7993
7994
7995
# File 'lib/models/porcelain.rb', line 7993

def password
  @password
end

#portObject

Returns the value of attribute port.



7995
7996
7997
# File 'lib/models/porcelain.rb', line 7995

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



7997
7998
7999
# File 'lib/models/porcelain.rb', line 7997

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7999
8000
8001
# File 'lib/models/porcelain.rb', line 7999

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8001
8002
8003
# File 'lib/models/porcelain.rb', line 8001

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8003
8004
8005
# File 'lib/models/porcelain.rb', line 8003

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



8005
8006
8007
# File 'lib/models/porcelain.rb', line 8005

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8039
8040
8041
8042
8043
8044
8045
# File 'lib/models/porcelain.rb', line 8039

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end