Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
7861
7862
7863
# File 'lib/models/porcelain.rb', line 7833

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



7805
7806
7807
# File 'lib/models/porcelain.rb', line 7805

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



7807
7808
7809
# File 'lib/models/porcelain.rb', line 7807

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7809
7810
7811
# File 'lib/models/porcelain.rb', line 7809

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7811
7812
7813
# File 'lib/models/porcelain.rb', line 7811

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7813
7814
7815
# File 'lib/models/porcelain.rb', line 7813

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7815
7816
7817
# File 'lib/models/porcelain.rb', line 7815

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7817
7818
7819
# File 'lib/models/porcelain.rb', line 7817

def name
  @name
end

#passwordObject

Returns the value of attribute password.



7819
7820
7821
# File 'lib/models/porcelain.rb', line 7819

def password
  @password
end

#portObject

Returns the value of attribute port.



7821
7822
7823
# File 'lib/models/porcelain.rb', line 7821

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



7823
7824
7825
# File 'lib/models/porcelain.rb', line 7823

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7825
7826
7827
# File 'lib/models/porcelain.rb', line 7825

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7827
7828
7829
# File 'lib/models/porcelain.rb', line 7827

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7829
7830
7831
# File 'lib/models/porcelain.rb', line 7829

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7831
7832
7833
# File 'lib/models/porcelain.rb', line 7831

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7865
7866
7867
7868
7869
7870
7871
# File 'lib/models/porcelain.rb', line 7865

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end