Class: SDM::SingleStore
- Inherits:
-
Object
- Object
- SDM::SingleStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SingleStore
constructor
A new instance of SingleStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SingleStore
Returns a new instance of SingleStore.
7334 7335 7336 7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 7352 7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 |
# File 'lib/models/porcelain.rb', line 7334 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7308 7309 7310 |
# File 'lib/models/porcelain.rb', line 7308 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
7310 7311 7312 |
# File 'lib/models/porcelain.rb', line 7310 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7312 7313 7314 |
# File 'lib/models/porcelain.rb', line 7312 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7314 7315 7316 |
# File 'lib/models/porcelain.rb', line 7314 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7316 7317 7318 |
# File 'lib/models/porcelain.rb', line 7316 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7318 7319 7320 |
# File 'lib/models/porcelain.rb', line 7318 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7320 7321 7322 |
# File 'lib/models/porcelain.rb', line 7320 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
7322 7323 7324 |
# File 'lib/models/porcelain.rb', line 7322 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
7324 7325 7326 |
# File 'lib/models/porcelain.rb', line 7324 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7326 7327 7328 |
# File 'lib/models/porcelain.rb', line 7326 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7328 7329 7330 |
# File 'lib/models/porcelain.rb', line 7328 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7330 7331 7332 |
# File 'lib/models/porcelain.rb', line 7330 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7332 7333 7334 |
# File 'lib/models/porcelain.rb', line 7332 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7364 7365 7366 7367 7368 7369 7370 |
# File 'lib/models/porcelain.rb', line 7364 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |