Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
6434
6435
6436
6437
6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
# File 'lib/models/porcelain.rb', line 6422

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



6396
6397
6398
# File 'lib/models/porcelain.rb', line 6396

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



6398
6399
6400
# File 'lib/models/porcelain.rb', line 6398

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6400
6401
6402
# File 'lib/models/porcelain.rb', line 6400

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6402
6403
6404
# File 'lib/models/porcelain.rb', line 6402

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6404
6405
6406
# File 'lib/models/porcelain.rb', line 6404

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6406
6407
6408
# File 'lib/models/porcelain.rb', line 6406

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6408
6409
6410
# File 'lib/models/porcelain.rb', line 6408

def name
  @name
end

#passwordObject

Returns the value of attribute password.



6410
6411
6412
# File 'lib/models/porcelain.rb', line 6410

def password
  @password
end

#portObject

Returns the value of attribute port.



6412
6413
6414
# File 'lib/models/porcelain.rb', line 6412

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



6414
6415
6416
# File 'lib/models/porcelain.rb', line 6414

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6416
6417
6418
# File 'lib/models/porcelain.rb', line 6416

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6418
6419
6420
# File 'lib/models/porcelain.rb', line 6418

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6420
6421
6422
# File 'lib/models/porcelain.rb', line 6420

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6452
6453
6454
6455
6456
6457
6458
# File 'lib/models/porcelain.rb', line 6452

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end