Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
6434
6435
6436
6437
6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
# File 'lib/models/porcelain.rb', line 6423

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



6397
6398
6399
# File 'lib/models/porcelain.rb', line 6397

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



6399
6400
6401
# File 'lib/models/porcelain.rb', line 6399

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6401
6402
6403
# File 'lib/models/porcelain.rb', line 6401

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6403
6404
6405
# File 'lib/models/porcelain.rb', line 6403

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6405
6406
6407
# File 'lib/models/porcelain.rb', line 6405

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6407
6408
6409
# File 'lib/models/porcelain.rb', line 6407

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6409
6410
6411
# File 'lib/models/porcelain.rb', line 6409

def name
  @name
end

#passwordObject

Returns the value of attribute password.



6411
6412
6413
# File 'lib/models/porcelain.rb', line 6411

def password
  @password
end

#portObject

Returns the value of attribute port.



6413
6414
6415
# File 'lib/models/porcelain.rb', line 6413

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



6415
6416
6417
# File 'lib/models/porcelain.rb', line 6415

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6417
6418
6419
# File 'lib/models/porcelain.rb', line 6417

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6419
6420
6421
# File 'lib/models/porcelain.rb', line 6419

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6421
6422
6423
# File 'lib/models/porcelain.rb', line 6421

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6453
6454
6455
6456
6457
6458
6459
# File 'lib/models/porcelain.rb', line 6453

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end