Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
6359
6360
6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
# File 'lib/models/porcelain.rb', line 6346

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



6320
6321
6322
# File 'lib/models/porcelain.rb', line 6320

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



6322
6323
6324
# File 'lib/models/porcelain.rb', line 6322

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6324
6325
6326
# File 'lib/models/porcelain.rb', line 6324

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6326
6327
6328
# File 'lib/models/porcelain.rb', line 6326

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6328
6329
6330
# File 'lib/models/porcelain.rb', line 6328

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6330
6331
6332
# File 'lib/models/porcelain.rb', line 6330

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6332
6333
6334
# File 'lib/models/porcelain.rb', line 6332

def name
  @name
end

#passwordObject

Returns the value of attribute password.



6334
6335
6336
# File 'lib/models/porcelain.rb', line 6334

def password
  @password
end

#portObject

Returns the value of attribute port.



6336
6337
6338
# File 'lib/models/porcelain.rb', line 6336

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



6338
6339
6340
# File 'lib/models/porcelain.rb', line 6338

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6340
6341
6342
# File 'lib/models/porcelain.rb', line 6340

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6342
6343
6344
# File 'lib/models/porcelain.rb', line 6342

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6344
6345
6346
# File 'lib/models/porcelain.rb', line 6344

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6376
6377
6378
6379
6380
6381
6382
# File 'lib/models/porcelain.rb', line 6376

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end