Class: SDM::SingleStore
- Inherits:
-
Object
- Object
- SDM::SingleStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SingleStore
constructor
A new instance of SingleStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SingleStore
Returns a new instance of SingleStore.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 |
# File 'lib/models/porcelain.rb', line 6315 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6289 6290 6291 |
# File 'lib/models/porcelain.rb', line 6289 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
6291 6292 6293 |
# File 'lib/models/porcelain.rb', line 6291 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6293 6294 6295 |
# File 'lib/models/porcelain.rb', line 6293 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6295 6296 6297 |
# File 'lib/models/porcelain.rb', line 6295 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6297 6298 6299 |
# File 'lib/models/porcelain.rb', line 6297 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6299 6300 6301 |
# File 'lib/models/porcelain.rb', line 6299 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6301 6302 6303 |
# File 'lib/models/porcelain.rb', line 6301 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6303 6304 6305 |
# File 'lib/models/porcelain.rb', line 6303 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6305 6306 6307 |
# File 'lib/models/porcelain.rb', line 6305 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6307 6308 6309 |
# File 'lib/models/porcelain.rb', line 6307 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6309 6310 6311 |
# File 'lib/models/porcelain.rb', line 6309 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6311 6312 6313 |
# File 'lib/models/porcelain.rb', line 6311 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6313 6314 6315 |
# File 'lib/models/porcelain.rb', line 6313 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6345 6346 6347 6348 6349 6350 6351 |
# File 'lib/models/porcelain.rb', line 6345 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |