Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
6328
6329
6330
6331
# File 'lib/models/porcelain.rb', line 6303

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



6277
6278
6279
# File 'lib/models/porcelain.rb', line 6277

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



6279
6280
6281
# File 'lib/models/porcelain.rb', line 6279

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6281
6282
6283
# File 'lib/models/porcelain.rb', line 6281

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6283
6284
6285
# File 'lib/models/porcelain.rb', line 6283

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6285
6286
6287
# File 'lib/models/porcelain.rb', line 6285

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6287
6288
6289
# File 'lib/models/porcelain.rb', line 6287

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6289
6290
6291
# File 'lib/models/porcelain.rb', line 6289

def name
  @name
end

#passwordObject

Returns the value of attribute password.



6291
6292
6293
# File 'lib/models/porcelain.rb', line 6291

def password
  @password
end

#portObject

Returns the value of attribute port.



6293
6294
6295
# File 'lib/models/porcelain.rb', line 6293

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



6295
6296
6297
# File 'lib/models/porcelain.rb', line 6295

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6297
6298
6299
# File 'lib/models/porcelain.rb', line 6297

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6299
6300
6301
# File 'lib/models/porcelain.rb', line 6299

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6301
6302
6303
# File 'lib/models/porcelain.rb', line 6301

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6333
6334
6335
6336
6337
6338
6339
# File 'lib/models/porcelain.rb', line 6333

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end