Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/models/porcelain.rb', line 6165

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



6139
6140
6141
# File 'lib/models/porcelain.rb', line 6139

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



6141
6142
6143
# File 'lib/models/porcelain.rb', line 6141

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6143
6144
6145
# File 'lib/models/porcelain.rb', line 6143

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6145
6146
6147
# File 'lib/models/porcelain.rb', line 6145

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6147
6148
6149
# File 'lib/models/porcelain.rb', line 6147

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6149
6150
6151
# File 'lib/models/porcelain.rb', line 6149

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6151
6152
6153
# File 'lib/models/porcelain.rb', line 6151

def name
  @name
end

#passwordObject

Returns the value of attribute password.



6153
6154
6155
# File 'lib/models/porcelain.rb', line 6153

def password
  @password
end

#portObject

Returns the value of attribute port.



6155
6156
6157
# File 'lib/models/porcelain.rb', line 6155

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



6157
6158
6159
# File 'lib/models/porcelain.rb', line 6157

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6159
6160
6161
# File 'lib/models/porcelain.rb', line 6159

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6161
6162
6163
# File 'lib/models/porcelain.rb', line 6161

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6163
6164
6165
# File 'lib/models/porcelain.rb', line 6163

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6195
6196
6197
6198
6199
6200
6201
# File 'lib/models/porcelain.rb', line 6195

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end