Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



7153
7154
7155
7156
7157
7158
7159
7160
7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
# File 'lib/models/porcelain.rb', line 7153

def initialize(
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  if database != nil
    @database = database
  end
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if healthy != nil
    @healthy = healthy
  end
  if hostname != nil
    @hostname = hostname
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if password != nil
    @password = password
  end
  if port != nil
    @port = port
  end
  if port_override != nil
    @port_override = port_override
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if tags != nil
    @tags = tags
  end
  if username != nil
    @username = username
  end
end

Instance Attribute Details

#databaseObject

Returns the value of attribute database.



7129
7130
7131
# File 'lib/models/porcelain.rb', line 7129

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7131
7132
7133
# File 'lib/models/porcelain.rb', line 7131

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7133
7134
7135
# File 'lib/models/porcelain.rb', line 7133

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7135
7136
7137
# File 'lib/models/porcelain.rb', line 7135

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7137
7138
7139
# File 'lib/models/porcelain.rb', line 7137

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7139
7140
7141
# File 'lib/models/porcelain.rb', line 7139

def name
  @name
end

#passwordObject

Returns the value of attribute password.



7141
7142
7143
# File 'lib/models/porcelain.rb', line 7141

def password
  @password
end

#portObject

Returns the value of attribute port.



7143
7144
7145
# File 'lib/models/porcelain.rb', line 7143

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



7145
7146
7147
# File 'lib/models/porcelain.rb', line 7145

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7147
7148
7149
# File 'lib/models/porcelain.rb', line 7147

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



7149
7150
7151
# File 'lib/models/porcelain.rb', line 7149

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7151
7152
7153
# File 'lib/models/porcelain.rb', line 7151

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7205
7206
7207
7208
7209
7210
7211
# File 'lib/models/porcelain.rb', line 7205

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end