Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



14158
14159
14160
14161
14162
14163
14164
14165
14166
14167
14168
14169
14170
14171
14172
14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
14188
14189
14190
14191
14192
14193
14194
# File 'lib/models/porcelain.rb', line 14158

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14124
14125
14126
# File 'lib/models/porcelain.rb', line 14124

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



14126
14127
14128
# File 'lib/models/porcelain.rb', line 14126

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14128
14129
14130
# File 'lib/models/porcelain.rb', line 14128

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14130
14131
14132
# File 'lib/models/porcelain.rb', line 14130

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14132
14133
14134
# File 'lib/models/porcelain.rb', line 14132

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14134
14135
14136
# File 'lib/models/porcelain.rb', line 14134

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14136
14137
14138
# File 'lib/models/porcelain.rb', line 14136

def name
  @name
end

#passwordObject

The password to authenticate with.



14138
14139
14140
# File 'lib/models/porcelain.rb', line 14138

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14140
14141
14142
# File 'lib/models/porcelain.rb', line 14140

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14142
14143
14144
# File 'lib/models/porcelain.rb', line 14142

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14144
14145
14146
# File 'lib/models/porcelain.rb', line 14144

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



14146
14147
14148
# File 'lib/models/porcelain.rb', line 14146

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14148
14149
14150
# File 'lib/models/porcelain.rb', line 14148

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14150
14151
14152
# File 'lib/models/porcelain.rb', line 14150

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14152
14153
14154
# File 'lib/models/porcelain.rb', line 14152

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



14154
14155
14156
# File 'lib/models/porcelain.rb', line 14154

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



14156
14157
14158
# File 'lib/models/porcelain.rb', line 14156

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14196
14197
14198
14199
14200
14201
14202
# File 'lib/models/porcelain.rb', line 14196

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end