Class: SDM::SingleStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ SingleStore

Returns a new instance of SingleStore.



17755
17756
17757
17758
17759
17760
17761
17762
17763
17764
17765
17766
17767
17768
17769
17770
17771
17772
17773
17774
17775
17776
17777
17778
17779
17780
17781
17782
17783
17784
17785
17786
17787
17788
17789
17790
17791
# File 'lib/models/porcelain.rb', line 17755

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17721
17722
17723
# File 'lib/models/porcelain.rb', line 17721

def bind_interface
  @bind_interface
end

#database ⇒ Object

The database for healthchecks. Does not affect client requests.



17723
17724
17725
# File 'lib/models/porcelain.rb', line 17723

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



17725
17726
17727
# File 'lib/models/porcelain.rb', line 17725

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



17727
17728
17729
# File 'lib/models/porcelain.rb', line 17727

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



17729
17730
17731
# File 'lib/models/porcelain.rb', line 17729

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



17731
17732
17733
# File 'lib/models/porcelain.rb', line 17731

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



17733
17734
17735
# File 'lib/models/porcelain.rb', line 17733

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



17735
17736
17737
# File 'lib/models/porcelain.rb', line 17735

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



17737
17738
17739
# File 'lib/models/porcelain.rb', line 17737

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17739
17740
17741
# File 'lib/models/porcelain.rb', line 17739

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



17741
17742
17743
# File 'lib/models/porcelain.rb', line 17741

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_auth ⇒ Object

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



17743
17744
17745
# File 'lib/models/porcelain.rb', line 17743

def require_native_auth
  @require_native_auth
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



17745
17746
17747
# File 'lib/models/porcelain.rb', line 17745

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17747
17748
17749
# File 'lib/models/porcelain.rb', line 17747

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



17749
17750
17751
# File 'lib/models/porcelain.rb', line 17749

def tags
  @tags
end

#use_azure_single_server_usernames ⇒ Object

If true, appends the hostname to the username when hitting a database.azure.com address



17751
17752
17753
# File 'lib/models/porcelain.rb', line 17751

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#username ⇒ Object

The username to authenticate with.



17753
17754
17755
# File 'lib/models/porcelain.rb', line 17753

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17793
17794
17795
17796
17797
17798
17799
# File 'lib/models/porcelain.rb', line 17793

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end