Class: SDM::SnapshotClient

Inherits:
Object
  • Object
show all
Defined in:
lib/strongdm.rb

Overview

SnapshotClient exposes methods to query historical records at a provided timestamp.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ SnapshotClient

Returns a new instance of SnapshotClient.



635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
# File 'lib/strongdm.rb', line 635

def initialize(client)
  @access_requests = SnapshotAccessRequests.new(client.access_requests)
  @account_attachments = SnapshotAccountAttachments.new(client.)
  @account_grants = SnapshotAccountGrants.new(client.)
  @account_permissions = SnapshotAccountPermissions.new(client.)
  @account_resources = SnapshotAccountResources.new(client.)
  @accounts = SnapshotAccounts.new(client.accounts)
  @accounts_groups = SnapshotAccountsGroups.new(client.accounts_groups)
  @approval_workflow_approvers = SnapshotApprovalWorkflowApprovers.new(client.approval_workflow_approvers)
  @approval_workflow_steps = SnapshotApprovalWorkflowSteps.new(client.approval_workflow_steps)
  @approval_workflows = SnapshotApprovalWorkflows.new(client.approval_workflows)
  @discovery_connectors = SnapshotDiscoveryConnectors.new(client.discovery_connectors)
  @granted_account_entitlements = SnapshotGrantedAccountEntitlements.new(client.)
  @granted_resource_entitlements = SnapshotGrantedResourceEntitlements.new(client.granted_resource_entitlements)
  @granted_role_entitlements = SnapshotGrantedRoleEntitlements.new(client.granted_role_entitlements)
  @roles = SnapshotRoles.new(client.roles)
  @groups = SnapshotGroups.new(client.groups)
  @groups_roles = SnapshotGroupsRoles.new(client.groups_roles)
  @identity_aliases = SnapshotIdentityAliases.new(client.identity_aliases)
  @identity_sets = SnapshotIdentitySets.new(client.identity_sets)
  @nodes = SnapshotNodes.new(client.nodes)
  @policies = SnapshotPolicies.new(client.policies)
  @proxy_cluster_keys = SnapshotProxyClusterKeys.new(client.proxy_cluster_keys)
  @remote_identities = SnapshotRemoteIdentities.new(client.remote_identities)
  @remote_identity_groups = SnapshotRemoteIdentityGroups.new(client.remote_identity_groups)
  @resources = SnapshotResources.new(client.resources)
  @role_resources = SnapshotRoleResources.new(client.role_resources)
  @secret_stores = SnapshotSecretStores.new(client.secret_stores)
  @workflow_approvers = SnapshotWorkflowApprovers.new(client.workflow_approvers)
  @workflow_roles = SnapshotWorkflowRoles.new(client.workflow_roles)
  @workflows = SnapshotWorkflows.new(client.workflows)
end

Instance Attribute Details

#access_requestsObject (readonly)

AccessRequests are requests for access to a resource that may match a Workflow.

See SDM::SnapshotAccessRequests.



671
672
673
# File 'lib/strongdm.rb', line 671

def access_requests
  @access_requests
end

#account_attachmentsObject (readonly)

AccountAttachments assign an account to a role.

See SDM::SnapshotAccountAttachments.



675
676
677
# File 'lib/strongdm.rb', line 675

def 
  @account_attachments
end

#account_grantsObject (readonly)

AccountGrants assign a resource directly to an account, giving the account the permission to connect to that resource.

See SDM::SnapshotAccountGrants.



679
680
681
# File 'lib/strongdm.rb', line 679

def 
  @account_grants
end

#account_permissionsObject (readonly)

AccountPermissions records the granular permissions accounts have, allowing them to execute relevant commands via StrongDM's APIs.

See SDM::SnapshotAccountPermissions.



684
685
686
# File 'lib/strongdm.rb', line 684

def 
  @account_permissions
end

#account_resourcesObject (readonly)

AccountResources enumerates the resources to which accounts have access. The AccountResources service is read-only.

See SDM::SnapshotAccountResources.



689
690
691
# File 'lib/strongdm.rb', line 689

def 
  @account_resources
end

#accountsObject (readonly)

Accounts are users that have access to strongDM. There are two types of accounts:

  1. Users: humans who are authenticated through username and password or SSO.
  2. Service Accounts: machines that are authenticated using a service token.
  3. Tokens are access keys with permissions that can be used for authentication.

See SDM::SnapshotAccounts.



696
697
698
# File 'lib/strongdm.rb', line 696

def accounts
  @accounts
end

#accounts_groupsObject (readonly)

An AccountGroup links an account and a group.

See SDM::SnapshotAccountsGroups.



700
701
702
# File 'lib/strongdm.rb', line 700

def accounts_groups
  @accounts_groups
end

#approval_workflow_approversObject (readonly)

ApprovalWorkflowApprovers link approval workflow approvers to an ApprovalWorkflowStep

See SDM::SnapshotApprovalWorkflowApprovers.



704
705
706
# File 'lib/strongdm.rb', line 704

def approval_workflow_approvers
  @approval_workflow_approvers
end

#approval_workflow_stepsObject (readonly)

ApprovalWorkflowSteps link approval workflow steps to an ApprovalWorkflow

See SDM::SnapshotApprovalWorkflowSteps.



708
709
710
# File 'lib/strongdm.rb', line 708

def approval_workflow_steps
  @approval_workflow_steps
end

#approval_workflowsObject (readonly)

ApprovalWorkflows are the mechanism by which requests for access can be viewed by authorized approvers and be approved or denied.

See SDM::SnapshotApprovalWorkflows.



713
714
715
# File 'lib/strongdm.rb', line 713

def approval_workflows
  @approval_workflows
end

#discovery_connectorsObject (readonly)

A Discovery Connector is a configuration object for performing Resource Scans in remote systems such as AWS, GCP, Azure, and other systems.

See SDM::SnapshotDiscoveryConnectors.



718
719
720
# File 'lib/strongdm.rb', line 718

def discovery_connectors
  @discovery_connectors
end

#granted_account_entitlementsObject (readonly)

GrantedAccountEntitlements enumerates the resources to which an account has been granted access. The GrantedAccountEntitlements service is read-only.

See SDM::SnapshotGrantedAccountEntitlements.



723
724
725
# File 'lib/strongdm.rb', line 723

def 
  @granted_account_entitlements
end

#granted_resource_entitlementsObject (readonly)

GrantedResourceEntitlements enumerates the accounts that have been granted access to a given resource. The GrantedResourceEntitlements service is read-only.

See SDM::SnapshotGrantedResourceEntitlements.



728
729
730
# File 'lib/strongdm.rb', line 728

def granted_resource_entitlements
  @granted_resource_entitlements
end

#granted_role_entitlementsObject (readonly)

GrantedRoleEntitlements enumerates the resources to which a role grants access. The GrantedRoleEntitlements service is read-only.

See SDM::SnapshotGrantedRoleEntitlements.



733
734
735
# File 'lib/strongdm.rb', line 733

def granted_role_entitlements
  @granted_role_entitlements
end

#groupsObject (readonly)

A Group is a set of principals.

See SDM::SnapshotGroups.



743
744
745
# File 'lib/strongdm.rb', line 743

def groups
  @groups
end

#groups_rolesObject (readonly)

A GroupRole is an assignment of a Group to a Role.

See SDM::SnapshotGroupsRoles.



747
748
749
# File 'lib/strongdm.rb', line 747

def groups_roles
  @groups_roles
end

#identity_aliasesObject (readonly)

IdentityAliases assign an alias to an account within an IdentitySet. The alias is used as the username when connecting to a identity supported resource.

See SDM::SnapshotIdentityAliases.



752
753
754
# File 'lib/strongdm.rb', line 752

def identity_aliases
  @identity_aliases
end

#identity_setsObject (readonly)

A IdentitySet is a named grouping of Identity Aliases for Accounts. An Account's relationship to a IdentitySet is defined via IdentityAlias objects.

See SDM::SnapshotIdentitySets.



757
758
759
# File 'lib/strongdm.rb', line 757

def identity_sets
  @identity_sets
end

#nodesObject (readonly)

Nodes make up the StrongDM network, and allow your users to connect securely to your resources. There are three types of nodes:

  1. Relay: creates connectivity to your datasources, while maintaining the egress-only nature of your firewall
  2. Gateway: a relay that also listens for connections from StrongDM clients
  3. Proxy Cluster: a cluster of workers that together mediate access from clients to resources

See SDM::SnapshotNodes.



765
766
767
# File 'lib/strongdm.rb', line 765

def nodes
  @nodes
end

#policiesObject (readonly)

Policies are the collection of one or more statements that enforce fine-grained access control for the users of an organization.

See SDM::SnapshotPolicies.



770
771
772
# File 'lib/strongdm.rb', line 770

def policies
  @policies
end

#proxy_cluster_keysObject (readonly)

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

See SDM::SnapshotProxyClusterKeys.



776
777
778
# File 'lib/strongdm.rb', line 776

def proxy_cluster_keys
  @proxy_cluster_keys
end

#remote_identitiesObject (readonly)

RemoteIdentities assign a resource directly to an account, giving the account the permission to connect to that resource.

See SDM::SnapshotRemoteIdentities.



780
781
782
# File 'lib/strongdm.rb', line 780

def remote_identities
  @remote_identities
end

#remote_identity_groupsObject (readonly)

A RemoteIdentityGroup is a named grouping of Remote Identities for Accounts. An Account's relationship to a RemoteIdentityGroup is defined via RemoteIdentity objects.

See SDM::SnapshotRemoteIdentityGroups.



785
786
787
# File 'lib/strongdm.rb', line 785

def remote_identity_groups
  @remote_identity_groups
end

#resourcesObject (readonly)

Resources are databases, servers, clusters, websites, or clouds that strongDM delegates access to.

See SDM::SnapshotResources.



790
791
792
# File 'lib/strongdm.rb', line 790

def resources
  @resources
end

#role_resourcesObject (readonly)

RoleResources enumerates the resources to which roles have access. The RoleResources service is read-only.

See SDM::SnapshotRoleResources.



795
796
797
# File 'lib/strongdm.rb', line 795

def role_resources
  @role_resources
end

#rolesObject (readonly)

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

See SDM::SnapshotRoles.



739
740
741
# File 'lib/strongdm.rb', line 739

def roles
  @roles
end

#secret_storesObject (readonly)

SecretStores are servers where resource secrets (passwords, keys) are stored.

See SDM::SnapshotSecretStores.



799
800
801
# File 'lib/strongdm.rb', line 799

def secret_stores
  @secret_stores
end

#workflow_approversObject (readonly)

WorkflowApprovers is an account or a role with the ability to approve requests bound to a workflow.

See SDM::SnapshotWorkflowApprovers.



803
804
805
# File 'lib/strongdm.rb', line 803

def workflow_approvers
  @workflow_approvers
end

#workflow_rolesObject (readonly)

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

See SDM::SnapshotWorkflowRoles.



808
809
810
# File 'lib/strongdm.rb', line 808

def workflow_roles
  @workflow_roles
end

#workflowsObject (readonly)

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either be automatic approval or a set of users authorized to approve the requests.

See SDM::SnapshotWorkflows.



814
815
816
# File 'lib/strongdm.rb', line 814

def workflows
  @workflows
end