Class: SDM::SnapshotGroups
- Inherits:
-
Object
- Object
- SDM::SnapshotGroups
- Extended by:
- Gem::Deprecate
- Defined in:
- lib/svc.rb
Overview
SnapshotGroups exposes the read only methods of the Groups service for historical queries.
Instance Method Summary collapse
-
#get(id, deadline: nil) ⇒ Object
Get reads one Group by ID.
-
#initialize(groups) ⇒ SnapshotGroups
constructor
A new instance of SnapshotGroups.
-
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of Groups matching a given set of criteria.
Constructor Details
#initialize(groups) ⇒ SnapshotGroups
Returns a new instance of SnapshotGroups.
3472 3473 3474 |
# File 'lib/svc.rb', line 3472 def initialize(groups) @groups = groups end |
Instance Method Details
#get(id, deadline: nil) ⇒ Object
Get reads one Group by ID.
3477 3478 3479 3480 3481 3482 3483 3484 3485 |
# File 'lib/svc.rb', line 3477 def get( id, deadline: nil ) return @groups.get( id, deadline: deadline, ) end |
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of Groups matching a given set of criteria.
3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 |
# File 'lib/svc.rb', line 3488 def list( filter, *args, deadline: nil ) return @groups.list( filter, *args, deadline: deadline, ) end |