Class: SDM::SnapshotPeeringGroupNodes
- Inherits:
-
Object
- Object
- SDM::SnapshotPeeringGroupNodes
- Extended by:
- Gem::Deprecate
- Defined in:
- lib/svc.rb
Overview
SnapshotPeeringGroupNodes exposes the read only methods of the PeeringGroupNodes service for historical queries.
Instance Method Summary collapse
-
#get(id, deadline: nil) ⇒ Object
Get reads the information of one peering group to node attachment.
-
#initialize(peering_group_nodes) ⇒ SnapshotPeeringGroupNodes
constructor
A new instance of SnapshotPeeringGroupNodes.
-
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of peering group node attachments.
Constructor Details
#initialize(peering_group_nodes) ⇒ SnapshotPeeringGroupNodes
Returns a new instance of SnapshotPeeringGroupNodes.
1643 1644 1645 |
# File 'lib/svc.rb', line 1643 def initialize(peering_group_nodes) @peering_group_nodes = peering_group_nodes end |
Instance Method Details
#get(id, deadline: nil) ⇒ Object
Get reads the information of one peering group to node attachment.
1648 1649 1650 1651 1652 1653 1654 1655 1656 |
# File 'lib/svc.rb', line 1648 def get( id, deadline: nil ) return @peering_group_nodes.get( id, deadline: deadline, ) end |
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of peering group node attachments.
1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 |
# File 'lib/svc.rb', line 1659 def list( filter, *args, deadline: nil ) return @peering_group_nodes.list( filter, *args, deadline: deadline, ) end |