Class: SDM::SnapshotPeeringGroupPeers

Inherits:
Object
  • Object
show all
Extended by:
Gem::Deprecate
Defined in:
lib/svc.rb

Overview

SnapshotPeeringGroupPeers exposes the read only methods of the PeeringGroupPeers service for historical queries.

Instance Method Summary collapse

Constructor Details

#initialize(peering_group_peers) ⇒ SnapshotPeeringGroupPeers

Returns a new instance of SnapshotPeeringGroupPeers.



1826
1827
1828
# File 'lib/svc.rb', line 1826

def initialize(peering_group_peers)
  @peering_group_peers = peering_group_peers
end

Instance Method Details

#get(id, deadline: nil) ⇒ Object

Get reads the information of one peering group link.



1831
1832
1833
1834
1835
1836
1837
1838
1839
# File 'lib/svc.rb', line 1831

def get(
  id,
  deadline: nil
)
  return @peering_group_peers.get(
           id,
           deadline: deadline,
         )
end

#list(filter, *args, deadline: nil) ⇒ Object

List gets a list of peering group links.



1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
# File 'lib/svc.rb', line 1842

def list(
  filter,
  *args,
  deadline: nil
)
  return @peering_group_peers.list(
           filter,
                        *args,
                        deadline: deadline,
         )
end