Class: SDM::SnapshotPeeringGroupResources

Inherits:
Object
  • Object
show all
Extended by:
Gem::Deprecate
Defined in:
lib/svc.rb

Overview

SnapshotPeeringGroupResources exposes the read only methods of the PeeringGroupResources service for historical queries.

Instance Method Summary collapse

Constructor Details

#initialize(peering_group_resources) ⇒ SnapshotPeeringGroupResources

Returns a new instance of SnapshotPeeringGroupResources.



2009
2010
2011
# File 'lib/svc.rb', line 2009

def initialize(peering_group_resources)
  @peering_group_resources = peering_group_resources
end

Instance Method Details

#get(id, deadline: nil) ⇒ Object

Get reads the information of one peering group to resource attachment.



2014
2015
2016
2017
2018
2019
2020
2021
2022
# File 'lib/svc.rb', line 2014

def get(
  id,
  deadline: nil
)
  return @peering_group_resources.get(
           id,
           deadline: deadline,
         )
end

#list(filter, *args, deadline: nil) ⇒ Object

List gets a list of peering group resource attachments.



2025
2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
# File 'lib/svc.rb', line 2025

def list(
  filter,
  *args,
  deadline: nil
)
  return @peering_group_resources.list(
           filter,
                        *args,
                        deadline: deadline,
         )
end