Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



17776
17777
17778
17779
17780
17781
17782
17783
17784
17785
17786
17787
17788
17789
17790
17791
17792
17793
17794
17795
17796
17797
17798
17799
17800
17801
17802
17803
17804
17805
17806
17807
17808
17809
17810
# File 'lib/models/porcelain.rb', line 17776

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17744
17745
17746
# File 'lib/models/porcelain.rb', line 17744

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



17746
17747
17748
# File 'lib/models/porcelain.rb', line 17746

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17748
17749
17750
# File 'lib/models/porcelain.rb', line 17748

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17750
17751
17752
# File 'lib/models/porcelain.rb', line 17750

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17752
17753
17754
# File 'lib/models/porcelain.rb', line 17752

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17754
17755
17756
# File 'lib/models/porcelain.rb', line 17754

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17756
17757
17758
# File 'lib/models/porcelain.rb', line 17756

def name
  @name
end

#passwordObject



17758
17759
17760
# File 'lib/models/porcelain.rb', line 17758

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17760
17761
17762
# File 'lib/models/porcelain.rb', line 17760

def port_override
  @port_override
end

#private_keyObject

RSA Private Key for authentication



17762
17763
17764
# File 'lib/models/porcelain.rb', line 17762

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17764
17765
17766
# File 'lib/models/porcelain.rb', line 17764

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



17766
17767
17768
# File 'lib/models/porcelain.rb', line 17766

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17768
17769
17770
# File 'lib/models/porcelain.rb', line 17768

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17770
17771
17772
# File 'lib/models/porcelain.rb', line 17770

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17772
17773
17774
# File 'lib/models/porcelain.rb', line 17772

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17774
17775
17776
# File 'lib/models/porcelain.rb', line 17774

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17812
17813
17814
17815
17816
17817
17818
# File 'lib/models/porcelain.rb', line 17812

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end