Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



17728
17729
17730
17731
17732
17733
17734
17735
17736
17737
17738
17739
17740
17741
17742
17743
17744
17745
17746
17747
17748
17749
17750
17751
17752
17753
17754
17755
17756
17757
17758
17759
17760
17761
17762
# File 'lib/models/porcelain.rb', line 17728

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17696
17697
17698
# File 'lib/models/porcelain.rb', line 17696

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



17698
17699
17700
# File 'lib/models/porcelain.rb', line 17698

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17700
17701
17702
# File 'lib/models/porcelain.rb', line 17700

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17702
17703
17704
# File 'lib/models/porcelain.rb', line 17702

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17704
17705
17706
# File 'lib/models/porcelain.rb', line 17704

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17706
17707
17708
# File 'lib/models/porcelain.rb', line 17706

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17708
17709
17710
# File 'lib/models/porcelain.rb', line 17708

def name
  @name
end

#passwordObject



17710
17711
17712
# File 'lib/models/porcelain.rb', line 17710

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17712
17713
17714
# File 'lib/models/porcelain.rb', line 17712

def port_override
  @port_override
end

#private_keyObject

RSA Private Key for authentication



17714
17715
17716
# File 'lib/models/porcelain.rb', line 17714

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17716
17717
17718
# File 'lib/models/porcelain.rb', line 17716

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



17718
17719
17720
# File 'lib/models/porcelain.rb', line 17718

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17720
17721
17722
# File 'lib/models/porcelain.rb', line 17720

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17722
17723
17724
# File 'lib/models/porcelain.rb', line 17722

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17724
17725
17726
# File 'lib/models/porcelain.rb', line 17724

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17726
17727
17728
# File 'lib/models/porcelain.rb', line 17726

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17764
17765
17766
17767
17768
17769
17770
# File 'lib/models/porcelain.rb', line 17764

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end