Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
- #password ⇒ Object
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#private_key ⇒ Object
RSA Private Key for authentication.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#schema ⇒ Object
The schema to provide on authentication.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
17644 17645 17646 17647 17648 17649 17650 17651 17652 17653 17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 17664 17665 17666 17667 17668 17669 17670 17671 17672 17673 17674 17675 17676 17677 17678 |
# File 'lib/models/porcelain.rb', line 17644 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @private_key = private_key == nil ? "" : private_key @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
17612 17613 17614 |
# File 'lib/models/porcelain.rb', line 17612 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
17614 17615 17616 |
# File 'lib/models/porcelain.rb', line 17614 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
17616 17617 17618 |
# File 'lib/models/porcelain.rb', line 17616 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
17618 17619 17620 |
# File 'lib/models/porcelain.rb', line 17618 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
17620 17621 17622 |
# File 'lib/models/porcelain.rb', line 17620 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
17622 17623 17624 |
# File 'lib/models/porcelain.rb', line 17622 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
17624 17625 17626 |
# File 'lib/models/porcelain.rb', line 17624 def name @name end |
#password ⇒ Object
17626 17627 17628 |
# File 'lib/models/porcelain.rb', line 17626 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
17628 17629 17630 |
# File 'lib/models/porcelain.rb', line 17628 def port_override @port_override end |
#private_key ⇒ Object
RSA Private Key for authentication
17630 17631 17632 |
# File 'lib/models/porcelain.rb', line 17630 def private_key @private_key end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
17632 17633 17634 |
# File 'lib/models/porcelain.rb', line 17632 def proxy_cluster_id @proxy_cluster_id end |
#schema ⇒ Object
The schema to provide on authentication.
17634 17635 17636 |
# File 'lib/models/porcelain.rb', line 17634 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
17636 17637 17638 |
# File 'lib/models/porcelain.rb', line 17636 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
17638 17639 17640 |
# File 'lib/models/porcelain.rb', line 17638 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17640 17641 17642 |
# File 'lib/models/porcelain.rb', line 17640 def @tags end |
#username ⇒ Object
The username to authenticate with.
17642 17643 17644 |
# File 'lib/models/porcelain.rb', line 17642 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17680 17681 17682 17683 17684 17685 17686 |
# File 'lib/models/porcelain.rb', line 17680 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |