Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



17417
17418
17419
17420
17421
17422
17423
17424
17425
17426
17427
17428
17429
17430
17431
17432
17433
17434
17435
17436
17437
17438
17439
17440
17441
17442
17443
17444
17445
17446
17447
17448
17449
17450
17451
# File 'lib/models/porcelain.rb', line 17417

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17385
17386
17387
# File 'lib/models/porcelain.rb', line 17385

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



17387
17388
17389
# File 'lib/models/porcelain.rb', line 17387

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17389
17390
17391
# File 'lib/models/porcelain.rb', line 17389

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17391
17392
17393
# File 'lib/models/porcelain.rb', line 17391

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17393
17394
17395
# File 'lib/models/porcelain.rb', line 17393

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17395
17396
17397
# File 'lib/models/porcelain.rb', line 17395

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17397
17398
17399
# File 'lib/models/porcelain.rb', line 17397

def name
  @name
end

#passwordObject



17399
17400
17401
# File 'lib/models/porcelain.rb', line 17399

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17401
17402
17403
# File 'lib/models/porcelain.rb', line 17401

def port_override
  @port_override
end

#private_keyObject

RSA Private Key for authentication



17403
17404
17405
# File 'lib/models/porcelain.rb', line 17403

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17405
17406
17407
# File 'lib/models/porcelain.rb', line 17405

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



17407
17408
17409
# File 'lib/models/porcelain.rb', line 17407

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17409
17410
17411
# File 'lib/models/porcelain.rb', line 17409

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17411
17412
17413
# File 'lib/models/porcelain.rb', line 17411

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17413
17414
17415
# File 'lib/models/porcelain.rb', line 17413

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17415
17416
17417
# File 'lib/models/porcelain.rb', line 17415

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17453
17454
17455
17456
17457
17458
17459
# File 'lib/models/porcelain.rb', line 17453

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end