Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



17294
17295
17296
17297
17298
17299
17300
17301
17302
17303
17304
17305
17306
17307
17308
17309
17310
17311
17312
17313
17314
17315
17316
17317
17318
17319
17320
17321
17322
17323
17324
17325
17326
17327
17328
# File 'lib/models/porcelain.rb', line 17294

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17262
17263
17264
# File 'lib/models/porcelain.rb', line 17262

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



17264
17265
17266
# File 'lib/models/porcelain.rb', line 17264

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17266
17267
17268
# File 'lib/models/porcelain.rb', line 17266

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17268
17269
17270
# File 'lib/models/porcelain.rb', line 17268

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17270
17271
17272
# File 'lib/models/porcelain.rb', line 17270

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17272
17273
17274
# File 'lib/models/porcelain.rb', line 17272

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17274
17275
17276
# File 'lib/models/porcelain.rb', line 17274

def name
  @name
end

#passwordObject



17276
17277
17278
# File 'lib/models/porcelain.rb', line 17276

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17278
17279
17280
# File 'lib/models/porcelain.rb', line 17278

def port_override
  @port_override
end

#private_keyObject

RSA Private Key for authentication



17280
17281
17282
# File 'lib/models/porcelain.rb', line 17280

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17282
17283
17284
# File 'lib/models/porcelain.rb', line 17282

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



17284
17285
17286
# File 'lib/models/porcelain.rb', line 17284

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17286
17287
17288
# File 'lib/models/porcelain.rb', line 17286

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17288
17289
17290
# File 'lib/models/porcelain.rb', line 17288

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17290
17291
17292
# File 'lib/models/porcelain.rb', line 17290

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17292
17293
17294
# File 'lib/models/porcelain.rb', line 17292

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17330
17331
17332
17333
17334
17335
17336
# File 'lib/models/porcelain.rb', line 17330

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end