Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



16619
16620
16621
16622
16623
16624
16625
16626
16627
16628
16629
16630
16631
16632
16633
16634
16635
16636
16637
16638
16639
16640
16641
16642
16643
16644
16645
16646
16647
16648
16649
16650
16651
16652
16653
# File 'lib/models/porcelain.rb', line 16619

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16587
16588
16589
# File 'lib/models/porcelain.rb', line 16587

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



16589
16590
16591
# File 'lib/models/porcelain.rb', line 16589

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16591
16592
16593
# File 'lib/models/porcelain.rb', line 16591

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16593
16594
16595
# File 'lib/models/porcelain.rb', line 16593

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16595
16596
16597
# File 'lib/models/porcelain.rb', line 16595

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16597
16598
16599
# File 'lib/models/porcelain.rb', line 16597

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



16599
16600
16601
# File 'lib/models/porcelain.rb', line 16599

def name
  @name
end

#passwordObject



16601
16602
16603
# File 'lib/models/porcelain.rb', line 16601

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16603
16604
16605
# File 'lib/models/porcelain.rb', line 16603

def port_override
  @port_override
end

#private_keyObject

RSA Private Key for authentication



16605
16606
16607
# File 'lib/models/porcelain.rb', line 16605

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16607
16608
16609
# File 'lib/models/porcelain.rb', line 16607

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



16609
16610
16611
# File 'lib/models/porcelain.rb', line 16609

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16611
16612
16613
# File 'lib/models/porcelain.rb', line 16611

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16613
16614
16615
# File 'lib/models/porcelain.rb', line 16613

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16615
16616
16617
# File 'lib/models/porcelain.rb', line 16615

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16617
16618
16619
# File 'lib/models/porcelain.rb', line 16617

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16655
16656
16657
16658
16659
16660
16661
# File 'lib/models/porcelain.rb', line 16655

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end