Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



16555
16556
16557
16558
16559
16560
16561
16562
16563
16564
16565
16566
16567
16568
16569
16570
16571
16572
16573
16574
16575
16576
16577
16578
16579
16580
16581
16582
16583
16584
16585
16586
16587
16588
16589
# File 'lib/models/porcelain.rb', line 16555

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16523
16524
16525
# File 'lib/models/porcelain.rb', line 16523

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



16525
16526
16527
# File 'lib/models/porcelain.rb', line 16525

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16527
16528
16529
# File 'lib/models/porcelain.rb', line 16527

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16529
16530
16531
# File 'lib/models/porcelain.rb', line 16529

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16531
16532
16533
# File 'lib/models/porcelain.rb', line 16531

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16533
16534
16535
# File 'lib/models/porcelain.rb', line 16533

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



16535
16536
16537
# File 'lib/models/porcelain.rb', line 16535

def name
  @name
end

#passwordObject



16537
16538
16539
# File 'lib/models/porcelain.rb', line 16537

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16539
16540
16541
# File 'lib/models/porcelain.rb', line 16539

def port_override
  @port_override
end

#private_keyObject

RSA Private Key for authentication



16541
16542
16543
# File 'lib/models/porcelain.rb', line 16541

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16543
16544
16545
# File 'lib/models/porcelain.rb', line 16543

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



16545
16546
16547
# File 'lib/models/porcelain.rb', line 16545

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16547
16548
16549
# File 'lib/models/porcelain.rb', line 16547

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16549
16550
16551
# File 'lib/models/porcelain.rb', line 16549

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16551
16552
16553
# File 'lib/models/porcelain.rb', line 16551

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16553
16554
16555
# File 'lib/models/porcelain.rb', line 16553

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16591
16592
16593
16594
16595
16596
16597
# File 'lib/models/porcelain.rb', line 16591

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end