Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



15713
15714
15715
15716
15717
15718
15719
15720
15721
15722
15723
15724
15725
15726
15727
15728
15729
15730
15731
15732
15733
15734
15735
15736
15737
15738
15739
15740
15741
15742
15743
15744
15745
15746
15747
# File 'lib/models/porcelain.rb', line 15713

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15681
15682
15683
# File 'lib/models/porcelain.rb', line 15681

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15683
15684
15685
# File 'lib/models/porcelain.rb', line 15683

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15685
15686
15687
# File 'lib/models/porcelain.rb', line 15685

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15687
15688
15689
# File 'lib/models/porcelain.rb', line 15687

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15689
15690
15691
# File 'lib/models/porcelain.rb', line 15689

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15691
15692
15693
# File 'lib/models/porcelain.rb', line 15691

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15693
15694
15695
# File 'lib/models/porcelain.rb', line 15693

def name
  @name
end

#passwordObject



15695
15696
15697
# File 'lib/models/porcelain.rb', line 15695

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15697
15698
15699
# File 'lib/models/porcelain.rb', line 15697

def port_override
  @port_override
end

#private_keyObject

RSA Private Key for authentication



15699
15700
15701
# File 'lib/models/porcelain.rb', line 15699

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15701
15702
15703
# File 'lib/models/porcelain.rb', line 15701

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



15703
15704
15705
# File 'lib/models/porcelain.rb', line 15703

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15705
15706
15707
# File 'lib/models/porcelain.rb', line 15705

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15707
15708
15709
# File 'lib/models/porcelain.rb', line 15707

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15709
15710
15711
# File 'lib/models/porcelain.rb', line 15709

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15711
15712
15713
# File 'lib/models/porcelain.rb', line 15711

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15749
15750
15751
15752
15753
15754
15755
# File 'lib/models/porcelain.rb', line 15749

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end