Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



14693
14694
14695
14696
14697
14698
14699
14700
14701
14702
14703
14704
14705
14706
14707
14708
14709
14710
14711
14712
14713
14714
14715
14716
14717
14718
14719
14720
14721
14722
14723
14724
14725
14726
14727
# File 'lib/models/porcelain.rb', line 14693

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14661
14662
14663
# File 'lib/models/porcelain.rb', line 14661

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14663
14664
14665
# File 'lib/models/porcelain.rb', line 14663

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14665
14666
14667
# File 'lib/models/porcelain.rb', line 14665

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14667
14668
14669
# File 'lib/models/porcelain.rb', line 14667

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14669
14670
14671
# File 'lib/models/porcelain.rb', line 14669

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14671
14672
14673
# File 'lib/models/porcelain.rb', line 14671

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14673
14674
14675
# File 'lib/models/porcelain.rb', line 14673

def name
  @name
end

#passwordObject



14675
14676
14677
# File 'lib/models/porcelain.rb', line 14675

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



14677
14678
14679
# File 'lib/models/porcelain.rb', line 14677

def port_override
  @port_override
end

#private_keyObject

RSA Private Key for authentication



14679
14680
14681
# File 'lib/models/porcelain.rb', line 14679

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14681
14682
14683
# File 'lib/models/porcelain.rb', line 14681

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



14683
14684
14685
# File 'lib/models/porcelain.rb', line 14683

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14685
14686
14687
# File 'lib/models/porcelain.rb', line 14685

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14687
14688
14689
# File 'lib/models/porcelain.rb', line 14687

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14689
14690
14691
# File 'lib/models/porcelain.rb', line 14689

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14691
14692
14693
# File 'lib/models/porcelain.rb', line 14691

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14729
14730
14731
14732
14733
14734
14735
# File 'lib/models/porcelain.rb', line 14729

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end