Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



14433
14434
14435
14436
14437
14438
14439
14440
14441
14442
14443
14444
14445
14446
14447
14448
14449
14450
14451
14452
14453
14454
14455
14456
14457
14458
14459
14460
14461
14462
14463
14464
14465
14466
14467
# File 'lib/models/porcelain.rb', line 14433

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14401
14402
14403
# File 'lib/models/porcelain.rb', line 14401

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14403
14404
14405
# File 'lib/models/porcelain.rb', line 14403

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14405
14406
14407
# File 'lib/models/porcelain.rb', line 14405

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14407
14408
14409
# File 'lib/models/porcelain.rb', line 14407

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14409
14410
14411
# File 'lib/models/porcelain.rb', line 14409

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14411
14412
14413
# File 'lib/models/porcelain.rb', line 14411

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14413
14414
14415
# File 'lib/models/porcelain.rb', line 14413

def name
  @name
end

#passwordObject



14415
14416
14417
# File 'lib/models/porcelain.rb', line 14415

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



14417
14418
14419
# File 'lib/models/porcelain.rb', line 14417

def port_override
  @port_override
end

#private_keyObject

RSA Private Key for authentication



14419
14420
14421
# File 'lib/models/porcelain.rb', line 14419

def private_key
  @private_key
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14421
14422
14423
# File 'lib/models/porcelain.rb', line 14421

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



14423
14424
14425
# File 'lib/models/porcelain.rb', line 14423

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14425
14426
14427
# File 'lib/models/porcelain.rb', line 14425

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14427
14428
14429
# File 'lib/models/porcelain.rb', line 14427

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14429
14430
14431
# File 'lib/models/porcelain.rb', line 14429

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14431
14432
14433
# File 'lib/models/porcelain.rb', line 14431

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14469
14470
14471
14472
14473
14474
14475
# File 'lib/models/porcelain.rb', line 14469

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end