Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



14169
14170
14171
14172
14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
14188
14189
14190
14191
14192
14193
14194
14195
14196
14197
14198
14199
14200
14201
# File 'lib/models/porcelain.rb', line 14169

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14139
14140
14141
# File 'lib/models/porcelain.rb', line 14139

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14141
14142
14143
# File 'lib/models/porcelain.rb', line 14141

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14143
14144
14145
# File 'lib/models/porcelain.rb', line 14143

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14145
14146
14147
# File 'lib/models/porcelain.rb', line 14145

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14147
14148
14149
# File 'lib/models/porcelain.rb', line 14147

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14149
14150
14151
# File 'lib/models/porcelain.rb', line 14149

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14151
14152
14153
# File 'lib/models/porcelain.rb', line 14151

def name
  @name
end

#passwordObject

The password to authenticate with.



14153
14154
14155
# File 'lib/models/porcelain.rb', line 14153

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



14155
14156
14157
# File 'lib/models/porcelain.rb', line 14155

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14157
14158
14159
# File 'lib/models/porcelain.rb', line 14157

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



14159
14160
14161
# File 'lib/models/porcelain.rb', line 14159

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14161
14162
14163
# File 'lib/models/porcelain.rb', line 14161

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14163
14164
14165
# File 'lib/models/porcelain.rb', line 14163

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14165
14166
14167
# File 'lib/models/porcelain.rb', line 14165

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14167
14168
14169
# File 'lib/models/porcelain.rb', line 14167

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14203
14204
14205
14206
14207
14208
14209
# File 'lib/models/porcelain.rb', line 14203

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end