Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



14028
14029
14030
14031
14032
14033
14034
14035
14036
14037
14038
14039
14040
14041
14042
14043
14044
14045
14046
14047
14048
14049
14050
14051
14052
14053
14054
14055
14056
14057
14058
14059
14060
# File 'lib/models/porcelain.rb', line 14028

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13998
13999
14000
# File 'lib/models/porcelain.rb', line 13998

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14000
14001
14002
# File 'lib/models/porcelain.rb', line 14000

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14002
14003
14004
# File 'lib/models/porcelain.rb', line 14002

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14004
14005
14006
# File 'lib/models/porcelain.rb', line 14004

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14006
14007
14008
# File 'lib/models/porcelain.rb', line 14006

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14008
14009
14010
# File 'lib/models/porcelain.rb', line 14008

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14010
14011
14012
# File 'lib/models/porcelain.rb', line 14010

def name
  @name
end

#passwordObject

The password to authenticate with.



14012
14013
14014
# File 'lib/models/porcelain.rb', line 14012

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



14014
14015
14016
# File 'lib/models/porcelain.rb', line 14014

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14016
14017
14018
# File 'lib/models/porcelain.rb', line 14016

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



14018
14019
14020
# File 'lib/models/porcelain.rb', line 14018

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14020
14021
14022
# File 'lib/models/porcelain.rb', line 14020

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14022
14023
14024
# File 'lib/models/porcelain.rb', line 14022

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14024
14025
14026
# File 'lib/models/porcelain.rb', line 14024

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14026
14027
14028
# File 'lib/models/porcelain.rb', line 14026

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14062
14063
14064
14065
14066
14067
14068
# File 'lib/models/porcelain.rb', line 14062

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end