Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



12844
12845
12846
12847
12848
12849
12850
12851
12852
12853
12854
12855
12856
12857
12858
12859
12860
12861
12862
12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
# File 'lib/models/porcelain.rb', line 12844

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12814
12815
12816
# File 'lib/models/porcelain.rb', line 12814

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12816
12817
12818
# File 'lib/models/porcelain.rb', line 12816

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12818
12819
12820
# File 'lib/models/porcelain.rb', line 12818

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12820
12821
12822
# File 'lib/models/porcelain.rb', line 12820

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12822
12823
12824
# File 'lib/models/porcelain.rb', line 12822

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12824
12825
12826
# File 'lib/models/porcelain.rb', line 12824

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12826
12827
12828
# File 'lib/models/porcelain.rb', line 12826

def name
  @name
end

#passwordObject

The password to authenticate with.



12828
12829
12830
# File 'lib/models/porcelain.rb', line 12828

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



12830
12831
12832
# File 'lib/models/porcelain.rb', line 12830

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12832
12833
12834
# File 'lib/models/porcelain.rb', line 12832

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



12834
12835
12836
# File 'lib/models/porcelain.rb', line 12834

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12836
12837
12838
# File 'lib/models/porcelain.rb', line 12836

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12838
12839
12840
# File 'lib/models/porcelain.rb', line 12838

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12840
12841
12842
# File 'lib/models/porcelain.rb', line 12840

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12842
12843
12844
# File 'lib/models/porcelain.rb', line 12842

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12878
12879
12880
12881
12882
12883
12884
# File 'lib/models/porcelain.rb', line 12878

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end