Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#schema ⇒ Object
The schema to provide on authentication.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 12866 12867 12868 12869 12870 12871 12872 12873 12874 12875 12876 |
# File 'lib/models/porcelain.rb', line 12844 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12814 12815 12816 |
# File 'lib/models/porcelain.rb', line 12814 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
12816 12817 12818 |
# File 'lib/models/porcelain.rb', line 12816 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12818 12819 12820 |
# File 'lib/models/porcelain.rb', line 12818 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12820 12821 12822 |
# File 'lib/models/porcelain.rb', line 12820 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12822 12823 12824 |
# File 'lib/models/porcelain.rb', line 12822 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12824 12825 12826 |
# File 'lib/models/porcelain.rb', line 12824 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12826 12827 12828 |
# File 'lib/models/porcelain.rb', line 12826 def name @name end |
#password ⇒ Object
The password to authenticate with.
12828 12829 12830 |
# File 'lib/models/porcelain.rb', line 12828 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
12830 12831 12832 |
# File 'lib/models/porcelain.rb', line 12830 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12832 12833 12834 |
# File 'lib/models/porcelain.rb', line 12832 def proxy_cluster_id @proxy_cluster_id end |
#schema ⇒ Object
The schema to provide on authentication.
12834 12835 12836 |
# File 'lib/models/porcelain.rb', line 12834 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12836 12837 12838 |
# File 'lib/models/porcelain.rb', line 12836 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
12838 12839 12840 |
# File 'lib/models/porcelain.rb', line 12838 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12840 12841 12842 |
# File 'lib/models/porcelain.rb', line 12840 def @tags end |
#username ⇒ Object
The username to authenticate with.
12842 12843 12844 |
# File 'lib/models/porcelain.rb', line 12842 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12878 12879 12880 12881 12882 12883 12884 |
# File 'lib/models/porcelain.rb', line 12878 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |