Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



12593
12594
12595
12596
12597
12598
12599
12600
12601
12602
12603
12604
12605
12606
12607
12608
12609
12610
12611
12612
12613
12614
12615
12616
12617
12618
12619
12620
12621
12622
12623
12624
12625
# File 'lib/models/porcelain.rb', line 12593

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12563
12564
12565
# File 'lib/models/porcelain.rb', line 12563

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12565
12566
12567
# File 'lib/models/porcelain.rb', line 12565

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12567
12568
12569
# File 'lib/models/porcelain.rb', line 12567

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12569
12570
12571
# File 'lib/models/porcelain.rb', line 12569

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12571
12572
12573
# File 'lib/models/porcelain.rb', line 12571

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12573
12574
12575
# File 'lib/models/porcelain.rb', line 12573

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12575
12576
12577
# File 'lib/models/porcelain.rb', line 12575

def name
  @name
end

#passwordObject

The password to authenticate with.



12577
12578
12579
# File 'lib/models/porcelain.rb', line 12577

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



12579
12580
12581
# File 'lib/models/porcelain.rb', line 12579

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12581
12582
12583
# File 'lib/models/porcelain.rb', line 12581

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



12583
12584
12585
# File 'lib/models/porcelain.rb', line 12583

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12585
12586
12587
# File 'lib/models/porcelain.rb', line 12585

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12587
12588
12589
# File 'lib/models/porcelain.rb', line 12587

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12589
12590
12591
# File 'lib/models/porcelain.rb', line 12589

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12591
12592
12593
# File 'lib/models/porcelain.rb', line 12591

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12627
12628
12629
12630
12631
12632
12633
# File 'lib/models/porcelain.rb', line 12627

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end