Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



12525
12526
12527
12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
12550
12551
12552
12553
12554
12555
12556
12557
# File 'lib/models/porcelain.rb', line 12525

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12495
12496
12497
# File 'lib/models/porcelain.rb', line 12495

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12497
12498
12499
# File 'lib/models/porcelain.rb', line 12497

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12499
12500
12501
# File 'lib/models/porcelain.rb', line 12499

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12501
12502
12503
# File 'lib/models/porcelain.rb', line 12501

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12503
12504
12505
# File 'lib/models/porcelain.rb', line 12503

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12505
12506
12507
# File 'lib/models/porcelain.rb', line 12505

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12507
12508
12509
# File 'lib/models/porcelain.rb', line 12507

def name
  @name
end

#passwordObject

The password to authenticate with.



12509
12510
12511
# File 'lib/models/porcelain.rb', line 12509

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



12511
12512
12513
# File 'lib/models/porcelain.rb', line 12511

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12513
12514
12515
# File 'lib/models/porcelain.rb', line 12513

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



12515
12516
12517
# File 'lib/models/porcelain.rb', line 12515

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12517
12518
12519
# File 'lib/models/porcelain.rb', line 12517

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12519
12520
12521
# File 'lib/models/porcelain.rb', line 12519

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12521
12522
12523
# File 'lib/models/porcelain.rb', line 12521

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12523
12524
12525
# File 'lib/models/porcelain.rb', line 12523

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12559
12560
12561
12562
12563
12564
12565
# File 'lib/models/porcelain.rb', line 12559

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end