Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



12446
12447
12448
12449
12450
12451
12452
12453
12454
12455
12456
12457
12458
12459
12460
12461
12462
12463
12464
12465
12466
12467
12468
12469
12470
12471
12472
12473
12474
12475
12476
12477
12478
# File 'lib/models/porcelain.rb', line 12446

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12416
12417
12418
# File 'lib/models/porcelain.rb', line 12416

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12418
12419
12420
# File 'lib/models/porcelain.rb', line 12418

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12420
12421
12422
# File 'lib/models/porcelain.rb', line 12420

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12422
12423
12424
# File 'lib/models/porcelain.rb', line 12422

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12424
12425
12426
# File 'lib/models/porcelain.rb', line 12424

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12426
12427
12428
# File 'lib/models/porcelain.rb', line 12426

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12428
12429
12430
# File 'lib/models/porcelain.rb', line 12428

def name
  @name
end

#passwordObject

The password to authenticate with.



12430
12431
12432
# File 'lib/models/porcelain.rb', line 12430

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



12432
12433
12434
# File 'lib/models/porcelain.rb', line 12432

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12434
12435
12436
# File 'lib/models/porcelain.rb', line 12434

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



12436
12437
12438
# File 'lib/models/porcelain.rb', line 12436

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12438
12439
12440
# File 'lib/models/porcelain.rb', line 12438

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12440
12441
12442
# File 'lib/models/porcelain.rb', line 12440

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12442
12443
12444
# File 'lib/models/porcelain.rb', line 12442

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12444
12445
12446
# File 'lib/models/porcelain.rb', line 12444

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12480
12481
12482
12483
12484
12485
12486
# File 'lib/models/porcelain.rb', line 12480

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end