Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
# File 'lib/models/porcelain.rb', line 12372

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12342
12343
12344
# File 'lib/models/porcelain.rb', line 12342

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12344
12345
12346
# File 'lib/models/porcelain.rb', line 12344

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12346
12347
12348
# File 'lib/models/porcelain.rb', line 12346

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12348
12349
12350
# File 'lib/models/porcelain.rb', line 12348

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12350
12351
12352
# File 'lib/models/porcelain.rb', line 12350

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12352
12353
12354
# File 'lib/models/porcelain.rb', line 12352

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12354
12355
12356
# File 'lib/models/porcelain.rb', line 12354

def name
  @name
end

#passwordObject

The password to authenticate with.



12356
12357
12358
# File 'lib/models/porcelain.rb', line 12356

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



12358
12359
12360
# File 'lib/models/porcelain.rb', line 12358

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12360
12361
12362
# File 'lib/models/porcelain.rb', line 12360

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



12362
12363
12364
# File 'lib/models/porcelain.rb', line 12362

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12364
12365
12366
# File 'lib/models/porcelain.rb', line 12364

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12366
12367
12368
# File 'lib/models/porcelain.rb', line 12366

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12368
12369
12370
# File 'lib/models/porcelain.rb', line 12368

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12370
12371
12372
# File 'lib/models/porcelain.rb', line 12370

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12406
12407
12408
12409
12410
12411
12412
# File 'lib/models/porcelain.rb', line 12406

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end