Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



12010
12011
12012
12013
12014
12015
12016
12017
12018
12019
12020
12021
12022
12023
12024
12025
12026
12027
12028
12029
12030
12031
12032
12033
12034
12035
12036
12037
12038
12039
12040
12041
12042
# File 'lib/models/porcelain.rb', line 12010

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11980
11981
11982
# File 'lib/models/porcelain.rb', line 11980

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



11982
11983
11984
# File 'lib/models/porcelain.rb', line 11982

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11984
11985
11986
# File 'lib/models/porcelain.rb', line 11984

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11986
11987
11988
# File 'lib/models/porcelain.rb', line 11986

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11988
11989
11990
# File 'lib/models/porcelain.rb', line 11988

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11990
11991
11992
# File 'lib/models/porcelain.rb', line 11990

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11992
11993
11994
# File 'lib/models/porcelain.rb', line 11992

def name
  @name
end

#passwordObject

The password to authenticate with.



11994
11995
11996
# File 'lib/models/porcelain.rb', line 11994

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



11996
11997
11998
# File 'lib/models/porcelain.rb', line 11996

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11998
11999
12000
# File 'lib/models/porcelain.rb', line 11998

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



12000
12001
12002
# File 'lib/models/porcelain.rb', line 12000

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12002
12003
12004
# File 'lib/models/porcelain.rb', line 12002

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12004
12005
12006
# File 'lib/models/porcelain.rb', line 12004

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12006
12007
12008
# File 'lib/models/porcelain.rb', line 12006

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12008
12009
12010
# File 'lib/models/porcelain.rb', line 12008

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12044
12045
12046
12047
12048
12049
12050
# File 'lib/models/porcelain.rb', line 12044

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end