Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



11922
11923
11924
11925
11926
11927
11928
11929
11930
11931
11932
11933
11934
11935
11936
11937
11938
11939
11940
11941
11942
11943
11944
11945
11946
11947
11948
11949
11950
11951
11952
11953
11954
# File 'lib/models/porcelain.rb', line 11922

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11892
11893
11894
# File 'lib/models/porcelain.rb', line 11892

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



11894
11895
11896
# File 'lib/models/porcelain.rb', line 11894

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11896
11897
11898
# File 'lib/models/porcelain.rb', line 11896

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11898
11899
11900
# File 'lib/models/porcelain.rb', line 11898

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11900
11901
11902
# File 'lib/models/porcelain.rb', line 11900

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11902
11903
11904
# File 'lib/models/porcelain.rb', line 11902

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11904
11905
11906
# File 'lib/models/porcelain.rb', line 11904

def name
  @name
end

#passwordObject

The password to authenticate with.



11906
11907
11908
# File 'lib/models/porcelain.rb', line 11906

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



11908
11909
11910
# File 'lib/models/porcelain.rb', line 11908

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11910
11911
11912
# File 'lib/models/porcelain.rb', line 11910

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



11912
11913
11914
# File 'lib/models/porcelain.rb', line 11912

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11914
11915
11916
# File 'lib/models/porcelain.rb', line 11914

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11916
11917
11918
# File 'lib/models/porcelain.rb', line 11916

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11918
11919
11920
# File 'lib/models/porcelain.rb', line 11918

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11920
11921
11922
# File 'lib/models/porcelain.rb', line 11920

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11956
11957
11958
11959
11960
11961
11962
# File 'lib/models/porcelain.rb', line 11956

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end