Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



11682
11683
11684
11685
11686
11687
11688
11689
11690
11691
11692
11693
11694
11695
11696
11697
11698
11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
# File 'lib/models/porcelain.rb', line 11682

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11652
11653
11654
# File 'lib/models/porcelain.rb', line 11652

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



11654
11655
11656
# File 'lib/models/porcelain.rb', line 11654

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11656
11657
11658
# File 'lib/models/porcelain.rb', line 11656

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11658
11659
11660
# File 'lib/models/porcelain.rb', line 11658

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11660
11661
11662
# File 'lib/models/porcelain.rb', line 11660

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11662
11663
11664
# File 'lib/models/porcelain.rb', line 11662

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11664
11665
11666
# File 'lib/models/porcelain.rb', line 11664

def name
  @name
end

#passwordObject

The password to authenticate with.



11666
11667
11668
# File 'lib/models/porcelain.rb', line 11666

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



11668
11669
11670
# File 'lib/models/porcelain.rb', line 11668

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11670
11671
11672
# File 'lib/models/porcelain.rb', line 11670

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



11672
11673
11674
# File 'lib/models/porcelain.rb', line 11672

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11674
11675
11676
# File 'lib/models/porcelain.rb', line 11674

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11676
11677
11678
# File 'lib/models/porcelain.rb', line 11676

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11678
11679
11680
# File 'lib/models/porcelain.rb', line 11678

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11680
11681
11682
# File 'lib/models/porcelain.rb', line 11680

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11716
11717
11718
11719
11720
11721
11722
# File 'lib/models/porcelain.rb', line 11716

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end