Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#schema ⇒ Object
The schema to provide on authentication.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
11613 11614 11615 11616 11617 11618 11619 11620 11621 11622 11623 11624 11625 11626 11627 11628 11629 11630 11631 11632 11633 11634 11635 11636 11637 11638 11639 11640 11641 11642 11643 11644 11645 |
# File 'lib/models/porcelain.rb', line 11613 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11583 11584 11585 |
# File 'lib/models/porcelain.rb', line 11583 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
11585 11586 11587 |
# File 'lib/models/porcelain.rb', line 11585 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11587 11588 11589 |
# File 'lib/models/porcelain.rb', line 11587 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11589 11590 11591 |
# File 'lib/models/porcelain.rb', line 11589 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11591 11592 11593 |
# File 'lib/models/porcelain.rb', line 11591 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11593 11594 11595 |
# File 'lib/models/porcelain.rb', line 11593 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11595 11596 11597 |
# File 'lib/models/porcelain.rb', line 11595 def name @name end |
#password ⇒ Object
The password to authenticate with.
11597 11598 11599 |
# File 'lib/models/porcelain.rb', line 11597 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11599 11600 11601 |
# File 'lib/models/porcelain.rb', line 11599 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11601 11602 11603 |
# File 'lib/models/porcelain.rb', line 11601 def proxy_cluster_id @proxy_cluster_id end |
#schema ⇒ Object
The schema to provide on authentication.
11603 11604 11605 |
# File 'lib/models/porcelain.rb', line 11603 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11605 11606 11607 |
# File 'lib/models/porcelain.rb', line 11605 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11607 11608 11609 |
# File 'lib/models/porcelain.rb', line 11607 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11609 11610 11611 |
# File 'lib/models/porcelain.rb', line 11609 def @tags end |
#username ⇒ Object
The username to authenticate with.
11611 11612 11613 |
# File 'lib/models/porcelain.rb', line 11611 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11647 11648 11649 11650 11651 11652 11653 |
# File 'lib/models/porcelain.rb', line 11647 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |