Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



11606
11607
11608
11609
11610
11611
11612
11613
11614
11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
11626
11627
11628
11629
11630
11631
11632
11633
11634
11635
11636
11637
11638
# File 'lib/models/porcelain.rb', line 11606

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11576
11577
11578
# File 'lib/models/porcelain.rb', line 11576

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



11578
11579
11580
# File 'lib/models/porcelain.rb', line 11578

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11580
11581
11582
# File 'lib/models/porcelain.rb', line 11580

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11582
11583
11584
# File 'lib/models/porcelain.rb', line 11582

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11584
11585
11586
# File 'lib/models/porcelain.rb', line 11584

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11586
11587
11588
# File 'lib/models/porcelain.rb', line 11586

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11588
11589
11590
# File 'lib/models/porcelain.rb', line 11588

def name
  @name
end

#passwordObject

The password to authenticate with.



11590
11591
11592
# File 'lib/models/porcelain.rb', line 11590

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



11592
11593
11594
# File 'lib/models/porcelain.rb', line 11592

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11594
11595
11596
# File 'lib/models/porcelain.rb', line 11594

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The schema to provide on authentication.



11596
11597
11598
# File 'lib/models/porcelain.rb', line 11596

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11598
11599
11600
# File 'lib/models/porcelain.rb', line 11598

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11600
11601
11602
# File 'lib/models/porcelain.rb', line 11600

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11602
11603
11604
# File 'lib/models/porcelain.rb', line 11602

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11604
11605
11606
# File 'lib/models/porcelain.rb', line 11604

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11640
11641
11642
11643
11644
11645
11646
# File 'lib/models/porcelain.rb', line 11640

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end