Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#schema ⇒ Object
The schema to provide on authentication.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
11280 11281 11282 11283 11284 11285 11286 11287 11288 11289 11290 11291 11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 11307 11308 11309 11310 |
# File 'lib/models/porcelain.rb', line 11280 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11252 11253 11254 |
# File 'lib/models/porcelain.rb', line 11252 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
11254 11255 11256 |
# File 'lib/models/porcelain.rb', line 11254 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11256 11257 11258 |
# File 'lib/models/porcelain.rb', line 11256 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11258 11259 11260 |
# File 'lib/models/porcelain.rb', line 11258 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11260 11261 11262 |
# File 'lib/models/porcelain.rb', line 11260 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11262 11263 11264 |
# File 'lib/models/porcelain.rb', line 11262 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11264 11265 11266 |
# File 'lib/models/porcelain.rb', line 11264 def name @name end |
#password ⇒ Object
The password to authenticate with.
11266 11267 11268 |
# File 'lib/models/porcelain.rb', line 11266 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11268 11269 11270 |
# File 'lib/models/porcelain.rb', line 11268 def port_override @port_override end |
#schema ⇒ Object
The schema to provide on authentication.
11270 11271 11272 |
# File 'lib/models/porcelain.rb', line 11270 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11272 11273 11274 |
# File 'lib/models/porcelain.rb', line 11272 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11274 11275 11276 |
# File 'lib/models/porcelain.rb', line 11274 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11276 11277 11278 |
# File 'lib/models/porcelain.rb', line 11276 def @tags end |
#username ⇒ Object
The username to authenticate with.
11278 11279 11280 |
# File 'lib/models/porcelain.rb', line 11278 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11312 11313 11314 11315 11316 11317 11318 |
# File 'lib/models/porcelain.rb', line 11312 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |