Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#schema ⇒ Object
The schema to provide on authentication.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 11121 11122 11123 11124 11125 11126 11127 11128 11129 11130 11131 11132 11133 11134 11135 11136 11137 11138 11139 11140 11141 |
# File 'lib/models/porcelain.rb', line 11111 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11083 11084 11085 |
# File 'lib/models/porcelain.rb', line 11083 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
11085 11086 11087 |
# File 'lib/models/porcelain.rb', line 11085 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11087 11088 11089 |
# File 'lib/models/porcelain.rb', line 11087 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11089 11090 11091 |
# File 'lib/models/porcelain.rb', line 11089 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11091 11092 11093 |
# File 'lib/models/porcelain.rb', line 11091 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11093 11094 11095 |
# File 'lib/models/porcelain.rb', line 11093 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11095 11096 11097 |
# File 'lib/models/porcelain.rb', line 11095 def name @name end |
#password ⇒ Object
The password to authenticate with.
11097 11098 11099 |
# File 'lib/models/porcelain.rb', line 11097 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11099 11100 11101 |
# File 'lib/models/porcelain.rb', line 11099 def port_override @port_override end |
#schema ⇒ Object
The schema to provide on authentication.
11101 11102 11103 |
# File 'lib/models/porcelain.rb', line 11101 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11103 11104 11105 |
# File 'lib/models/porcelain.rb', line 11103 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11105 11106 11107 |
# File 'lib/models/porcelain.rb', line 11105 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11107 11108 11109 |
# File 'lib/models/porcelain.rb', line 11107 def @tags end |
#username ⇒ Object
The username to authenticate with.
11109 11110 11111 |
# File 'lib/models/porcelain.rb', line 11109 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11143 11144 11145 11146 11147 11148 11149 |
# File 'lib/models/porcelain.rb', line 11143 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |