Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
9459
9460
9461
9462
9463
9464
9465
9466
9467
9468
9469
9470
9471
9472
9473
9474
# File 'lib/models/porcelain.rb', line 9444

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9416
9417
9418
# File 'lib/models/porcelain.rb', line 9416

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



9418
9419
9420
# File 'lib/models/porcelain.rb', line 9418

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9420
9421
9422
# File 'lib/models/porcelain.rb', line 9420

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9422
9423
9424
# File 'lib/models/porcelain.rb', line 9422

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9424
9425
9426
# File 'lib/models/porcelain.rb', line 9424

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9426
9427
9428
# File 'lib/models/porcelain.rb', line 9426

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9428
9429
9430
# File 'lib/models/porcelain.rb', line 9428

def name
  @name
end

#passwordObject

The password to authenticate with.



9430
9431
9432
# File 'lib/models/porcelain.rb', line 9430

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



9432
9433
9434
# File 'lib/models/porcelain.rb', line 9432

def port_override
  @port_override
end

#schemaObject

The schema to provide on authentication.



9434
9435
9436
# File 'lib/models/porcelain.rb', line 9434

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9436
9437
9438
# File 'lib/models/porcelain.rb', line 9436

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9438
9439
9440
# File 'lib/models/porcelain.rb', line 9438

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9440
9441
9442
# File 'lib/models/porcelain.rb', line 9440

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9442
9443
9444
# File 'lib/models/porcelain.rb', line 9442

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9476
9477
9478
9479
9480
9481
9482
# File 'lib/models/porcelain.rb', line 9476

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end