Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#schema ⇒ Object
The schema to provide on authentication.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
8918 8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 8944 8945 8946 8947 8948 |
# File 'lib/models/porcelain.rb', line 8918 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8890 8891 8892 |
# File 'lib/models/porcelain.rb', line 8890 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
8892 8893 8894 |
# File 'lib/models/porcelain.rb', line 8892 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8894 8895 8896 |
# File 'lib/models/porcelain.rb', line 8894 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8896 8897 8898 |
# File 'lib/models/porcelain.rb', line 8896 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8898 8899 8900 |
# File 'lib/models/porcelain.rb', line 8898 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8900 8901 8902 |
# File 'lib/models/porcelain.rb', line 8900 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8902 8903 8904 |
# File 'lib/models/porcelain.rb', line 8902 def name @name end |
#password ⇒ Object
The password to authenticate with.
8904 8905 8906 |
# File 'lib/models/porcelain.rb', line 8904 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8906 8907 8908 |
# File 'lib/models/porcelain.rb', line 8906 def port_override @port_override end |
#schema ⇒ Object
The schema to provide on authentication.
8908 8909 8910 |
# File 'lib/models/porcelain.rb', line 8908 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8910 8911 8912 |
# File 'lib/models/porcelain.rb', line 8910 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8912 8913 8914 |
# File 'lib/models/porcelain.rb', line 8912 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8914 8915 8916 |
# File 'lib/models/porcelain.rb', line 8914 def @tags end |
#username ⇒ Object
The username to authenticate with.
8916 8917 8918 |
# File 'lib/models/porcelain.rb', line 8916 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8950 8951 8952 8953 8954 8955 8956 |
# File 'lib/models/porcelain.rb', line 8950 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |