Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#schema ⇒ Object
The schema to provide on authentication.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 |
# File 'lib/models/porcelain.rb', line 8746 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8718 8719 8720 |
# File 'lib/models/porcelain.rb', line 8718 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
8720 8721 8722 |
# File 'lib/models/porcelain.rb', line 8720 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8722 8723 8724 |
# File 'lib/models/porcelain.rb', line 8722 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8724 8725 8726 |
# File 'lib/models/porcelain.rb', line 8724 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8726 8727 8728 |
# File 'lib/models/porcelain.rb', line 8726 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8728 8729 8730 |
# File 'lib/models/porcelain.rb', line 8728 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8730 8731 8732 |
# File 'lib/models/porcelain.rb', line 8730 def name @name end |
#password ⇒ Object
The password to authenticate with.
8732 8733 8734 |
# File 'lib/models/porcelain.rb', line 8732 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8734 8735 8736 |
# File 'lib/models/porcelain.rb', line 8734 def port_override @port_override end |
#schema ⇒ Object
The schema to provide on authentication.
8736 8737 8738 |
# File 'lib/models/porcelain.rb', line 8736 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8738 8739 8740 |
# File 'lib/models/porcelain.rb', line 8738 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8740 8741 8742 |
# File 'lib/models/porcelain.rb', line 8740 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8742 8743 8744 |
# File 'lib/models/porcelain.rb', line 8742 def @tags end |
#username ⇒ Object
The username to authenticate with.
8744 8745 8746 |
# File 'lib/models/porcelain.rb', line 8744 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8778 8779 8780 8781 8782 8783 8784 |
# File 'lib/models/porcelain.rb', line 8778 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |