Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#schema ⇒ Object
The schema to provide on authentication.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 |
# File 'lib/models/porcelain.rb', line 8323 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8295 8296 8297 |
# File 'lib/models/porcelain.rb', line 8295 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
8297 8298 8299 |
# File 'lib/models/porcelain.rb', line 8297 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8299 8300 8301 |
# File 'lib/models/porcelain.rb', line 8299 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8301 8302 8303 |
# File 'lib/models/porcelain.rb', line 8301 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8303 8304 8305 |
# File 'lib/models/porcelain.rb', line 8303 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8305 8306 8307 |
# File 'lib/models/porcelain.rb', line 8305 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8307 8308 8309 |
# File 'lib/models/porcelain.rb', line 8307 def name @name end |
#password ⇒ Object
The password to authenticate with.
8309 8310 8311 |
# File 'lib/models/porcelain.rb', line 8309 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8311 8312 8313 |
# File 'lib/models/porcelain.rb', line 8311 def port_override @port_override end |
#schema ⇒ Object
The schema to provide on authentication.
8313 8314 8315 |
# File 'lib/models/porcelain.rb', line 8313 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8315 8316 8317 |
# File 'lib/models/porcelain.rb', line 8315 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8317 8318 8319 |
# File 'lib/models/porcelain.rb', line 8317 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8319 8320 8321 |
# File 'lib/models/porcelain.rb', line 8319 def @tags end |
#username ⇒ Object
The username to authenticate with.
8321 8322 8323 |
# File 'lib/models/porcelain.rb', line 8321 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8355 8356 8357 8358 8359 8360 8361 |
# File 'lib/models/porcelain.rb', line 8355 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |