Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
8157
8158
8159
8160
8161
8162
8163
8164
8165
8166
8167
8168
8169
8170
8171
8172
# File 'lib/models/porcelain.rb', line 8142

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



8114
8115
8116
# File 'lib/models/porcelain.rb', line 8114

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



8116
8117
8118
# File 'lib/models/porcelain.rb', line 8116

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8118
8119
8120
# File 'lib/models/porcelain.rb', line 8118

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8120
8121
8122
# File 'lib/models/porcelain.rb', line 8120

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



8122
8123
8124
# File 'lib/models/porcelain.rb', line 8122

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8124
8125
8126
# File 'lib/models/porcelain.rb', line 8124

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8126
8127
8128
# File 'lib/models/porcelain.rb', line 8126

def name
  @name
end

#passwordObject

Returns the value of attribute password.



8128
8129
8130
# File 'lib/models/porcelain.rb', line 8128

def password
  @password
end

#port_overrideObject

Returns the value of attribute port_override.



8130
8131
8132
# File 'lib/models/porcelain.rb', line 8130

def port_override
  @port_override
end

#schemaObject

Returns the value of attribute schema.



8132
8133
8134
# File 'lib/models/porcelain.rb', line 8132

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8134
8135
8136
# File 'lib/models/porcelain.rb', line 8134

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8136
8137
8138
# File 'lib/models/porcelain.rb', line 8136

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8138
8139
8140
# File 'lib/models/porcelain.rb', line 8138

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



8140
8141
8142
# File 'lib/models/porcelain.rb', line 8140

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8174
8175
8176
8177
8178
8179
8180
# File 'lib/models/porcelain.rb', line 8174

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end