Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
# File 'lib/models/porcelain.rb', line 8078

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



8050
8051
8052
# File 'lib/models/porcelain.rb', line 8050

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



8052
8053
8054
# File 'lib/models/porcelain.rb', line 8052

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8054
8055
8056
# File 'lib/models/porcelain.rb', line 8054

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8056
8057
8058
# File 'lib/models/porcelain.rb', line 8056

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



8058
8059
8060
# File 'lib/models/porcelain.rb', line 8058

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8060
8061
8062
# File 'lib/models/porcelain.rb', line 8060

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8062
8063
8064
# File 'lib/models/porcelain.rb', line 8062

def name
  @name
end

#passwordObject

Returns the value of attribute password.



8064
8065
8066
# File 'lib/models/porcelain.rb', line 8064

def password
  @password
end

#port_overrideObject

Returns the value of attribute port_override.



8066
8067
8068
# File 'lib/models/porcelain.rb', line 8066

def port_override
  @port_override
end

#schemaObject

Returns the value of attribute schema.



8068
8069
8070
# File 'lib/models/porcelain.rb', line 8068

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8070
8071
8072
# File 'lib/models/porcelain.rb', line 8070

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8072
8073
8074
# File 'lib/models/porcelain.rb', line 8072

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8074
8075
8076
# File 'lib/models/porcelain.rb', line 8074

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



8076
8077
8078
# File 'lib/models/porcelain.rb', line 8076

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8110
8111
8112
8113
8114
8115
8116
# File 'lib/models/porcelain.rb', line 8110

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end