Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 |
# File 'lib/models/porcelain.rb', line 7904 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7876 7877 7878 |
# File 'lib/models/porcelain.rb', line 7876 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
7878 7879 7880 |
# File 'lib/models/porcelain.rb', line 7878 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7880 7881 7882 |
# File 'lib/models/porcelain.rb', line 7880 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7882 7883 7884 |
# File 'lib/models/porcelain.rb', line 7882 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7884 7885 7886 |
# File 'lib/models/porcelain.rb', line 7884 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7886 7887 7888 |
# File 'lib/models/porcelain.rb', line 7886 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7888 7889 7890 |
# File 'lib/models/porcelain.rb', line 7888 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
7890 7891 7892 |
# File 'lib/models/porcelain.rb', line 7890 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7892 7893 7894 |
# File 'lib/models/porcelain.rb', line 7892 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
7894 7895 7896 |
# File 'lib/models/porcelain.rb', line 7894 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7896 7897 7898 |
# File 'lib/models/porcelain.rb', line 7896 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7898 7899 7900 |
# File 'lib/models/porcelain.rb', line 7898 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7900 7901 7902 |
# File 'lib/models/porcelain.rb', line 7900 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7902 7903 7904 |
# File 'lib/models/porcelain.rb', line 7902 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7936 7937 7938 7939 7940 7941 7942 |
# File 'lib/models/porcelain.rb', line 7936 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |