Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



7401
7402
7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
7419
7420
7421
7422
7423
7424
7425
7426
7427
7428
7429
# File 'lib/models/porcelain.rb', line 7401

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  schema: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



7375
7376
7377
# File 'lib/models/porcelain.rb', line 7375

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



7377
7378
7379
# File 'lib/models/porcelain.rb', line 7377

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7379
7380
7381
# File 'lib/models/porcelain.rb', line 7379

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7381
7382
7383
# File 'lib/models/porcelain.rb', line 7381

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7383
7384
7385
# File 'lib/models/porcelain.rb', line 7383

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7385
7386
7387
# File 'lib/models/porcelain.rb', line 7385

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7387
7388
7389
# File 'lib/models/porcelain.rb', line 7387

def name
  @name
end

#passwordObject

Returns the value of attribute password.



7389
7390
7391
# File 'lib/models/porcelain.rb', line 7389

def password
  @password
end

#port_overrideObject

Returns the value of attribute port_override.



7391
7392
7393
# File 'lib/models/porcelain.rb', line 7391

def port_override
  @port_override
end

#schemaObject

Returns the value of attribute schema.



7393
7394
7395
# File 'lib/models/porcelain.rb', line 7393

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7395
7396
7397
# File 'lib/models/porcelain.rb', line 7395

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



7397
7398
7399
# File 'lib/models/porcelain.rb', line 7397

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7399
7400
7401
# File 'lib/models/porcelain.rb', line 7399

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7431
7432
7433
7434
7435
7436
7437
# File 'lib/models/porcelain.rb', line 7431

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end