Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



6489
6490
6491
6492
6493
6494
6495
6496
6497
6498
6499
6500
6501
6502
6503
6504
6505
6506
6507
6508
6509
6510
6511
6512
6513
6514
6515
6516
6517
# File 'lib/models/porcelain.rb', line 6489

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  schema: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



6463
6464
6465
# File 'lib/models/porcelain.rb', line 6463

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



6465
6466
6467
# File 'lib/models/porcelain.rb', line 6465

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6467
6468
6469
# File 'lib/models/porcelain.rb', line 6467

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6469
6470
6471
# File 'lib/models/porcelain.rb', line 6469

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6471
6472
6473
# File 'lib/models/porcelain.rb', line 6471

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6473
6474
6475
# File 'lib/models/porcelain.rb', line 6473

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6475
6476
6477
# File 'lib/models/porcelain.rb', line 6475

def name
  @name
end

#passwordObject

Returns the value of attribute password.



6477
6478
6479
# File 'lib/models/porcelain.rb', line 6477

def password
  @password
end

#port_overrideObject

Returns the value of attribute port_override.



6479
6480
6481
# File 'lib/models/porcelain.rb', line 6479

def port_override
  @port_override
end

#schemaObject

Returns the value of attribute schema.



6481
6482
6483
# File 'lib/models/porcelain.rb', line 6481

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6483
6484
6485
# File 'lib/models/porcelain.rb', line 6483

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6485
6486
6487
# File 'lib/models/porcelain.rb', line 6485

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6487
6488
6489
# File 'lib/models/porcelain.rb', line 6487

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6519
6520
6521
6522
6523
6524
6525
# File 'lib/models/porcelain.rb', line 6519

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end