Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 6518 |
# File 'lib/models/porcelain.rb', line 6490 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6464 6465 6466 |
# File 'lib/models/porcelain.rb', line 6464 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
6466 6467 6468 |
# File 'lib/models/porcelain.rb', line 6466 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6468 6469 6470 |
# File 'lib/models/porcelain.rb', line 6468 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6470 6471 6472 |
# File 'lib/models/porcelain.rb', line 6470 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6472 6473 6474 |
# File 'lib/models/porcelain.rb', line 6472 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6474 6475 6476 |
# File 'lib/models/porcelain.rb', line 6474 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6476 6477 6478 |
# File 'lib/models/porcelain.rb', line 6476 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6478 6479 6480 |
# File 'lib/models/porcelain.rb', line 6478 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6480 6481 6482 |
# File 'lib/models/porcelain.rb', line 6480 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
6482 6483 6484 |
# File 'lib/models/porcelain.rb', line 6482 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6484 6485 6486 |
# File 'lib/models/porcelain.rb', line 6484 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6486 6487 6488 |
# File 'lib/models/porcelain.rb', line 6486 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6488 6489 6490 |
# File 'lib/models/porcelain.rb', line 6488 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6520 6521 6522 6523 6524 6525 6526 |
# File 'lib/models/porcelain.rb', line 6520 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |