Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 |
# File 'lib/models/porcelain.rb', line 6382 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6356 6357 6358 |
# File 'lib/models/porcelain.rb', line 6356 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
6358 6359 6360 |
# File 'lib/models/porcelain.rb', line 6358 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6360 6361 6362 |
# File 'lib/models/porcelain.rb', line 6360 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6362 6363 6364 |
# File 'lib/models/porcelain.rb', line 6362 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6364 6365 6366 |
# File 'lib/models/porcelain.rb', line 6364 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6366 6367 6368 |
# File 'lib/models/porcelain.rb', line 6366 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6368 6369 6370 |
# File 'lib/models/porcelain.rb', line 6368 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6370 6371 6372 |
# File 'lib/models/porcelain.rb', line 6370 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6372 6373 6374 |
# File 'lib/models/porcelain.rb', line 6372 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
6374 6375 6376 |
# File 'lib/models/porcelain.rb', line 6374 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6376 6377 6378 |
# File 'lib/models/porcelain.rb', line 6376 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6378 6379 6380 |
# File 'lib/models/porcelain.rb', line 6378 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6380 6381 6382 |
# File 'lib/models/porcelain.rb', line 6380 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6412 6413 6414 6415 6416 6417 6418 |
# File 'lib/models/porcelain.rb', line 6412 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |