Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
6232 6233 6234 6235 6236 6237 6238 6239 6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 |
# File 'lib/models/porcelain.rb', line 6232 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6206 6207 6208 |
# File 'lib/models/porcelain.rb', line 6206 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
6208 6209 6210 |
# File 'lib/models/porcelain.rb', line 6208 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6210 6211 6212 |
# File 'lib/models/porcelain.rb', line 6210 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6212 6213 6214 |
# File 'lib/models/porcelain.rb', line 6212 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6214 6215 6216 |
# File 'lib/models/porcelain.rb', line 6214 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6216 6217 6218 |
# File 'lib/models/porcelain.rb', line 6216 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6218 6219 6220 |
# File 'lib/models/porcelain.rb', line 6218 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6220 6221 6222 |
# File 'lib/models/porcelain.rb', line 6220 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6222 6223 6224 |
# File 'lib/models/porcelain.rb', line 6222 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
6224 6225 6226 |
# File 'lib/models/porcelain.rb', line 6224 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6226 6227 6228 |
# File 'lib/models/porcelain.rb', line 6226 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6228 6229 6230 |
# File 'lib/models/porcelain.rb', line 6228 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6230 6231 6232 |
# File 'lib/models/porcelain.rb', line 6230 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6262 6263 6264 6265 6266 6267 6268 |
# File 'lib/models/porcelain.rb', line 6262 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |