Class: SDM::Snowflake
- Inherits:
-
Object
- Object
- SDM::Snowflake
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Snowflake
constructor
A new instance of Snowflake.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Snowflake
Returns a new instance of Snowflake.
7239 7240 7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 7288 7289 |
# File 'lib/models/porcelain.rb', line 7239 def initialize( database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil ) if database != nil @database = database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port_override != nil @port_override = port_override end if schema != nil @schema = schema end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#database ⇒ Object
Returns the value of attribute database.
7215 7216 7217 |
# File 'lib/models/porcelain.rb', line 7215 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7217 7218 7219 |
# File 'lib/models/porcelain.rb', line 7217 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7219 7220 7221 |
# File 'lib/models/porcelain.rb', line 7219 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7221 7222 7223 |
# File 'lib/models/porcelain.rb', line 7221 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7223 7224 7225 |
# File 'lib/models/porcelain.rb', line 7223 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7225 7226 7227 |
# File 'lib/models/porcelain.rb', line 7225 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
7227 7228 7229 |
# File 'lib/models/porcelain.rb', line 7227 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7229 7230 7231 |
# File 'lib/models/porcelain.rb', line 7229 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
7231 7232 7233 |
# File 'lib/models/porcelain.rb', line 7231 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7233 7234 7235 |
# File 'lib/models/porcelain.rb', line 7233 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7235 7236 7237 |
# File 'lib/models/porcelain.rb', line 7235 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7237 7238 7239 |
# File 'lib/models/porcelain.rb', line 7237 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7291 7292 7293 7294 7295 7296 7297 |
# File 'lib/models/porcelain.rb', line 7291 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |