Class: SDM::Snowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Snowflake

Returns a new instance of Snowflake.



17836
17837
17838
17839
17840
17841
17842
17843
17844
17845
17846
17847
17848
17849
17850
17851
17852
17853
17854
17855
17856
17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
# File 'lib/models/porcelain.rb', line 17836

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17804
17805
17806
# File 'lib/models/porcelain.rb', line 17804

def bind_interface
  @bind_interface
end

#database ⇒ Object

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



17806
17807
17808
# File 'lib/models/porcelain.rb', line 17806

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



17808
17809
17810
# File 'lib/models/porcelain.rb', line 17808

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



17810
17811
17812
# File 'lib/models/porcelain.rb', line 17810

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



17812
17813
17814
# File 'lib/models/porcelain.rb', line 17812

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



17814
17815
17816
# File 'lib/models/porcelain.rb', line 17814

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



17816
17817
17818
# File 'lib/models/porcelain.rb', line 17816

def name
  @name
end

#password ⇒ Object



17818
17819
17820
# File 'lib/models/porcelain.rb', line 17818

def password
  @password
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17820
17821
17822
# File 'lib/models/porcelain.rb', line 17820

def port_override
  @port_override
end

#private_key ⇒ Object

RSA Private Key for authentication



17822
17823
17824
# File 'lib/models/porcelain.rb', line 17822

def private_key
  @private_key
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



17824
17825
17826
# File 'lib/models/porcelain.rb', line 17824

def proxy_cluster_id
  @proxy_cluster_id
end

#schema ⇒ Object

The schema to provide on authentication.



17826
17827
17828
# File 'lib/models/porcelain.rb', line 17826

def schema
  @schema
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



17828
17829
17830
# File 'lib/models/porcelain.rb', line 17828

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17830
17831
17832
# File 'lib/models/porcelain.rb', line 17830

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



17832
17833
17834
# File 'lib/models/porcelain.rb', line 17832

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



17834
17835
17836
# File 'lib/models/porcelain.rb', line 17834

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17872
17873
17874
17875
17876
17877
17878
# File 'lib/models/porcelain.rb', line 17872

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end