Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_https: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



17851
17852
17853
17854
17855
17856
17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
17875
17876
17877
17878
17879
17880
17881
# File 'lib/models/porcelain.rb', line 17851

def initialize(
  bind_interface: nil,
  connecttodefault: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_https: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connecttodefault = connecttodefault == nil ? false : connecttodefault
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_https = use_https == nil ? false : use_https
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17823
17824
17825
# File 'lib/models/porcelain.rb', line 17823

def bind_interface
  @bind_interface
end

#connecttodefaultObject

If true, select the ACS with isDefault=true



17825
17826
17827
# File 'lib/models/porcelain.rb', line 17825

def connecttodefault
  @connecttodefault
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17827
17828
17829
# File 'lib/models/porcelain.rb', line 17827

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



17829
17830
17831
# File 'lib/models/porcelain.rb', line 17829

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17831
17832
17833
# File 'lib/models/porcelain.rb', line 17831

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



17833
17834
17835
# File 'lib/models/porcelain.rb', line 17833

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17835
17836
17837
# File 'lib/models/porcelain.rb', line 17835

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17837
17838
17839
# File 'lib/models/porcelain.rb', line 17837

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17839
17840
17841
# File 'lib/models/porcelain.rb', line 17839

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



17841
17842
17843
# File 'lib/models/porcelain.rb', line 17841

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17843
17844
17845
# File 'lib/models/porcelain.rb', line 17843

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



17845
17846
17847
# File 'lib/models/porcelain.rb', line 17845

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17847
17848
17849
# File 'lib/models/porcelain.rb', line 17847

def tags
  @tags
end

#use_httpsObject

This option enforces HTTPS on the client, not resource connection.



17849
17850
17851
# File 'lib/models/porcelain.rb', line 17849

def use_https
  @use_https
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17883
17884
17885
17886
17887
17888
17889
# File 'lib/models/porcelain.rb', line 17883

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end