Class: SDM::Snowsight
- Inherits:
-
Object
- Object
- SDM::Snowsight
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#connecttodefault ⇒ Object
If true, select the ACS with isDefault=true.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_username ⇒ Object
The StrongDM user email to use for healthchecks.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#samlmetadata ⇒ Object
The Metadata for your snowflake IDP integration.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_https ⇒ Object
This option enforces HTTPS on the client, not resource connection.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_https: nil) ⇒ Snowsight
constructor
A new instance of Snowsight.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_https: nil) ⇒ Snowsight
Returns a new instance of Snowsight.
17803 17804 17805 17806 17807 17808 17809 17810 17811 17812 17813 17814 17815 17816 17817 17818 17819 17820 17821 17822 17823 17824 17825 17826 17827 17828 17829 17830 17831 17832 17833 |
# File 'lib/models/porcelain.rb', line 17803 def initialize( bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_https: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @connecttodefault = connecttodefault == nil ? false : connecttodefault @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @samlmetadata = == nil ? "" : @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_https = use_https == nil ? false : use_https end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
17775 17776 17777 |
# File 'lib/models/porcelain.rb', line 17775 def bind_interface @bind_interface end |
#connecttodefault ⇒ Object
If true, select the ACS with isDefault=true
17777 17778 17779 |
# File 'lib/models/porcelain.rb', line 17777 def connecttodefault @connecttodefault end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
17779 17780 17781 |
# File 'lib/models/porcelain.rb', line 17779 def egress_filter @egress_filter end |
#healthcheck_username ⇒ Object
The StrongDM user email to use for healthchecks.
17781 17782 17783 |
# File 'lib/models/porcelain.rb', line 17781 def healthcheck_username @healthcheck_username end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
17783 17784 17785 |
# File 'lib/models/porcelain.rb', line 17783 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
17785 17786 17787 |
# File 'lib/models/porcelain.rb', line 17785 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
17787 17788 17789 |
# File 'lib/models/porcelain.rb', line 17787 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
17789 17790 17791 |
# File 'lib/models/porcelain.rb', line 17789 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
17791 17792 17793 |
# File 'lib/models/porcelain.rb', line 17791 def proxy_cluster_id @proxy_cluster_id end |
#samlmetadata ⇒ Object
The Metadata for your snowflake IDP integration
17793 17794 17795 |
# File 'lib/models/porcelain.rb', line 17793 def @samlmetadata end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
17795 17796 17797 |
# File 'lib/models/porcelain.rb', line 17795 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
17797 17798 17799 |
# File 'lib/models/porcelain.rb', line 17797 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17799 17800 17801 |
# File 'lib/models/porcelain.rb', line 17799 def @tags end |
#use_https ⇒ Object
This option enforces HTTPS on the client, not resource connection.
17801 17802 17803 |
# File 'lib/models/porcelain.rb', line 17801 def use_https @use_https end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17835 17836 17837 17838 17839 17840 17841 |
# File 'lib/models/porcelain.rb', line 17835 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |