Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_https: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



17719
17720
17721
17722
17723
17724
17725
17726
17727
17728
17729
17730
17731
17732
17733
17734
17735
17736
17737
17738
17739
17740
17741
17742
17743
17744
17745
17746
17747
17748
17749
# File 'lib/models/porcelain.rb', line 17719

def initialize(
  bind_interface: nil,
  connecttodefault: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_https: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connecttodefault = connecttodefault == nil ? false : connecttodefault
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_https = use_https == nil ? false : use_https
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17691
17692
17693
# File 'lib/models/porcelain.rb', line 17691

def bind_interface
  @bind_interface
end

#connecttodefaultObject

If true, select the ACS with isDefault=true



17693
17694
17695
# File 'lib/models/porcelain.rb', line 17693

def connecttodefault
  @connecttodefault
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17695
17696
17697
# File 'lib/models/porcelain.rb', line 17695

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



17697
17698
17699
# File 'lib/models/porcelain.rb', line 17697

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17699
17700
17701
# File 'lib/models/porcelain.rb', line 17699

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



17701
17702
17703
# File 'lib/models/porcelain.rb', line 17701

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17703
17704
17705
# File 'lib/models/porcelain.rb', line 17703

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17705
17706
17707
# File 'lib/models/porcelain.rb', line 17705

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17707
17708
17709
# File 'lib/models/porcelain.rb', line 17707

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



17709
17710
17711
# File 'lib/models/porcelain.rb', line 17709

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17711
17712
17713
# File 'lib/models/porcelain.rb', line 17711

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



17713
17714
17715
# File 'lib/models/porcelain.rb', line 17713

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17715
17716
17717
# File 'lib/models/porcelain.rb', line 17715

def tags
  @tags
end

#use_httpsObject

This option enforces HTTPS on the client, not resource connection.



17717
17718
17719
# File 'lib/models/porcelain.rb', line 17717

def use_https
  @use_https
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17751
17752
17753
17754
17755
17756
17757
# File 'lib/models/porcelain.rb', line 17751

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end