Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_https: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



17485
17486
17487
17488
17489
17490
17491
17492
17493
17494
17495
17496
17497
17498
17499
17500
17501
17502
17503
17504
17505
17506
17507
17508
17509
17510
17511
17512
17513
17514
17515
# File 'lib/models/porcelain.rb', line 17485

def initialize(
  bind_interface: nil,
  connecttodefault: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_https: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connecttodefault = connecttodefault == nil ? false : connecttodefault
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_https = use_https == nil ? false : use_https
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17457
17458
17459
# File 'lib/models/porcelain.rb', line 17457

def bind_interface
  @bind_interface
end

#connecttodefaultObject

If true, select the ACS with isDefault=true



17459
17460
17461
# File 'lib/models/porcelain.rb', line 17459

def connecttodefault
  @connecttodefault
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17461
17462
17463
# File 'lib/models/porcelain.rb', line 17461

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



17463
17464
17465
# File 'lib/models/porcelain.rb', line 17463

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17465
17466
17467
# File 'lib/models/porcelain.rb', line 17465

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



17467
17468
17469
# File 'lib/models/porcelain.rb', line 17467

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17469
17470
17471
# File 'lib/models/porcelain.rb', line 17469

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17471
17472
17473
# File 'lib/models/porcelain.rb', line 17471

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17473
17474
17475
# File 'lib/models/porcelain.rb', line 17473

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



17475
17476
17477
# File 'lib/models/porcelain.rb', line 17475

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17477
17478
17479
# File 'lib/models/porcelain.rb', line 17477

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



17479
17480
17481
# File 'lib/models/porcelain.rb', line 17479

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17481
17482
17483
# File 'lib/models/porcelain.rb', line 17481

def tags
  @tags
end

#use_httpsObject

This option enforces HTTPS on the client, not resource connection.



17483
17484
17485
# File 'lib/models/porcelain.rb', line 17483

def use_https
  @use_https
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17517
17518
17519
17520
17521
17522
17523
# File 'lib/models/porcelain.rb', line 17517

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end