Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_https: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



17369
17370
17371
17372
17373
17374
17375
17376
17377
17378
17379
17380
17381
17382
17383
17384
17385
17386
17387
17388
17389
17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
# File 'lib/models/porcelain.rb', line 17369

def initialize(
  bind_interface: nil,
  connecttodefault: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_https: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connecttodefault = connecttodefault == nil ? false : connecttodefault
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_https = use_https == nil ? false : use_https
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17341
17342
17343
# File 'lib/models/porcelain.rb', line 17341

def bind_interface
  @bind_interface
end

#connecttodefaultObject

If true, select the ACS with isDefault=true



17343
17344
17345
# File 'lib/models/porcelain.rb', line 17343

def connecttodefault
  @connecttodefault
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17345
17346
17347
# File 'lib/models/porcelain.rb', line 17345

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



17347
17348
17349
# File 'lib/models/porcelain.rb', line 17347

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17349
17350
17351
# File 'lib/models/porcelain.rb', line 17349

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



17351
17352
17353
# File 'lib/models/porcelain.rb', line 17351

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17353
17354
17355
# File 'lib/models/porcelain.rb', line 17353

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17355
17356
17357
# File 'lib/models/porcelain.rb', line 17355

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17357
17358
17359
# File 'lib/models/porcelain.rb', line 17357

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



17359
17360
17361
# File 'lib/models/porcelain.rb', line 17359

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17361
17362
17363
# File 'lib/models/porcelain.rb', line 17361

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



17363
17364
17365
# File 'lib/models/porcelain.rb', line 17363

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17365
17366
17367
# File 'lib/models/porcelain.rb', line 17365

def tags
  @tags
end

#use_httpsObject

This option enforces HTTPS on the client, not resource connection.



17367
17368
17369
# File 'lib/models/porcelain.rb', line 17367

def use_https
  @use_https
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17401
17402
17403
17404
17405
17406
17407
# File 'lib/models/porcelain.rb', line 17401

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end