Class: SDM::Snowsight
- Inherits:
-
Object
- Object
- SDM::Snowsight
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#connecttodefault ⇒ Object
If true, select the ACS with isDefault=true.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_username ⇒ Object
The StrongDM user email to use for healthchecks.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#samlmetadata ⇒ Object
The Metadata for your snowflake IDP integration.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
constructor
A new instance of Snowsight.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
Returns a new instance of Snowsight.
15786 15787 15788 15789 15790 15791 15792 15793 15794 15795 15796 15797 15798 15799 15800 15801 15802 15803 15804 15805 15806 15807 15808 15809 15810 15811 15812 15813 15814 |
# File 'lib/models/porcelain.rb', line 15786 def initialize( bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @connecttodefault = connecttodefault == nil ? false : connecttodefault @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @samlmetadata = == nil ? "" : @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
15760 15761 15762 |
# File 'lib/models/porcelain.rb', line 15760 def bind_interface @bind_interface end |
#connecttodefault ⇒ Object
If true, select the ACS with isDefault=true
15762 15763 15764 |
# File 'lib/models/porcelain.rb', line 15762 def connecttodefault @connecttodefault end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
15764 15765 15766 |
# File 'lib/models/porcelain.rb', line 15764 def egress_filter @egress_filter end |
#healthcheck_username ⇒ Object
The StrongDM user email to use for healthchecks.
15766 15767 15768 |
# File 'lib/models/porcelain.rb', line 15766 def healthcheck_username @healthcheck_username end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
15768 15769 15770 |
# File 'lib/models/porcelain.rb', line 15768 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
15770 15771 15772 |
# File 'lib/models/porcelain.rb', line 15770 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
15772 15773 15774 |
# File 'lib/models/porcelain.rb', line 15772 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
15774 15775 15776 |
# File 'lib/models/porcelain.rb', line 15774 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
15776 15777 15778 |
# File 'lib/models/porcelain.rb', line 15776 def proxy_cluster_id @proxy_cluster_id end |
#samlmetadata ⇒ Object
The Metadata for your snowflake IDP integration
15778 15779 15780 |
# File 'lib/models/porcelain.rb', line 15778 def @samlmetadata end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
15780 15781 15782 |
# File 'lib/models/porcelain.rb', line 15780 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
15782 15783 15784 |
# File 'lib/models/porcelain.rb', line 15782 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
15784 15785 15786 |
# File 'lib/models/porcelain.rb', line 15784 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15816 15817 15818 15819 15820 15821 15822 |
# File 'lib/models/porcelain.rb', line 15816 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |