Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



14764
14765
14766
14767
14768
14769
14770
14771
14772
14773
14774
14775
14776
14777
14778
14779
14780
14781
14782
14783
14784
14785
14786
14787
14788
14789
14790
# File 'lib/models/porcelain.rb', line 14764

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14740
14741
14742
# File 'lib/models/porcelain.rb', line 14740

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14742
14743
14744
# File 'lib/models/porcelain.rb', line 14742

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



14744
14745
14746
# File 'lib/models/porcelain.rb', line 14744

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14746
14747
14748
# File 'lib/models/porcelain.rb', line 14746

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



14748
14749
14750
# File 'lib/models/porcelain.rb', line 14748

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14750
14751
14752
# File 'lib/models/porcelain.rb', line 14750

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



14752
14753
14754
# File 'lib/models/porcelain.rb', line 14752

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14754
14755
14756
# File 'lib/models/porcelain.rb', line 14754

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



14756
14757
14758
# File 'lib/models/porcelain.rb', line 14756

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14758
14759
14760
# File 'lib/models/porcelain.rb', line 14758

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14760
14761
14762
# File 'lib/models/porcelain.rb', line 14760

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14762
14763
14764
# File 'lib/models/porcelain.rb', line 14762

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14792
14793
14794
14795
14796
14797
14798
# File 'lib/models/porcelain.rb', line 14792

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end