Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



14501
14502
14503
14504
14505
14506
14507
14508
14509
14510
14511
14512
14513
14514
14515
14516
14517
14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
# File 'lib/models/porcelain.rb', line 14501

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14477
14478
14479
# File 'lib/models/porcelain.rb', line 14477

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14479
14480
14481
# File 'lib/models/porcelain.rb', line 14479

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



14481
14482
14483
# File 'lib/models/porcelain.rb', line 14481

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14483
14484
14485
# File 'lib/models/porcelain.rb', line 14483

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



14485
14486
14487
# File 'lib/models/porcelain.rb', line 14485

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14487
14488
14489
# File 'lib/models/porcelain.rb', line 14487

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



14489
14490
14491
# File 'lib/models/porcelain.rb', line 14489

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14491
14492
14493
# File 'lib/models/porcelain.rb', line 14491

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



14493
14494
14495
# File 'lib/models/porcelain.rb', line 14493

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14495
14496
14497
# File 'lib/models/porcelain.rb', line 14495

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14497
14498
14499
# File 'lib/models/porcelain.rb', line 14497

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14499
14500
14501
# File 'lib/models/porcelain.rb', line 14499

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14529
14530
14531
14532
14533
14534
14535
# File 'lib/models/porcelain.rb', line 14529

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end