Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



14317
14318
14319
14320
14321
14322
14323
14324
14325
14326
14327
14328
14329
14330
14331
14332
14333
14334
14335
14336
14337
14338
14339
14340
14341
14342
14343
# File 'lib/models/porcelain.rb', line 14317

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14293
14294
14295
# File 'lib/models/porcelain.rb', line 14293

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14295
14296
14297
# File 'lib/models/porcelain.rb', line 14295

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



14297
14298
14299
# File 'lib/models/porcelain.rb', line 14297

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14299
14300
14301
# File 'lib/models/porcelain.rb', line 14299

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



14301
14302
14303
# File 'lib/models/porcelain.rb', line 14301

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14303
14304
14305
# File 'lib/models/porcelain.rb', line 14303

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



14305
14306
14307
# File 'lib/models/porcelain.rb', line 14305

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14307
14308
14309
# File 'lib/models/porcelain.rb', line 14307

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



14309
14310
14311
# File 'lib/models/porcelain.rb', line 14309

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14311
14312
14313
# File 'lib/models/porcelain.rb', line 14311

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14313
14314
14315
# File 'lib/models/porcelain.rb', line 14313

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14315
14316
14317
# File 'lib/models/porcelain.rb', line 14315

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14345
14346
14347
14348
14349
14350
14351
# File 'lib/models/porcelain.rb', line 14345

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end