Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
14316
14317
14318
14319
14320
14321
14322
14323
14324
14325
14326
14327
14328
14329
14330
14331
14332
# File 'lib/models/porcelain.rb', line 14306

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14282
14283
14284
# File 'lib/models/porcelain.rb', line 14282

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14284
14285
14286
# File 'lib/models/porcelain.rb', line 14284

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



14286
14287
14288
# File 'lib/models/porcelain.rb', line 14286

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14288
14289
14290
# File 'lib/models/porcelain.rb', line 14288

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



14290
14291
14292
# File 'lib/models/porcelain.rb', line 14290

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14292
14293
14294
# File 'lib/models/porcelain.rb', line 14292

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



14294
14295
14296
# File 'lib/models/porcelain.rb', line 14294

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14296
14297
14298
# File 'lib/models/porcelain.rb', line 14296

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



14298
14299
14300
# File 'lib/models/porcelain.rb', line 14298

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14300
14301
14302
# File 'lib/models/porcelain.rb', line 14300

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14302
14303
14304
# File 'lib/models/porcelain.rb', line 14302

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14304
14305
14306
# File 'lib/models/porcelain.rb', line 14304

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14334
14335
14336
14337
14338
14339
14340
# File 'lib/models/porcelain.rb', line 14334

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end