Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



14238
14239
14240
14241
14242
14243
14244
14245
14246
14247
14248
14249
14250
14251
14252
14253
14254
14255
14256
14257
14258
14259
14260
14261
14262
14263
14264
# File 'lib/models/porcelain.rb', line 14238

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14214
14215
14216
# File 'lib/models/porcelain.rb', line 14214

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14216
14217
14218
# File 'lib/models/porcelain.rb', line 14216

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



14218
14219
14220
# File 'lib/models/porcelain.rb', line 14218

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14220
14221
14222
# File 'lib/models/porcelain.rb', line 14220

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



14222
14223
14224
# File 'lib/models/porcelain.rb', line 14222

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14224
14225
14226
# File 'lib/models/porcelain.rb', line 14224

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



14226
14227
14228
# File 'lib/models/porcelain.rb', line 14226

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14228
14229
14230
# File 'lib/models/porcelain.rb', line 14228

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



14230
14231
14232
# File 'lib/models/porcelain.rb', line 14230

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14232
14233
14234
# File 'lib/models/porcelain.rb', line 14232

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14234
14235
14236
# File 'lib/models/porcelain.rb', line 14234

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14236
14237
14238
# File 'lib/models/porcelain.rb', line 14236

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14266
14267
14268
14269
14270
14271
14272
# File 'lib/models/porcelain.rb', line 14266

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end