Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



14164
14165
14166
14167
14168
14169
14170
14171
14172
14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
14188
14189
14190
# File 'lib/models/porcelain.rb', line 14164

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14140
14141
14142
# File 'lib/models/porcelain.rb', line 14140

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14142
14143
14144
# File 'lib/models/porcelain.rb', line 14142

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



14144
14145
14146
# File 'lib/models/porcelain.rb', line 14144

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14146
14147
14148
# File 'lib/models/porcelain.rb', line 14146

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



14148
14149
14150
# File 'lib/models/porcelain.rb', line 14148

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14150
14151
14152
# File 'lib/models/porcelain.rb', line 14150

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



14152
14153
14154
# File 'lib/models/porcelain.rb', line 14152

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14154
14155
14156
# File 'lib/models/porcelain.rb', line 14154

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



14156
14157
14158
# File 'lib/models/porcelain.rb', line 14156

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14158
14159
14160
# File 'lib/models/porcelain.rb', line 14158

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14160
14161
14162
# File 'lib/models/porcelain.rb', line 14160

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14162
14163
14164
# File 'lib/models/porcelain.rb', line 14162

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14192
14193
14194
14195
14196
14197
14198
# File 'lib/models/porcelain.rb', line 14192

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end