Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



14097
14098
14099
14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
# File 'lib/models/porcelain.rb', line 14097

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14073
14074
14075
# File 'lib/models/porcelain.rb', line 14073

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14075
14076
14077
# File 'lib/models/porcelain.rb', line 14075

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



14077
14078
14079
# File 'lib/models/porcelain.rb', line 14077

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14079
14080
14081
# File 'lib/models/porcelain.rb', line 14079

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



14081
14082
14083
# File 'lib/models/porcelain.rb', line 14081

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14083
14084
14085
# File 'lib/models/porcelain.rb', line 14083

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



14085
14086
14087
# File 'lib/models/porcelain.rb', line 14085

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14087
14088
14089
# File 'lib/models/porcelain.rb', line 14087

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



14089
14090
14091
# File 'lib/models/porcelain.rb', line 14089

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14091
14092
14093
# File 'lib/models/porcelain.rb', line 14091

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14093
14094
14095
# File 'lib/models/porcelain.rb', line 14093

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14095
14096
14097
# File 'lib/models/porcelain.rb', line 14095

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14125
14126
14127
14128
14129
14130
14131
# File 'lib/models/porcelain.rb', line 14125

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end