Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
12931
12932
12933
12934
12935
12936
12937
12938
12939
12940
12941
12942
12943
12944
12945
12946
12947
# File 'lib/models/porcelain.rb', line 12921

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12897
12898
12899
# File 'lib/models/porcelain.rb', line 12897

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12899
12900
12901
# File 'lib/models/porcelain.rb', line 12899

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



12901
12902
12903
# File 'lib/models/porcelain.rb', line 12901

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12903
12904
12905
# File 'lib/models/porcelain.rb', line 12903

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12905
12906
12907
# File 'lib/models/porcelain.rb', line 12905

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12907
12908
12909
# File 'lib/models/porcelain.rb', line 12907

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



12909
12910
12911
# File 'lib/models/porcelain.rb', line 12909

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12911
12912
12913
# File 'lib/models/porcelain.rb', line 12911

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



12913
12914
12915
# File 'lib/models/porcelain.rb', line 12913

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12915
12916
12917
# File 'lib/models/porcelain.rb', line 12915

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12917
12918
12919
# File 'lib/models/porcelain.rb', line 12917

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12919
12920
12921
# File 'lib/models/porcelain.rb', line 12919

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12949
12950
12951
12952
12953
12954
12955
# File 'lib/models/porcelain.rb', line 12949

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end