Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
12848
12849
12850
12851
12852
12853
12854
12855
12856
12857
12858
12859
12860
12861
12862
12863
12864
# File 'lib/models/porcelain.rb', line 12838

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12814
12815
12816
# File 'lib/models/porcelain.rb', line 12814

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12816
12817
12818
# File 'lib/models/porcelain.rb', line 12816

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



12818
12819
12820
# File 'lib/models/porcelain.rb', line 12818

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12820
12821
12822
# File 'lib/models/porcelain.rb', line 12820

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12822
12823
12824
# File 'lib/models/porcelain.rb', line 12822

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12824
12825
12826
# File 'lib/models/porcelain.rb', line 12824

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



12826
12827
12828
# File 'lib/models/porcelain.rb', line 12826

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12828
12829
12830
# File 'lib/models/porcelain.rb', line 12828

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



12830
12831
12832
# File 'lib/models/porcelain.rb', line 12830

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12832
12833
12834
# File 'lib/models/porcelain.rb', line 12832

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12834
12835
12836
# File 'lib/models/porcelain.rb', line 12834

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12836
12837
12838
# File 'lib/models/porcelain.rb', line 12836

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12866
12867
12868
12869
12870
12871
12872
# File 'lib/models/porcelain.rb', line 12866

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end