Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



12594
12595
12596
12597
12598
12599
12600
12601
12602
12603
12604
12605
12606
12607
12608
12609
12610
12611
12612
12613
12614
12615
12616
12617
12618
12619
12620
# File 'lib/models/porcelain.rb', line 12594

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12570
12571
12572
# File 'lib/models/porcelain.rb', line 12570

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12572
12573
12574
# File 'lib/models/porcelain.rb', line 12572

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



12574
12575
12576
# File 'lib/models/porcelain.rb', line 12574

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12576
12577
12578
# File 'lib/models/porcelain.rb', line 12576

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12578
12579
12580
# File 'lib/models/porcelain.rb', line 12578

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12580
12581
12582
# File 'lib/models/porcelain.rb', line 12580

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



12582
12583
12584
# File 'lib/models/porcelain.rb', line 12582

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12584
12585
12586
# File 'lib/models/porcelain.rb', line 12584

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



12586
12587
12588
# File 'lib/models/porcelain.rb', line 12586

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12588
12589
12590
# File 'lib/models/porcelain.rb', line 12588

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12590
12591
12592
# File 'lib/models/porcelain.rb', line 12590

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12592
12593
12594
# File 'lib/models/porcelain.rb', line 12592

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12622
12623
12624
12625
12626
12627
12628
# File 'lib/models/porcelain.rb', line 12622

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end