Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



12440
12441
12442
12443
12444
12445
12446
12447
12448
12449
12450
12451
12452
12453
12454
12455
12456
12457
12458
12459
12460
12461
12462
12463
12464
12465
12466
# File 'lib/models/porcelain.rb', line 12440

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12416
12417
12418
# File 'lib/models/porcelain.rb', line 12416

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12418
12419
12420
# File 'lib/models/porcelain.rb', line 12418

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



12420
12421
12422
# File 'lib/models/porcelain.rb', line 12420

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12422
12423
12424
# File 'lib/models/porcelain.rb', line 12422

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12424
12425
12426
# File 'lib/models/porcelain.rb', line 12424

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12426
12427
12428
# File 'lib/models/porcelain.rb', line 12426

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



12428
12429
12430
# File 'lib/models/porcelain.rb', line 12428

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12430
12431
12432
# File 'lib/models/porcelain.rb', line 12430

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



12432
12433
12434
# File 'lib/models/porcelain.rb', line 12432

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12434
12435
12436
# File 'lib/models/porcelain.rb', line 12434

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12436
12437
12438
# File 'lib/models/porcelain.rb', line 12436

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12438
12439
12440
# File 'lib/models/porcelain.rb', line 12438

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12468
12469
12470
12471
12472
12473
12474
# File 'lib/models/porcelain.rb', line 12468

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end