Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
# File 'lib/models/porcelain.rb', line 12374

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12350
12351
12352
# File 'lib/models/porcelain.rb', line 12350

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12352
12353
12354
# File 'lib/models/porcelain.rb', line 12352

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



12354
12355
12356
# File 'lib/models/porcelain.rb', line 12354

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12356
12357
12358
# File 'lib/models/porcelain.rb', line 12356

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12358
12359
12360
# File 'lib/models/porcelain.rb', line 12358

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12360
12361
12362
# File 'lib/models/porcelain.rb', line 12360

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



12362
12363
12364
# File 'lib/models/porcelain.rb', line 12362

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12364
12365
12366
# File 'lib/models/porcelain.rb', line 12364

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



12366
12367
12368
# File 'lib/models/porcelain.rb', line 12366

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12368
12369
12370
# File 'lib/models/porcelain.rb', line 12368

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12370
12371
12372
# File 'lib/models/porcelain.rb', line 12370

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12372
12373
12374
# File 'lib/models/porcelain.rb', line 12372

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12402
12403
12404
12405
12406
12407
12408
# File 'lib/models/porcelain.rb', line 12402

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end