Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



12079
12080
12081
12082
12083
12084
12085
12086
12087
12088
12089
12090
12091
12092
12093
12094
12095
12096
12097
12098
12099
12100
12101
12102
12103
12104
12105
# File 'lib/models/porcelain.rb', line 12079

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12055
12056
12057
# File 'lib/models/porcelain.rb', line 12055

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12057
12058
12059
# File 'lib/models/porcelain.rb', line 12057

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



12059
12060
12061
# File 'lib/models/porcelain.rb', line 12059

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12061
12062
12063
# File 'lib/models/porcelain.rb', line 12061

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12063
12064
12065
# File 'lib/models/porcelain.rb', line 12063

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12065
12066
12067
# File 'lib/models/porcelain.rb', line 12065

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



12067
12068
12069
# File 'lib/models/porcelain.rb', line 12067

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12069
12070
12071
# File 'lib/models/porcelain.rb', line 12069

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



12071
12072
12073
# File 'lib/models/porcelain.rb', line 12071

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12073
12074
12075
# File 'lib/models/porcelain.rb', line 12073

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12075
12076
12077
# File 'lib/models/porcelain.rb', line 12075

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12077
12078
12079
# File 'lib/models/porcelain.rb', line 12077

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12107
12108
12109
12110
12111
12112
12113
# File 'lib/models/porcelain.rb', line 12107

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end