Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



11999
12000
12001
12002
12003
12004
12005
12006
12007
12008
12009
12010
12011
12012
12013
12014
12015
12016
12017
12018
12019
12020
12021
12022
12023
12024
12025
# File 'lib/models/porcelain.rb', line 11999

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11975
11976
11977
# File 'lib/models/porcelain.rb', line 11975

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11977
11978
11979
# File 'lib/models/porcelain.rb', line 11977

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



11979
11980
11981
# File 'lib/models/porcelain.rb', line 11979

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11981
11982
11983
# File 'lib/models/porcelain.rb', line 11981

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



11983
11984
11985
# File 'lib/models/porcelain.rb', line 11983

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11985
11986
11987
# File 'lib/models/porcelain.rb', line 11985

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



11987
11988
11989
# File 'lib/models/porcelain.rb', line 11987

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11989
11990
11991
# File 'lib/models/porcelain.rb', line 11989

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



11991
11992
11993
# File 'lib/models/porcelain.rb', line 11991

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11993
11994
11995
# File 'lib/models/porcelain.rb', line 11993

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11995
11996
11997
# File 'lib/models/porcelain.rb', line 11995

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11997
11998
11999
# File 'lib/models/porcelain.rb', line 11997

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12027
12028
12029
12030
12031
12032
12033
# File 'lib/models/porcelain.rb', line 12027

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end