Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



11822
11823
11824
11825
11826
11827
11828
11829
11830
11831
11832
11833
11834
11835
11836
11837
11838
11839
11840
11841
11842
11843
11844
11845
11846
11847
11848
# File 'lib/models/porcelain.rb', line 11822

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11798
11799
11800
# File 'lib/models/porcelain.rb', line 11798

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11800
11801
11802
# File 'lib/models/porcelain.rb', line 11800

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



11802
11803
11804
# File 'lib/models/porcelain.rb', line 11802

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11804
11805
11806
# File 'lib/models/porcelain.rb', line 11804

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



11806
11807
11808
# File 'lib/models/porcelain.rb', line 11806

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11808
11809
11810
# File 'lib/models/porcelain.rb', line 11808

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



11810
11811
11812
# File 'lib/models/porcelain.rb', line 11810

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11812
11813
11814
# File 'lib/models/porcelain.rb', line 11812

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



11814
11815
11816
# File 'lib/models/porcelain.rb', line 11814

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11816
11817
11818
# File 'lib/models/porcelain.rb', line 11816

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11818
11819
11820
# File 'lib/models/porcelain.rb', line 11818

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11820
11821
11822
# File 'lib/models/porcelain.rb', line 11820

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11850
11851
11852
11853
11854
11855
11856
# File 'lib/models/porcelain.rb', line 11850

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end