Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



11751
11752
11753
11754
11755
11756
11757
11758
11759
11760
11761
11762
11763
11764
11765
11766
11767
11768
11769
11770
11771
11772
11773
11774
11775
11776
11777
# File 'lib/models/porcelain.rb', line 11751

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11727
11728
11729
# File 'lib/models/porcelain.rb', line 11727

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11729
11730
11731
# File 'lib/models/porcelain.rb', line 11729

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



11731
11732
11733
# File 'lib/models/porcelain.rb', line 11731

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11733
11734
11735
# File 'lib/models/porcelain.rb', line 11733

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



11735
11736
11737
# File 'lib/models/porcelain.rb', line 11735

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11737
11738
11739
# File 'lib/models/porcelain.rb', line 11737

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



11739
11740
11741
# File 'lib/models/porcelain.rb', line 11739

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11741
11742
11743
# File 'lib/models/porcelain.rb', line 11741

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



11743
11744
11745
# File 'lib/models/porcelain.rb', line 11743

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11745
11746
11747
# File 'lib/models/porcelain.rb', line 11745

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11747
11748
11749
# File 'lib/models/porcelain.rb', line 11747

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11749
11750
11751
# File 'lib/models/porcelain.rb', line 11749

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11779
11780
11781
11782
11783
11784
11785
# File 'lib/models/porcelain.rb', line 11779

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end