Class: SDM::Snowsight
- Inherits:
-
Object
- Object
- SDM::Snowsight
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_username ⇒ Object
The StrongDM user email to use for healthchecks.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#samlmetadata ⇒ Object
The Metadata for your snowflake IDP integration.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
constructor
A new instance of Snowsight.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
Returns a new instance of Snowsight.
11682 11683 11684 11685 11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 |
# File 'lib/models/porcelain.rb', line 11682 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @samlmetadata = == nil ? "" : @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11658 11659 11660 |
# File 'lib/models/porcelain.rb', line 11658 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11660 11661 11662 |
# File 'lib/models/porcelain.rb', line 11660 def egress_filter @egress_filter end |
#healthcheck_username ⇒ Object
The StrongDM user email to use for healthchecks.
11662 11663 11664 |
# File 'lib/models/porcelain.rb', line 11662 def healthcheck_username @healthcheck_username end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11664 11665 11666 |
# File 'lib/models/porcelain.rb', line 11664 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
11666 11667 11668 |
# File 'lib/models/porcelain.rb', line 11666 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11668 11669 11670 |
# File 'lib/models/porcelain.rb', line 11668 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11670 11671 11672 |
# File 'lib/models/porcelain.rb', line 11670 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11672 11673 11674 |
# File 'lib/models/porcelain.rb', line 11672 def proxy_cluster_id @proxy_cluster_id end |
#samlmetadata ⇒ Object
The Metadata for your snowflake IDP integration
11674 11675 11676 |
# File 'lib/models/porcelain.rb', line 11674 def @samlmetadata end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11676 11677 11678 |
# File 'lib/models/porcelain.rb', line 11676 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11678 11679 11680 |
# File 'lib/models/porcelain.rb', line 11678 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11680 11681 11682 |
# File 'lib/models/porcelain.rb', line 11680 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11710 11711 11712 11713 11714 11715 11716 |
# File 'lib/models/porcelain.rb', line 11710 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |