Class: SDM::Snowsight
- Inherits:
-
Object
- Object
- SDM::Snowsight
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_username ⇒ Object
The StrongDM user email to use for healthchecks.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#samlmetadata ⇒ Object
The Metadata for your snowflake IDP integration.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
constructor
A new instance of Snowsight.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
Returns a new instance of Snowsight.
11345 11346 11347 11348 11349 11350 11351 11352 11353 11354 11355 11356 11357 11358 11359 11360 11361 11362 11363 11364 11365 11366 11367 11368 11369 |
# File 'lib/models/porcelain.rb', line 11345 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @samlmetadata = == nil ? "" : @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11323 11324 11325 |
# File 'lib/models/porcelain.rb', line 11323 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11325 11326 11327 |
# File 'lib/models/porcelain.rb', line 11325 def egress_filter @egress_filter end |
#healthcheck_username ⇒ Object
The StrongDM user email to use for healthchecks.
11327 11328 11329 |
# File 'lib/models/porcelain.rb', line 11327 def healthcheck_username @healthcheck_username end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11329 11330 11331 |
# File 'lib/models/porcelain.rb', line 11329 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
11331 11332 11333 |
# File 'lib/models/porcelain.rb', line 11331 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11333 11334 11335 |
# File 'lib/models/porcelain.rb', line 11333 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11335 11336 11337 |
# File 'lib/models/porcelain.rb', line 11335 def port_override @port_override end |
#samlmetadata ⇒ Object
The Metadata for your snowflake IDP integration
11337 11338 11339 |
# File 'lib/models/porcelain.rb', line 11337 def @samlmetadata end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11339 11340 11341 |
# File 'lib/models/porcelain.rb', line 11339 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11341 11342 11343 |
# File 'lib/models/porcelain.rb', line 11341 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11343 11344 11345 |
# File 'lib/models/porcelain.rb', line 11343 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11371 11372 11373 11374 11375 11376 11377 |
# File 'lib/models/porcelain.rb', line 11371 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |