Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



11172
11173
11174
11175
11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
11191
11192
11193
11194
11195
11196
# File 'lib/models/porcelain.rb', line 11172

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11150
11151
11152
# File 'lib/models/porcelain.rb', line 11150

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11152
11153
11154
# File 'lib/models/porcelain.rb', line 11152

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



11154
11155
11156
# File 'lib/models/porcelain.rb', line 11154

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11156
11157
11158
# File 'lib/models/porcelain.rb', line 11156

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



11158
11159
11160
# File 'lib/models/porcelain.rb', line 11158

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11160
11161
11162
# File 'lib/models/porcelain.rb', line 11160

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



11162
11163
11164
# File 'lib/models/porcelain.rb', line 11162

def port_override
  @port_override
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



11164
11165
11166
# File 'lib/models/porcelain.rb', line 11164

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11166
11167
11168
# File 'lib/models/porcelain.rb', line 11166

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11168
11169
11170
# File 'lib/models/porcelain.rb', line 11168

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11170
11171
11172
# File 'lib/models/porcelain.rb', line 11170

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11198
11199
11200
11201
11202
11203
11204
# File 'lib/models/porcelain.rb', line 11198

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end