Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



9509
9510
9511
9512
9513
9514
9515
9516
9517
9518
9519
9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
# File 'lib/models/porcelain.rb', line 9509

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9487
9488
9489
# File 'lib/models/porcelain.rb', line 9487

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9489
9490
9491
# File 'lib/models/porcelain.rb', line 9489

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



9491
9492
9493
# File 'lib/models/porcelain.rb', line 9491

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9493
9494
9495
# File 'lib/models/porcelain.rb', line 9493

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



9495
9496
9497
# File 'lib/models/porcelain.rb', line 9495

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9497
9498
9499
# File 'lib/models/porcelain.rb', line 9497

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



9499
9500
9501
# File 'lib/models/porcelain.rb', line 9499

def port_override
  @port_override
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



9501
9502
9503
# File 'lib/models/porcelain.rb', line 9501

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9503
9504
9505
# File 'lib/models/porcelain.rb', line 9503

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9505
9506
9507
# File 'lib/models/porcelain.rb', line 9505

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9507
9508
9509
# File 'lib/models/porcelain.rb', line 9507

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9535
9536
9537
9538
9539
9540
9541
# File 'lib/models/porcelain.rb', line 9535

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end