Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



8984
8985
8986
8987
8988
8989
8990
8991
8992
8993
8994
8995
8996
8997
8998
8999
9000
9001
9002
9003
9004
9005
9006
9007
9008
# File 'lib/models/porcelain.rb', line 8984

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8962
8963
8964
# File 'lib/models/porcelain.rb', line 8962

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8964
8965
8966
# File 'lib/models/porcelain.rb', line 8964

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



8966
8967
8968
# File 'lib/models/porcelain.rb', line 8966

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8968
8969
8970
# File 'lib/models/porcelain.rb', line 8968

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



8970
8971
8972
# File 'lib/models/porcelain.rb', line 8970

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8972
8973
8974
# File 'lib/models/porcelain.rb', line 8972

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



8974
8975
8976
# File 'lib/models/porcelain.rb', line 8974

def port_override
  @port_override
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



8976
8977
8978
# File 'lib/models/porcelain.rb', line 8976

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8978
8979
8980
# File 'lib/models/porcelain.rb', line 8978

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8980
8981
8982
# File 'lib/models/porcelain.rb', line 8980

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8982
8983
8984
# File 'lib/models/porcelain.rb', line 8982

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9010
9011
9012
9013
9014
9015
9016
# File 'lib/models/porcelain.rb', line 9010

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end