Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
# File 'lib/models/porcelain.rb', line 8820

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8798
8799
8800
# File 'lib/models/porcelain.rb', line 8798

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8800
8801
8802
# File 'lib/models/porcelain.rb', line 8800

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



8802
8803
8804
# File 'lib/models/porcelain.rb', line 8802

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8804
8805
8806
# File 'lib/models/porcelain.rb', line 8804

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



8806
8807
8808
# File 'lib/models/porcelain.rb', line 8806

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8808
8809
8810
# File 'lib/models/porcelain.rb', line 8808

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



8810
8811
8812
# File 'lib/models/porcelain.rb', line 8810

def port_override
  @port_override
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



8812
8813
8814
# File 'lib/models/porcelain.rb', line 8812

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8814
8815
8816
# File 'lib/models/porcelain.rb', line 8814

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8816
8817
8818
# File 'lib/models/porcelain.rb', line 8816

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8818
8819
8820
# File 'lib/models/porcelain.rb', line 8818

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8846
8847
8848
8849
8850
8851
8852
# File 'lib/models/porcelain.rb', line 8846

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end