Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



8383
8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
8394
8395
8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
# File 'lib/models/porcelain.rb', line 8383

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8361
8362
8363
# File 'lib/models/porcelain.rb', line 8361

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8363
8364
8365
# File 'lib/models/porcelain.rb', line 8363

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



8365
8366
8367
# File 'lib/models/porcelain.rb', line 8365

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8367
8368
8369
# File 'lib/models/porcelain.rb', line 8367

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



8369
8370
8371
# File 'lib/models/porcelain.rb', line 8369

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8371
8372
8373
# File 'lib/models/porcelain.rb', line 8371

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



8373
8374
8375
# File 'lib/models/porcelain.rb', line 8373

def port_override
  @port_override
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



8375
8376
8377
# File 'lib/models/porcelain.rb', line 8375

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8377
8378
8379
# File 'lib/models/porcelain.rb', line 8377

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8379
8380
8381
# File 'lib/models/porcelain.rb', line 8379

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8381
8382
8383
# File 'lib/models/porcelain.rb', line 8381

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8409
8410
8411
8412
8413
8414
8415
# File 'lib/models/porcelain.rb', line 8409

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end