Class: SDM::Snowsight
- Inherits:
-
Object
- Object
- SDM::Snowsight
- Defined in:
- lib/models/porcelain.rb
Overview
Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_username ⇒ Object
Returns the value of attribute healthcheck_username.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#samlmetadata ⇒ Object
Returns the value of attribute samlmetadata.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
constructor
A new instance of Snowsight.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
Returns a new instance of Snowsight.
8208 8209 8210 8211 8212 8213 8214 8215 8216 8217 8218 8219 8220 8221 8222 8223 8224 8225 8226 8227 8228 8229 8230 8231 8232 |
# File 'lib/models/porcelain.rb', line 8208 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @samlmetadata = == nil ? "" : @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
8186 8187 8188 |
# File 'lib/models/porcelain.rb', line 8186 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8188 8189 8190 |
# File 'lib/models/porcelain.rb', line 8188 def egress_filter @egress_filter end |
#healthcheck_username ⇒ Object
Returns the value of attribute healthcheck_username.
8190 8191 8192 |
# File 'lib/models/porcelain.rb', line 8190 def healthcheck_username @healthcheck_username end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8192 8193 8194 |
# File 'lib/models/porcelain.rb', line 8192 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
8194 8195 8196 |
# File 'lib/models/porcelain.rb', line 8194 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8196 8197 8198 |
# File 'lib/models/porcelain.rb', line 8196 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
8198 8199 8200 |
# File 'lib/models/porcelain.rb', line 8198 def port_override @port_override end |
#samlmetadata ⇒ Object
Returns the value of attribute samlmetadata.
8200 8201 8202 |
# File 'lib/models/porcelain.rb', line 8200 def @samlmetadata end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8202 8203 8204 |
# File 'lib/models/porcelain.rb', line 8202 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
8204 8205 8206 |
# File 'lib/models/porcelain.rb', line 8204 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8206 8207 8208 |
# File 'lib/models/porcelain.rb', line 8206 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8234 8235 8236 8237 8238 8239 8240 |
# File 'lib/models/porcelain.rb', line 8234 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |