Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
8157
8158
8159
8160
8161
8162
8163
8164
8165
8166
8167
8168
# File 'lib/models/porcelain.rb', line 8144

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



8122
8123
8124
# File 'lib/models/porcelain.rb', line 8122

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8124
8125
8126
# File 'lib/models/porcelain.rb', line 8124

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

Returns the value of attribute healthcheck_username.



8126
8127
8128
# File 'lib/models/porcelain.rb', line 8126

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8128
8129
8130
# File 'lib/models/porcelain.rb', line 8128

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



8130
8131
8132
# File 'lib/models/porcelain.rb', line 8130

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8132
8133
8134
# File 'lib/models/porcelain.rb', line 8132

def name
  @name
end

#port_overrideObject

Returns the value of attribute port_override.



8134
8135
8136
# File 'lib/models/porcelain.rb', line 8134

def port_override
  @port_override
end

#samlmetadataObject

Returns the value of attribute samlmetadata.



8136
8137
8138
# File 'lib/models/porcelain.rb', line 8136

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8138
8139
8140
# File 'lib/models/porcelain.rb', line 8138

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



8140
8141
8142
# File 'lib/models/porcelain.rb', line 8140

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8142
8143
8144
# File 'lib/models/porcelain.rb', line 8142

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8170
8171
8172
8173
8174
8175
8176
# File 'lib/models/porcelain.rb', line 8170

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end