Class: SDM::Snowsight
- Inherits:
-
Object
- Object
- SDM::Snowsight
- Defined in:
- lib/models/porcelain.rb
Overview
Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_username ⇒ Object
Returns the value of attribute healthcheck_username.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#samlmetadata ⇒ Object
Returns the value of attribute samlmetadata.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
constructor
A new instance of Snowsight.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
Returns a new instance of Snowsight.
7970 7971 7972 7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 |
# File 'lib/models/porcelain.rb', line 7970 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @samlmetadata = == nil ? "" : @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7948 7949 7950 |
# File 'lib/models/porcelain.rb', line 7948 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7950 7951 7952 |
# File 'lib/models/porcelain.rb', line 7950 def egress_filter @egress_filter end |
#healthcheck_username ⇒ Object
Returns the value of attribute healthcheck_username.
7952 7953 7954 |
# File 'lib/models/porcelain.rb', line 7952 def healthcheck_username @healthcheck_username end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7954 7955 7956 |
# File 'lib/models/porcelain.rb', line 7954 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
7956 7957 7958 |
# File 'lib/models/porcelain.rb', line 7956 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7958 7959 7960 |
# File 'lib/models/porcelain.rb', line 7958 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7960 7961 7962 |
# File 'lib/models/porcelain.rb', line 7960 def port_override @port_override end |
#samlmetadata ⇒ Object
Returns the value of attribute samlmetadata.
7962 7963 7964 |
# File 'lib/models/porcelain.rb', line 7962 def @samlmetadata end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7964 7965 7966 |
# File 'lib/models/porcelain.rb', line 7964 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
7966 7967 7968 |
# File 'lib/models/porcelain.rb', line 7966 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7968 7969 7970 |
# File 'lib/models/porcelain.rb', line 7968 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7996 7997 7998 7999 8000 8001 8002 |
# File 'lib/models/porcelain.rb', line 7996 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |