Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
7935
7936
7937
7938
7939
7940
7941
# File 'lib/models/porcelain.rb', line 7917

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



7895
7896
7897
# File 'lib/models/porcelain.rb', line 7895

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7897
7898
7899
# File 'lib/models/porcelain.rb', line 7897

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

Returns the value of attribute healthcheck_username.



7899
7900
7901
# File 'lib/models/porcelain.rb', line 7899

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7901
7902
7903
# File 'lib/models/porcelain.rb', line 7901

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7903
7904
7905
# File 'lib/models/porcelain.rb', line 7903

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7905
7906
7907
# File 'lib/models/porcelain.rb', line 7905

def name
  @name
end

#port_overrideObject

Returns the value of attribute port_override.



7907
7908
7909
# File 'lib/models/porcelain.rb', line 7907

def port_override
  @port_override
end

#samlmetadataObject

Returns the value of attribute samlmetadata.



7909
7910
7911
# File 'lib/models/porcelain.rb', line 7909

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7911
7912
7913
# File 'lib/models/porcelain.rb', line 7911

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



7913
7914
7915
# File 'lib/models/porcelain.rb', line 7913

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7915
7916
7917
# File 'lib/models/porcelain.rb', line 7915

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7943
7944
7945
7946
7947
7948
7949
# File 'lib/models/porcelain.rb', line 7943

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end