Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



7717
7718
7719
7720
7721
7722
7723
7724
7725
7726
7727
7728
7729
7730
7731
7732
7733
7734
7735
7736
7737
7738
7739
7740
7741
# File 'lib/models/porcelain.rb', line 7717

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



7695
7696
7697
# File 'lib/models/porcelain.rb', line 7695

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7697
7698
7699
# File 'lib/models/porcelain.rb', line 7697

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

Returns the value of attribute healthcheck_username.



7699
7700
7701
# File 'lib/models/porcelain.rb', line 7699

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7701
7702
7703
# File 'lib/models/porcelain.rb', line 7701

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7703
7704
7705
# File 'lib/models/porcelain.rb', line 7703

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7705
7706
7707
# File 'lib/models/porcelain.rb', line 7705

def name
  @name
end

#port_overrideObject

Returns the value of attribute port_override.



7707
7708
7709
# File 'lib/models/porcelain.rb', line 7707

def port_override
  @port_override
end

#samlmetadataObject

Returns the value of attribute samlmetadata.



7709
7710
7711
# File 'lib/models/porcelain.rb', line 7709

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7711
7712
7713
# File 'lib/models/porcelain.rb', line 7711

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



7713
7714
7715
# File 'lib/models/porcelain.rb', line 7713

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7715
7716
7717
# File 'lib/models/porcelain.rb', line 7715

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7743
7744
7745
7746
7747
7748
7749
# File 'lib/models/porcelain.rb', line 7743

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end