Class: SDM::Snowsight
- Inherits:
-
Object
- Object
- SDM::Snowsight
- Defined in:
- lib/models/porcelain.rb
Overview
Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_username ⇒ Object
Returns the value of attribute healthcheck_username.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#samlmetadata ⇒ Object
Returns the value of attribute samlmetadata.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
constructor
A new instance of Snowsight.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
Returns a new instance of Snowsight.
7465 7466 7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/models/porcelain.rb', line 7465 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @samlmetadata = == nil ? "" : @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7443 7444 7445 |
# File 'lib/models/porcelain.rb', line 7443 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7445 7446 7447 |
# File 'lib/models/porcelain.rb', line 7445 def egress_filter @egress_filter end |
#healthcheck_username ⇒ Object
Returns the value of attribute healthcheck_username.
7447 7448 7449 |
# File 'lib/models/porcelain.rb', line 7447 def healthcheck_username @healthcheck_username end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7449 7450 7451 |
# File 'lib/models/porcelain.rb', line 7449 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
7451 7452 7453 |
# File 'lib/models/porcelain.rb', line 7451 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7453 7454 7455 |
# File 'lib/models/porcelain.rb', line 7453 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7455 7456 7457 |
# File 'lib/models/porcelain.rb', line 7455 def port_override @port_override end |
#samlmetadata ⇒ Object
Returns the value of attribute samlmetadata.
7457 7458 7459 |
# File 'lib/models/porcelain.rb', line 7457 def @samlmetadata end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7459 7460 7461 |
# File 'lib/models/porcelain.rb', line 7459 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
7461 7462 7463 |
# File 'lib/models/porcelain.rb', line 7461 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7463 7464 7465 |
# File 'lib/models/porcelain.rb', line 7463 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/models/porcelain.rb', line 7491 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |