Class: SDM::Snowsight
- Inherits:
-
Object
- Object
- SDM::Snowsight
- Defined in:
- lib/models/porcelain.rb
Overview
Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_username ⇒ Object
Returns the value of attribute healthcheck_username.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#samlmetadata ⇒ Object
Returns the value of attribute samlmetadata.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
constructor
A new instance of Snowsight.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
Returns a new instance of Snowsight.
6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 6565 6566 6567 6568 6569 6570 6571 6572 6573 6574 6575 6576 6577 6578 |
# File 'lib/models/porcelain.rb', line 6554 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @samlmetadata = == nil ? "" : @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6532 6533 6534 |
# File 'lib/models/porcelain.rb', line 6532 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6534 6535 6536 |
# File 'lib/models/porcelain.rb', line 6534 def egress_filter @egress_filter end |
#healthcheck_username ⇒ Object
Returns the value of attribute healthcheck_username.
6536 6537 6538 |
# File 'lib/models/porcelain.rb', line 6536 def healthcheck_username @healthcheck_username end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6538 6539 6540 |
# File 'lib/models/porcelain.rb', line 6538 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
6540 6541 6542 |
# File 'lib/models/porcelain.rb', line 6540 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6542 6543 6544 |
# File 'lib/models/porcelain.rb', line 6542 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6544 6545 6546 |
# File 'lib/models/porcelain.rb', line 6544 def port_override @port_override end |
#samlmetadata ⇒ Object
Returns the value of attribute samlmetadata.
6546 6547 6548 |
# File 'lib/models/porcelain.rb', line 6546 def @samlmetadata end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6548 6549 6550 |
# File 'lib/models/porcelain.rb', line 6548 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
6550 6551 6552 |
# File 'lib/models/porcelain.rb', line 6550 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6552 6553 6554 |
# File 'lib/models/porcelain.rb', line 6552 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6580 6581 6582 6583 6584 6585 6586 |
# File 'lib/models/porcelain.rb', line 6580 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |