Class: SDM::Snowsight
- Inherits:
-
Object
- Object
- SDM::Snowsight
- Defined in:
- lib/models/porcelain.rb
Overview
Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_username ⇒ Object
Returns the value of attribute healthcheck_username.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#samlmetadata ⇒ Object
Returns the value of attribute samlmetadata.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
constructor
A new instance of Snowsight.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
Returns a new instance of Snowsight.
6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 |
# File 'lib/models/porcelain.rb', line 6446 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @samlmetadata = == nil ? "" : @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6424 6425 6426 |
# File 'lib/models/porcelain.rb', line 6424 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6426 6427 6428 |
# File 'lib/models/porcelain.rb', line 6426 def egress_filter @egress_filter end |
#healthcheck_username ⇒ Object
Returns the value of attribute healthcheck_username.
6428 6429 6430 |
# File 'lib/models/porcelain.rb', line 6428 def healthcheck_username @healthcheck_username end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6430 6431 6432 |
# File 'lib/models/porcelain.rb', line 6430 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
6432 6433 6434 |
# File 'lib/models/porcelain.rb', line 6432 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6434 6435 6436 |
# File 'lib/models/porcelain.rb', line 6434 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6436 6437 6438 |
# File 'lib/models/porcelain.rb', line 6436 def port_override @port_override end |
#samlmetadata ⇒ Object
Returns the value of attribute samlmetadata.
6438 6439 6440 |
# File 'lib/models/porcelain.rb', line 6438 def @samlmetadata end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6440 6441 6442 |
# File 'lib/models/porcelain.rb', line 6440 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
6442 6443 6444 |
# File 'lib/models/porcelain.rb', line 6442 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6444 6445 6446 |
# File 'lib/models/porcelain.rb', line 6444 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6472 6473 6474 6475 6476 6477 6478 |
# File 'lib/models/porcelain.rb', line 6472 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |