Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



6434
6435
6436
6437
6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
6456
6457
6458
# File 'lib/models/porcelain.rb', line 6434

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



6412
6413
6414
# File 'lib/models/porcelain.rb', line 6412

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6414
6415
6416
# File 'lib/models/porcelain.rb', line 6414

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

Returns the value of attribute healthcheck_username.



6416
6417
6418
# File 'lib/models/porcelain.rb', line 6416

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6418
6419
6420
# File 'lib/models/porcelain.rb', line 6418

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6420
6421
6422
# File 'lib/models/porcelain.rb', line 6420

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6422
6423
6424
# File 'lib/models/porcelain.rb', line 6422

def name
  @name
end

#port_overrideObject

Returns the value of attribute port_override.



6424
6425
6426
# File 'lib/models/porcelain.rb', line 6424

def port_override
  @port_override
end

#samlmetadataObject

Returns the value of attribute samlmetadata.



6426
6427
6428
# File 'lib/models/porcelain.rb', line 6426

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6428
6429
6430
# File 'lib/models/porcelain.rb', line 6428

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



6430
6431
6432
# File 'lib/models/porcelain.rb', line 6430

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6432
6433
6434
# File 'lib/models/porcelain.rb', line 6432

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6460
6461
6462
6463
6464
6465
6466
# File 'lib/models/porcelain.rb', line 6460

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end