Class: SDM::Snowsight
- Inherits:
-
Object
- Object
- SDM::Snowsight
- Defined in:
- lib/models/porcelain.rb
Overview
Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_username ⇒ Object
Returns the value of attribute healthcheck_username.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#samlmetadata ⇒ Object
Returns the value of attribute samlmetadata.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
constructor
A new instance of Snowsight.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight
Returns a new instance of Snowsight.
6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 6415 6416 6417 6418 6419 6420 6421 6422 6423 6424 |
# File 'lib/models/porcelain.rb', line 6400 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @samlmetadata = == nil ? "" : @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6378 6379 6380 |
# File 'lib/models/porcelain.rb', line 6378 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6380 6381 6382 |
# File 'lib/models/porcelain.rb', line 6380 def egress_filter @egress_filter end |
#healthcheck_username ⇒ Object
Returns the value of attribute healthcheck_username.
6382 6383 6384 |
# File 'lib/models/porcelain.rb', line 6382 def healthcheck_username @healthcheck_username end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6384 6385 6386 |
# File 'lib/models/porcelain.rb', line 6384 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
6386 6387 6388 |
# File 'lib/models/porcelain.rb', line 6386 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6388 6389 6390 |
# File 'lib/models/porcelain.rb', line 6388 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6390 6391 6392 |
# File 'lib/models/porcelain.rb', line 6390 def port_override @port_override end |
#samlmetadata ⇒ Object
Returns the value of attribute samlmetadata.
6392 6393 6394 |
# File 'lib/models/porcelain.rb', line 6392 def @samlmetadata end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6394 6395 6396 |
# File 'lib/models/porcelain.rb', line 6394 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
6396 6397 6398 |
# File 'lib/models/porcelain.rb', line 6396 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6398 6399 6400 |
# File 'lib/models/porcelain.rb', line 6398 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6426 6427 6428 6429 6430 6431 6432 |
# File 'lib/models/porcelain.rb', line 6426 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |