Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Snowsight is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
# File 'lib/models/porcelain.rb', line 6333

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @samlmetadata =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



6311
6312
6313
# File 'lib/models/porcelain.rb', line 6311

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6313
6314
6315
# File 'lib/models/porcelain.rb', line 6313

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

Returns the value of attribute healthcheck_username.



6315
6316
6317
# File 'lib/models/porcelain.rb', line 6315

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6317
6318
6319
# File 'lib/models/porcelain.rb', line 6317

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6319
6320
6321
# File 'lib/models/porcelain.rb', line 6319

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6321
6322
6323
# File 'lib/models/porcelain.rb', line 6321

def name
  @name
end

#port_overrideObject

Returns the value of attribute port_override.



6323
6324
6325
# File 'lib/models/porcelain.rb', line 6323

def port_override
  @port_override
end

#samlmetadataObject

Returns the value of attribute samlmetadata.



6325
6326
6327
# File 'lib/models/porcelain.rb', line 6325

def 
  @samlmetadata
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6327
6328
6329
# File 'lib/models/porcelain.rb', line 6327

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



6329
6330
6331
# File 'lib/models/porcelain.rb', line 6329

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6331
6332
6333
# File 'lib/models/porcelain.rb', line 6331

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6359
6360
6361
6362
6363
6364
6365
# File 'lib/models/porcelain.rb', line 6359

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end