Class: SDM::Snowsight

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Snowsight

Returns a new instance of Snowsight.



17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
17088
17089
17090
17091
17092
17093
17094
17095
# File 'lib/models/porcelain.rb', line 17067

def initialize(
  bind_interface: nil,
  connecttodefault: nil,
  egress_filter: nil,
  healthcheck_username: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  samlmetadata: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connecttodefault = connecttodefault == nil ? false : connecttodefault
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
   =  == nil ? "" : 
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17041
17042
17043
# File 'lib/models/porcelain.rb', line 17041

def bind_interface
  @bind_interface
end

#connecttodefaultObject

If true, select the ACS with isDefault=true



17043
17044
17045
# File 'lib/models/porcelain.rb', line 17043

def connecttodefault
  @connecttodefault
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17045
17046
17047
# File 'lib/models/porcelain.rb', line 17045

def egress_filter
  @egress_filter
end

#healthcheck_usernameObject

The StrongDM user email to use for healthchecks.



17047
17048
17049
# File 'lib/models/porcelain.rb', line 17047

def healthcheck_username
  @healthcheck_username
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17049
17050
17051
# File 'lib/models/porcelain.rb', line 17049

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



17051
17052
17053
# File 'lib/models/porcelain.rb', line 17051

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17053
17054
17055
# File 'lib/models/porcelain.rb', line 17053

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17055
17056
17057
# File 'lib/models/porcelain.rb', line 17055

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17057
17058
17059
# File 'lib/models/porcelain.rb', line 17057

def proxy_cluster_id
  @proxy_cluster_id
end

#samlmetadataObject

The Metadata for your snowflake IDP integration



17059
17060
17061
# File 'lib/models/porcelain.rb', line 17059

def 
  
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17061
17062
17063
# File 'lib/models/porcelain.rb', line 17061

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



17063
17064
17065
# File 'lib/models/porcelain.rb', line 17063

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17065
17066
17067
# File 'lib/models/porcelain.rb', line 17065

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17097
17098
17099
17100
17101
17102
17103
# File 'lib/models/porcelain.rb', line 17097

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end