Class: SDM::Snowsight
- Inherits:
-
Object
- Object
- SDM::Snowsight
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#connecttodefault ⇒ Object
If true, select the ACS with isDefault=true.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_username ⇒ Object
The StrongDM user email to use for healthchecks.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#samlmetadata ⇒ Object
The Metadata for your snowflake IDP integration.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_https ⇒ Object
This option enforces HTTPS on the client, not resource connection.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_https: nil) ⇒ Snowsight
constructor
A new instance of Snowsight.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_https: nil) ⇒ Snowsight
Returns a new instance of Snowsight.
17911 17912 17913 17914 17915 17916 17917 17918 17919 17920 17921 17922 17923 17924 17925 17926 17927 17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 |
# File 'lib/models/porcelain.rb', line 17911 def initialize( bind_interface: nil, connecttodefault: nil, egress_filter: nil, healthcheck_username: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, samlmetadata: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_https: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @connecttodefault = connecttodefault == nil ? false : connecttodefault @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_username = healthcheck_username == nil ? "" : healthcheck_username @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @samlmetadata = == nil ? "" : @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_https = use_https == nil ? false : use_https end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
17883 17884 17885 |
# File 'lib/models/porcelain.rb', line 17883 def bind_interface @bind_interface end |
#connecttodefault ⇒ Object
If true, select the ACS with isDefault=true
17885 17886 17887 |
# File 'lib/models/porcelain.rb', line 17885 def connecttodefault @connecttodefault end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
17887 17888 17889 |
# File 'lib/models/porcelain.rb', line 17887 def egress_filter @egress_filter end |
#healthcheck_username ⇒ Object
The StrongDM user email to use for healthchecks.
17889 17890 17891 |
# File 'lib/models/porcelain.rb', line 17889 def healthcheck_username @healthcheck_username end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
17891 17892 17893 |
# File 'lib/models/porcelain.rb', line 17891 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
17893 17894 17895 |
# File 'lib/models/porcelain.rb', line 17893 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
17895 17896 17897 |
# File 'lib/models/porcelain.rb', line 17895 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
17897 17898 17899 |
# File 'lib/models/porcelain.rb', line 17897 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
17899 17900 17901 |
# File 'lib/models/porcelain.rb', line 17899 def proxy_cluster_id @proxy_cluster_id end |
#samlmetadata ⇒ Object
The Metadata for your snowflake IDP integration
17901 17902 17903 |
# File 'lib/models/porcelain.rb', line 17901 def @samlmetadata end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
17903 17904 17905 |
# File 'lib/models/porcelain.rb', line 17903 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
17905 17906 17907 |
# File 'lib/models/porcelain.rb', line 17905 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17907 17908 17909 |
# File 'lib/models/porcelain.rb', line 17907 def @tags end |
#use_https ⇒ Object
This option enforces HTTPS on the client, not resource connection.
17909 17910 17911 |
# File 'lib/models/porcelain.rb', line 17909 def use_https @use_https end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17943 17944 17945 17946 17947 17948 17949 |
# File 'lib/models/porcelain.rb', line 17943 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |