Class: SDM::SqlserverEngine

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil) ⇒ SqlserverEngine

Returns a new instance of SqlserverEngine.



17930
17931
17932
17933
17934
17935
17936
17937
17938
17939
17940
17941
17942
17943
17944
17945
17946
17947
17948
17949
17950
17951
17952
17953
17954
17955
17956
17957
17958
17959
17960
17961
17962
17963
17964
17965
17966
17967
17968
# File 'lib/models/porcelain.rb', line 17930

def initialize(
  after_read_ttl: nil,
  database: nil,
  hostname: nil,
  id: nil,
  key_rotation_interval_days: nil,
  name: nil,
  node_selector: nil,
  password: nil,
  policy: nil,
  port: nil,
  public_key: nil,
  secret_store_id: nil,
  secret_store_root_path: nil,
  tags: nil,
  tls: nil,
  tls_skip_verify: nil,
  ttl: nil,
  username: nil
)
  @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl
  @database = database == nil ? "" : database
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days
  @name = name == nil ? "" : name
  @node_selector = node_selector == nil ? "" : node_selector
  @password = password == nil ? "" : password
  @policy = policy == nil ? nil : policy
  @port = port == nil ? 0 : port
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls = tls == nil ? false : tls
  @tls_skip_verify = tls_skip_verify == nil ? false : tls_skip_verify
  @ttl = ttl == nil ? nil : ttl
  @username = username == nil ? "" : username
end

Instance Attribute Details

#after_read_ttlObject

The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.



17894
17895
17896
# File 'lib/models/porcelain.rb', line 17894

def after_read_ttl
  @after_read_ttl
end

#databaseObject

Database is the database to verify credential against.



17896
17897
17898
# File 'lib/models/porcelain.rb', line 17896

def database
  @database
end

#hostnameObject

Hostname is the hostname or IP address of the SQL Server.



17898
17899
17900
# File 'lib/models/porcelain.rb', line 17898

def hostname
  @hostname
end

#idObject

Unique identifier of the Secret Engine.



17900
17901
17902
# File 'lib/models/porcelain.rb', line 17900

def id
  @id
end

#key_rotation_interval_daysObject

An interval of public/private key rotation for secret engine in days



17902
17903
17904
# File 'lib/models/porcelain.rb', line 17902

def key_rotation_interval_days
  @key_rotation_interval_days
end

#nameObject

Unique human-readable name of the Secret Engine.



17904
17905
17906
# File 'lib/models/porcelain.rb', line 17904

def name
  @name
end

#node_selectorObject

node selector is used to narrow down the nodes used to communicate with with secret engine



17906
17907
17908
# File 'lib/models/porcelain.rb', line 17906

def node_selector
  @node_selector
end

#passwordObject

Password is the password to connect to the SQL Server server.



17908
17909
17910
# File 'lib/models/porcelain.rb', line 17908

def password
  @password
end

#policyObject

Policy for password creation



17910
17911
17912
# File 'lib/models/porcelain.rb', line 17910

def policy
  @policy
end

#portObject

Port is the port number of the SQL Server server.



17912
17913
17914
# File 'lib/models/porcelain.rb', line 17912

def port
  @port
end

#public_keyObject

Public key linked with a secret engine



17914
17915
17916
# File 'lib/models/porcelain.rb', line 17914

def public_key
  @public_key
end

#secret_store_idObject

Backing secret store identifier



17916
17917
17918
# File 'lib/models/porcelain.rb', line 17916

def secret_store_id
  @secret_store_id
end

#secret_store_root_pathObject

Backing Secret Store root path where managed secrets are going to be stored



17918
17919
17920
# File 'lib/models/porcelain.rb', line 17918

def secret_store_root_path
  @secret_store_root_path
end

#tagsObject

Tags is a map of key, value pairs.



17920
17921
17922
# File 'lib/models/porcelain.rb', line 17920

def tags
  @tags
end

#tlsObject

TLS enables TLS/SSL when connecting to the SQL Server server.



17922
17923
17924
# File 'lib/models/porcelain.rb', line 17922

def tls
  @tls
end

#tls_skip_verifyObject

TLS disable certificate verification



17924
17925
17926
# File 'lib/models/porcelain.rb', line 17924

def tls_skip_verify
  @tls_skip_verify
end

#ttlObject

The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.



17926
17927
17928
# File 'lib/models/porcelain.rb', line 17926

def ttl
  @ttl
end

#usernameObject

Username is the username to connect to the SQL Server.



17928
17929
17930
# File 'lib/models/porcelain.rb', line 17928

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17970
17971
17972
17973
17974
17975
17976
# File 'lib/models/porcelain.rb', line 17970

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end