Class: SDM::SqlserverEngine
- Inherits:
-
Object
- Object
- SDM::SqlserverEngine
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#after_read_ttl ⇒ Object
The default time-to-live duration of the password after it's read.
-
#database ⇒ Object
Database is the database to verify credential against.
-
#hostname ⇒ Object
Hostname is the hostname or IP address of the SQL Server.
-
#id ⇒ Object
Unique identifier of the Secret Engine.
-
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days.
-
#name ⇒ Object
Unique human-readable name of the Secret Engine.
-
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine.
-
#password ⇒ Object
Password is the password to connect to the SQL Server server.
-
#policy ⇒ Object
Policy for password creation.
-
#port ⇒ Object
Port is the port number of the SQL Server server.
-
#public_key ⇒ Object
Public key linked with a secret engine.
-
#secret_store_id ⇒ Object
Backing secret store identifier.
-
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls ⇒ Object
TLS enables TLS/SSL when connecting to the SQL Server server.
-
#tls_skip_verify ⇒ Object
TLS disable certificate verification.
-
#ttl ⇒ Object
The default password time-to-live duration.
-
#username ⇒ Object
Username is the username to connect to the SQL Server.
Instance Method Summary collapse
-
#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil) ⇒ SqlserverEngine
constructor
A new instance of SqlserverEngine.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil) ⇒ SqlserverEngine
Returns a new instance of SqlserverEngine.
17882 17883 17884 17885 17886 17887 17888 17889 17890 17891 17892 17893 17894 17895 17896 17897 17898 17899 17900 17901 17902 17903 17904 17905 17906 17907 17908 17909 17910 17911 17912 17913 17914 17915 17916 17917 17918 17919 17920 |
# File 'lib/models/porcelain.rb', line 17882 def initialize( after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil ) @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl @database = database == nil ? "" : database @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days @name = name == nil ? "" : name @node_selector = node_selector == nil ? "" : node_selector @password = password == nil ? "" : password @policy = policy == nil ? nil : policy @port = port == nil ? 0 : port @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path @tags = == nil ? SDM::() : @tls = tls == nil ? false : tls @tls_skip_verify = tls_skip_verify == nil ? false : tls_skip_verify @ttl = ttl == nil ? nil : ttl @username = username == nil ? "" : username end |
Instance Attribute Details
#after_read_ttl ⇒ Object
The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.
17846 17847 17848 |
# File 'lib/models/porcelain.rb', line 17846 def after_read_ttl @after_read_ttl end |
#database ⇒ Object
Database is the database to verify credential against.
17848 17849 17850 |
# File 'lib/models/porcelain.rb', line 17848 def database @database end |
#hostname ⇒ Object
Hostname is the hostname or IP address of the SQL Server.
17850 17851 17852 |
# File 'lib/models/porcelain.rb', line 17850 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Secret Engine.
17852 17853 17854 |
# File 'lib/models/porcelain.rb', line 17852 def id @id end |
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days
17854 17855 17856 |
# File 'lib/models/porcelain.rb', line 17854 def key_rotation_interval_days @key_rotation_interval_days end |
#name ⇒ Object
Unique human-readable name of the Secret Engine.
17856 17857 17858 |
# File 'lib/models/porcelain.rb', line 17856 def name @name end |
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine
17858 17859 17860 |
# File 'lib/models/porcelain.rb', line 17858 def node_selector @node_selector end |
#password ⇒ Object
Password is the password to connect to the SQL Server server.
17860 17861 17862 |
# File 'lib/models/porcelain.rb', line 17860 def password @password end |
#policy ⇒ Object
Policy for password creation
17862 17863 17864 |
# File 'lib/models/porcelain.rb', line 17862 def policy @policy end |
#port ⇒ Object
Port is the port number of the SQL Server server.
17864 17865 17866 |
# File 'lib/models/porcelain.rb', line 17864 def port @port end |
#public_key ⇒ Object
Public key linked with a secret engine
17866 17867 17868 |
# File 'lib/models/porcelain.rb', line 17866 def public_key @public_key end |
#secret_store_id ⇒ Object
Backing secret store identifier
17868 17869 17870 |
# File 'lib/models/porcelain.rb', line 17868 def secret_store_id @secret_store_id end |
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored
17870 17871 17872 |
# File 'lib/models/porcelain.rb', line 17870 def secret_store_root_path @secret_store_root_path end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17872 17873 17874 |
# File 'lib/models/porcelain.rb', line 17872 def @tags end |
#tls ⇒ Object
TLS enables TLS/SSL when connecting to the SQL Server server.
17874 17875 17876 |
# File 'lib/models/porcelain.rb', line 17874 def tls @tls end |
#tls_skip_verify ⇒ Object
TLS disable certificate verification
17876 17877 17878 |
# File 'lib/models/porcelain.rb', line 17876 def tls_skip_verify @tls_skip_verify end |
#ttl ⇒ Object
The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.
17878 17879 17880 |
# File 'lib/models/porcelain.rb', line 17878 def ttl @ttl end |
#username ⇒ Object
Username is the username to connect to the SQL Server.
17880 17881 17882 |
# File 'lib/models/porcelain.rb', line 17880 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17922 17923 17924 17925 17926 17927 17928 |
# File 'lib/models/porcelain.rb', line 17922 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |