Class: SDM::SqlserverEngine

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil) ⇒ SqlserverEngine

Returns a new instance of SqlserverEngine.



17798
17799
17800
17801
17802
17803
17804
17805
17806
17807
17808
17809
17810
17811
17812
17813
17814
17815
17816
17817
17818
17819
17820
17821
17822
17823
17824
17825
17826
17827
17828
17829
17830
17831
17832
17833
17834
17835
17836
# File 'lib/models/porcelain.rb', line 17798

def initialize(
  after_read_ttl: nil,
  database: nil,
  hostname: nil,
  id: nil,
  key_rotation_interval_days: nil,
  name: nil,
  node_selector: nil,
  password: nil,
  policy: nil,
  port: nil,
  public_key: nil,
  secret_store_id: nil,
  secret_store_root_path: nil,
  tags: nil,
  tls: nil,
  tls_skip_verify: nil,
  ttl: nil,
  username: nil
)
  @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl
  @database = database == nil ? "" : database
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days
  @name = name == nil ? "" : name
  @node_selector = node_selector == nil ? "" : node_selector
  @password = password == nil ? "" : password
  @policy = policy == nil ? nil : policy
  @port = port == nil ? 0 : port
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls = tls == nil ? false : tls
  @tls_skip_verify = tls_skip_verify == nil ? false : tls_skip_verify
  @ttl = ttl == nil ? nil : ttl
  @username = username == nil ? "" : username
end

Instance Attribute Details

#after_read_ttlObject

The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.



17762
17763
17764
# File 'lib/models/porcelain.rb', line 17762

def after_read_ttl
  @after_read_ttl
end

#databaseObject

Database is the database to verify credential against.



17764
17765
17766
# File 'lib/models/porcelain.rb', line 17764

def database
  @database
end

#hostnameObject

Hostname is the hostname or IP address of the SQL Server.



17766
17767
17768
# File 'lib/models/porcelain.rb', line 17766

def hostname
  @hostname
end

#idObject

Unique identifier of the Secret Engine.



17768
17769
17770
# File 'lib/models/porcelain.rb', line 17768

def id
  @id
end

#key_rotation_interval_daysObject

An interval of public/private key rotation for secret engine in days



17770
17771
17772
# File 'lib/models/porcelain.rb', line 17770

def key_rotation_interval_days
  @key_rotation_interval_days
end

#nameObject

Unique human-readable name of the Secret Engine.



17772
17773
17774
# File 'lib/models/porcelain.rb', line 17772

def name
  @name
end

#node_selectorObject

node selector is used to narrow down the nodes used to communicate with with secret engine



17774
17775
17776
# File 'lib/models/porcelain.rb', line 17774

def node_selector
  @node_selector
end

#passwordObject

Password is the password to connect to the SQL Server server.



17776
17777
17778
# File 'lib/models/porcelain.rb', line 17776

def password
  @password
end

#policyObject

Policy for password creation



17778
17779
17780
# File 'lib/models/porcelain.rb', line 17778

def policy
  @policy
end

#portObject

Port is the port number of the SQL Server server.



17780
17781
17782
# File 'lib/models/porcelain.rb', line 17780

def port
  @port
end

#public_keyObject

Public key linked with a secret engine



17782
17783
17784
# File 'lib/models/porcelain.rb', line 17782

def public_key
  @public_key
end

#secret_store_idObject

Backing secret store identifier



17784
17785
17786
# File 'lib/models/porcelain.rb', line 17784

def secret_store_id
  @secret_store_id
end

#secret_store_root_pathObject

Backing Secret Store root path where managed secrets are going to be stored



17786
17787
17788
# File 'lib/models/porcelain.rb', line 17786

def secret_store_root_path
  @secret_store_root_path
end

#tagsObject

Tags is a map of key, value pairs.



17788
17789
17790
# File 'lib/models/porcelain.rb', line 17788

def tags
  @tags
end

#tlsObject

TLS enables TLS/SSL when connecting to the SQL Server server.



17790
17791
17792
# File 'lib/models/porcelain.rb', line 17790

def tls
  @tls
end

#tls_skip_verifyObject

TLS disable certificate verification



17792
17793
17794
# File 'lib/models/porcelain.rb', line 17792

def tls_skip_verify
  @tls_skip_verify
end

#ttlObject

The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.



17794
17795
17796
# File 'lib/models/porcelain.rb', line 17794

def ttl
  @ttl
end

#usernameObject

Username is the username to connect to the SQL Server.



17796
17797
17798
# File 'lib/models/porcelain.rb', line 17796

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17838
17839
17840
17841
17842
17843
17844
# File 'lib/models/porcelain.rb', line 17838

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end