Class: SDM::SqlserverEngine
- Inherits:
-
Object
- Object
- SDM::SqlserverEngine
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#after_read_ttl ⇒ Object
The default time-to-live duration of the password after it's read.
-
#database ⇒ Object
Database is the database to verify credential against.
-
#hostname ⇒ Object
Hostname is the hostname or IP address of the SQL Server.
-
#id ⇒ Object
Unique identifier of the Secret Engine.
-
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days.
-
#name ⇒ Object
Unique human-readable name of the Secret Engine.
-
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine.
-
#password ⇒ Object
Password is the password to connect to the SQL Server server.
-
#policy ⇒ Object
Policy for password creation.
-
#port ⇒ Object
Port is the port number of the SQL Server server.
-
#public_key ⇒ Object
Public key linked with a secret engine.
-
#secret_store_id ⇒ Object
Backing secret store identifier.
-
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls ⇒ Object
TLS enables TLS/SSL when connecting to the SQL Server server.
-
#tls_skip_verify ⇒ Object
TLS disable certificate verification.
-
#ttl ⇒ Object
The default password time-to-live duration.
-
#username ⇒ Object
Username is the username to connect to the SQL Server.
Instance Method Summary collapse
-
#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil) ⇒ SqlserverEngine
constructor
A new instance of SqlserverEngine.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil) ⇒ SqlserverEngine
Returns a new instance of SqlserverEngine.
17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 17082 17083 17084 17085 17086 17087 17088 17089 17090 17091 17092 17093 17094 17095 17096 17097 17098 17099 17100 17101 17102 17103 17104 17105 17106 17107 17108 17109 |
# File 'lib/models/porcelain.rb', line 17071 def initialize( after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil ) @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl @database = database == nil ? "" : database @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days @name = name == nil ? "" : name @node_selector = node_selector == nil ? "" : node_selector @password = password == nil ? "" : password @policy = policy == nil ? nil : policy @port = port == nil ? 0 : port @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path @tags = == nil ? SDM::() : @tls = tls == nil ? false : tls @tls_skip_verify = tls_skip_verify == nil ? false : tls_skip_verify @ttl = ttl == nil ? nil : ttl @username = username == nil ? "" : username end |
Instance Attribute Details
#after_read_ttl ⇒ Object
The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.
17035 17036 17037 |
# File 'lib/models/porcelain.rb', line 17035 def after_read_ttl @after_read_ttl end |
#database ⇒ Object
Database is the database to verify credential against.
17037 17038 17039 |
# File 'lib/models/porcelain.rb', line 17037 def database @database end |
#hostname ⇒ Object
Hostname is the hostname or IP address of the SQL Server.
17039 17040 17041 |
# File 'lib/models/porcelain.rb', line 17039 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Secret Engine.
17041 17042 17043 |
# File 'lib/models/porcelain.rb', line 17041 def id @id end |
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days
17043 17044 17045 |
# File 'lib/models/porcelain.rb', line 17043 def key_rotation_interval_days @key_rotation_interval_days end |
#name ⇒ Object
Unique human-readable name of the Secret Engine.
17045 17046 17047 |
# File 'lib/models/porcelain.rb', line 17045 def name @name end |
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine
17047 17048 17049 |
# File 'lib/models/porcelain.rb', line 17047 def node_selector @node_selector end |
#password ⇒ Object
Password is the password to connect to the SQL Server server.
17049 17050 17051 |
# File 'lib/models/porcelain.rb', line 17049 def password @password end |
#policy ⇒ Object
Policy for password creation
17051 17052 17053 |
# File 'lib/models/porcelain.rb', line 17051 def policy @policy end |
#port ⇒ Object
Port is the port number of the SQL Server server.
17053 17054 17055 |
# File 'lib/models/porcelain.rb', line 17053 def port @port end |
#public_key ⇒ Object
Public key linked with a secret engine
17055 17056 17057 |
# File 'lib/models/porcelain.rb', line 17055 def public_key @public_key end |
#secret_store_id ⇒ Object
Backing secret store identifier
17057 17058 17059 |
# File 'lib/models/porcelain.rb', line 17057 def secret_store_id @secret_store_id end |
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored
17059 17060 17061 |
# File 'lib/models/porcelain.rb', line 17059 def secret_store_root_path @secret_store_root_path end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17061 17062 17063 |
# File 'lib/models/porcelain.rb', line 17061 def @tags end |
#tls ⇒ Object
TLS enables TLS/SSL when connecting to the SQL Server server.
17063 17064 17065 |
# File 'lib/models/porcelain.rb', line 17063 def tls @tls end |
#tls_skip_verify ⇒ Object
TLS disable certificate verification
17065 17066 17067 |
# File 'lib/models/porcelain.rb', line 17065 def tls_skip_verify @tls_skip_verify end |
#ttl ⇒ Object
The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.
17067 17068 17069 |
# File 'lib/models/porcelain.rb', line 17067 def ttl @ttl end |
#username ⇒ Object
Username is the username to connect to the SQL Server.
17069 17070 17071 |
# File 'lib/models/porcelain.rb', line 17069 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17111 17112 17113 17114 17115 17116 17117 |
# File 'lib/models/porcelain.rb', line 17111 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |