Class: SDM::SqlserverEngine

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil) ⇒ SqlserverEngine

Returns a new instance of SqlserverEngine.



17053
17054
17055
17056
17057
17058
17059
17060
17061
17062
17063
17064
17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
17088
17089
# File 'lib/models/porcelain.rb', line 17053

def initialize(
  after_read_ttl: nil,
  database: nil,
  hostname: nil,
  id: nil,
  key_rotation_interval_days: nil,
  name: nil,
  password: nil,
  policy: nil,
  port: nil,
  public_key: nil,
  secret_store_id: nil,
  secret_store_root_path: nil,
  tags: nil,
  tls: nil,
  tls_skip_verify: nil,
  ttl: nil,
  username: nil
)
  @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl
  @database = database == nil ? "" : database
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @policy = policy == nil ? nil : policy
  @port = port == nil ? 0 : port
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls = tls == nil ? false : tls
  @tls_skip_verify = tls_skip_verify == nil ? false : tls_skip_verify
  @ttl = ttl == nil ? nil : ttl
  @username = username == nil ? "" : username
end

Instance Attribute Details

#after_read_ttlObject

The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.



17019
17020
17021
# File 'lib/models/porcelain.rb', line 17019

def after_read_ttl
  @after_read_ttl
end

#databaseObject

Database is the database to verify credential against.



17021
17022
17023
# File 'lib/models/porcelain.rb', line 17021

def database
  @database
end

#hostnameObject

Hostname is the hostname or IP address of the SQL Server.



17023
17024
17025
# File 'lib/models/porcelain.rb', line 17023

def hostname
  @hostname
end

#idObject

Unique identifier of the Secret Engine.



17025
17026
17027
# File 'lib/models/porcelain.rb', line 17025

def id
  @id
end

#key_rotation_interval_daysObject

An interval of public/private key rotation for secret engine in days



17027
17028
17029
# File 'lib/models/porcelain.rb', line 17027

def key_rotation_interval_days
  @key_rotation_interval_days
end

#nameObject

Unique human-readable name of the Secret Engine.



17029
17030
17031
# File 'lib/models/porcelain.rb', line 17029

def name
  @name
end

#passwordObject

Password is the password to connect to the SQL Server server.



17031
17032
17033
# File 'lib/models/porcelain.rb', line 17031

def password
  @password
end

#policyObject

Policy for password creation



17033
17034
17035
# File 'lib/models/porcelain.rb', line 17033

def policy
  @policy
end

#portObject

Port is the port number of the SQL Server server.



17035
17036
17037
# File 'lib/models/porcelain.rb', line 17035

def port
  @port
end

#public_keyObject

Public key linked with a secret engine



17037
17038
17039
# File 'lib/models/porcelain.rb', line 17037

def public_key
  @public_key
end

#secret_store_idObject

Backing secret store identifier



17039
17040
17041
# File 'lib/models/porcelain.rb', line 17039

def secret_store_id
  @secret_store_id
end

#secret_store_root_pathObject

Backing Secret Store root path where managed secrets are going to be stored



17041
17042
17043
# File 'lib/models/porcelain.rb', line 17041

def secret_store_root_path
  @secret_store_root_path
end

#tagsObject

Tags is a map of key, value pairs.



17043
17044
17045
# File 'lib/models/porcelain.rb', line 17043

def tags
  @tags
end

#tlsObject

TLS enables TLS/SSL when connecting to the SQL Server server.



17045
17046
17047
# File 'lib/models/porcelain.rb', line 17045

def tls
  @tls
end

#tls_skip_verifyObject

TLS disable certificate verification



17047
17048
17049
# File 'lib/models/porcelain.rb', line 17047

def tls_skip_verify
  @tls_skip_verify
end

#ttlObject

The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.



17049
17050
17051
# File 'lib/models/porcelain.rb', line 17049

def ttl
  @ttl
end

#usernameObject

Username is the username to connect to the SQL Server.



17051
17052
17053
# File 'lib/models/porcelain.rb', line 17051

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17091
17092
17093
17094
17095
17096
17097
# File 'lib/models/porcelain.rb', line 17091

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end