Class: SDM::SqlserverEngine

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil) ⇒ SqlserverEngine

Returns a new instance of SqlserverEngine.



16767
16768
16769
16770
16771
16772
16773
16774
16775
16776
16777
16778
16779
16780
16781
16782
16783
16784
16785
16786
16787
16788
16789
16790
16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
16802
16803
# File 'lib/models/porcelain.rb', line 16767

def initialize(
  after_read_ttl: nil,
  database: nil,
  hostname: nil,
  id: nil,
  key_rotation_interval_days: nil,
  name: nil,
  password: nil,
  policy: nil,
  port: nil,
  public_key: nil,
  secret_store_id: nil,
  secret_store_root_path: nil,
  tags: nil,
  tls: nil,
  tls_skip_verify: nil,
  ttl: nil,
  username: nil
)
  @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl
  @database = database == nil ? "" : database
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @policy = policy == nil ? nil : policy
  @port = port == nil ? 0 : port
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls = tls == nil ? false : tls
  @tls_skip_verify = tls_skip_verify == nil ? false : tls_skip_verify
  @ttl = ttl == nil ? nil : ttl
  @username = username == nil ? "" : username
end

Instance Attribute Details

#after_read_ttlObject

The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.



16733
16734
16735
# File 'lib/models/porcelain.rb', line 16733

def after_read_ttl
  @after_read_ttl
end

#databaseObject

Database is the database to verify credential against.



16735
16736
16737
# File 'lib/models/porcelain.rb', line 16735

def database
  @database
end

#hostnameObject

Hostname is the hostname or IP address of the SQL Server.



16737
16738
16739
# File 'lib/models/porcelain.rb', line 16737

def hostname
  @hostname
end

#idObject

Unique identifier of the Secret Engine.



16739
16740
16741
# File 'lib/models/porcelain.rb', line 16739

def id
  @id
end

#key_rotation_interval_daysObject

An interval of public/private key rotation for secret engine in days



16741
16742
16743
# File 'lib/models/porcelain.rb', line 16741

def key_rotation_interval_days
  @key_rotation_interval_days
end

#nameObject

Unique human-readable name of the Secret Engine.



16743
16744
16745
# File 'lib/models/porcelain.rb', line 16743

def name
  @name
end

#passwordObject

Password is the password to connect to the SQL Server server.



16745
16746
16747
# File 'lib/models/porcelain.rb', line 16745

def password
  @password
end

#policyObject

Policy for password creation



16747
16748
16749
# File 'lib/models/porcelain.rb', line 16747

def policy
  @policy
end

#portObject

Port is the port number of the SQL Server server.



16749
16750
16751
# File 'lib/models/porcelain.rb', line 16749

def port
  @port
end

#public_keyObject

Public key linked with a secret engine



16751
16752
16753
# File 'lib/models/porcelain.rb', line 16751

def public_key
  @public_key
end

#secret_store_idObject

Backing secret store identifier



16753
16754
16755
# File 'lib/models/porcelain.rb', line 16753

def secret_store_id
  @secret_store_id
end

#secret_store_root_pathObject

Backing Secret Store root path where managed secrets are going to be stored



16755
16756
16757
# File 'lib/models/porcelain.rb', line 16755

def secret_store_root_path
  @secret_store_root_path
end

#tagsObject

Tags is a map of key, value pairs.



16757
16758
16759
# File 'lib/models/porcelain.rb', line 16757

def tags
  @tags
end

#tlsObject

TLS enables TLS/SSL when connecting to the SQL Server server.



16759
16760
16761
# File 'lib/models/porcelain.rb', line 16759

def tls
  @tls
end

#tls_skip_verifyObject

TLS disable certificate verification



16761
16762
16763
# File 'lib/models/porcelain.rb', line 16761

def tls_skip_verify
  @tls_skip_verify
end

#ttlObject

The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.



16763
16764
16765
# File 'lib/models/porcelain.rb', line 16763

def ttl
  @ttl
end

#usernameObject

Username is the username to connect to the SQL Server.



16765
16766
16767
# File 'lib/models/porcelain.rb', line 16765

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16805
16806
16807
16808
16809
16810
16811
# File 'lib/models/porcelain.rb', line 16805

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end