Class: SDM::SqlserverEngine

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil) ⇒ SqlserverEngine

Returns a new instance of SqlserverEngine.



17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
18016
18017
18018
18019
18020
18021
18022
18023
18024
18025
18026
18027
18028
# File 'lib/models/porcelain.rb', line 17990

def initialize(
  after_read_ttl: nil,
  database: nil,
  hostname: nil,
  id: nil,
  key_rotation_interval_days: nil,
  name: nil,
  node_selector: nil,
  password: nil,
  policy: nil,
  port: nil,
  public_key: nil,
  secret_store_id: nil,
  secret_store_root_path: nil,
  tags: nil,
  tls: nil,
  tls_skip_verify: nil,
  ttl: nil,
  username: nil
)
  @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl
  @database = database == nil ? "" : database
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days
  @name = name == nil ? "" : name
  @node_selector = node_selector == nil ? "" : node_selector
  @password = password == nil ? "" : password
  @policy = policy == nil ? nil : policy
  @port = port == nil ? 0 : port
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls = tls == nil ? false : tls
  @tls_skip_verify = tls_skip_verify == nil ? false : tls_skip_verify
  @ttl = ttl == nil ? nil : ttl
  @username = username == nil ? "" : username
end

Instance Attribute Details

#after_read_ttl ⇒ Object

The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.



17954
17955
17956
# File 'lib/models/porcelain.rb', line 17954

def after_read_ttl
  @after_read_ttl
end

#database ⇒ Object

Database is the database to verify credential against.



17956
17957
17958
# File 'lib/models/porcelain.rb', line 17956

def database
  @database
end

#hostname ⇒ Object

Hostname is the hostname or IP address of the SQL Server.



17958
17959
17960
# File 'lib/models/porcelain.rb', line 17958

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Secret Engine.



17960
17961
17962
# File 'lib/models/porcelain.rb', line 17960

def id
  @id
end

#key_rotation_interval_days ⇒ Object

An interval of public/private key rotation for secret engine in days



17962
17963
17964
# File 'lib/models/porcelain.rb', line 17962

def key_rotation_interval_days
  @key_rotation_interval_days
end

#name ⇒ Object

Unique human-readable name of the Secret Engine.



17964
17965
17966
# File 'lib/models/porcelain.rb', line 17964

def name
  @name
end

#node_selector ⇒ Object

node selector is used to narrow down the nodes used to communicate with with secret engine



17966
17967
17968
# File 'lib/models/porcelain.rb', line 17966

def node_selector
  @node_selector
end

#password ⇒ Object

Password is the password to connect to the SQL Server server.



17968
17969
17970
# File 'lib/models/porcelain.rb', line 17968

def password
  @password
end

#policy ⇒ Object

Policy for password creation



17970
17971
17972
# File 'lib/models/porcelain.rb', line 17970

def policy
  @policy
end

#port ⇒ Object

Port is the port number of the SQL Server server.



17972
17973
17974
# File 'lib/models/porcelain.rb', line 17972

def port
  @port
end

#public_key ⇒ Object

Public key linked with a secret engine



17974
17975
17976
# File 'lib/models/porcelain.rb', line 17974

def public_key
  @public_key
end

#secret_store_id ⇒ Object

Backing secret store identifier



17976
17977
17978
# File 'lib/models/porcelain.rb', line 17976

def secret_store_id
  @secret_store_id
end

#secret_store_root_path ⇒ Object

Backing Secret Store root path where managed secrets are going to be stored



17978
17979
17980
# File 'lib/models/porcelain.rb', line 17978

def secret_store_root_path
  @secret_store_root_path
end

#tags ⇒ Object

Tags is a map of key, value pairs.



17980
17981
17982
# File 'lib/models/porcelain.rb', line 17980

def tags
  @tags
end

#tls ⇒ Object

TLS enables TLS/SSL when connecting to the SQL Server server.



17982
17983
17984
# File 'lib/models/porcelain.rb', line 17982

def tls
  @tls
end

#tls_skip_verify ⇒ Object

TLS disable certificate verification



17984
17985
17986
# File 'lib/models/porcelain.rb', line 17984

def tls_skip_verify
  @tls_skip_verify
end

#ttl ⇒ Object

The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.



17986
17987
17988
# File 'lib/models/porcelain.rb', line 17986

def ttl
  @ttl
end

#username ⇒ Object

Username is the username to connect to the SQL Server.



17988
17989
17990
# File 'lib/models/porcelain.rb', line 17988

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18030
18031
18032
18033
18034
18035
18036
# File 'lib/models/porcelain.rb', line 18030

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end