Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
18000
18001
18002
18003
18004
18005
18006
18007
18008
18009
18010
18011
18012
18013
18014
18015
18016
18017
18018
# File 'lib/models/porcelain.rb', line 17988

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17960
17961
17962
# File 'lib/models/porcelain.rb', line 17960

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17962
17963
17964
# File 'lib/models/porcelain.rb', line 17962

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17964
17965
17966
# File 'lib/models/porcelain.rb', line 17964

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17966
17967
17968
# File 'lib/models/porcelain.rb', line 17966

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17968
17969
17970
# File 'lib/models/porcelain.rb', line 17968

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17970
17971
17972
# File 'lib/models/porcelain.rb', line 17970

def name
  @name
end

#passwordObject

The password to authenticate with.



17972
17973
17974
# File 'lib/models/porcelain.rb', line 17972

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17974
17975
17976
# File 'lib/models/porcelain.rb', line 17974

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17976
17977
17978
# File 'lib/models/porcelain.rb', line 17976

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17978
17979
17980
# File 'lib/models/porcelain.rb', line 17978

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17980
17981
17982
# File 'lib/models/porcelain.rb', line 17980

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17982
17983
17984
# File 'lib/models/porcelain.rb', line 17982

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17984
17985
17986
# File 'lib/models/porcelain.rb', line 17984

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17986
17987
17988
# File 'lib/models/porcelain.rb', line 17986

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18020
18021
18022
18023
18024
18025
18026
# File 'lib/models/porcelain.rb', line 18020

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end