Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
17690
17691
17692
17693
17694
17695
17696
17697
17698
17699
17700
17701
17702
17703
17704
17705
17706
17707
# File 'lib/models/porcelain.rb', line 17677

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17649
17650
17651
# File 'lib/models/porcelain.rb', line 17649

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17651
17652
17653
# File 'lib/models/porcelain.rb', line 17651

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17653
17654
17655
# File 'lib/models/porcelain.rb', line 17653

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17655
17656
17657
# File 'lib/models/porcelain.rb', line 17655

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17657
17658
17659
# File 'lib/models/porcelain.rb', line 17657

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17659
17660
17661
# File 'lib/models/porcelain.rb', line 17659

def name
  @name
end

#passwordObject

The password to authenticate with.



17661
17662
17663
# File 'lib/models/porcelain.rb', line 17661

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17663
17664
17665
# File 'lib/models/porcelain.rb', line 17663

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17665
17666
17667
# File 'lib/models/porcelain.rb', line 17665

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17667
17668
17669
# File 'lib/models/porcelain.rb', line 17667

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17669
17670
17671
# File 'lib/models/porcelain.rb', line 17669

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17671
17672
17673
# File 'lib/models/porcelain.rb', line 17671

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17673
17674
17675
# File 'lib/models/porcelain.rb', line 17673

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17675
17676
17677
# File 'lib/models/porcelain.rb', line 17675

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17709
17710
17711
17712
17713
17714
17715
# File 'lib/models/porcelain.rb', line 17709

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end