Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



17670
17671
17672
17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
17690
17691
17692
17693
17694
17695
17696
17697
17698
17699
17700
# File 'lib/models/porcelain.rb', line 17670

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17642
17643
17644
# File 'lib/models/porcelain.rb', line 17642

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17644
17645
17646
# File 'lib/models/porcelain.rb', line 17644

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17646
17647
17648
# File 'lib/models/porcelain.rb', line 17646

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17648
17649
17650
# File 'lib/models/porcelain.rb', line 17648

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17650
17651
17652
# File 'lib/models/porcelain.rb', line 17650

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17652
17653
17654
# File 'lib/models/porcelain.rb', line 17652

def name
  @name
end

#passwordObject

The password to authenticate with.



17654
17655
17656
# File 'lib/models/porcelain.rb', line 17654

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17656
17657
17658
# File 'lib/models/porcelain.rb', line 17656

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17658
17659
17660
# File 'lib/models/porcelain.rb', line 17658

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17660
17661
17662
# File 'lib/models/porcelain.rb', line 17660

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17662
17663
17664
# File 'lib/models/porcelain.rb', line 17662

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17664
17665
17666
# File 'lib/models/porcelain.rb', line 17664

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17666
17667
17668
# File 'lib/models/porcelain.rb', line 17666

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17668
17669
17670
# File 'lib/models/porcelain.rb', line 17668

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17702
17703
17704
17705
17706
17707
17708
# File 'lib/models/porcelain.rb', line 17702

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end