Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



17554
17555
17556
17557
17558
17559
17560
17561
17562
17563
17564
17565
17566
17567
17568
17569
17570
17571
17572
17573
17574
17575
17576
17577
17578
17579
17580
17581
17582
17583
17584
# File 'lib/models/porcelain.rb', line 17554

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17526
17527
17528
# File 'lib/models/porcelain.rb', line 17526

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17528
17529
17530
# File 'lib/models/porcelain.rb', line 17528

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17530
17531
17532
# File 'lib/models/porcelain.rb', line 17530

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17532
17533
17534
# File 'lib/models/porcelain.rb', line 17532

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17534
17535
17536
# File 'lib/models/porcelain.rb', line 17534

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17536
17537
17538
# File 'lib/models/porcelain.rb', line 17536

def name
  @name
end

#passwordObject

The password to authenticate with.



17538
17539
17540
# File 'lib/models/porcelain.rb', line 17538

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17540
17541
17542
# File 'lib/models/porcelain.rb', line 17540

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17542
17543
17544
# File 'lib/models/porcelain.rb', line 17542

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17544
17545
17546
# File 'lib/models/porcelain.rb', line 17544

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17546
17547
17548
# File 'lib/models/porcelain.rb', line 17546

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17548
17549
17550
# File 'lib/models/porcelain.rb', line 17548

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17550
17551
17552
# File 'lib/models/porcelain.rb', line 17550

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17552
17553
17554
# File 'lib/models/porcelain.rb', line 17552

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17586
17587
17588
17589
17590
17591
17592
# File 'lib/models/porcelain.rb', line 17586

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end