Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



17251
17252
17253
17254
17255
17256
17257
17258
17259
17260
17261
17262
17263
17264
17265
17266
17267
17268
17269
17270
17271
17272
17273
17274
17275
17276
17277
17278
17279
17280
17281
# File 'lib/models/porcelain.rb', line 17251

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17223
17224
17225
# File 'lib/models/porcelain.rb', line 17223

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17225
17226
17227
# File 'lib/models/porcelain.rb', line 17225

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17227
17228
17229
# File 'lib/models/porcelain.rb', line 17227

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17229
17230
17231
# File 'lib/models/porcelain.rb', line 17229

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17231
17232
17233
# File 'lib/models/porcelain.rb', line 17231

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17233
17234
17235
# File 'lib/models/porcelain.rb', line 17233

def name
  @name
end

#passwordObject

The password to authenticate with.



17235
17236
17237
# File 'lib/models/porcelain.rb', line 17235

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17237
17238
17239
# File 'lib/models/porcelain.rb', line 17237

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17239
17240
17241
# File 'lib/models/porcelain.rb', line 17239

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17241
17242
17243
# File 'lib/models/porcelain.rb', line 17241

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17243
17244
17245
# File 'lib/models/porcelain.rb', line 17243

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17245
17246
17247
# File 'lib/models/porcelain.rb', line 17245

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17247
17248
17249
# File 'lib/models/porcelain.rb', line 17247

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17249
17250
17251
# File 'lib/models/porcelain.rb', line 17249

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17283
17284
17285
17286
17287
17288
17289
# File 'lib/models/porcelain.rb', line 17283

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end