Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



17157
17158
17159
17160
17161
17162
17163
17164
17165
17166
17167
17168
17169
17170
17171
17172
17173
17174
17175
17176
17177
17178
17179
17180
17181
17182
17183
17184
17185
17186
17187
# File 'lib/models/porcelain.rb', line 17157

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17129
17130
17131
# File 'lib/models/porcelain.rb', line 17129

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17131
17132
17133
# File 'lib/models/porcelain.rb', line 17131

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17133
17134
17135
# File 'lib/models/porcelain.rb', line 17133

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17135
17136
17137
# File 'lib/models/porcelain.rb', line 17135

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17137
17138
17139
# File 'lib/models/porcelain.rb', line 17137

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17139
17140
17141
# File 'lib/models/porcelain.rb', line 17139

def name
  @name
end

#passwordObject

The password to authenticate with.



17141
17142
17143
# File 'lib/models/porcelain.rb', line 17141

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17143
17144
17145
# File 'lib/models/porcelain.rb', line 17143

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17145
17146
17147
# File 'lib/models/porcelain.rb', line 17145

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17147
17148
17149
# File 'lib/models/porcelain.rb', line 17147

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17149
17150
17151
# File 'lib/models/porcelain.rb', line 17149

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17151
17152
17153
# File 'lib/models/porcelain.rb', line 17151

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17153
17154
17155
# File 'lib/models/porcelain.rb', line 17153

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17155
17156
17157
# File 'lib/models/porcelain.rb', line 17155

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17189
17190
17191
17192
17193
17194
17195
# File 'lib/models/porcelain.rb', line 17189

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end