Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



15883
15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
15910
15911
15912
15913
# File 'lib/models/porcelain.rb', line 15883

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15855
15856
15857
# File 'lib/models/porcelain.rb', line 15855

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15857
15858
15859
# File 'lib/models/porcelain.rb', line 15857

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15859
15860
15861
# File 'lib/models/porcelain.rb', line 15859

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15861
15862
15863
# File 'lib/models/porcelain.rb', line 15861

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15863
15864
15865
# File 'lib/models/porcelain.rb', line 15863

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15865
15866
15867
# File 'lib/models/porcelain.rb', line 15865

def name
  @name
end

#passwordObject

The password to authenticate with.



15867
15868
15869
# File 'lib/models/porcelain.rb', line 15867

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15869
15870
15871
# File 'lib/models/porcelain.rb', line 15869

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15871
15872
15873
# File 'lib/models/porcelain.rb', line 15871

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15873
15874
15875
# File 'lib/models/porcelain.rb', line 15873

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15875
15876
15877
# File 'lib/models/porcelain.rb', line 15875

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15877
15878
15879
# File 'lib/models/porcelain.rb', line 15877

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15879
15880
15881
# File 'lib/models/porcelain.rb', line 15879

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15881
15882
15883
# File 'lib/models/porcelain.rb', line 15881

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15915
15916
15917
15918
15919
15920
15921
# File 'lib/models/porcelain.rb', line 15915

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end