Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
14384 14385 14386 14387 14388 14389 14390 14391 14392 14393 14394 14395 14396 14397 14398 14399 14400 14401 14402 14403 14404 14405 14406 14407 14408 14409 14410 14411 14412 14413 14414 |
# File 'lib/models/porcelain.rb', line 14384 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
14356 14357 14358 |
# File 'lib/models/porcelain.rb', line 14356 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
14358 14359 14360 |
# File 'lib/models/porcelain.rb', line 14358 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
14360 14361 14362 |
# File 'lib/models/porcelain.rb', line 14360 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
14362 14363 14364 |
# File 'lib/models/porcelain.rb', line 14362 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
14364 14365 14366 |
# File 'lib/models/porcelain.rb', line 14364 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
14366 14367 14368 |
# File 'lib/models/porcelain.rb', line 14366 def name @name end |
#password ⇒ Object
The password to authenticate with.
14368 14369 14370 |
# File 'lib/models/porcelain.rb', line 14368 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
14370 14371 14372 |
# File 'lib/models/porcelain.rb', line 14370 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
14372 14373 14374 |
# File 'lib/models/porcelain.rb', line 14372 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
14374 14375 14376 |
# File 'lib/models/porcelain.rb', line 14374 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
14376 14377 14378 |
# File 'lib/models/porcelain.rb', line 14376 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
14378 14379 14380 |
# File 'lib/models/porcelain.rb', line 14378 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14380 14381 14382 |
# File 'lib/models/porcelain.rb', line 14380 def @tags end |
#username ⇒ Object
The username to authenticate with.
14382 14383 14384 |
# File 'lib/models/porcelain.rb', line 14382 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14416 14417 14418 14419 14420 14421 14422 |
# File 'lib/models/porcelain.rb', line 14416 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |