Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
14232 14233 14234 14235 14236 14237 14238 14239 14240 14241 14242 14243 14244 14245 14246 14247 14248 14249 14250 14251 14252 14253 14254 14255 14256 14257 14258 14259 14260 14261 14262 |
# File 'lib/models/porcelain.rb', line 14232 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
14204 14205 14206 |
# File 'lib/models/porcelain.rb', line 14204 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
14206 14207 14208 |
# File 'lib/models/porcelain.rb', line 14206 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
14208 14209 14210 |
# File 'lib/models/porcelain.rb', line 14208 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
14210 14211 14212 |
# File 'lib/models/porcelain.rb', line 14210 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
14212 14213 14214 |
# File 'lib/models/porcelain.rb', line 14212 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
14214 14215 14216 |
# File 'lib/models/porcelain.rb', line 14214 def name @name end |
#password ⇒ Object
The password to authenticate with.
14216 14217 14218 |
# File 'lib/models/porcelain.rb', line 14216 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
14218 14219 14220 |
# File 'lib/models/porcelain.rb', line 14218 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
14220 14221 14222 |
# File 'lib/models/porcelain.rb', line 14220 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
14222 14223 14224 |
# File 'lib/models/porcelain.rb', line 14222 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
14224 14225 14226 |
# File 'lib/models/porcelain.rb', line 14224 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
14226 14227 14228 |
# File 'lib/models/porcelain.rb', line 14226 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14228 14229 14230 |
# File 'lib/models/porcelain.rb', line 14228 def @tags end |
#username ⇒ Object
The username to authenticate with.
14230 14231 14232 |
# File 'lib/models/porcelain.rb', line 14230 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14264 14265 14266 14267 14268 14269 14270 |
# File 'lib/models/porcelain.rb', line 14264 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |