Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
12988 12989 12990 12991 12992 12993 12994 12995 12996 12997 12998 12999 13000 13001 13002 13003 13004 13005 13006 13007 13008 13009 13010 13011 13012 13013 13014 13015 13016 13017 13018 |
# File 'lib/models/porcelain.rb', line 12988 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12960 12961 12962 |
# File 'lib/models/porcelain.rb', line 12960 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12962 12963 12964 |
# File 'lib/models/porcelain.rb', line 12962 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12964 12965 12966 |
# File 'lib/models/porcelain.rb', line 12964 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12966 12967 12968 |
# File 'lib/models/porcelain.rb', line 12966 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12968 12969 12970 |
# File 'lib/models/porcelain.rb', line 12968 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12970 12971 12972 |
# File 'lib/models/porcelain.rb', line 12970 def name @name end |
#password ⇒ Object
The password to authenticate with.
12972 12973 12974 |
# File 'lib/models/porcelain.rb', line 12972 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12974 12975 12976 |
# File 'lib/models/porcelain.rb', line 12974 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
12976 12977 12978 |
# File 'lib/models/porcelain.rb', line 12976 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12978 12979 12980 |
# File 'lib/models/porcelain.rb', line 12978 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12980 12981 12982 |
# File 'lib/models/porcelain.rb', line 12980 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
12982 12983 12984 |
# File 'lib/models/porcelain.rb', line 12982 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12984 12985 12986 |
# File 'lib/models/porcelain.rb', line 12984 def @tags end |
#username ⇒ Object
The username to authenticate with.
12986 12987 12988 |
# File 'lib/models/porcelain.rb', line 12986 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13020 13021 13022 13023 13024 13025 13026 |
# File 'lib/models/porcelain.rb', line 13020 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |