Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



12980
12981
12982
12983
12984
12985
12986
12987
12988
12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
13002
13003
13004
13005
13006
13007
13008
13009
13010
# File 'lib/models/porcelain.rb', line 12980

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12952
12953
12954
# File 'lib/models/porcelain.rb', line 12952

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12954
12955
12956
# File 'lib/models/porcelain.rb', line 12954

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12956
12957
12958
# File 'lib/models/porcelain.rb', line 12956

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12958
12959
12960
# File 'lib/models/porcelain.rb', line 12958

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12960
12961
12962
# File 'lib/models/porcelain.rb', line 12960

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12962
12963
12964
# File 'lib/models/porcelain.rb', line 12962

def name
  @name
end

#passwordObject

The password to authenticate with.



12964
12965
12966
# File 'lib/models/porcelain.rb', line 12964

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12966
12967
12968
# File 'lib/models/porcelain.rb', line 12966

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12968
12969
12970
# File 'lib/models/porcelain.rb', line 12968

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12970
12971
12972
# File 'lib/models/porcelain.rb', line 12970

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12972
12973
12974
# File 'lib/models/porcelain.rb', line 12972

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12974
12975
12976
# File 'lib/models/porcelain.rb', line 12974

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12976
12977
12978
# File 'lib/models/porcelain.rb', line 12976

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12978
12979
12980
# File 'lib/models/porcelain.rb', line 12978

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13012
13013
13014
13015
13016
13017
13018
# File 'lib/models/porcelain.rb', line 13012

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end