Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
12897 12898 12899 12900 12901 12902 12903 12904 12905 12906 12907 12908 12909 12910 12911 12912 12913 12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 |
# File 'lib/models/porcelain.rb', line 12897 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12869 12870 12871 |
# File 'lib/models/porcelain.rb', line 12869 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12871 12872 12873 |
# File 'lib/models/porcelain.rb', line 12871 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12873 12874 12875 |
# File 'lib/models/porcelain.rb', line 12873 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12875 12876 12877 |
# File 'lib/models/porcelain.rb', line 12875 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12877 12878 12879 |
# File 'lib/models/porcelain.rb', line 12877 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12879 12880 12881 |
# File 'lib/models/porcelain.rb', line 12879 def name @name end |
#password ⇒ Object
The password to authenticate with.
12881 12882 12883 |
# File 'lib/models/porcelain.rb', line 12881 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12883 12884 12885 |
# File 'lib/models/porcelain.rb', line 12883 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
12885 12886 12887 |
# File 'lib/models/porcelain.rb', line 12885 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12887 12888 12889 |
# File 'lib/models/porcelain.rb', line 12887 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12889 12890 12891 |
# File 'lib/models/porcelain.rb', line 12889 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
12891 12892 12893 |
# File 'lib/models/porcelain.rb', line 12891 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12893 12894 12895 |
# File 'lib/models/porcelain.rb', line 12893 def @tags end |
#username ⇒ Object
The username to authenticate with.
12895 12896 12897 |
# File 'lib/models/porcelain.rb', line 12895 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12929 12930 12931 12932 12933 12934 12935 |
# File 'lib/models/porcelain.rb', line 12929 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |