Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
12658 12659 12660 12661 12662 12663 12664 12665 12666 12667 12668 12669 12670 12671 12672 12673 12674 12675 12676 12677 12678 12679 12680 12681 12682 12683 12684 12685 12686 12687 12688 |
# File 'lib/models/porcelain.rb', line 12658 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12630 12631 12632 |
# File 'lib/models/porcelain.rb', line 12630 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12632 12633 12634 |
# File 'lib/models/porcelain.rb', line 12632 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12634 12635 12636 |
# File 'lib/models/porcelain.rb', line 12634 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12636 12637 12638 |
# File 'lib/models/porcelain.rb', line 12636 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12638 12639 12640 |
# File 'lib/models/porcelain.rb', line 12638 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12640 12641 12642 |
# File 'lib/models/porcelain.rb', line 12640 def name @name end |
#password ⇒ Object
The password to authenticate with.
12642 12643 12644 |
# File 'lib/models/porcelain.rb', line 12642 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12644 12645 12646 |
# File 'lib/models/porcelain.rb', line 12644 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
12646 12647 12648 |
# File 'lib/models/porcelain.rb', line 12646 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12648 12649 12650 |
# File 'lib/models/porcelain.rb', line 12648 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12650 12651 12652 |
# File 'lib/models/porcelain.rb', line 12650 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
12652 12653 12654 |
# File 'lib/models/porcelain.rb', line 12652 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12654 12655 12656 |
# File 'lib/models/porcelain.rb', line 12654 def @tags end |
#username ⇒ Object
The username to authenticate with.
12656 12657 12658 |
# File 'lib/models/porcelain.rb', line 12656 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12690 12691 12692 12693 12694 12695 12696 |
# File 'lib/models/porcelain.rb', line 12690 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |