Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
12507 12508 12509 12510 12511 12512 12513 12514 12515 12516 12517 12518 12519 12520 12521 12522 12523 12524 12525 12526 12527 12528 12529 12530 12531 12532 12533 12534 12535 12536 12537 |
# File 'lib/models/porcelain.rb', line 12507 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12479 12480 12481 |
# File 'lib/models/porcelain.rb', line 12479 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12481 12482 12483 |
# File 'lib/models/porcelain.rb', line 12481 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12483 12484 12485 |
# File 'lib/models/porcelain.rb', line 12483 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12485 12486 12487 |
# File 'lib/models/porcelain.rb', line 12485 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12487 12488 12489 |
# File 'lib/models/porcelain.rb', line 12487 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12489 12490 12491 |
# File 'lib/models/porcelain.rb', line 12489 def name @name end |
#password ⇒ Object
The password to authenticate with.
12491 12492 12493 |
# File 'lib/models/porcelain.rb', line 12491 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12493 12494 12495 |
# File 'lib/models/porcelain.rb', line 12493 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
12495 12496 12497 |
# File 'lib/models/porcelain.rb', line 12495 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12497 12498 12499 |
# File 'lib/models/porcelain.rb', line 12497 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12499 12500 12501 |
# File 'lib/models/porcelain.rb', line 12499 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
12501 12502 12503 |
# File 'lib/models/porcelain.rb', line 12501 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12503 12504 12505 |
# File 'lib/models/porcelain.rb', line 12503 def @tags end |
#username ⇒ Object
The username to authenticate with.
12505 12506 12507 |
# File 'lib/models/porcelain.rb', line 12505 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12539 12540 12541 12542 12543 12544 12545 |
# File 'lib/models/porcelain.rb', line 12539 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |