Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
12146 12147 12148 12149 12150 12151 12152 12153 12154 12155 12156 12157 12158 12159 12160 12161 12162 12163 12164 12165 12166 12167 12168 12169 12170 12171 12172 12173 12174 12175 12176 |
# File 'lib/models/porcelain.rb', line 12146 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12118 12119 12120 |
# File 'lib/models/porcelain.rb', line 12118 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12120 12121 12122 |
# File 'lib/models/porcelain.rb', line 12120 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12122 12123 12124 |
# File 'lib/models/porcelain.rb', line 12122 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12124 12125 12126 |
# File 'lib/models/porcelain.rb', line 12124 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12126 12127 12128 |
# File 'lib/models/porcelain.rb', line 12126 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12128 12129 12130 |
# File 'lib/models/porcelain.rb', line 12128 def name @name end |
#password ⇒ Object
The password to authenticate with.
12130 12131 12132 |
# File 'lib/models/porcelain.rb', line 12130 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12132 12133 12134 |
# File 'lib/models/porcelain.rb', line 12132 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
12134 12135 12136 |
# File 'lib/models/porcelain.rb', line 12134 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12136 12137 12138 |
# File 'lib/models/porcelain.rb', line 12136 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12138 12139 12140 |
# File 'lib/models/porcelain.rb', line 12138 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
12140 12141 12142 |
# File 'lib/models/porcelain.rb', line 12140 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12142 12143 12144 |
# File 'lib/models/porcelain.rb', line 12142 def @tags end |
#username ⇒ Object
The username to authenticate with.
12144 12145 12146 |
# File 'lib/models/porcelain.rb', line 12144 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12178 12179 12180 12181 12182 12183 12184 |
# File 'lib/models/porcelain.rb', line 12178 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |