Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



11889
11890
11891
11892
11893
11894
11895
11896
11897
11898
11899
11900
11901
11902
11903
11904
11905
11906
11907
11908
11909
11910
11911
11912
11913
11914
11915
11916
11917
11918
11919
# File 'lib/models/porcelain.rb', line 11889

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11861
11862
11863
# File 'lib/models/porcelain.rb', line 11861

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11863
11864
11865
# File 'lib/models/porcelain.rb', line 11863

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11865
11866
11867
# File 'lib/models/porcelain.rb', line 11865

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11867
11868
11869
# File 'lib/models/porcelain.rb', line 11867

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11869
11870
11871
# File 'lib/models/porcelain.rb', line 11869

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11871
11872
11873
# File 'lib/models/porcelain.rb', line 11871

def name
  @name
end

#passwordObject

The password to authenticate with.



11873
11874
11875
# File 'lib/models/porcelain.rb', line 11873

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11875
11876
11877
# File 'lib/models/porcelain.rb', line 11875

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11877
11878
11879
# File 'lib/models/porcelain.rb', line 11877

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11879
11880
11881
# File 'lib/models/porcelain.rb', line 11879

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11881
11882
11883
# File 'lib/models/porcelain.rb', line 11881

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11883
11884
11885
# File 'lib/models/porcelain.rb', line 11883

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11885
11886
11887
# File 'lib/models/porcelain.rb', line 11885

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11887
11888
11889
# File 'lib/models/porcelain.rb', line 11887

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11921
11922
11923
11924
11925
11926
11927
# File 'lib/models/porcelain.rb', line 11921

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end