Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
11818 11819 11820 11821 11822 11823 11824 11825 11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 11844 11845 11846 11847 11848 |
# File 'lib/models/porcelain.rb', line 11818 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11790 11791 11792 |
# File 'lib/models/porcelain.rb', line 11790 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11792 11793 11794 |
# File 'lib/models/porcelain.rb', line 11792 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11794 11795 11796 |
# File 'lib/models/porcelain.rb', line 11794 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11796 11797 11798 |
# File 'lib/models/porcelain.rb', line 11796 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11798 11799 11800 |
# File 'lib/models/porcelain.rb', line 11798 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11800 11801 11802 |
# File 'lib/models/porcelain.rb', line 11800 def name @name end |
#password ⇒ Object
The password to authenticate with.
11802 11803 11804 |
# File 'lib/models/porcelain.rb', line 11802 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11804 11805 11806 |
# File 'lib/models/porcelain.rb', line 11804 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11806 11807 11808 |
# File 'lib/models/porcelain.rb', line 11806 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11808 11809 11810 |
# File 'lib/models/porcelain.rb', line 11808 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11810 11811 11812 |
# File 'lib/models/porcelain.rb', line 11810 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11812 11813 11814 |
# File 'lib/models/porcelain.rb', line 11812 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11814 11815 11816 |
# File 'lib/models/porcelain.rb', line 11814 def @tags end |
#username ⇒ Object
The username to authenticate with.
11816 11817 11818 |
# File 'lib/models/porcelain.rb', line 11816 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11850 11851 11852 11853 11854 11855 11856 |
# File 'lib/models/porcelain.rb', line 11850 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |