Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



11749
11750
11751
11752
11753
11754
11755
11756
11757
11758
11759
11760
11761
11762
11763
11764
11765
11766
11767
11768
11769
11770
11771
11772
11773
11774
11775
11776
11777
11778
11779
# File 'lib/models/porcelain.rb', line 11749

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11721
11722
11723
# File 'lib/models/porcelain.rb', line 11721

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11723
11724
11725
# File 'lib/models/porcelain.rb', line 11723

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11725
11726
11727
# File 'lib/models/porcelain.rb', line 11725

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11727
11728
11729
# File 'lib/models/porcelain.rb', line 11727

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11729
11730
11731
# File 'lib/models/porcelain.rb', line 11729

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11731
11732
11733
# File 'lib/models/porcelain.rb', line 11731

def name
  @name
end

#passwordObject

The password to authenticate with.



11733
11734
11735
# File 'lib/models/porcelain.rb', line 11733

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11735
11736
11737
# File 'lib/models/porcelain.rb', line 11735

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11737
11738
11739
# File 'lib/models/porcelain.rb', line 11737

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11739
11740
11741
# File 'lib/models/porcelain.rb', line 11739

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11741
11742
11743
# File 'lib/models/porcelain.rb', line 11741

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11743
11744
11745
# File 'lib/models/porcelain.rb', line 11743

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11745
11746
11747
# File 'lib/models/porcelain.rb', line 11745

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11747
11748
11749
# File 'lib/models/porcelain.rb', line 11747

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11781
11782
11783
11784
11785
11786
11787
# File 'lib/models/porcelain.rb', line 11781

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end