Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
11742 11743 11744 11745 11746 11747 11748 11749 11750 11751 11752 11753 11754 11755 11756 11757 11758 11759 11760 11761 11762 11763 11764 11765 11766 11767 11768 11769 11770 11771 11772 |
# File 'lib/models/porcelain.rb', line 11742 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11714 11715 11716 |
# File 'lib/models/porcelain.rb', line 11714 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11716 11717 11718 |
# File 'lib/models/porcelain.rb', line 11716 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11718 11719 11720 |
# File 'lib/models/porcelain.rb', line 11718 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11720 11721 11722 |
# File 'lib/models/porcelain.rb', line 11720 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11722 11723 11724 |
# File 'lib/models/porcelain.rb', line 11722 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11724 11725 11726 |
# File 'lib/models/porcelain.rb', line 11724 def name @name end |
#password ⇒ Object
The password to authenticate with.
11726 11727 11728 |
# File 'lib/models/porcelain.rb', line 11726 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11728 11729 11730 |
# File 'lib/models/porcelain.rb', line 11728 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11730 11731 11732 |
# File 'lib/models/porcelain.rb', line 11730 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11732 11733 11734 |
# File 'lib/models/porcelain.rb', line 11732 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11734 11735 11736 |
# File 'lib/models/porcelain.rb', line 11734 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11736 11737 11738 |
# File 'lib/models/porcelain.rb', line 11736 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11738 11739 11740 |
# File 'lib/models/porcelain.rb', line 11738 def @tags end |
#username ⇒ Object
The username to authenticate with.
11740 11741 11742 |
# File 'lib/models/porcelain.rb', line 11740 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11774 11775 11776 11777 11778 11779 11780 |
# File 'lib/models/porcelain.rb', line 11774 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |