Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
11418
11419
11420
11421
11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
# File 'lib/models/porcelain.rb', line 11408

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11382
11383
11384
# File 'lib/models/porcelain.rb', line 11382

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11384
11385
11386
# File 'lib/models/porcelain.rb', line 11384

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11386
11387
11388
# File 'lib/models/porcelain.rb', line 11386

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11388
11389
11390
# File 'lib/models/porcelain.rb', line 11388

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11390
11391
11392
# File 'lib/models/porcelain.rb', line 11390

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11392
11393
11394
# File 'lib/models/porcelain.rb', line 11392

def name
  @name
end

#passwordObject

The password to authenticate with.



11394
11395
11396
# File 'lib/models/porcelain.rb', line 11394

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11396
11397
11398
# File 'lib/models/porcelain.rb', line 11396

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11398
11399
11400
# File 'lib/models/porcelain.rb', line 11398

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11400
11401
11402
# File 'lib/models/porcelain.rb', line 11400

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11402
11403
11404
# File 'lib/models/porcelain.rb', line 11402

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11404
11405
11406
# File 'lib/models/porcelain.rb', line 11404

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11406
11407
11408
# File 'lib/models/porcelain.rb', line 11406

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11438
11439
11440
11441
11442
11443
11444
# File 'lib/models/porcelain.rb', line 11438

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end