Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 11255 11256 11257 11258 11259 11260 11261 11262 11263 |
# File 'lib/models/porcelain.rb', line 11235 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11209 11210 11211 |
# File 'lib/models/porcelain.rb', line 11209 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11211 11212 11213 |
# File 'lib/models/porcelain.rb', line 11211 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11213 11214 11215 |
# File 'lib/models/porcelain.rb', line 11213 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11215 11216 11217 |
# File 'lib/models/porcelain.rb', line 11215 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11217 11218 11219 |
# File 'lib/models/porcelain.rb', line 11217 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11219 11220 11221 |
# File 'lib/models/porcelain.rb', line 11219 def name @name end |
#password ⇒ Object
The password to authenticate with.
11221 11222 11223 |
# File 'lib/models/porcelain.rb', line 11221 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11223 11224 11225 |
# File 'lib/models/porcelain.rb', line 11223 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11225 11226 11227 |
# File 'lib/models/porcelain.rb', line 11225 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11227 11228 11229 |
# File 'lib/models/porcelain.rb', line 11227 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11229 11230 11231 |
# File 'lib/models/porcelain.rb', line 11229 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11231 11232 11233 |
# File 'lib/models/porcelain.rb', line 11231 def @tags end |
#username ⇒ Object
The username to authenticate with.
11233 11234 11235 |
# File 'lib/models/porcelain.rb', line 11233 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11265 11266 11267 11268 11269 11270 11271 |
# File 'lib/models/porcelain.rb', line 11265 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |