Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



11068
11069
11070
11071
11072
11073
11074
11075
11076
11077
11078
11079
11080
11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
11093
11094
11095
11096
# File 'lib/models/porcelain.rb', line 11068

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11042
11043
11044
# File 'lib/models/porcelain.rb', line 11042

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11044
11045
11046
# File 'lib/models/porcelain.rb', line 11044

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11046
11047
11048
# File 'lib/models/porcelain.rb', line 11046

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11048
11049
11050
# File 'lib/models/porcelain.rb', line 11048

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11050
11051
11052
# File 'lib/models/porcelain.rb', line 11050

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11052
11053
11054
# File 'lib/models/porcelain.rb', line 11052

def name
  @name
end

#passwordObject

The password to authenticate with.



11054
11055
11056
# File 'lib/models/porcelain.rb', line 11054

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11056
11057
11058
# File 'lib/models/porcelain.rb', line 11056

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11058
11059
11060
# File 'lib/models/porcelain.rb', line 11058

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11060
11061
11062
# File 'lib/models/porcelain.rb', line 11060

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11062
11063
11064
# File 'lib/models/porcelain.rb', line 11062

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11064
11065
11066
# File 'lib/models/porcelain.rb', line 11064

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11066
11067
11068
# File 'lib/models/porcelain.rb', line 11066

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11098
11099
11100
11101
11102
11103
11104
# File 'lib/models/porcelain.rb', line 11098

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end