Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



9664
9665
9666
9667
9668
9669
9670
9671
9672
9673
9674
9675
9676
9677
9678
9679
9680
9681
9682
9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
# File 'lib/models/porcelain.rb', line 9664

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9638
9639
9640
# File 'lib/models/porcelain.rb', line 9638

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9640
9641
9642
# File 'lib/models/porcelain.rb', line 9640

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9642
9643
9644
# File 'lib/models/porcelain.rb', line 9642

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9644
9645
9646
# File 'lib/models/porcelain.rb', line 9644

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9646
9647
9648
# File 'lib/models/porcelain.rb', line 9646

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9648
9649
9650
# File 'lib/models/porcelain.rb', line 9648

def name
  @name
end

#passwordObject

The password to authenticate with.



9650
9651
9652
# File 'lib/models/porcelain.rb', line 9650

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9652
9653
9654
# File 'lib/models/porcelain.rb', line 9652

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9654
9655
9656
# File 'lib/models/porcelain.rb', line 9654

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9656
9657
9658
# File 'lib/models/porcelain.rb', line 9656

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9658
9659
9660
# File 'lib/models/porcelain.rb', line 9658

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9660
9661
9662
# File 'lib/models/porcelain.rb', line 9660

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9662
9663
9664
# File 'lib/models/porcelain.rb', line 9662

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9694
9695
9696
9697
9698
9699
9700
# File 'lib/models/porcelain.rb', line 9694

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end