Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 |
# File 'lib/models/porcelain.rb', line 9104 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9078 9079 9080 |
# File 'lib/models/porcelain.rb', line 9078 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9080 9081 9082 |
# File 'lib/models/porcelain.rb', line 9080 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9082 9083 9084 |
# File 'lib/models/porcelain.rb', line 9082 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9084 9085 9086 |
# File 'lib/models/porcelain.rb', line 9084 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9086 9087 9088 |
# File 'lib/models/porcelain.rb', line 9086 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9088 9089 9090 |
# File 'lib/models/porcelain.rb', line 9088 def name @name end |
#password ⇒ Object
The password to authenticate with.
9090 9091 9092 |
# File 'lib/models/porcelain.rb', line 9090 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9092 9093 9094 |
# File 'lib/models/porcelain.rb', line 9092 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9094 9095 9096 |
# File 'lib/models/porcelain.rb', line 9094 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9096 9097 9098 |
# File 'lib/models/porcelain.rb', line 9096 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9098 9099 9100 |
# File 'lib/models/porcelain.rb', line 9098 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9100 9101 9102 |
# File 'lib/models/porcelain.rb', line 9100 def @tags end |
#username ⇒ Object
The username to authenticate with.
9102 9103 9104 |
# File 'lib/models/porcelain.rb', line 9102 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9134 9135 9136 9137 9138 9139 9140 |
# File 'lib/models/porcelain.rb', line 9134 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |