Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 8905 8906 8907 8908 8909 8910 8911 |
# File 'lib/models/porcelain.rb', line 8883 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8857 8858 8859 |
# File 'lib/models/porcelain.rb', line 8857 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8859 8860 8861 |
# File 'lib/models/porcelain.rb', line 8859 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8861 8862 8863 |
# File 'lib/models/porcelain.rb', line 8861 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8863 8864 8865 |
# File 'lib/models/porcelain.rb', line 8863 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8865 8866 8867 |
# File 'lib/models/porcelain.rb', line 8865 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8867 8868 8869 |
# File 'lib/models/porcelain.rb', line 8867 def name @name end |
#password ⇒ Object
The password to authenticate with.
8869 8870 8871 |
# File 'lib/models/porcelain.rb', line 8869 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8871 8872 8873 |
# File 'lib/models/porcelain.rb', line 8871 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8873 8874 8875 |
# File 'lib/models/porcelain.rb', line 8873 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8875 8876 8877 |
# File 'lib/models/porcelain.rb', line 8875 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8877 8878 8879 |
# File 'lib/models/porcelain.rb', line 8877 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8879 8880 8881 |
# File 'lib/models/porcelain.rb', line 8879 def @tags end |
#username ⇒ Object
The username to authenticate with.
8881 8882 8883 |
# File 'lib/models/porcelain.rb', line 8881 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8913 8914 8915 8916 8917 8918 8919 |
# File 'lib/models/porcelain.rb', line 8913 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |