Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



8446
8447
8448
8449
8450
8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
8469
8470
8471
8472
8473
8474
# File 'lib/models/porcelain.rb', line 8446

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8420
8421
8422
# File 'lib/models/porcelain.rb', line 8420

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8422
8423
8424
# File 'lib/models/porcelain.rb', line 8422

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8424
8425
8426
# File 'lib/models/porcelain.rb', line 8424

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8426
8427
8428
# File 'lib/models/porcelain.rb', line 8426

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8428
8429
8430
# File 'lib/models/porcelain.rb', line 8428

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8430
8431
8432
# File 'lib/models/porcelain.rb', line 8430

def name
  @name
end

#passwordObject

The password to authenticate with.



8432
8433
8434
# File 'lib/models/porcelain.rb', line 8432

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8434
8435
8436
# File 'lib/models/porcelain.rb', line 8434

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8436
8437
8438
# File 'lib/models/porcelain.rb', line 8436

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8438
8439
8440
# File 'lib/models/porcelain.rb', line 8438

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8440
8441
8442
# File 'lib/models/porcelain.rb', line 8440

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8442
8443
8444
# File 'lib/models/porcelain.rb', line 8442

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8444
8445
8446
# File 'lib/models/porcelain.rb', line 8444

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8476
8477
8478
8479
8480
8481
8482
# File 'lib/models/porcelain.rb', line 8476

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end