Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
8456 8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 8470 8471 8472 8473 8474 8475 8476 8477 8478 8479 8480 8481 8482 8483 8484 |
# File 'lib/models/porcelain.rb', line 8456 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8430 8431 8432 |
# File 'lib/models/porcelain.rb', line 8430 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8432 8433 8434 |
# File 'lib/models/porcelain.rb', line 8432 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8434 8435 8436 |
# File 'lib/models/porcelain.rb', line 8434 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8436 8437 8438 |
# File 'lib/models/porcelain.rb', line 8436 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8438 8439 8440 |
# File 'lib/models/porcelain.rb', line 8438 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8440 8441 8442 |
# File 'lib/models/porcelain.rb', line 8440 def name @name end |
#password ⇒ Object
The password to authenticate with.
8442 8443 8444 |
# File 'lib/models/porcelain.rb', line 8442 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8444 8445 8446 |
# File 'lib/models/porcelain.rb', line 8444 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8446 8447 8448 |
# File 'lib/models/porcelain.rb', line 8446 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8448 8449 8450 |
# File 'lib/models/porcelain.rb', line 8448 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8450 8451 8452 |
# File 'lib/models/porcelain.rb', line 8450 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8452 8453 8454 |
# File 'lib/models/porcelain.rb', line 8452 def @tags end |
#username ⇒ Object
The username to authenticate with.
8454 8455 8456 |
# File 'lib/models/porcelain.rb', line 8454 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8486 8487 8488 8489 8490 8491 8492 |
# File 'lib/models/porcelain.rb', line 8486 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |