Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
8271 8272 8273 8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 8285 8286 8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 |
# File 'lib/models/porcelain.rb', line 8271 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
8245 8246 8247 |
# File 'lib/models/porcelain.rb', line 8245 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8247 8248 8249 |
# File 'lib/models/porcelain.rb', line 8247 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8249 8250 8251 |
# File 'lib/models/porcelain.rb', line 8249 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
8251 8252 8253 |
# File 'lib/models/porcelain.rb', line 8251 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8253 8254 8255 |
# File 'lib/models/porcelain.rb', line 8253 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8255 8256 8257 |
# File 'lib/models/porcelain.rb', line 8255 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
8257 8258 8259 |
# File 'lib/models/porcelain.rb', line 8257 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
8259 8260 8261 |
# File 'lib/models/porcelain.rb', line 8259 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
8261 8262 8263 |
# File 'lib/models/porcelain.rb', line 8261 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8263 8264 8265 |
# File 'lib/models/porcelain.rb', line 8263 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8265 8266 8267 |
# File 'lib/models/porcelain.rb', line 8265 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8267 8268 8269 |
# File 'lib/models/porcelain.rb', line 8267 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
8269 8270 8271 |
# File 'lib/models/porcelain.rb', line 8269 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8301 8302 8303 8304 8305 8306 8307 |
# File 'lib/models/porcelain.rb', line 8301 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |