Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



8033
8034
8035
8036
8037
8038
8039
8040
8041
8042
8043
8044
8045
8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
8060
8061
# File 'lib/models/porcelain.rb', line 8033

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



8007
8008
8009
# File 'lib/models/porcelain.rb', line 8007

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8009
8010
8011
# File 'lib/models/porcelain.rb', line 8009

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8011
8012
8013
# File 'lib/models/porcelain.rb', line 8011

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



8013
8014
8015
# File 'lib/models/porcelain.rb', line 8013

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8015
8016
8017
# File 'lib/models/porcelain.rb', line 8015

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8017
8018
8019
# File 'lib/models/porcelain.rb', line 8017

def name
  @name
end

#passwordObject

Returns the value of attribute password.



8019
8020
8021
# File 'lib/models/porcelain.rb', line 8019

def password
  @password
end

#portObject

Returns the value of attribute port.



8021
8022
8023
# File 'lib/models/porcelain.rb', line 8021

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



8023
8024
8025
# File 'lib/models/porcelain.rb', line 8023

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8025
8026
8027
# File 'lib/models/porcelain.rb', line 8025

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8027
8028
8029
# File 'lib/models/porcelain.rb', line 8027

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8029
8030
8031
# File 'lib/models/porcelain.rb', line 8029

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



8031
8032
8033
# File 'lib/models/porcelain.rb', line 8031

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8063
8064
8065
8066
8067
8068
8069
# File 'lib/models/porcelain.rb', line 8063

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end