Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 8008 |
# File 'lib/models/porcelain.rb', line 7980 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7954 7955 7956 |
# File 'lib/models/porcelain.rb', line 7954 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7956 7957 7958 |
# File 'lib/models/porcelain.rb', line 7956 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7958 7959 7960 |
# File 'lib/models/porcelain.rb', line 7958 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7960 7961 7962 |
# File 'lib/models/porcelain.rb', line 7960 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7962 7963 7964 |
# File 'lib/models/porcelain.rb', line 7962 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7964 7965 7966 |
# File 'lib/models/porcelain.rb', line 7964 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
7966 7967 7968 |
# File 'lib/models/porcelain.rb', line 7966 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
7968 7969 7970 |
# File 'lib/models/porcelain.rb', line 7968 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7970 7971 7972 |
# File 'lib/models/porcelain.rb', line 7970 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7972 7973 7974 |
# File 'lib/models/porcelain.rb', line 7972 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7974 7975 7976 |
# File 'lib/models/porcelain.rb', line 7974 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7976 7977 7978 |
# File 'lib/models/porcelain.rb', line 7976 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7978 7979 7980 |
# File 'lib/models/porcelain.rb', line 7978 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8010 8011 8012 8013 8014 8015 8016 |
# File 'lib/models/porcelain.rb', line 8010 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |