Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
7526 7527 7528 7529 7530 7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 7550 7551 7552 |
# File 'lib/models/porcelain.rb', line 7526 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7502 7503 7504 |
# File 'lib/models/porcelain.rb', line 7502 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7504 7505 7506 |
# File 'lib/models/porcelain.rb', line 7504 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7506 7507 7508 |
# File 'lib/models/porcelain.rb', line 7506 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7508 7509 7510 |
# File 'lib/models/porcelain.rb', line 7508 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7510 7511 7512 |
# File 'lib/models/porcelain.rb', line 7510 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7512 7513 7514 |
# File 'lib/models/porcelain.rb', line 7512 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
7514 7515 7516 |
# File 'lib/models/porcelain.rb', line 7514 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
7516 7517 7518 |
# File 'lib/models/porcelain.rb', line 7516 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7518 7519 7520 |
# File 'lib/models/porcelain.rb', line 7518 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7520 7521 7522 |
# File 'lib/models/porcelain.rb', line 7520 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7522 7523 7524 |
# File 'lib/models/porcelain.rb', line 7522 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7524 7525 7526 |
# File 'lib/models/porcelain.rb', line 7524 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7554 7555 7556 7557 7558 7559 7560 |
# File 'lib/models/porcelain.rb', line 7554 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |