Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
6614 6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 |
# File 'lib/models/porcelain.rb', line 6614 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6590 6591 6592 |
# File 'lib/models/porcelain.rb', line 6590 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6592 6593 6594 |
# File 'lib/models/porcelain.rb', line 6592 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6594 6595 6596 |
# File 'lib/models/porcelain.rb', line 6594 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6596 6597 6598 |
# File 'lib/models/porcelain.rb', line 6596 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6598 6599 6600 |
# File 'lib/models/porcelain.rb', line 6598 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6600 6601 6602 |
# File 'lib/models/porcelain.rb', line 6600 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6602 6603 6604 |
# File 'lib/models/porcelain.rb', line 6602 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6604 6605 6606 |
# File 'lib/models/porcelain.rb', line 6604 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6606 6607 6608 |
# File 'lib/models/porcelain.rb', line 6606 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6608 6609 6610 |
# File 'lib/models/porcelain.rb', line 6608 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6610 6611 6612 |
# File 'lib/models/porcelain.rb', line 6610 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6612 6613 6614 |
# File 'lib/models/porcelain.rb', line 6612 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6642 6643 6644 6645 6646 6647 6648 |
# File 'lib/models/porcelain.rb', line 6642 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |