Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/models/porcelain.rb', line 6538 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6514 6515 6516 |
# File 'lib/models/porcelain.rb', line 6514 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6516 6517 6518 |
# File 'lib/models/porcelain.rb', line 6516 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6518 6519 6520 |
# File 'lib/models/porcelain.rb', line 6518 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6520 6521 6522 |
# File 'lib/models/porcelain.rb', line 6520 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6522 6523 6524 |
# File 'lib/models/porcelain.rb', line 6522 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6524 6525 6526 |
# File 'lib/models/porcelain.rb', line 6524 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6526 6527 6528 |
# File 'lib/models/porcelain.rb', line 6526 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6528 6529 6530 |
# File 'lib/models/porcelain.rb', line 6528 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6530 6531 6532 |
# File 'lib/models/porcelain.rb', line 6530 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6532 6533 6534 |
# File 'lib/models/porcelain.rb', line 6532 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6534 6535 6536 |
# File 'lib/models/porcelain.rb', line 6534 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6536 6537 6538 |
# File 'lib/models/porcelain.rb', line 6536 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6566 6567 6568 6569 6570 6571 6572 |
# File 'lib/models/porcelain.rb', line 6566 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |