Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 6529 6530 6531 6532 6533 |
# File 'lib/models/porcelain.rb', line 6507 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6483 6484 6485 |
# File 'lib/models/porcelain.rb', line 6483 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6485 6486 6487 |
# File 'lib/models/porcelain.rb', line 6485 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6487 6488 6489 |
# File 'lib/models/porcelain.rb', line 6487 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6489 6490 6491 |
# File 'lib/models/porcelain.rb', line 6489 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6491 6492 6493 |
# File 'lib/models/porcelain.rb', line 6491 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6493 6494 6495 |
# File 'lib/models/porcelain.rb', line 6493 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6495 6496 6497 |
# File 'lib/models/porcelain.rb', line 6495 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6497 6498 6499 |
# File 'lib/models/porcelain.rb', line 6497 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6499 6500 6501 |
# File 'lib/models/porcelain.rb', line 6499 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6501 6502 6503 |
# File 'lib/models/porcelain.rb', line 6501 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6503 6504 6505 |
# File 'lib/models/porcelain.rb', line 6503 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6505 6506 6507 |
# File 'lib/models/porcelain.rb', line 6505 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6535 6536 6537 6538 6539 6540 6541 |
# File 'lib/models/porcelain.rb', line 6535 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |