Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
6495 6496 6497 6498 6499 6500 6501 6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 6518 6519 6520 6521 |
# File 'lib/models/porcelain.rb', line 6495 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6471 6472 6473 |
# File 'lib/models/porcelain.rb', line 6471 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6473 6474 6475 |
# File 'lib/models/porcelain.rb', line 6473 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6475 6476 6477 |
# File 'lib/models/porcelain.rb', line 6475 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6477 6478 6479 |
# File 'lib/models/porcelain.rb', line 6477 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6479 6480 6481 |
# File 'lib/models/porcelain.rb', line 6479 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6481 6482 6483 |
# File 'lib/models/porcelain.rb', line 6481 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6483 6484 6485 |
# File 'lib/models/porcelain.rb', line 6483 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6485 6486 6487 |
# File 'lib/models/porcelain.rb', line 6485 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6487 6488 6489 |
# File 'lib/models/porcelain.rb', line 6487 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6489 6490 6491 |
# File 'lib/models/porcelain.rb', line 6489 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6491 6492 6493 |
# File 'lib/models/porcelain.rb', line 6491 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6493 6494 6495 |
# File 'lib/models/porcelain.rb', line 6493 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6523 6524 6525 6526 6527 6528 6529 |
# File 'lib/models/porcelain.rb', line 6523 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |