Class: SDM::Sybase
- Inherits:
-
Object
- Object
- SDM::Sybase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Sybase
constructor
A new instance of Sybase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Sybase
Returns a new instance of Sybase.
7324 7325 7326 7327 7328 7329 7330 7331 7332 7333 7334 7335 7336 7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 7352 7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 |
# File 'lib/models/porcelain.rb', line 7324 def initialize( egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7302 7303 7304 |
# File 'lib/models/porcelain.rb', line 7302 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7304 7305 7306 |
# File 'lib/models/porcelain.rb', line 7304 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7306 7307 7308 |
# File 'lib/models/porcelain.rb', line 7306 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7308 7309 7310 |
# File 'lib/models/porcelain.rb', line 7308 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7310 7311 7312 |
# File 'lib/models/porcelain.rb', line 7310 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
7312 7313 7314 |
# File 'lib/models/porcelain.rb', line 7312 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
7314 7315 7316 |
# File 'lib/models/porcelain.rb', line 7314 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7316 7317 7318 |
# File 'lib/models/porcelain.rb', line 7316 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7318 7319 7320 |
# File 'lib/models/porcelain.rb', line 7318 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7320 7321 7322 |
# File 'lib/models/porcelain.rb', line 7320 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7322 7323 7324 |
# File 'lib/models/porcelain.rb', line 7322 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7372 7373 7374 7375 7376 7377 7378 |
# File 'lib/models/porcelain.rb', line 7372 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |