Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



18107
18108
18109
18110
18111
18112
18113
18114
18115
18116
18117
18118
18119
18120
18121
18122
18123
18124
18125
18126
18127
18128
18129
18130
18131
18132
18133
18134
18135
18136
18137
# File 'lib/models/porcelain.rb', line 18107

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



18079
18080
18081
# File 'lib/models/porcelain.rb', line 18079

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



18081
18082
18083
# File 'lib/models/porcelain.rb', line 18081

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



18083
18084
18085
# File 'lib/models/porcelain.rb', line 18083

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



18085
18086
18087
# File 'lib/models/porcelain.rb', line 18085

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



18087
18088
18089
# File 'lib/models/porcelain.rb', line 18087

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



18089
18090
18091
# File 'lib/models/porcelain.rb', line 18089

def name
  @name
end

#passwordObject

The password to authenticate with.



18091
18092
18093
# File 'lib/models/porcelain.rb', line 18091

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



18093
18094
18095
# File 'lib/models/porcelain.rb', line 18093

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



18095
18096
18097
# File 'lib/models/porcelain.rb', line 18095

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



18097
18098
18099
# File 'lib/models/porcelain.rb', line 18097

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



18099
18100
18101
# File 'lib/models/porcelain.rb', line 18099

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



18101
18102
18103
# File 'lib/models/porcelain.rb', line 18101

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



18103
18104
18105
# File 'lib/models/porcelain.rb', line 18103

def tags
  @tags
end

#usernameObject

The username to authenticate with.



18105
18106
18107
# File 'lib/models/porcelain.rb', line 18105

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18139
18140
18141
18142
18143
18144
18145
# File 'lib/models/porcelain.rb', line 18139

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end