Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



17748
17749
17750
17751
17752
17753
17754
17755
17756
17757
17758
17759
17760
17761
17762
17763
17764
17765
17766
17767
17768
17769
17770
17771
17772
17773
17774
17775
17776
17777
17778
# File 'lib/models/porcelain.rb', line 17748

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17720
17721
17722
# File 'lib/models/porcelain.rb', line 17720

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17722
17723
17724
# File 'lib/models/porcelain.rb', line 17722

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17724
17725
17726
# File 'lib/models/porcelain.rb', line 17724

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17726
17727
17728
# File 'lib/models/porcelain.rb', line 17726

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17728
17729
17730
# File 'lib/models/porcelain.rb', line 17728

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17730
17731
17732
# File 'lib/models/porcelain.rb', line 17730

def name
  @name
end

#passwordObject

The password to authenticate with.



17732
17733
17734
# File 'lib/models/porcelain.rb', line 17732

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17734
17735
17736
# File 'lib/models/porcelain.rb', line 17734

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17736
17737
17738
# File 'lib/models/porcelain.rb', line 17736

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17738
17739
17740
# File 'lib/models/porcelain.rb', line 17738

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17740
17741
17742
# File 'lib/models/porcelain.rb', line 17740

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17742
17743
17744
# File 'lib/models/porcelain.rb', line 17742

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17744
17745
17746
# File 'lib/models/porcelain.rb', line 17744

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17746
17747
17748
# File 'lib/models/porcelain.rb', line 17746

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17780
17781
17782
17783
17784
17785
17786
# File 'lib/models/porcelain.rb', line 17780

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end