Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



17625
17626
17627
17628
17629
17630
17631
17632
17633
17634
17635
17636
17637
17638
17639
17640
17641
17642
17643
17644
17645
17646
17647
17648
17649
17650
17651
17652
17653
17654
17655
# File 'lib/models/porcelain.rb', line 17625

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17597
17598
17599
# File 'lib/models/porcelain.rb', line 17597

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17599
17600
17601
# File 'lib/models/porcelain.rb', line 17599

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17601
17602
17603
# File 'lib/models/porcelain.rb', line 17601

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17603
17604
17605
# File 'lib/models/porcelain.rb', line 17603

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17605
17606
17607
# File 'lib/models/porcelain.rb', line 17605

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17607
17608
17609
# File 'lib/models/porcelain.rb', line 17607

def name
  @name
end

#passwordObject

The password to authenticate with.



17609
17610
17611
# File 'lib/models/porcelain.rb', line 17609

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17611
17612
17613
# File 'lib/models/porcelain.rb', line 17611

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17613
17614
17615
# File 'lib/models/porcelain.rb', line 17613

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17615
17616
17617
# File 'lib/models/porcelain.rb', line 17615

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17617
17618
17619
# File 'lib/models/porcelain.rb', line 17617

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17619
17620
17621
# File 'lib/models/porcelain.rb', line 17619

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17621
17622
17623
# File 'lib/models/porcelain.rb', line 17621

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17623
17624
17625
# File 'lib/models/porcelain.rb', line 17623

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17657
17658
17659
17660
17661
17662
17663
# File 'lib/models/porcelain.rb', line 17657

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end