Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



16942
16943
16944
16945
16946
16947
16948
16949
16950
16951
16952
16953
16954
16955
16956
16957
16958
16959
16960
16961
16962
16963
16964
16965
16966
16967
16968
16969
16970
16971
16972
# File 'lib/models/porcelain.rb', line 16942

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16914
16915
16916
# File 'lib/models/porcelain.rb', line 16914

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16916
16917
16918
# File 'lib/models/porcelain.rb', line 16916

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16918
16919
16920
# File 'lib/models/porcelain.rb', line 16918

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16920
16921
16922
# File 'lib/models/porcelain.rb', line 16920

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16922
16923
16924
# File 'lib/models/porcelain.rb', line 16922

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



16924
16925
16926
# File 'lib/models/porcelain.rb', line 16924

def name
  @name
end

#passwordObject

The password to authenticate with.



16926
16927
16928
# File 'lib/models/porcelain.rb', line 16926

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16928
16929
16930
# File 'lib/models/porcelain.rb', line 16928

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16930
16931
16932
# File 'lib/models/porcelain.rb', line 16930

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16932
16933
16934
# File 'lib/models/porcelain.rb', line 16932

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16934
16935
16936
# File 'lib/models/porcelain.rb', line 16934

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16936
16937
16938
# File 'lib/models/porcelain.rb', line 16936

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16938
16939
16940
# File 'lib/models/porcelain.rb', line 16938

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16940
16941
16942
# File 'lib/models/porcelain.rb', line 16940

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16974
16975
16976
16977
16978
16979
16980
# File 'lib/models/porcelain.rb', line 16974

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end