Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



16878
16879
16880
16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
16900
16901
16902
16903
16904
16905
16906
16907
16908
# File 'lib/models/porcelain.rb', line 16878

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16850
16851
16852
# File 'lib/models/porcelain.rb', line 16850

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16852
16853
16854
# File 'lib/models/porcelain.rb', line 16852

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16854
16855
16856
# File 'lib/models/porcelain.rb', line 16854

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16856
16857
16858
# File 'lib/models/porcelain.rb', line 16856

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16858
16859
16860
# File 'lib/models/porcelain.rb', line 16858

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



16860
16861
16862
# File 'lib/models/porcelain.rb', line 16860

def name
  @name
end

#passwordObject

The password to authenticate with.



16862
16863
16864
# File 'lib/models/porcelain.rb', line 16862

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16864
16865
16866
# File 'lib/models/porcelain.rb', line 16864

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16866
16867
16868
# File 'lib/models/porcelain.rb', line 16866

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16868
16869
16870
# File 'lib/models/porcelain.rb', line 16868

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16870
16871
16872
# File 'lib/models/porcelain.rb', line 16870

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16872
16873
16874
# File 'lib/models/porcelain.rb', line 16872

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16874
16875
16876
# File 'lib/models/porcelain.rb', line 16874

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16876
16877
16878
# File 'lib/models/porcelain.rb', line 16876

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16910
16911
16912
16913
16914
16915
16916
# File 'lib/models/porcelain.rb', line 16910

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end