Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



15954
15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
15982
15983
15984
# File 'lib/models/porcelain.rb', line 15954

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15926
15927
15928
# File 'lib/models/porcelain.rb', line 15926

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15928
15929
15930
# File 'lib/models/porcelain.rb', line 15928

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15930
15931
15932
# File 'lib/models/porcelain.rb', line 15930

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15932
15933
15934
# File 'lib/models/porcelain.rb', line 15932

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15934
15935
15936
# File 'lib/models/porcelain.rb', line 15934

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15936
15937
15938
# File 'lib/models/porcelain.rb', line 15936

def name
  @name
end

#passwordObject

The password to authenticate with.



15938
15939
15940
# File 'lib/models/porcelain.rb', line 15938

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15940
15941
15942
# File 'lib/models/porcelain.rb', line 15940

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15942
15943
15944
# File 'lib/models/porcelain.rb', line 15942

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15944
15945
15946
# File 'lib/models/porcelain.rb', line 15944

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15946
15947
15948
# File 'lib/models/porcelain.rb', line 15946

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15948
15949
15950
# File 'lib/models/porcelain.rb', line 15948

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15950
15951
15952
# File 'lib/models/porcelain.rb', line 15950

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15952
15953
15954
# File 'lib/models/porcelain.rb', line 15952

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15986
15987
15988
15989
15990
15991
15992
# File 'lib/models/porcelain.rb', line 15986

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end