Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
14720 14721 14722 14723 14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 |
# File 'lib/models/porcelain.rb', line 14720 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
14692 14693 14694 |
# File 'lib/models/porcelain.rb', line 14692 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
14694 14695 14696 |
# File 'lib/models/porcelain.rb', line 14694 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
14696 14697 14698 |
# File 'lib/models/porcelain.rb', line 14696 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
14698 14699 14700 |
# File 'lib/models/porcelain.rb', line 14698 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
14700 14701 14702 |
# File 'lib/models/porcelain.rb', line 14700 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
14702 14703 14704 |
# File 'lib/models/porcelain.rb', line 14702 def name @name end |
#password ⇒ Object
The password to authenticate with.
14704 14705 14706 |
# File 'lib/models/porcelain.rb', line 14704 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
14706 14707 14708 |
# File 'lib/models/porcelain.rb', line 14706 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
14708 14709 14710 |
# File 'lib/models/porcelain.rb', line 14708 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
14710 14711 14712 |
# File 'lib/models/porcelain.rb', line 14710 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
14712 14713 14714 |
# File 'lib/models/porcelain.rb', line 14712 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
14714 14715 14716 |
# File 'lib/models/porcelain.rb', line 14714 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14716 14717 14718 |
# File 'lib/models/porcelain.rb', line 14716 def @tags end |
#username ⇒ Object
The username to authenticate with.
14718 14719 14720 |
# File 'lib/models/porcelain.rb', line 14718 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14752 14753 14754 14755 14756 14757 14758 |
# File 'lib/models/porcelain.rb', line 14752 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |