Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



14642
14643
14644
14645
14646
14647
14648
14649
14650
14651
14652
14653
14654
14655
14656
14657
14658
14659
14660
14661
14662
14663
14664
14665
14666
14667
14668
14669
14670
14671
14672
# File 'lib/models/porcelain.rb', line 14642

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14614
14615
14616
# File 'lib/models/porcelain.rb', line 14614

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14616
14617
14618
# File 'lib/models/porcelain.rb', line 14616

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14618
14619
14620
# File 'lib/models/porcelain.rb', line 14618

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14620
14621
14622
# File 'lib/models/porcelain.rb', line 14620

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14622
14623
14624
# File 'lib/models/porcelain.rb', line 14622

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14624
14625
14626
# File 'lib/models/porcelain.rb', line 14624

def name
  @name
end

#passwordObject

The password to authenticate with.



14626
14627
14628
# File 'lib/models/porcelain.rb', line 14626

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14628
14629
14630
# File 'lib/models/porcelain.rb', line 14628

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14630
14631
14632
# File 'lib/models/porcelain.rb', line 14630

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14632
14633
14634
# File 'lib/models/porcelain.rb', line 14632

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14634
14635
14636
# File 'lib/models/porcelain.rb', line 14634

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14636
14637
14638
# File 'lib/models/porcelain.rb', line 14636

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14638
14639
14640
# File 'lib/models/porcelain.rb', line 14638

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14640
14641
14642
# File 'lib/models/porcelain.rb', line 14640

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14674
14675
14676
14677
14678
14679
14680
# File 'lib/models/porcelain.rb', line 14674

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end