Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



14455
14456
14457
14458
14459
14460
14461
14462
14463
14464
14465
14466
14467
14468
14469
14470
14471
14472
14473
14474
14475
14476
14477
14478
14479
14480
14481
14482
14483
14484
14485
# File 'lib/models/porcelain.rb', line 14455

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14427
14428
14429
# File 'lib/models/porcelain.rb', line 14427

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14429
14430
14431
# File 'lib/models/porcelain.rb', line 14429

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14431
14432
14433
# File 'lib/models/porcelain.rb', line 14431

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14433
14434
14435
# File 'lib/models/porcelain.rb', line 14433

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14435
14436
14437
# File 'lib/models/porcelain.rb', line 14435

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14437
14438
14439
# File 'lib/models/porcelain.rb', line 14437

def name
  @name
end

#passwordObject

The password to authenticate with.



14439
14440
14441
# File 'lib/models/porcelain.rb', line 14439

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14441
14442
14443
# File 'lib/models/porcelain.rb', line 14441

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14443
14444
14445
# File 'lib/models/porcelain.rb', line 14443

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14445
14446
14447
# File 'lib/models/porcelain.rb', line 14445

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14447
14448
14449
# File 'lib/models/porcelain.rb', line 14447

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14449
14450
14451
# File 'lib/models/porcelain.rb', line 14449

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14451
14452
14453
# File 'lib/models/porcelain.rb', line 14451

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14453
14454
14455
# File 'lib/models/porcelain.rb', line 14453

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14487
14488
14489
14490
14491
14492
14493
# File 'lib/models/porcelain.rb', line 14487

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end