Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
14444 14445 14446 14447 14448 14449 14450 14451 14452 14453 14454 14455 14456 14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 |
# File 'lib/models/porcelain.rb', line 14444 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
14416 14417 14418 |
# File 'lib/models/porcelain.rb', line 14416 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
14418 14419 14420 |
# File 'lib/models/porcelain.rb', line 14418 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
14420 14421 14422 |
# File 'lib/models/porcelain.rb', line 14420 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
14422 14423 14424 |
# File 'lib/models/porcelain.rb', line 14422 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
14424 14425 14426 |
# File 'lib/models/porcelain.rb', line 14424 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
14426 14427 14428 |
# File 'lib/models/porcelain.rb', line 14426 def name @name end |
#password ⇒ Object
The password to authenticate with.
14428 14429 14430 |
# File 'lib/models/porcelain.rb', line 14428 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
14430 14431 14432 |
# File 'lib/models/porcelain.rb', line 14430 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
14432 14433 14434 |
# File 'lib/models/porcelain.rb', line 14432 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
14434 14435 14436 |
# File 'lib/models/porcelain.rb', line 14434 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
14436 14437 14438 |
# File 'lib/models/porcelain.rb', line 14436 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
14438 14439 14440 |
# File 'lib/models/porcelain.rb', line 14438 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14440 14441 14442 |
# File 'lib/models/porcelain.rb', line 14440 def @tags end |
#username ⇒ Object
The username to authenticate with.
14442 14443 14444 |
# File 'lib/models/porcelain.rb', line 14442 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14476 14477 14478 14479 14480 14481 14482 |
# File 'lib/models/porcelain.rb', line 14476 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |