Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
14403
14404
14405
14406
# File 'lib/models/porcelain.rb', line 14376

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14348
14349
14350
# File 'lib/models/porcelain.rb', line 14348

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14350
14351
14352
# File 'lib/models/porcelain.rb', line 14350

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14352
14353
14354
# File 'lib/models/porcelain.rb', line 14352

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14354
14355
14356
# File 'lib/models/porcelain.rb', line 14354

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14356
14357
14358
# File 'lib/models/porcelain.rb', line 14356

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14358
14359
14360
# File 'lib/models/porcelain.rb', line 14358

def name
  @name
end

#passwordObject

The password to authenticate with.



14360
14361
14362
# File 'lib/models/porcelain.rb', line 14360

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14362
14363
14364
# File 'lib/models/porcelain.rb', line 14362

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14364
14365
14366
# File 'lib/models/porcelain.rb', line 14364

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14366
14367
14368
# File 'lib/models/porcelain.rb', line 14366

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14368
14369
14370
# File 'lib/models/porcelain.rb', line 14368

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14370
14371
14372
# File 'lib/models/porcelain.rb', line 14370

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14372
14373
14374
# File 'lib/models/porcelain.rb', line 14372

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14374
14375
14376
# File 'lib/models/porcelain.rb', line 14374

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14408
14409
14410
14411
14412
14413
14414
# File 'lib/models/porcelain.rb', line 14408

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end