Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
14303 14304 14305 14306 14307 14308 14309 14310 14311 14312 14313 14314 14315 14316 14317 14318 14319 14320 14321 14322 14323 14324 14325 14326 14327 14328 14329 14330 14331 14332 14333 |
# File 'lib/models/porcelain.rb', line 14303 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
14275 14276 14277 |
# File 'lib/models/porcelain.rb', line 14275 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
14277 14278 14279 |
# File 'lib/models/porcelain.rb', line 14277 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
14279 14280 14281 |
# File 'lib/models/porcelain.rb', line 14279 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
14281 14282 14283 |
# File 'lib/models/porcelain.rb', line 14281 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
14283 14284 14285 |
# File 'lib/models/porcelain.rb', line 14283 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
14285 14286 14287 |
# File 'lib/models/porcelain.rb', line 14285 def name @name end |
#password ⇒ Object
The password to authenticate with.
14287 14288 14289 |
# File 'lib/models/porcelain.rb', line 14287 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
14289 14290 14291 |
# File 'lib/models/porcelain.rb', line 14289 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
14291 14292 14293 |
# File 'lib/models/porcelain.rb', line 14291 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
14293 14294 14295 |
# File 'lib/models/porcelain.rb', line 14293 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
14295 14296 14297 |
# File 'lib/models/porcelain.rb', line 14295 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
14297 14298 14299 |
# File 'lib/models/porcelain.rb', line 14297 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14299 14300 14301 |
# File 'lib/models/porcelain.rb', line 14299 def @tags end |
#username ⇒ Object
The username to authenticate with.
14301 14302 14303 |
# File 'lib/models/porcelain.rb', line 14301 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14335 14336 14337 14338 14339 14340 14341 |
# File 'lib/models/porcelain.rb', line 14335 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |