Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
13059 13060 13061 13062 13063 13064 13065 13066 13067 13068 13069 13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 13088 13089 |
# File 'lib/models/porcelain.rb', line 13059 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
13031 13032 13033 |
# File 'lib/models/porcelain.rb', line 13031 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
13033 13034 13035 |
# File 'lib/models/porcelain.rb', line 13033 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
13035 13036 13037 |
# File 'lib/models/porcelain.rb', line 13035 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
13037 13038 13039 |
# File 'lib/models/porcelain.rb', line 13037 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
13039 13040 13041 |
# File 'lib/models/porcelain.rb', line 13039 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
13041 13042 13043 |
# File 'lib/models/porcelain.rb', line 13041 def name @name end |
#password ⇒ Object
The password to authenticate with.
13043 13044 13045 |
# File 'lib/models/porcelain.rb', line 13043 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
13045 13046 13047 |
# File 'lib/models/porcelain.rb', line 13045 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
13047 13048 13049 |
# File 'lib/models/porcelain.rb', line 13047 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
13049 13050 13051 |
# File 'lib/models/porcelain.rb', line 13049 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
13051 13052 13053 |
# File 'lib/models/porcelain.rb', line 13051 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
13053 13054 13055 |
# File 'lib/models/porcelain.rb', line 13053 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13055 13056 13057 |
# File 'lib/models/porcelain.rb', line 13055 def @tags end |
#username ⇒ Object
The username to authenticate with.
13057 13058 13059 |
# File 'lib/models/porcelain.rb', line 13057 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13091 13092 13093 13094 13095 13096 13097 |
# File 'lib/models/porcelain.rb', line 13091 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |