Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



12732
12733
12734
12735
12736
12737
12738
12739
12740
12741
12742
12743
12744
12745
12746
12747
12748
12749
12750
12751
12752
12753
12754
12755
12756
12757
12758
12759
12760
12761
12762
# File 'lib/models/porcelain.rb', line 12732

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12704
12705
12706
# File 'lib/models/porcelain.rb', line 12704

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12706
12707
12708
# File 'lib/models/porcelain.rb', line 12706

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12708
12709
12710
# File 'lib/models/porcelain.rb', line 12708

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12710
12711
12712
# File 'lib/models/porcelain.rb', line 12710

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12712
12713
12714
# File 'lib/models/porcelain.rb', line 12712

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12714
12715
12716
# File 'lib/models/porcelain.rb', line 12714

def name
  @name
end

#passwordObject

The password to authenticate with.



12716
12717
12718
# File 'lib/models/porcelain.rb', line 12716

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12718
12719
12720
# File 'lib/models/porcelain.rb', line 12718

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12720
12721
12722
# File 'lib/models/porcelain.rb', line 12720

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12722
12723
12724
# File 'lib/models/porcelain.rb', line 12722

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12724
12725
12726
# File 'lib/models/porcelain.rb', line 12724

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12726
12727
12728
# File 'lib/models/porcelain.rb', line 12726

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12728
12729
12730
# File 'lib/models/porcelain.rb', line 12728

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12730
12731
12732
# File 'lib/models/porcelain.rb', line 12730

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12764
12765
12766
12767
12768
12769
12770
# File 'lib/models/porcelain.rb', line 12764

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end