Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



12578
12579
12580
12581
12582
12583
12584
12585
12586
12587
12588
12589
12590
12591
12592
12593
12594
12595
12596
12597
12598
12599
12600
12601
12602
12603
12604
12605
12606
12607
12608
# File 'lib/models/porcelain.rb', line 12578

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12550
12551
12552
# File 'lib/models/porcelain.rb', line 12550

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12552
12553
12554
# File 'lib/models/porcelain.rb', line 12552

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12554
12555
12556
# File 'lib/models/porcelain.rb', line 12554

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12556
12557
12558
# File 'lib/models/porcelain.rb', line 12556

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12558
12559
12560
# File 'lib/models/porcelain.rb', line 12558

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12560
12561
12562
# File 'lib/models/porcelain.rb', line 12560

def name
  @name
end

#passwordObject

The password to authenticate with.



12562
12563
12564
# File 'lib/models/porcelain.rb', line 12562

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12564
12565
12566
# File 'lib/models/porcelain.rb', line 12564

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12566
12567
12568
# File 'lib/models/porcelain.rb', line 12566

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12568
12569
12570
# File 'lib/models/porcelain.rb', line 12568

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12570
12571
12572
# File 'lib/models/porcelain.rb', line 12570

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12572
12573
12574
# File 'lib/models/porcelain.rb', line 12572

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12574
12575
12576
# File 'lib/models/porcelain.rb', line 12574

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12576
12577
12578
# File 'lib/models/porcelain.rb', line 12576

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12610
12611
12612
12613
12614
12615
12616
# File 'lib/models/porcelain.rb', line 12610

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end