Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
12578 12579 12580 12581 12582 12583 12584 12585 12586 12587 12588 12589 12590 12591 12592 12593 12594 12595 12596 12597 12598 12599 12600 12601 12602 12603 12604 12605 12606 12607 12608 |
# File 'lib/models/porcelain.rb', line 12578 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12550 12551 12552 |
# File 'lib/models/porcelain.rb', line 12550 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12552 12553 12554 |
# File 'lib/models/porcelain.rb', line 12552 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12554 12555 12556 |
# File 'lib/models/porcelain.rb', line 12554 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12556 12557 12558 |
# File 'lib/models/porcelain.rb', line 12556 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12558 12559 12560 |
# File 'lib/models/porcelain.rb', line 12558 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12560 12561 12562 |
# File 'lib/models/porcelain.rb', line 12560 def name @name end |
#password ⇒ Object
The password to authenticate with.
12562 12563 12564 |
# File 'lib/models/porcelain.rb', line 12562 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12564 12565 12566 |
# File 'lib/models/porcelain.rb', line 12564 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
12566 12567 12568 |
# File 'lib/models/porcelain.rb', line 12566 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12568 12569 12570 |
# File 'lib/models/porcelain.rb', line 12568 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12570 12571 12572 |
# File 'lib/models/porcelain.rb', line 12570 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
12572 12573 12574 |
# File 'lib/models/porcelain.rb', line 12572 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12574 12575 12576 |
# File 'lib/models/porcelain.rb', line 12574 def @tags end |
#username ⇒ Object
The username to authenticate with.
12576 12577 12578 |
# File 'lib/models/porcelain.rb', line 12576 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12610 12611 12612 12613 12614 12615 12616 |
# File 'lib/models/porcelain.rb', line 12610 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |