Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
12512 12513 12514 12515 12516 12517 12518 12519 12520 12521 12522 12523 12524 12525 12526 12527 12528 12529 12530 12531 12532 12533 12534 12535 12536 12537 12538 12539 12540 12541 12542 |
# File 'lib/models/porcelain.rb', line 12512 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12484 12485 12486 |
# File 'lib/models/porcelain.rb', line 12484 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12486 12487 12488 |
# File 'lib/models/porcelain.rb', line 12486 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12488 12489 12490 |
# File 'lib/models/porcelain.rb', line 12488 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12490 12491 12492 |
# File 'lib/models/porcelain.rb', line 12490 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12492 12493 12494 |
# File 'lib/models/porcelain.rb', line 12492 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12494 12495 12496 |
# File 'lib/models/porcelain.rb', line 12494 def name @name end |
#password ⇒ Object
The password to authenticate with.
12496 12497 12498 |
# File 'lib/models/porcelain.rb', line 12496 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12498 12499 12500 |
# File 'lib/models/porcelain.rb', line 12498 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
12500 12501 12502 |
# File 'lib/models/porcelain.rb', line 12500 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12502 12503 12504 |
# File 'lib/models/porcelain.rb', line 12502 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12504 12505 12506 |
# File 'lib/models/porcelain.rb', line 12504 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
12506 12507 12508 |
# File 'lib/models/porcelain.rb', line 12506 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12508 12509 12510 |
# File 'lib/models/porcelain.rb', line 12508 def @tags end |
#username ⇒ Object
The username to authenticate with.
12510 12511 12512 |
# File 'lib/models/porcelain.rb', line 12510 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12544 12545 12546 12547 12548 12549 12550 |
# File 'lib/models/porcelain.rb', line 12544 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |