Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
11494
11495
11496
11497
11498
11499
11500
11501
11502
11503
# File 'lib/models/porcelain.rb', line 11475

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11449
11450
11451
# File 'lib/models/porcelain.rb', line 11449

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11451
11452
11453
# File 'lib/models/porcelain.rb', line 11451

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11453
11454
11455
# File 'lib/models/porcelain.rb', line 11453

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11455
11456
11457
# File 'lib/models/porcelain.rb', line 11455

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11457
11458
11459
# File 'lib/models/porcelain.rb', line 11457

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11459
11460
11461
# File 'lib/models/porcelain.rb', line 11459

def name
  @name
end

#passwordObject

The password to authenticate with.



11461
11462
11463
# File 'lib/models/porcelain.rb', line 11461

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11463
11464
11465
# File 'lib/models/porcelain.rb', line 11463

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11465
11466
11467
# File 'lib/models/porcelain.rb', line 11465

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11467
11468
11469
# File 'lib/models/porcelain.rb', line 11467

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11469
11470
11471
# File 'lib/models/porcelain.rb', line 11469

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11471
11472
11473
# File 'lib/models/porcelain.rb', line 11471

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11473
11474
11475
# File 'lib/models/porcelain.rb', line 11473

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11505
11506
11507
11508
11509
11510
11511
# File 'lib/models/porcelain.rb', line 11505

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end