Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
10685 10686 10687 10688 10689 10690 10691 10692 10693 10694 10695 10696 10697 10698 10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 |
# File 'lib/models/porcelain.rb', line 10685 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
10659 10660 10661 |
# File 'lib/models/porcelain.rb', line 10659 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10661 10662 10663 |
# File 'lib/models/porcelain.rb', line 10661 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10663 10664 10665 |
# File 'lib/models/porcelain.rb', line 10663 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10665 10666 10667 |
# File 'lib/models/porcelain.rb', line 10665 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10667 10668 10669 |
# File 'lib/models/porcelain.rb', line 10667 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10669 10670 10671 |
# File 'lib/models/porcelain.rb', line 10669 def name @name end |
#password ⇒ Object
The password to authenticate with.
10671 10672 10673 |
# File 'lib/models/porcelain.rb', line 10671 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10673 10674 10675 |
# File 'lib/models/porcelain.rb', line 10673 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
10675 10676 10677 |
# File 'lib/models/porcelain.rb', line 10675 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10677 10678 10679 |
# File 'lib/models/porcelain.rb', line 10677 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
10679 10680 10681 |
# File 'lib/models/porcelain.rb', line 10679 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10681 10682 10683 |
# File 'lib/models/porcelain.rb', line 10681 def @tags end |
#username ⇒ Object
The username to authenticate with.
10683 10684 10685 |
# File 'lib/models/porcelain.rb', line 10683 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10715 10716 10717 10718 10719 10720 10721 |
# File 'lib/models/porcelain.rb', line 10715 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |