Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



9639
9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
9657
9658
9659
9660
9661
9662
9663
9664
9665
9666
9667
# File 'lib/models/porcelain.rb', line 9639

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9613
9614
9615
# File 'lib/models/porcelain.rb', line 9613

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9615
9616
9617
# File 'lib/models/porcelain.rb', line 9615

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9617
9618
9619
# File 'lib/models/porcelain.rb', line 9617

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9619
9620
9621
# File 'lib/models/porcelain.rb', line 9619

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9621
9622
9623
# File 'lib/models/porcelain.rb', line 9621

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9623
9624
9625
# File 'lib/models/porcelain.rb', line 9623

def name
  @name
end

#passwordObject

The password to authenticate with.



9625
9626
9627
# File 'lib/models/porcelain.rb', line 9625

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9627
9628
9629
# File 'lib/models/porcelain.rb', line 9627

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9629
9630
9631
# File 'lib/models/porcelain.rb', line 9629

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9631
9632
9633
# File 'lib/models/porcelain.rb', line 9631

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9633
9634
9635
# File 'lib/models/porcelain.rb', line 9633

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9635
9636
9637
# File 'lib/models/porcelain.rb', line 9635

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9637
9638
9639
# File 'lib/models/porcelain.rb', line 9637

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9669
9670
9671
9672
9673
9674
9675
# File 'lib/models/porcelain.rb', line 9669

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end