Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
9639 9640 9641 9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 9667 |
# File 'lib/models/porcelain.rb', line 9639 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9613 9614 9615 |
# File 'lib/models/porcelain.rb', line 9613 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9615 9616 9617 |
# File 'lib/models/porcelain.rb', line 9615 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9617 9618 9619 |
# File 'lib/models/porcelain.rb', line 9617 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9619 9620 9621 |
# File 'lib/models/porcelain.rb', line 9619 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9621 9622 9623 |
# File 'lib/models/porcelain.rb', line 9621 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9623 9624 9625 |
# File 'lib/models/porcelain.rb', line 9623 def name @name end |
#password ⇒ Object
The password to authenticate with.
9625 9626 9627 |
# File 'lib/models/porcelain.rb', line 9625 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9627 9628 9629 |
# File 'lib/models/porcelain.rb', line 9627 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9629 9630 9631 |
# File 'lib/models/porcelain.rb', line 9629 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9631 9632 9633 |
# File 'lib/models/porcelain.rb', line 9631 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9633 9634 9635 |
# File 'lib/models/porcelain.rb', line 9633 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9635 9636 9637 |
# File 'lib/models/porcelain.rb', line 9635 def @tags end |
#username ⇒ Object
The username to authenticate with.
9637 9638 9639 |
# File 'lib/models/porcelain.rb', line 9637 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9669 9670 9671 9672 9673 9674 9675 |
# File 'lib/models/porcelain.rb', line 9669 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |