Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



9171
9172
9173
9174
9175
9176
9177
9178
9179
9180
9181
9182
9183
9184
9185
9186
9187
9188
9189
9190
9191
9192
9193
9194
9195
9196
9197
9198
9199
# File 'lib/models/porcelain.rb', line 9171

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9145
9146
9147
# File 'lib/models/porcelain.rb', line 9145

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9147
9148
9149
# File 'lib/models/porcelain.rb', line 9147

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9149
9150
9151
# File 'lib/models/porcelain.rb', line 9149

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9151
9152
9153
# File 'lib/models/porcelain.rb', line 9151

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9153
9154
9155
# File 'lib/models/porcelain.rb', line 9153

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9155
9156
9157
# File 'lib/models/porcelain.rb', line 9155

def name
  @name
end

#passwordObject

The password to authenticate with.



9157
9158
9159
# File 'lib/models/porcelain.rb', line 9157

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9159
9160
9161
# File 'lib/models/porcelain.rb', line 9159

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9161
9162
9163
# File 'lib/models/porcelain.rb', line 9161

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9163
9164
9165
# File 'lib/models/porcelain.rb', line 9163

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9165
9166
9167
# File 'lib/models/porcelain.rb', line 9165

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9167
9168
9169
# File 'lib/models/porcelain.rb', line 9167

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9169
9170
9171
# File 'lib/models/porcelain.rb', line 9169

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9201
9202
9203
9204
9205
9206
9207
# File 'lib/models/porcelain.rb', line 9201

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end