Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



8519
8520
8521
8522
8523
8524
8525
8526
8527
8528
8529
8530
8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
# File 'lib/models/porcelain.rb', line 8519

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8493
8494
8495
# File 'lib/models/porcelain.rb', line 8493

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8495
8496
8497
# File 'lib/models/porcelain.rb', line 8495

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8497
8498
8499
# File 'lib/models/porcelain.rb', line 8497

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8499
8500
8501
# File 'lib/models/porcelain.rb', line 8499

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8501
8502
8503
# File 'lib/models/porcelain.rb', line 8501

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8503
8504
8505
# File 'lib/models/porcelain.rb', line 8503

def name
  @name
end

#passwordObject

The password to authenticate with.



8505
8506
8507
# File 'lib/models/porcelain.rb', line 8505

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8507
8508
8509
# File 'lib/models/porcelain.rb', line 8507

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8509
8510
8511
# File 'lib/models/porcelain.rb', line 8509

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8511
8512
8513
# File 'lib/models/porcelain.rb', line 8511

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8513
8514
8515
# File 'lib/models/porcelain.rb', line 8513

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8515
8516
8517
# File 'lib/models/porcelain.rb', line 8515

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8517
8518
8519
# File 'lib/models/porcelain.rb', line 8517

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8549
8550
8551
8552
8553
8554
8555
# File 'lib/models/porcelain.rb', line 8549

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end