Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



8338
8339
8340
8341
8342
8343
8344
8345
8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
# File 'lib/models/porcelain.rb', line 8338

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



8312
8313
8314
# File 'lib/models/porcelain.rb', line 8312

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8314
8315
8316
# File 'lib/models/porcelain.rb', line 8314

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8316
8317
8318
# File 'lib/models/porcelain.rb', line 8316

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



8318
8319
8320
# File 'lib/models/porcelain.rb', line 8318

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8320
8321
8322
# File 'lib/models/porcelain.rb', line 8320

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8322
8323
8324
# File 'lib/models/porcelain.rb', line 8322

def name
  @name
end

#passwordObject

Returns the value of attribute password.



8324
8325
8326
# File 'lib/models/porcelain.rb', line 8324

def password
  @password
end

#portObject

Returns the value of attribute port.



8326
8327
8328
# File 'lib/models/porcelain.rb', line 8326

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



8328
8329
8330
# File 'lib/models/porcelain.rb', line 8328

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8330
8331
8332
# File 'lib/models/porcelain.rb', line 8330

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8332
8333
8334
# File 'lib/models/porcelain.rb', line 8332

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8334
8335
8336
# File 'lib/models/porcelain.rb', line 8334

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



8336
8337
8338
# File 'lib/models/porcelain.rb', line 8336

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8368
8369
8370
8371
8372
8373
8374
# File 'lib/models/porcelain.rb', line 8368

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end