Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
8274 8275 8276 8277 8278 8279 8280 8281 8282 8283 8284 8285 8286 8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 |
# File 'lib/models/porcelain.rb', line 8274 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
8248 8249 8250 |
# File 'lib/models/porcelain.rb', line 8248 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8250 8251 8252 |
# File 'lib/models/porcelain.rb', line 8250 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8252 8253 8254 |
# File 'lib/models/porcelain.rb', line 8252 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
8254 8255 8256 |
# File 'lib/models/porcelain.rb', line 8254 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8256 8257 8258 |
# File 'lib/models/porcelain.rb', line 8256 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8258 8259 8260 |
# File 'lib/models/porcelain.rb', line 8258 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
8260 8261 8262 |
# File 'lib/models/porcelain.rb', line 8260 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
8262 8263 8264 |
# File 'lib/models/porcelain.rb', line 8262 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
8264 8265 8266 |
# File 'lib/models/porcelain.rb', line 8264 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8266 8267 8268 |
# File 'lib/models/porcelain.rb', line 8266 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8268 8269 8270 |
# File 'lib/models/porcelain.rb', line 8268 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8270 8271 8272 |
# File 'lib/models/porcelain.rb', line 8270 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
8272 8273 8274 |
# File 'lib/models/porcelain.rb', line 8272 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/models/porcelain.rb', line 8304 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |