Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 8127 8128 |
# File 'lib/models/porcelain.rb', line 8100 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
8074 8075 8076 |
# File 'lib/models/porcelain.rb', line 8074 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8076 8077 8078 |
# File 'lib/models/porcelain.rb', line 8076 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8078 8079 8080 |
# File 'lib/models/porcelain.rb', line 8078 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
8080 8081 8082 |
# File 'lib/models/porcelain.rb', line 8080 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8082 8083 8084 |
# File 'lib/models/porcelain.rb', line 8082 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8084 8085 8086 |
# File 'lib/models/porcelain.rb', line 8084 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
8086 8087 8088 |
# File 'lib/models/porcelain.rb', line 8086 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
8088 8089 8090 |
# File 'lib/models/porcelain.rb', line 8088 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
8090 8091 8092 |
# File 'lib/models/porcelain.rb', line 8090 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8092 8093 8094 |
# File 'lib/models/porcelain.rb', line 8092 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8094 8095 8096 |
# File 'lib/models/porcelain.rb', line 8094 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8096 8097 8098 |
# File 'lib/models/porcelain.rb', line 8096 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
8098 8099 8100 |
# File 'lib/models/porcelain.rb', line 8098 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8130 8131 8132 8133 8134 8135 8136 |
# File 'lib/models/porcelain.rb', line 8130 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |