Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
8047 8048 8049 8050 8051 8052 8053 8054 8055 8056 8057 8058 8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 8073 8074 8075 |
# File 'lib/models/porcelain.rb', line 8047 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
8021 8022 8023 |
# File 'lib/models/porcelain.rb', line 8021 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8023 8024 8025 |
# File 'lib/models/porcelain.rb', line 8023 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8025 8026 8027 |
# File 'lib/models/porcelain.rb', line 8025 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
8027 8028 8029 |
# File 'lib/models/porcelain.rb', line 8027 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8029 8030 8031 |
# File 'lib/models/porcelain.rb', line 8029 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8031 8032 8033 |
# File 'lib/models/porcelain.rb', line 8031 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
8033 8034 8035 |
# File 'lib/models/porcelain.rb', line 8033 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
8035 8036 8037 |
# File 'lib/models/porcelain.rb', line 8035 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
8037 8038 8039 |
# File 'lib/models/porcelain.rb', line 8037 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8039 8040 8041 |
# File 'lib/models/porcelain.rb', line 8039 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8041 8042 8043 |
# File 'lib/models/porcelain.rb', line 8041 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8043 8044 8045 |
# File 'lib/models/porcelain.rb', line 8043 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
8045 8046 8047 |
# File 'lib/models/porcelain.rb', line 8045 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8077 8078 8079 8080 8081 8082 8083 |
# File 'lib/models/porcelain.rb', line 8077 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |