Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 7869 7870 7871 7872 7873 7874 7875 |
# File 'lib/models/porcelain.rb', line 7847 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7821 7822 7823 |
# File 'lib/models/porcelain.rb', line 7821 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7823 7824 7825 |
# File 'lib/models/porcelain.rb', line 7823 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7825 7826 7827 |
# File 'lib/models/porcelain.rb', line 7825 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7827 7828 7829 |
# File 'lib/models/porcelain.rb', line 7827 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7829 7830 7831 |
# File 'lib/models/porcelain.rb', line 7829 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7831 7832 7833 |
# File 'lib/models/porcelain.rb', line 7831 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
7833 7834 7835 |
# File 'lib/models/porcelain.rb', line 7833 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
7835 7836 7837 |
# File 'lib/models/porcelain.rb', line 7835 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7837 7838 7839 |
# File 'lib/models/porcelain.rb', line 7837 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7839 7840 7841 |
# File 'lib/models/porcelain.rb', line 7839 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7841 7842 7843 |
# File 'lib/models/porcelain.rb', line 7841 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7843 7844 7845 |
# File 'lib/models/porcelain.rb', line 7843 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7845 7846 7847 |
# File 'lib/models/porcelain.rb', line 7845 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7877 7878 7879 7880 7881 7882 7883 |
# File 'lib/models/porcelain.rb', line 7877 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |