Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
7589 7590 7591 7592 7593 7594 7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 |
# File 'lib/models/porcelain.rb', line 7589 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7565 7566 7567 |
# File 'lib/models/porcelain.rb', line 7565 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7567 7568 7569 |
# File 'lib/models/porcelain.rb', line 7567 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7569 7570 7571 |
# File 'lib/models/porcelain.rb', line 7569 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7571 7572 7573 |
# File 'lib/models/porcelain.rb', line 7571 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7573 7574 7575 |
# File 'lib/models/porcelain.rb', line 7573 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7575 7576 7577 |
# File 'lib/models/porcelain.rb', line 7575 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
7577 7578 7579 |
# File 'lib/models/porcelain.rb', line 7577 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
7579 7580 7581 |
# File 'lib/models/porcelain.rb', line 7579 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7581 7582 7583 |
# File 'lib/models/porcelain.rb', line 7581 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7583 7584 7585 |
# File 'lib/models/porcelain.rb', line 7583 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7585 7586 7587 |
# File 'lib/models/porcelain.rb', line 7585 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7587 7588 7589 |
# File 'lib/models/porcelain.rb', line 7587 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/models/porcelain.rb', line 7617 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |