Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
6678 6679 6680 6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 6700 6701 6702 6703 6704 |
# File 'lib/models/porcelain.rb', line 6678 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6654 6655 6656 |
# File 'lib/models/porcelain.rb', line 6654 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6656 6657 6658 |
# File 'lib/models/porcelain.rb', line 6656 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6658 6659 6660 |
# File 'lib/models/porcelain.rb', line 6658 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6660 6661 6662 |
# File 'lib/models/porcelain.rb', line 6660 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6662 6663 6664 |
# File 'lib/models/porcelain.rb', line 6662 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6664 6665 6666 |
# File 'lib/models/porcelain.rb', line 6664 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6666 6667 6668 |
# File 'lib/models/porcelain.rb', line 6666 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6668 6669 6670 |
# File 'lib/models/porcelain.rb', line 6668 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6670 6671 6672 |
# File 'lib/models/porcelain.rb', line 6670 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6672 6673 6674 |
# File 'lib/models/porcelain.rb', line 6672 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6674 6675 6676 |
# File 'lib/models/porcelain.rb', line 6674 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6676 6677 6678 |
# File 'lib/models/porcelain.rb', line 6676 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6706 6707 6708 6709 6710 6711 6712 |
# File 'lib/models/porcelain.rb', line 6706 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |