Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
6570 6571 6572 6573 6574 6575 6576 6577 6578 6579 6580 6581 6582 6583 6584 6585 6586 6587 6588 6589 6590 6591 6592 6593 6594 6595 6596 |
# File 'lib/models/porcelain.rb', line 6570 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6546 6547 6548 |
# File 'lib/models/porcelain.rb', line 6546 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6548 6549 6550 |
# File 'lib/models/porcelain.rb', line 6548 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6550 6551 6552 |
# File 'lib/models/porcelain.rb', line 6550 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6552 6553 6554 |
# File 'lib/models/porcelain.rb', line 6552 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6554 6555 6556 |
# File 'lib/models/porcelain.rb', line 6554 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6556 6557 6558 |
# File 'lib/models/porcelain.rb', line 6556 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6558 6559 6560 |
# File 'lib/models/porcelain.rb', line 6558 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6560 6561 6562 |
# File 'lib/models/porcelain.rb', line 6560 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6562 6563 6564 |
# File 'lib/models/porcelain.rb', line 6562 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6564 6565 6566 |
# File 'lib/models/porcelain.rb', line 6564 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6566 6567 6568 |
# File 'lib/models/porcelain.rb', line 6566 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6568 6569 6570 |
# File 'lib/models/porcelain.rb', line 6568 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6598 6599 6600 6601 6602 6603 6604 |
# File 'lib/models/porcelain.rb', line 6598 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |