Class: SDM::SybaseIQ
- Inherits:
-
Object
- Object
- SDM::SybaseIQ
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SybaseIQ
constructor
A new instance of SybaseIQ.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SybaseIQ
Returns a new instance of SybaseIQ.
7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 7424 7425 7426 7427 7428 7429 7430 7431 7432 7433 7434 7435 7436 7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 7451 |
# File 'lib/models/porcelain.rb', line 7405 def initialize( egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7383 7384 7385 |
# File 'lib/models/porcelain.rb', line 7383 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7385 7386 7387 |
# File 'lib/models/porcelain.rb', line 7385 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7387 7388 7389 |
# File 'lib/models/porcelain.rb', line 7387 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7389 7390 7391 |
# File 'lib/models/porcelain.rb', line 7389 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7391 7392 7393 |
# File 'lib/models/porcelain.rb', line 7391 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
7393 7394 7395 |
# File 'lib/models/porcelain.rb', line 7393 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
7395 7396 7397 |
# File 'lib/models/porcelain.rb', line 7395 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7397 7398 7399 |
# File 'lib/models/porcelain.rb', line 7397 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7399 7400 7401 |
# File 'lib/models/porcelain.rb', line 7399 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7401 7402 7403 |
# File 'lib/models/porcelain.rb', line 7401 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7403 7404 7405 |
# File 'lib/models/porcelain.rb', line 7403 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/models/porcelain.rb', line 7453 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |