Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



18167
18168
18169
18170
18171
18172
18173
18174
18175
18176
18177
18178
18179
18180
18181
18182
18183
18184
18185
18186
18187
18188
18189
18190
18191
18192
18193
18194
18195
18196
18197
# File 'lib/models/porcelain.rb', line 18167

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



18139
18140
18141
# File 'lib/models/porcelain.rb', line 18139

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



18141
18142
18143
# File 'lib/models/porcelain.rb', line 18141

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



18143
18144
18145
# File 'lib/models/porcelain.rb', line 18143

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



18145
18146
18147
# File 'lib/models/porcelain.rb', line 18145

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



18147
18148
18149
# File 'lib/models/porcelain.rb', line 18147

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



18149
18150
18151
# File 'lib/models/porcelain.rb', line 18149

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



18151
18152
18153
# File 'lib/models/porcelain.rb', line 18151

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



18153
18154
18155
# File 'lib/models/porcelain.rb', line 18153

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



18155
18156
18157
# File 'lib/models/porcelain.rb', line 18155

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



18157
18158
18159
# File 'lib/models/porcelain.rb', line 18157

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



18159
18160
18161
# File 'lib/models/porcelain.rb', line 18159

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



18161
18162
18163
# File 'lib/models/porcelain.rb', line 18161

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



18163
18164
18165
# File 'lib/models/porcelain.rb', line 18163

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



18165
18166
18167
# File 'lib/models/porcelain.rb', line 18165

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18199
18200
18201
18202
18203
18204
18205
# File 'lib/models/porcelain.rb', line 18199

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end