Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



18153
18154
18155
18156
18157
18158
18159
18160
18161
18162
18163
18164
18165
18166
18167
18168
18169
18170
18171
18172
18173
18174
18175
18176
18177
18178
18179
18180
18181
18182
18183
# File 'lib/models/porcelain.rb', line 18153

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



18125
18126
18127
# File 'lib/models/porcelain.rb', line 18125

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



18127
18128
18129
# File 'lib/models/porcelain.rb', line 18127

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



18129
18130
18131
# File 'lib/models/porcelain.rb', line 18129

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



18131
18132
18133
# File 'lib/models/porcelain.rb', line 18131

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



18133
18134
18135
# File 'lib/models/porcelain.rb', line 18133

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



18135
18136
18137
# File 'lib/models/porcelain.rb', line 18135

def name
  @name
end

#passwordObject

The password to authenticate with.



18137
18138
18139
# File 'lib/models/porcelain.rb', line 18137

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



18139
18140
18141
# File 'lib/models/porcelain.rb', line 18139

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



18141
18142
18143
# File 'lib/models/porcelain.rb', line 18141

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



18143
18144
18145
# File 'lib/models/porcelain.rb', line 18143

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



18145
18146
18147
# File 'lib/models/porcelain.rb', line 18145

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



18147
18148
18149
# File 'lib/models/porcelain.rb', line 18147

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



18149
18150
18151
# File 'lib/models/porcelain.rb', line 18149

def tags
  @tags
end

#usernameObject

The username to authenticate with.



18151
18152
18153
# File 'lib/models/porcelain.rb', line 18151

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18185
18186
18187
18188
18189
18190
18191
# File 'lib/models/porcelain.rb', line 18185

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end