Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



17342
17343
17344
17345
17346
17347
17348
17349
17350
17351
17352
17353
17354
17355
17356
17357
17358
17359
17360
17361
17362
17363
17364
17365
17366
17367
17368
17369
17370
17371
17372
# File 'lib/models/porcelain.rb', line 17342

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17314
17315
17316
# File 'lib/models/porcelain.rb', line 17314

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17316
17317
17318
# File 'lib/models/porcelain.rb', line 17316

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17318
17319
17320
# File 'lib/models/porcelain.rb', line 17318

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17320
17321
17322
# File 'lib/models/porcelain.rb', line 17320

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17322
17323
17324
# File 'lib/models/porcelain.rb', line 17322

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17324
17325
17326
# File 'lib/models/porcelain.rb', line 17324

def name
  @name
end

#passwordObject

The password to authenticate with.



17326
17327
17328
# File 'lib/models/porcelain.rb', line 17326

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17328
17329
17330
# File 'lib/models/porcelain.rb', line 17328

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17330
17331
17332
# File 'lib/models/porcelain.rb', line 17330

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17332
17333
17334
# File 'lib/models/porcelain.rb', line 17332

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17334
17335
17336
# File 'lib/models/porcelain.rb', line 17334

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17336
17337
17338
# File 'lib/models/porcelain.rb', line 17336

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17338
17339
17340
# File 'lib/models/porcelain.rb', line 17338

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17340
17341
17342
# File 'lib/models/porcelain.rb', line 17340

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17374
17375
17376
17377
17378
17379
17380
# File 'lib/models/porcelain.rb', line 17374

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end