Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



16972
16973
16974
16975
16976
16977
16978
16979
16980
16981
16982
16983
16984
16985
16986
16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
# File 'lib/models/porcelain.rb', line 16972

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16944
16945
16946
# File 'lib/models/porcelain.rb', line 16944

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16946
16947
16948
# File 'lib/models/porcelain.rb', line 16946

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16948
16949
16950
# File 'lib/models/porcelain.rb', line 16948

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16950
16951
16952
# File 'lib/models/porcelain.rb', line 16950

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16952
16953
16954
# File 'lib/models/porcelain.rb', line 16952

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



16954
16955
16956
# File 'lib/models/porcelain.rb', line 16954

def name
  @name
end

#passwordObject

The password to authenticate with.



16956
16957
16958
# File 'lib/models/porcelain.rb', line 16956

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16958
16959
16960
# File 'lib/models/porcelain.rb', line 16958

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16960
16961
16962
# File 'lib/models/porcelain.rb', line 16960

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16962
16963
16964
# File 'lib/models/porcelain.rb', line 16962

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16964
16965
16966
# File 'lib/models/porcelain.rb', line 16964

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16966
16967
16968
# File 'lib/models/porcelain.rb', line 16966

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16968
16969
16970
# File 'lib/models/porcelain.rb', line 16968

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16970
16971
16972
# File 'lib/models/porcelain.rb', line 16970

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17004
17005
17006
17007
17008
17009
17010
# File 'lib/models/porcelain.rb', line 17004

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end