Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



14733
14734
14735
14736
14737
14738
14739
14740
14741
14742
14743
14744
14745
14746
14747
14748
14749
14750
14751
14752
14753
14754
14755
14756
14757
14758
14759
14760
14761
14762
14763
# File 'lib/models/porcelain.rb', line 14733

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14705
14706
14707
# File 'lib/models/porcelain.rb', line 14705

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14707
14708
14709
# File 'lib/models/porcelain.rb', line 14707

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14709
14710
14711
# File 'lib/models/porcelain.rb', line 14709

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14711
14712
14713
# File 'lib/models/porcelain.rb', line 14711

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14713
14714
14715
# File 'lib/models/porcelain.rb', line 14713

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14715
14716
14717
# File 'lib/models/porcelain.rb', line 14715

def name
  @name
end

#passwordObject

The password to authenticate with.



14717
14718
14719
# File 'lib/models/porcelain.rb', line 14717

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14719
14720
14721
# File 'lib/models/porcelain.rb', line 14719

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14721
14722
14723
# File 'lib/models/porcelain.rb', line 14721

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14723
14724
14725
# File 'lib/models/porcelain.rb', line 14723

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14725
14726
14727
# File 'lib/models/porcelain.rb', line 14725

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14727
14728
14729
# File 'lib/models/porcelain.rb', line 14727

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14729
14730
14731
# File 'lib/models/porcelain.rb', line 14729

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14731
14732
14733
# File 'lib/models/porcelain.rb', line 14731

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14765
14766
14767
14768
14769
14770
14771
# File 'lib/models/porcelain.rb', line 14765

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end