Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



14549
14550
14551
14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
14568
14569
14570
14571
14572
14573
14574
14575
14576
14577
14578
14579
# File 'lib/models/porcelain.rb', line 14549

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14521
14522
14523
# File 'lib/models/porcelain.rb', line 14521

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14523
14524
14525
# File 'lib/models/porcelain.rb', line 14523

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14525
14526
14527
# File 'lib/models/porcelain.rb', line 14525

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14527
14528
14529
# File 'lib/models/porcelain.rb', line 14527

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14529
14530
14531
# File 'lib/models/porcelain.rb', line 14529

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14531
14532
14533
# File 'lib/models/porcelain.rb', line 14531

def name
  @name
end

#passwordObject

The password to authenticate with.



14533
14534
14535
# File 'lib/models/porcelain.rb', line 14533

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14535
14536
14537
# File 'lib/models/porcelain.rb', line 14535

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14537
14538
14539
# File 'lib/models/porcelain.rb', line 14537

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14539
14540
14541
# File 'lib/models/porcelain.rb', line 14539

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14541
14542
14543
# File 'lib/models/porcelain.rb', line 14541

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14543
14544
14545
# File 'lib/models/porcelain.rb', line 14543

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14545
14546
14547
# File 'lib/models/porcelain.rb', line 14545

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14547
14548
14549
# File 'lib/models/porcelain.rb', line 14547

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14581
14582
14583
14584
14585
14586
14587
# File 'lib/models/porcelain.rb', line 14581

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end