Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
14397 14398 14399 14400 14401 14402 14403 14404 14405 14406 14407 14408 14409 14410 14411 14412 14413 14414 14415 14416 14417 14418 14419 14420 14421 14422 14423 14424 14425 14426 14427 |
# File 'lib/models/porcelain.rb', line 14397 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
14369 14370 14371 |
# File 'lib/models/porcelain.rb', line 14369 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
14371 14372 14373 |
# File 'lib/models/porcelain.rb', line 14371 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
14373 14374 14375 |
# File 'lib/models/porcelain.rb', line 14373 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
14375 14376 14377 |
# File 'lib/models/porcelain.rb', line 14375 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
14377 14378 14379 |
# File 'lib/models/porcelain.rb', line 14377 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
14379 14380 14381 |
# File 'lib/models/porcelain.rb', line 14379 def name @name end |
#password ⇒ Object
The password to authenticate with.
14381 14382 14383 |
# File 'lib/models/porcelain.rb', line 14381 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
14383 14384 14385 |
# File 'lib/models/porcelain.rb', line 14383 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
14385 14386 14387 |
# File 'lib/models/porcelain.rb', line 14385 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
14387 14388 14389 |
# File 'lib/models/porcelain.rb', line 14387 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
14389 14390 14391 |
# File 'lib/models/porcelain.rb', line 14389 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
14391 14392 14393 |
# File 'lib/models/porcelain.rb', line 14391 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14393 14394 14395 |
# File 'lib/models/porcelain.rb', line 14393 def @tags end |
#username ⇒ Object
The username to authenticate with.
14395 14396 14397 |
# File 'lib/models/porcelain.rb', line 14395 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14429 14430 14431 14432 14433 14434 14435 |
# File 'lib/models/porcelain.rb', line 14429 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |