Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
14329 14330 14331 14332 14333 14334 14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 14345 14346 14347 14348 14349 14350 14351 14352 14353 14354 14355 14356 14357 14358 14359 |
# File 'lib/models/porcelain.rb', line 14329 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
14301 14302 14303 |
# File 'lib/models/porcelain.rb', line 14301 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
14303 14304 14305 |
# File 'lib/models/porcelain.rb', line 14303 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
14305 14306 14307 |
# File 'lib/models/porcelain.rb', line 14305 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
14307 14308 14309 |
# File 'lib/models/porcelain.rb', line 14307 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
14309 14310 14311 |
# File 'lib/models/porcelain.rb', line 14309 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
14311 14312 14313 |
# File 'lib/models/porcelain.rb', line 14311 def name @name end |
#password ⇒ Object
The password to authenticate with.
14313 14314 14315 |
# File 'lib/models/porcelain.rb', line 14313 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
14315 14316 14317 |
# File 'lib/models/porcelain.rb', line 14315 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
14317 14318 14319 |
# File 'lib/models/porcelain.rb', line 14317 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
14319 14320 14321 |
# File 'lib/models/porcelain.rb', line 14319 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
14321 14322 14323 |
# File 'lib/models/porcelain.rb', line 14321 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
14323 14324 14325 |
# File 'lib/models/porcelain.rb', line 14323 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14325 14326 14327 |
# File 'lib/models/porcelain.rb', line 14325 def @tags end |
#username ⇒ Object
The username to authenticate with.
14327 14328 14329 |
# File 'lib/models/porcelain.rb', line 14327 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14361 14362 14363 14364 14365 14366 14367 |
# File 'lib/models/porcelain.rb', line 14361 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |