Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
13153 13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 13182 13183 |
# File 'lib/models/porcelain.rb', line 13153 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
13125 13126 13127 |
# File 'lib/models/porcelain.rb', line 13125 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
13127 13128 13129 |
# File 'lib/models/porcelain.rb', line 13127 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
13129 13130 13131 |
# File 'lib/models/porcelain.rb', line 13129 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
13131 13132 13133 |
# File 'lib/models/porcelain.rb', line 13131 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
13133 13134 13135 |
# File 'lib/models/porcelain.rb', line 13133 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
13135 13136 13137 |
# File 'lib/models/porcelain.rb', line 13135 def name @name end |
#password ⇒ Object
The password to authenticate with.
13137 13138 13139 |
# File 'lib/models/porcelain.rb', line 13137 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
13139 13140 13141 |
# File 'lib/models/porcelain.rb', line 13139 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
13141 13142 13143 |
# File 'lib/models/porcelain.rb', line 13141 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
13143 13144 13145 |
# File 'lib/models/porcelain.rb', line 13143 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
13145 13146 13147 |
# File 'lib/models/porcelain.rb', line 13145 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
13147 13148 13149 |
# File 'lib/models/porcelain.rb', line 13147 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13149 13150 13151 |
# File 'lib/models/porcelain.rb', line 13149 def @tags end |
#username ⇒ Object
The username to authenticate with.
13151 13152 13153 |
# File 'lib/models/porcelain.rb', line 13151 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13185 13186 13187 13188 13189 13190 13191 |
# File 'lib/models/porcelain.rb', line 13185 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |