Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 13088 13089 13090 13091 13092 13093 13094 13095 13096 13097 13098 13099 13100 |
# File 'lib/models/porcelain.rb', line 13070 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
13042 13043 13044 |
# File 'lib/models/porcelain.rb', line 13042 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
13044 13045 13046 |
# File 'lib/models/porcelain.rb', line 13044 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
13046 13047 13048 |
# File 'lib/models/porcelain.rb', line 13046 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
13048 13049 13050 |
# File 'lib/models/porcelain.rb', line 13048 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
13050 13051 13052 |
# File 'lib/models/porcelain.rb', line 13050 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
13052 13053 13054 |
# File 'lib/models/porcelain.rb', line 13052 def name @name end |
#password ⇒ Object
The password to authenticate with.
13054 13055 13056 |
# File 'lib/models/porcelain.rb', line 13054 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
13056 13057 13058 |
# File 'lib/models/porcelain.rb', line 13056 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
13058 13059 13060 |
# File 'lib/models/porcelain.rb', line 13058 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
13060 13061 13062 |
# File 'lib/models/porcelain.rb', line 13060 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
13062 13063 13064 |
# File 'lib/models/porcelain.rb', line 13062 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
13064 13065 13066 |
# File 'lib/models/porcelain.rb', line 13064 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13066 13067 13068 |
# File 'lib/models/porcelain.rb', line 13066 def @tags end |
#username ⇒ Object
The username to authenticate with.
13068 13069 13070 |
# File 'lib/models/porcelain.rb', line 13068 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13102 13103 13104 13105 13106 13107 13108 |
# File 'lib/models/porcelain.rb', line 13102 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |