Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
12826 12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 12839 12840 12841 12842 12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 |
# File 'lib/models/porcelain.rb', line 12826 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12798 12799 12800 |
# File 'lib/models/porcelain.rb', line 12798 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12800 12801 12802 |
# File 'lib/models/porcelain.rb', line 12800 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12802 12803 12804 |
# File 'lib/models/porcelain.rb', line 12802 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12804 12805 12806 |
# File 'lib/models/porcelain.rb', line 12804 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12806 12807 12808 |
# File 'lib/models/porcelain.rb', line 12806 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12808 12809 12810 |
# File 'lib/models/porcelain.rb', line 12808 def name @name end |
#password ⇒ Object
The password to authenticate with.
12810 12811 12812 |
# File 'lib/models/porcelain.rb', line 12810 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12812 12813 12814 |
# File 'lib/models/porcelain.rb', line 12812 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
12814 12815 12816 |
# File 'lib/models/porcelain.rb', line 12814 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12816 12817 12818 |
# File 'lib/models/porcelain.rb', line 12816 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12818 12819 12820 |
# File 'lib/models/porcelain.rb', line 12818 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
12820 12821 12822 |
# File 'lib/models/porcelain.rb', line 12820 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12822 12823 12824 |
# File 'lib/models/porcelain.rb', line 12822 def @tags end |
#username ⇒ Object
The username to authenticate with.
12824 12825 12826 |
# File 'lib/models/porcelain.rb', line 12824 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12858 12859 12860 12861 12862 12863 12864 |
# File 'lib/models/porcelain.rb', line 12858 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |