Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



12747
12748
12749
12750
12751
12752
12753
12754
12755
12756
12757
12758
12759
12760
12761
12762
12763
12764
12765
12766
12767
12768
12769
12770
12771
12772
12773
12774
12775
12776
12777
# File 'lib/models/porcelain.rb', line 12747

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12719
12720
12721
# File 'lib/models/porcelain.rb', line 12719

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12721
12722
12723
# File 'lib/models/porcelain.rb', line 12721

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12723
12724
12725
# File 'lib/models/porcelain.rb', line 12723

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12725
12726
12727
# File 'lib/models/porcelain.rb', line 12725

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12727
12728
12729
# File 'lib/models/porcelain.rb', line 12727

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12729
12730
12731
# File 'lib/models/porcelain.rb', line 12729

def name
  @name
end

#passwordObject

The password to authenticate with.



12731
12732
12733
# File 'lib/models/porcelain.rb', line 12731

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12733
12734
12735
# File 'lib/models/porcelain.rb', line 12733

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12735
12736
12737
# File 'lib/models/porcelain.rb', line 12735

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12737
12738
12739
# File 'lib/models/porcelain.rb', line 12737

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12739
12740
12741
# File 'lib/models/porcelain.rb', line 12739

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12741
12742
12743
# File 'lib/models/porcelain.rb', line 12741

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12743
12744
12745
# File 'lib/models/porcelain.rb', line 12743

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12745
12746
12747
# File 'lib/models/porcelain.rb', line 12745

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12779
12780
12781
12782
12783
12784
12785
# File 'lib/models/porcelain.rb', line 12779

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end