Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



12672
12673
12674
12675
12676
12677
12678
12679
12680
12681
12682
12683
12684
12685
12686
12687
12688
12689
12690
12691
12692
12693
12694
12695
12696
12697
12698
12699
12700
12701
12702
# File 'lib/models/porcelain.rb', line 12672

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12644
12645
12646
# File 'lib/models/porcelain.rb', line 12644

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12646
12647
12648
# File 'lib/models/porcelain.rb', line 12646

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12648
12649
12650
# File 'lib/models/porcelain.rb', line 12648

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12650
12651
12652
# File 'lib/models/porcelain.rb', line 12650

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12652
12653
12654
# File 'lib/models/porcelain.rb', line 12652

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12654
12655
12656
# File 'lib/models/porcelain.rb', line 12654

def name
  @name
end

#passwordObject

The password to authenticate with.



12656
12657
12658
# File 'lib/models/porcelain.rb', line 12656

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12658
12659
12660
# File 'lib/models/porcelain.rb', line 12658

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12660
12661
12662
# File 'lib/models/porcelain.rb', line 12660

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12662
12663
12664
# File 'lib/models/porcelain.rb', line 12662

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12664
12665
12666
# File 'lib/models/porcelain.rb', line 12664

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12666
12667
12668
# File 'lib/models/porcelain.rb', line 12666

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12668
12669
12670
# File 'lib/models/porcelain.rb', line 12668

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12670
12671
12672
# File 'lib/models/porcelain.rb', line 12670

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12704
12705
12706
12707
12708
12709
12710
# File 'lib/models/porcelain.rb', line 12704

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end