Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



12311
12312
12313
12314
12315
12316
12317
12318
12319
12320
12321
12322
12323
12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
# File 'lib/models/porcelain.rb', line 12311

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12283
12284
12285
# File 'lib/models/porcelain.rb', line 12283

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12285
12286
12287
# File 'lib/models/porcelain.rb', line 12285

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12287
12288
12289
# File 'lib/models/porcelain.rb', line 12287

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12289
12290
12291
# File 'lib/models/porcelain.rb', line 12289

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12291
12292
12293
# File 'lib/models/porcelain.rb', line 12291

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12293
12294
12295
# File 'lib/models/porcelain.rb', line 12293

def name
  @name
end

#passwordObject

The password to authenticate with.



12295
12296
12297
# File 'lib/models/porcelain.rb', line 12295

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12297
12298
12299
# File 'lib/models/porcelain.rb', line 12297

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12299
12300
12301
# File 'lib/models/porcelain.rb', line 12299

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12301
12302
12303
# File 'lib/models/porcelain.rb', line 12301

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12303
12304
12305
# File 'lib/models/porcelain.rb', line 12303

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12305
12306
12307
# File 'lib/models/porcelain.rb', line 12305

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12307
12308
12309
# File 'lib/models/porcelain.rb', line 12307

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12309
12310
12311
# File 'lib/models/porcelain.rb', line 12309

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12343
12344
12345
12346
12347
12348
12349
# File 'lib/models/porcelain.rb', line 12343

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end