Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



12054
12055
12056
12057
12058
12059
12060
12061
12062
12063
12064
12065
12066
12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
# File 'lib/models/porcelain.rb', line 12054

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12026
12027
12028
# File 'lib/models/porcelain.rb', line 12026

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12028
12029
12030
# File 'lib/models/porcelain.rb', line 12028

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12030
12031
12032
# File 'lib/models/porcelain.rb', line 12030

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12032
12033
12034
# File 'lib/models/porcelain.rb', line 12032

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12034
12035
12036
# File 'lib/models/porcelain.rb', line 12034

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12036
12037
12038
# File 'lib/models/porcelain.rb', line 12036

def name
  @name
end

#passwordObject

The password to authenticate with.



12038
12039
12040
# File 'lib/models/porcelain.rb', line 12038

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12040
12041
12042
# File 'lib/models/porcelain.rb', line 12040

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12042
12043
12044
# File 'lib/models/porcelain.rb', line 12042

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12044
12045
12046
# File 'lib/models/porcelain.rb', line 12044

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12046
12047
12048
# File 'lib/models/porcelain.rb', line 12046

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12048
12049
12050
# File 'lib/models/porcelain.rb', line 12048

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12050
12051
12052
# File 'lib/models/porcelain.rb', line 12050

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12052
12053
12054
# File 'lib/models/porcelain.rb', line 12052

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12086
12087
12088
12089
12090
12091
12092
# File 'lib/models/porcelain.rb', line 12086

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end