Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
11983 11984 11985 11986 11987 11988 11989 11990 11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 |
# File 'lib/models/porcelain.rb', line 11983 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11955 11956 11957 |
# File 'lib/models/porcelain.rb', line 11955 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11957 11958 11959 |
# File 'lib/models/porcelain.rb', line 11957 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11959 11960 11961 |
# File 'lib/models/porcelain.rb', line 11959 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11961 11962 11963 |
# File 'lib/models/porcelain.rb', line 11961 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11963 11964 11965 |
# File 'lib/models/porcelain.rb', line 11963 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11965 11966 11967 |
# File 'lib/models/porcelain.rb', line 11965 def name @name end |
#password ⇒ Object
The password to authenticate with.
11967 11968 11969 |
# File 'lib/models/porcelain.rb', line 11967 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11969 11970 11971 |
# File 'lib/models/porcelain.rb', line 11969 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11971 11972 11973 |
# File 'lib/models/porcelain.rb', line 11971 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11973 11974 11975 |
# File 'lib/models/porcelain.rb', line 11973 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11975 11976 11977 |
# File 'lib/models/porcelain.rb', line 11975 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11977 11978 11979 |
# File 'lib/models/porcelain.rb', line 11977 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11979 11980 11981 |
# File 'lib/models/porcelain.rb', line 11979 def @tags end |
#username ⇒ Object
The username to authenticate with.
11981 11982 11983 |
# File 'lib/models/porcelain.rb', line 11981 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12015 12016 12017 12018 12019 12020 12021 |
# File 'lib/models/porcelain.rb', line 12015 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |