Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 11931 11932 11933 11934 11935 11936 11937 11938 11939 11940 11941 11942 11943 11944 |
# File 'lib/models/porcelain.rb', line 11914 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11886 11887 11888 |
# File 'lib/models/porcelain.rb', line 11886 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11888 11889 11890 |
# File 'lib/models/porcelain.rb', line 11888 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11890 11891 11892 |
# File 'lib/models/porcelain.rb', line 11890 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11892 11893 11894 |
# File 'lib/models/porcelain.rb', line 11892 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11894 11895 11896 |
# File 'lib/models/porcelain.rb', line 11894 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11896 11897 11898 |
# File 'lib/models/porcelain.rb', line 11896 def name @name end |
#password ⇒ Object
The password to authenticate with.
11898 11899 11900 |
# File 'lib/models/porcelain.rb', line 11898 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11900 11901 11902 |
# File 'lib/models/porcelain.rb', line 11900 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11902 11903 11904 |
# File 'lib/models/porcelain.rb', line 11902 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11904 11905 11906 |
# File 'lib/models/porcelain.rb', line 11904 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11906 11907 11908 |
# File 'lib/models/porcelain.rb', line 11906 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11908 11909 11910 |
# File 'lib/models/porcelain.rb', line 11908 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11910 11911 11912 |
# File 'lib/models/porcelain.rb', line 11910 def @tags end |
#username ⇒ Object
The username to authenticate with.
11912 11913 11914 |
# File 'lib/models/porcelain.rb', line 11912 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11946 11947 11948 11949 11950 11951 11952 |
# File 'lib/models/porcelain.rb', line 11946 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |