Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
11565 11566 11567 11568 11569 11570 11571 11572 11573 11574 11575 11576 11577 11578 11579 11580 11581 11582 11583 11584 11585 11586 11587 11588 11589 11590 11591 11592 11593 |
# File 'lib/models/porcelain.rb', line 11565 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11539 11540 11541 |
# File 'lib/models/porcelain.rb', line 11539 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11541 11542 11543 |
# File 'lib/models/porcelain.rb', line 11541 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11543 11544 11545 |
# File 'lib/models/porcelain.rb', line 11543 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11545 11546 11547 |
# File 'lib/models/porcelain.rb', line 11545 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11547 11548 11549 |
# File 'lib/models/porcelain.rb', line 11547 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11549 11550 11551 |
# File 'lib/models/porcelain.rb', line 11549 def name @name end |
#password ⇒ Object
The password to authenticate with.
11551 11552 11553 |
# File 'lib/models/porcelain.rb', line 11551 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11553 11554 11555 |
# File 'lib/models/porcelain.rb', line 11553 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11555 11556 11557 |
# File 'lib/models/porcelain.rb', line 11555 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11557 11558 11559 |
# File 'lib/models/porcelain.rb', line 11557 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11559 11560 11561 |
# File 'lib/models/porcelain.rb', line 11559 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11561 11562 11563 |
# File 'lib/models/porcelain.rb', line 11561 def @tags end |
#username ⇒ Object
The username to authenticate with.
11563 11564 11565 |
# File 'lib/models/porcelain.rb', line 11563 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11595 11596 11597 11598 11599 11600 11601 |
# File 'lib/models/porcelain.rb', line 11595 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |