Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
11392 11393 11394 11395 11396 11397 11398 11399 11400 11401 11402 11403 11404 11405 11406 11407 11408 11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 |
# File 'lib/models/porcelain.rb', line 11392 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11366 11367 11368 |
# File 'lib/models/porcelain.rb', line 11366 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11368 11369 11370 |
# File 'lib/models/porcelain.rb', line 11368 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11370 11371 11372 |
# File 'lib/models/porcelain.rb', line 11370 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11372 11373 11374 |
# File 'lib/models/porcelain.rb', line 11372 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11374 11375 11376 |
# File 'lib/models/porcelain.rb', line 11374 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11376 11377 11378 |
# File 'lib/models/porcelain.rb', line 11376 def name @name end |
#password ⇒ Object
The password to authenticate with.
11378 11379 11380 |
# File 'lib/models/porcelain.rb', line 11378 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11380 11381 11382 |
# File 'lib/models/porcelain.rb', line 11380 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11382 11383 11384 |
# File 'lib/models/porcelain.rb', line 11382 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11384 11385 11386 |
# File 'lib/models/porcelain.rb', line 11384 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11386 11387 11388 |
# File 'lib/models/porcelain.rb', line 11386 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11388 11389 11390 |
# File 'lib/models/porcelain.rb', line 11388 def @tags end |
#username ⇒ Object
The username to authenticate with.
11390 11391 11392 |
# File 'lib/models/porcelain.rb', line 11390 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11422 11423 11424 11425 11426 11427 11428 |
# File 'lib/models/porcelain.rb', line 11422 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |