Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



11227
11228
11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
11239
11240
11241
11242
11243
11244
11245
11246
11247
11248
11249
11250
11251
11252
11253
11254
11255
# File 'lib/models/porcelain.rb', line 11227

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11201
11202
11203
# File 'lib/models/porcelain.rb', line 11201

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11203
11204
11205
# File 'lib/models/porcelain.rb', line 11203

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11205
11206
11207
# File 'lib/models/porcelain.rb', line 11205

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11207
11208
11209
# File 'lib/models/porcelain.rb', line 11207

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11209
11210
11211
# File 'lib/models/porcelain.rb', line 11209

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11211
11212
11213
# File 'lib/models/porcelain.rb', line 11211

def name
  @name
end

#passwordObject

The password to authenticate with.



11213
11214
11215
# File 'lib/models/porcelain.rb', line 11213

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11215
11216
11217
# File 'lib/models/porcelain.rb', line 11215

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11217
11218
11219
# File 'lib/models/porcelain.rb', line 11217

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11219
11220
11221
# File 'lib/models/porcelain.rb', line 11219

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11221
11222
11223
# File 'lib/models/porcelain.rb', line 11221

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11223
11224
11225
# File 'lib/models/porcelain.rb', line 11223

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11225
11226
11227
# File 'lib/models/porcelain.rb', line 11225

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11257
11258
11259
11260
11261
11262
11263
# File 'lib/models/porcelain.rb', line 11257

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end