Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



9821
9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
9840
9841
9842
9843
9844
9845
9846
9847
9848
9849
# File 'lib/models/porcelain.rb', line 9821

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9795
9796
9797
# File 'lib/models/porcelain.rb', line 9795

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9797
9798
9799
# File 'lib/models/porcelain.rb', line 9797

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9799
9800
9801
# File 'lib/models/porcelain.rb', line 9799

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9801
9802
9803
# File 'lib/models/porcelain.rb', line 9801

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9803
9804
9805
# File 'lib/models/porcelain.rb', line 9803

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9805
9806
9807
# File 'lib/models/porcelain.rb', line 9805

def name
  @name
end

#passwordObject

The password to authenticate with.



9807
9808
9809
# File 'lib/models/porcelain.rb', line 9807

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9809
9810
9811
# File 'lib/models/porcelain.rb', line 9809

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9811
9812
9813
# File 'lib/models/porcelain.rb', line 9811

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9813
9814
9815
# File 'lib/models/porcelain.rb', line 9813

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9815
9816
9817
# File 'lib/models/porcelain.rb', line 9815

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9817
9818
9819
# File 'lib/models/porcelain.rb', line 9817

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9819
9820
9821
# File 'lib/models/porcelain.rb', line 9819

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9851
9852
9853
9854
9855
9856
9857
# File 'lib/models/porcelain.rb', line 9851

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end