Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 9754 9755 9756 9757 |
# File 'lib/models/porcelain.rb', line 9729 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9703 9704 9705 |
# File 'lib/models/porcelain.rb', line 9703 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9705 9706 9707 |
# File 'lib/models/porcelain.rb', line 9705 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9707 9708 9709 |
# File 'lib/models/porcelain.rb', line 9707 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9709 9710 9711 |
# File 'lib/models/porcelain.rb', line 9709 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9711 9712 9713 |
# File 'lib/models/porcelain.rb', line 9711 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9713 9714 9715 |
# File 'lib/models/porcelain.rb', line 9713 def name @name end |
#password ⇒ Object
The password to authenticate with.
9715 9716 9717 |
# File 'lib/models/porcelain.rb', line 9715 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9717 9718 9719 |
# File 'lib/models/porcelain.rb', line 9717 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9719 9720 9721 |
# File 'lib/models/porcelain.rb', line 9719 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9721 9722 9723 |
# File 'lib/models/porcelain.rb', line 9721 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9723 9724 9725 |
# File 'lib/models/porcelain.rb', line 9723 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9725 9726 9727 |
# File 'lib/models/porcelain.rb', line 9725 def @tags end |
#username ⇒ Object
The username to authenticate with.
9727 9728 9729 |
# File 'lib/models/porcelain.rb', line 9727 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9759 9760 9761 9762 9763 9764 9765 |
# File 'lib/models/porcelain.rb', line 9759 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |