Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



9261
9262
9263
9264
9265
9266
9267
9268
9269
9270
9271
9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
9287
9288
9289
# File 'lib/models/porcelain.rb', line 9261

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9235
9236
9237
# File 'lib/models/porcelain.rb', line 9235

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9237
9238
9239
# File 'lib/models/porcelain.rb', line 9237

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9239
9240
9241
# File 'lib/models/porcelain.rb', line 9239

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9241
9242
9243
# File 'lib/models/porcelain.rb', line 9241

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9243
9244
9245
# File 'lib/models/porcelain.rb', line 9243

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9245
9246
9247
# File 'lib/models/porcelain.rb', line 9245

def name
  @name
end

#passwordObject

The password to authenticate with.



9247
9248
9249
# File 'lib/models/porcelain.rb', line 9247

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9249
9250
9251
# File 'lib/models/porcelain.rb', line 9249

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9251
9252
9253
# File 'lib/models/porcelain.rb', line 9251

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9253
9254
9255
# File 'lib/models/porcelain.rb', line 9253

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9255
9256
9257
# File 'lib/models/porcelain.rb', line 9255

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9257
9258
9259
# File 'lib/models/porcelain.rb', line 9257

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9259
9260
9261
# File 'lib/models/porcelain.rb', line 9259

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9291
9292
9293
9294
9295
9296
9297
# File 'lib/models/porcelain.rb', line 9291

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end