Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
9204 9205 9206 9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 |
# File 'lib/models/porcelain.rb', line 9204 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9178 9179 9180 |
# File 'lib/models/porcelain.rb', line 9178 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9180 9181 9182 |
# File 'lib/models/porcelain.rb', line 9180 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9182 9183 9184 |
# File 'lib/models/porcelain.rb', line 9182 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9184 9185 9186 |
# File 'lib/models/porcelain.rb', line 9184 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9186 9187 9188 |
# File 'lib/models/porcelain.rb', line 9186 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9188 9189 9190 |
# File 'lib/models/porcelain.rb', line 9188 def name @name end |
#password ⇒ Object
The password to authenticate with.
9190 9191 9192 |
# File 'lib/models/porcelain.rb', line 9190 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9192 9193 9194 |
# File 'lib/models/porcelain.rb', line 9192 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9194 9195 9196 |
# File 'lib/models/porcelain.rb', line 9194 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9196 9197 9198 |
# File 'lib/models/porcelain.rb', line 9196 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9198 9199 9200 |
# File 'lib/models/porcelain.rb', line 9198 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9200 9201 9202 |
# File 'lib/models/porcelain.rb', line 9200 def @tags end |
#username ⇒ Object
The username to authenticate with.
9202 9203 9204 |
# File 'lib/models/porcelain.rb', line 9202 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9234 9235 9236 9237 9238 9239 9240 |
# File 'lib/models/porcelain.rb', line 9234 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |