Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
# File 'lib/models/porcelain.rb', line 9040

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9014
9015
9016
# File 'lib/models/porcelain.rb', line 9014

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9016
9017
9018
# File 'lib/models/porcelain.rb', line 9016

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9018
9019
9020
# File 'lib/models/porcelain.rb', line 9018

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9020
9021
9022
# File 'lib/models/porcelain.rb', line 9020

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9022
9023
9024
# File 'lib/models/porcelain.rb', line 9022

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9024
9025
9026
# File 'lib/models/porcelain.rb', line 9024

def name
  @name
end

#passwordObject

The password to authenticate with.



9026
9027
9028
# File 'lib/models/porcelain.rb', line 9026

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9028
9029
9030
# File 'lib/models/porcelain.rb', line 9028

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9030
9031
9032
# File 'lib/models/porcelain.rb', line 9030

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9032
9033
9034
# File 'lib/models/porcelain.rb', line 9032

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9034
9035
9036
# File 'lib/models/porcelain.rb', line 9034

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9036
9037
9038
# File 'lib/models/porcelain.rb', line 9036

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9038
9039
9040
# File 'lib/models/porcelain.rb', line 9038

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9070
9071
9072
9073
9074
9075
9076
# File 'lib/models/porcelain.rb', line 9070

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end