Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



8603
8604
8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
8629
8630
8631
# File 'lib/models/porcelain.rb', line 8603

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8577
8578
8579
# File 'lib/models/porcelain.rb', line 8577

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8579
8580
8581
# File 'lib/models/porcelain.rb', line 8579

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8581
8582
8583
# File 'lib/models/porcelain.rb', line 8581

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8583
8584
8585
# File 'lib/models/porcelain.rb', line 8583

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8585
8586
8587
# File 'lib/models/porcelain.rb', line 8585

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8587
8588
8589
# File 'lib/models/porcelain.rb', line 8587

def name
  @name
end

#passwordObject

The password to authenticate with.



8589
8590
8591
# File 'lib/models/porcelain.rb', line 8589

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8591
8592
8593
# File 'lib/models/porcelain.rb', line 8591

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8593
8594
8595
# File 'lib/models/porcelain.rb', line 8593

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8595
8596
8597
# File 'lib/models/porcelain.rb', line 8595

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8597
8598
8599
# File 'lib/models/porcelain.rb', line 8597

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8599
8600
8601
# File 'lib/models/porcelain.rb', line 8599

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8601
8602
8603
# File 'lib/models/porcelain.rb', line 8601

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8633
8634
8635
8636
8637
8638
8639
# File 'lib/models/porcelain.rb', line 8633

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end