Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 8633 8634 8635 8636 8637 8638 8639 8640 8641 |
# File 'lib/models/porcelain.rb', line 8613 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8587 8588 8589 |
# File 'lib/models/porcelain.rb', line 8587 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8589 8590 8591 |
# File 'lib/models/porcelain.rb', line 8589 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8591 8592 8593 |
# File 'lib/models/porcelain.rb', line 8591 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8593 8594 8595 |
# File 'lib/models/porcelain.rb', line 8593 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8595 8596 8597 |
# File 'lib/models/porcelain.rb', line 8595 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8597 8598 8599 |
# File 'lib/models/porcelain.rb', line 8597 def name @name end |
#password ⇒ Object
The password to authenticate with.
8599 8600 8601 |
# File 'lib/models/porcelain.rb', line 8599 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8601 8602 8603 |
# File 'lib/models/porcelain.rb', line 8601 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8603 8604 8605 |
# File 'lib/models/porcelain.rb', line 8603 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8605 8606 8607 |
# File 'lib/models/porcelain.rb', line 8605 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8607 8608 8609 |
# File 'lib/models/porcelain.rb', line 8607 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8609 8610 8611 |
# File 'lib/models/porcelain.rb', line 8609 def @tags end |
#username ⇒ Object
The username to authenticate with.
8611 8612 8613 |
# File 'lib/models/porcelain.rb', line 8611 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8643 8644 8645 8646 8647 8648 8649 |
# File 'lib/models/porcelain.rb', line 8643 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |