Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
8427 8428 8429 8430 8431 8432 8433 8434 8435 8436 8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 |
# File 'lib/models/porcelain.rb', line 8427 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
8401 8402 8403 |
# File 'lib/models/porcelain.rb', line 8401 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8403 8404 8405 |
# File 'lib/models/porcelain.rb', line 8403 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8405 8406 8407 |
# File 'lib/models/porcelain.rb', line 8405 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
8407 8408 8409 |
# File 'lib/models/porcelain.rb', line 8407 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8409 8410 8411 |
# File 'lib/models/porcelain.rb', line 8409 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8411 8412 8413 |
# File 'lib/models/porcelain.rb', line 8411 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
8413 8414 8415 |
# File 'lib/models/porcelain.rb', line 8413 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
8415 8416 8417 |
# File 'lib/models/porcelain.rb', line 8415 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
8417 8418 8419 |
# File 'lib/models/porcelain.rb', line 8417 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8419 8420 8421 |
# File 'lib/models/porcelain.rb', line 8419 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8421 8422 8423 |
# File 'lib/models/porcelain.rb', line 8421 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8423 8424 8425 |
# File 'lib/models/porcelain.rb', line 8423 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
8425 8426 8427 |
# File 'lib/models/porcelain.rb', line 8425 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/models/porcelain.rb', line 8457 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |