Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
8375
8376
8377
8378
8379
8380
8381
8382
8383
8384
8385
8386
8387
8388
8389
8390
8391
# File 'lib/models/porcelain.rb', line 8363

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



8337
8338
8339
# File 'lib/models/porcelain.rb', line 8337

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8339
8340
8341
# File 'lib/models/porcelain.rb', line 8339

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8341
8342
8343
# File 'lib/models/porcelain.rb', line 8341

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



8343
8344
8345
# File 'lib/models/porcelain.rb', line 8343

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8345
8346
8347
# File 'lib/models/porcelain.rb', line 8345

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8347
8348
8349
# File 'lib/models/porcelain.rb', line 8347

def name
  @name
end

#passwordObject

Returns the value of attribute password.



8349
8350
8351
# File 'lib/models/porcelain.rb', line 8349

def password
  @password
end

#portObject

Returns the value of attribute port.



8351
8352
8353
# File 'lib/models/porcelain.rb', line 8351

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



8353
8354
8355
# File 'lib/models/porcelain.rb', line 8353

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8355
8356
8357
# File 'lib/models/porcelain.rb', line 8355

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8357
8358
8359
# File 'lib/models/porcelain.rb', line 8357

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8359
8360
8361
# File 'lib/models/porcelain.rb', line 8359

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



8361
8362
8363
# File 'lib/models/porcelain.rb', line 8361

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8393
8394
8395
8396
8397
8398
8399
# File 'lib/models/porcelain.rb', line 8393

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end