Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



8189
8190
8191
8192
8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
8214
8215
8216
8217
# File 'lib/models/porcelain.rb', line 8189

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



8163
8164
8165
# File 'lib/models/porcelain.rb', line 8163

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8165
8166
8167
# File 'lib/models/porcelain.rb', line 8165

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8167
8168
8169
# File 'lib/models/porcelain.rb', line 8167

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



8169
8170
8171
# File 'lib/models/porcelain.rb', line 8169

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8171
8172
8173
# File 'lib/models/porcelain.rb', line 8171

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8173
8174
8175
# File 'lib/models/porcelain.rb', line 8173

def name
  @name
end

#passwordObject

Returns the value of attribute password.



8175
8176
8177
# File 'lib/models/porcelain.rb', line 8175

def password
  @password
end

#portObject

Returns the value of attribute port.



8177
8178
8179
# File 'lib/models/porcelain.rb', line 8177

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



8179
8180
8181
# File 'lib/models/porcelain.rb', line 8179

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8181
8182
8183
# File 'lib/models/porcelain.rb', line 8181

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8183
8184
8185
# File 'lib/models/porcelain.rb', line 8183

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8185
8186
8187
# File 'lib/models/porcelain.rb', line 8185

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



8187
8188
8189
# File 'lib/models/porcelain.rb', line 8187

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8219
8220
8221
8222
8223
8224
8225
# File 'lib/models/porcelain.rb', line 8219

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end