Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
8136 8137 8138 8139 8140 8141 8142 8143 8144 8145 8146 8147 8148 8149 8150 8151 8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 8162 8163 8164 |
# File 'lib/models/porcelain.rb', line 8136 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
8110 8111 8112 |
# File 'lib/models/porcelain.rb', line 8110 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8112 8113 8114 |
# File 'lib/models/porcelain.rb', line 8112 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8114 8115 8116 |
# File 'lib/models/porcelain.rb', line 8114 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
8116 8117 8118 |
# File 'lib/models/porcelain.rb', line 8116 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8118 8119 8120 |
# File 'lib/models/porcelain.rb', line 8118 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8120 8121 8122 |
# File 'lib/models/porcelain.rb', line 8120 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
8122 8123 8124 |
# File 'lib/models/porcelain.rb', line 8122 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
8124 8125 8126 |
# File 'lib/models/porcelain.rb', line 8124 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
8126 8127 8128 |
# File 'lib/models/porcelain.rb', line 8126 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8128 8129 8130 |
# File 'lib/models/porcelain.rb', line 8128 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8130 8131 8132 |
# File 'lib/models/porcelain.rb', line 8130 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8132 8133 8134 |
# File 'lib/models/porcelain.rb', line 8132 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
8134 8135 8136 |
# File 'lib/models/porcelain.rb', line 8134 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8166 8167 8168 8169 8170 8171 8172 |
# File 'lib/models/porcelain.rb', line 8166 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |