Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



8062
8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
# File 'lib/models/porcelain.rb', line 8062

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



8036
8037
8038
# File 'lib/models/porcelain.rb', line 8036

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8038
8039
8040
# File 'lib/models/porcelain.rb', line 8038

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8040
8041
8042
# File 'lib/models/porcelain.rb', line 8040

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



8042
8043
8044
# File 'lib/models/porcelain.rb', line 8042

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8044
8045
8046
# File 'lib/models/porcelain.rb', line 8044

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8046
8047
8048
# File 'lib/models/porcelain.rb', line 8046

def name
  @name
end

#passwordObject

Returns the value of attribute password.



8048
8049
8050
# File 'lib/models/porcelain.rb', line 8048

def password
  @password
end

#portObject

Returns the value of attribute port.



8050
8051
8052
# File 'lib/models/porcelain.rb', line 8050

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



8052
8053
8054
# File 'lib/models/porcelain.rb', line 8052

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8054
8055
8056
# File 'lib/models/porcelain.rb', line 8054

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8056
8057
8058
# File 'lib/models/porcelain.rb', line 8056

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8058
8059
8060
# File 'lib/models/porcelain.rb', line 8058

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



8060
8061
8062
# File 'lib/models/porcelain.rb', line 8060

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8092
8093
8094
8095
8096
8097
8098
# File 'lib/models/porcelain.rb', line 8092

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end