Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



7936
7937
7938
7939
7940
7941
7942
7943
7944
7945
7946
7947
7948
7949
7950
7951
7952
7953
7954
7955
7956
7957
7958
7959
7960
7961
7962
7963
7964
# File 'lib/models/porcelain.rb', line 7936

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



7910
7911
7912
# File 'lib/models/porcelain.rb', line 7910

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7912
7913
7914
# File 'lib/models/porcelain.rb', line 7912

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7914
7915
7916
# File 'lib/models/porcelain.rb', line 7914

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7916
7917
7918
# File 'lib/models/porcelain.rb', line 7916

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7918
7919
7920
# File 'lib/models/porcelain.rb', line 7918

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7920
7921
7922
# File 'lib/models/porcelain.rb', line 7920

def name
  @name
end

#passwordObject

Returns the value of attribute password.



7922
7923
7924
# File 'lib/models/porcelain.rb', line 7922

def password
  @password
end

#portObject

Returns the value of attribute port.



7924
7925
7926
# File 'lib/models/porcelain.rb', line 7924

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



7926
7927
7928
# File 'lib/models/porcelain.rb', line 7926

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7928
7929
7930
# File 'lib/models/porcelain.rb', line 7928

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7930
7931
7932
# File 'lib/models/porcelain.rb', line 7930

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7932
7933
7934
# File 'lib/models/porcelain.rb', line 7932

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7934
7935
7936
# File 'lib/models/porcelain.rb', line 7934

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7966
7967
7968
7969
7970
7971
7972
# File 'lib/models/porcelain.rb', line 7966

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end