Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 |
# File 'lib/models/porcelain.rb', line 7674 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7650 7651 7652 |
# File 'lib/models/porcelain.rb', line 7650 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7652 7653 7654 |
# File 'lib/models/porcelain.rb', line 7652 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7654 7655 7656 |
# File 'lib/models/porcelain.rb', line 7654 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7656 7657 7658 |
# File 'lib/models/porcelain.rb', line 7656 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7658 7659 7660 |
# File 'lib/models/porcelain.rb', line 7658 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7660 7661 7662 |
# File 'lib/models/porcelain.rb', line 7660 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
7662 7663 7664 |
# File 'lib/models/porcelain.rb', line 7662 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
7664 7665 7666 |
# File 'lib/models/porcelain.rb', line 7664 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7666 7667 7668 |
# File 'lib/models/porcelain.rb', line 7666 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7668 7669 7670 |
# File 'lib/models/porcelain.rb', line 7668 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7670 7671 7672 |
# File 'lib/models/porcelain.rb', line 7670 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7672 7673 7674 |
# File 'lib/models/porcelain.rb', line 7672 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7702 7703 7704 7705 7706 7707 7708 |
# File 'lib/models/porcelain.rb', line 7702 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |