Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
6762 6763 6764 6765 6766 6767 6768 6769 6770 6771 6772 6773 6774 6775 6776 6777 6778 6779 6780 6781 6782 6783 6784 6785 6786 6787 6788 |
# File 'lib/models/porcelain.rb', line 6762 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6738 6739 6740 |
# File 'lib/models/porcelain.rb', line 6738 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6740 6741 6742 |
# File 'lib/models/porcelain.rb', line 6740 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6742 6743 6744 |
# File 'lib/models/porcelain.rb', line 6742 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6744 6745 6746 |
# File 'lib/models/porcelain.rb', line 6744 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6746 6747 6748 |
# File 'lib/models/porcelain.rb', line 6746 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6748 6749 6750 |
# File 'lib/models/porcelain.rb', line 6748 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6750 6751 6752 |
# File 'lib/models/porcelain.rb', line 6750 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6752 6753 6754 |
# File 'lib/models/porcelain.rb', line 6752 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6754 6755 6756 |
# File 'lib/models/porcelain.rb', line 6754 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6756 6757 6758 |
# File 'lib/models/porcelain.rb', line 6756 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6758 6759 6760 |
# File 'lib/models/porcelain.rb', line 6758 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6760 6761 6762 |
# File 'lib/models/porcelain.rb', line 6760 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6790 6791 6792 6793 6794 6795 6796 |
# File 'lib/models/porcelain.rb', line 6790 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |