Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
6763 6764 6765 6766 6767 6768 6769 6770 6771 6772 6773 6774 6775 6776 6777 6778 6779 6780 6781 6782 6783 6784 6785 6786 6787 6788 6789 |
# File 'lib/models/porcelain.rb', line 6763 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6739 6740 6741 |
# File 'lib/models/porcelain.rb', line 6739 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6741 6742 6743 |
# File 'lib/models/porcelain.rb', line 6741 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6743 6744 6745 |
# File 'lib/models/porcelain.rb', line 6743 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6745 6746 6747 |
# File 'lib/models/porcelain.rb', line 6745 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6747 6748 6749 |
# File 'lib/models/porcelain.rb', line 6747 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6749 6750 6751 |
# File 'lib/models/porcelain.rb', line 6749 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6751 6752 6753 |
# File 'lib/models/porcelain.rb', line 6751 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6753 6754 6755 |
# File 'lib/models/porcelain.rb', line 6753 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6755 6756 6757 |
# File 'lib/models/porcelain.rb', line 6755 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6757 6758 6759 |
# File 'lib/models/porcelain.rb', line 6757 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6759 6760 6761 |
# File 'lib/models/porcelain.rb', line 6759 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6761 6762 6763 |
# File 'lib/models/porcelain.rb', line 6761 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6791 6792 6793 6794 6795 6796 6797 |
# File 'lib/models/porcelain.rb', line 6791 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |