Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 6680 6681 |
# File 'lib/models/porcelain.rb', line 6655 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6631 6632 6633 |
# File 'lib/models/porcelain.rb', line 6631 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6633 6634 6635 |
# File 'lib/models/porcelain.rb', line 6633 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6635 6636 6637 |
# File 'lib/models/porcelain.rb', line 6635 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6637 6638 6639 |
# File 'lib/models/porcelain.rb', line 6637 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6639 6640 6641 |
# File 'lib/models/porcelain.rb', line 6639 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6641 6642 6643 |
# File 'lib/models/porcelain.rb', line 6641 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6643 6644 6645 |
# File 'lib/models/porcelain.rb', line 6643 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6645 6646 6647 |
# File 'lib/models/porcelain.rb', line 6645 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6647 6648 6649 |
# File 'lib/models/porcelain.rb', line 6647 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6649 6650 6651 |
# File 'lib/models/porcelain.rb', line 6649 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6651 6652 6653 |
# File 'lib/models/porcelain.rb', line 6651 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6653 6654 6655 |
# File 'lib/models/porcelain.rb', line 6653 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6683 6684 6685 6686 6687 6688 6689 |
# File 'lib/models/porcelain.rb', line 6683 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |