Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
6643 6644 6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 6667 6668 6669 |
# File 'lib/models/porcelain.rb', line 6643 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6619 6620 6621 |
# File 'lib/models/porcelain.rb', line 6619 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6621 6622 6623 |
# File 'lib/models/porcelain.rb', line 6621 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6623 6624 6625 |
# File 'lib/models/porcelain.rb', line 6623 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6625 6626 6627 |
# File 'lib/models/porcelain.rb', line 6625 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6627 6628 6629 |
# File 'lib/models/porcelain.rb', line 6627 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6629 6630 6631 |
# File 'lib/models/porcelain.rb', line 6629 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6631 6632 6633 |
# File 'lib/models/porcelain.rb', line 6631 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6633 6634 6635 |
# File 'lib/models/porcelain.rb', line 6633 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6635 6636 6637 |
# File 'lib/models/porcelain.rb', line 6635 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6637 6638 6639 |
# File 'lib/models/porcelain.rb', line 6637 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6639 6640 6641 |
# File 'lib/models/porcelain.rb', line 6639 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6641 6642 6643 |
# File 'lib/models/porcelain.rb', line 6641 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/models/porcelain.rb', line 6671 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |