Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
6470 6471 6472 6473 6474 6475 6476 6477 6478 6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 |
# File 'lib/models/porcelain.rb', line 6470 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6446 6447 6448 |
# File 'lib/models/porcelain.rb', line 6446 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6448 6449 6450 |
# File 'lib/models/porcelain.rb', line 6448 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6450 6451 6452 |
# File 'lib/models/porcelain.rb', line 6450 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6452 6453 6454 |
# File 'lib/models/porcelain.rb', line 6452 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6454 6455 6456 |
# File 'lib/models/porcelain.rb', line 6454 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6456 6457 6458 |
# File 'lib/models/porcelain.rb', line 6456 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6458 6459 6460 |
# File 'lib/models/porcelain.rb', line 6458 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6460 6461 6462 |
# File 'lib/models/porcelain.rb', line 6460 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6462 6463 6464 |
# File 'lib/models/porcelain.rb', line 6462 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6464 6465 6466 |
# File 'lib/models/porcelain.rb', line 6464 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6466 6467 6468 |
# File 'lib/models/porcelain.rb', line 6466 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6468 6469 6470 |
# File 'lib/models/porcelain.rb', line 6468 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6498 6499 6500 6501 6502 6503 6504 |
# File 'lib/models/porcelain.rb', line 6498 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |