Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 7522 7523 7524 7525 7526 7527 7528 7529 7530 7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 |
# File 'lib/models/porcelain.rb', line 7512 def initialize( egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7490 7491 7492 |
# File 'lib/models/porcelain.rb', line 7490 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7492 7493 7494 |
# File 'lib/models/porcelain.rb', line 7492 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7494 7495 7496 |
# File 'lib/models/porcelain.rb', line 7494 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7496 7497 7498 |
# File 'lib/models/porcelain.rb', line 7496 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7498 7499 7500 |
# File 'lib/models/porcelain.rb', line 7498 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
7500 7501 7502 |
# File 'lib/models/porcelain.rb', line 7500 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
7502 7503 7504 |
# File 'lib/models/porcelain.rb', line 7502 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7504 7505 7506 |
# File 'lib/models/porcelain.rb', line 7504 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7506 7507 7508 |
# File 'lib/models/porcelain.rb', line 7506 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7508 7509 7510 |
# File 'lib/models/porcelain.rb', line 7508 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7510 7511 7512 |
# File 'lib/models/porcelain.rb', line 7510 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7560 7561 7562 7563 7564 7565 7566 |
# File 'lib/models/porcelain.rb', line 7560 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |