Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



17698
17699
17700
17701
17702
17703
17704
17705
17706
17707
17708
17709
17710
17711
17712
17713
17714
17715
17716
17717
17718
17719
17720
17721
17722
17723
17724
17725
17726
17727
17728
# File 'lib/models/porcelain.rb', line 17698

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17670
17671
17672
# File 'lib/models/porcelain.rb', line 17670

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17672
17673
17674
# File 'lib/models/porcelain.rb', line 17672

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17674
17675
17676
# File 'lib/models/porcelain.rb', line 17674

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17676
17677
17678
# File 'lib/models/porcelain.rb', line 17676

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17678
17679
17680
# File 'lib/models/porcelain.rb', line 17678

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17680
17681
17682
# File 'lib/models/porcelain.rb', line 17680

def name
  @name
end

#passwordObject

The password to authenticate with.



17682
17683
17684
# File 'lib/models/porcelain.rb', line 17682

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17684
17685
17686
# File 'lib/models/porcelain.rb', line 17684

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17686
17687
17688
# File 'lib/models/porcelain.rb', line 17686

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17688
17689
17690
# File 'lib/models/porcelain.rb', line 17688

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17690
17691
17692
# File 'lib/models/porcelain.rb', line 17690

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17692
17693
17694
# File 'lib/models/porcelain.rb', line 17692

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17694
17695
17696
# File 'lib/models/porcelain.rb', line 17694

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17696
17697
17698
# File 'lib/models/porcelain.rb', line 17696

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17730
17731
17732
17733
17734
17735
17736
# File 'lib/models/porcelain.rb', line 17730

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end