Class: SDM::Teradata
- Inherits:
-
Object
- Object
- SDM::Teradata
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
constructor
A new instance of Teradata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata
Returns a new instance of Teradata.
18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 18279 18280 18281 18282 18283 18284 18285 18286 18287 18288 18289 18290 18291 |
# File 'lib/models/porcelain.rb', line 18261 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
18233 18234 18235 |
# File 'lib/models/porcelain.rb', line 18233 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
18235 18236 18237 |
# File 'lib/models/porcelain.rb', line 18235 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
18237 18238 18239 |
# File 'lib/models/porcelain.rb', line 18237 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
18239 18240 18241 |
# File 'lib/models/porcelain.rb', line 18239 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
18241 18242 18243 |
# File 'lib/models/porcelain.rb', line 18241 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
18243 18244 18245 |
# File 'lib/models/porcelain.rb', line 18243 def name @name end |
#password ⇒ Object
The password to authenticate with.
18245 18246 18247 |
# File 'lib/models/porcelain.rb', line 18245 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
18247 18248 18249 |
# File 'lib/models/porcelain.rb', line 18247 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
18249 18250 18251 |
# File 'lib/models/porcelain.rb', line 18249 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
18251 18252 18253 |
# File 'lib/models/porcelain.rb', line 18251 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
18253 18254 18255 |
# File 'lib/models/porcelain.rb', line 18253 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
18255 18256 18257 |
# File 'lib/models/porcelain.rb', line 18255 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18257 18258 18259 |
# File 'lib/models/porcelain.rb', line 18257 def @tags end |
#username ⇒ Object
The username to authenticate with.
18259 18260 18261 |
# File 'lib/models/porcelain.rb', line 18259 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18293 18294 18295 18296 18297 18298 18299 |
# File 'lib/models/porcelain.rb', line 18293 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |