Class: SDM::Token

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Token is an account providing tokenized access for automation or integration use. Tokens include admin tokens, API keys, and SCIM tokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_type: nil, created_at: nil, deadline: nil, duration: nil, id: nil, name: nil, permissions: nil, rekeyed: nil, suspended: nil, tags: nil) ⇒ Token

Returns a new instance of Token.



17784
17785
17786
17787
17788
17789
17790
17791
17792
17793
17794
17795
17796
17797
17798
17799
17800
17801
17802
17803
17804
17805
17806
# File 'lib/models/porcelain.rb', line 17784

def initialize(
  account_type: nil,
  created_at: nil,
  deadline: nil,
  duration: nil,
  id: nil,
  name: nil,
  permissions: nil,
  rekeyed: nil,
  suspended: nil,
  tags: nil
)
  @account_type =  == nil ? "" : 
  @created_at = created_at == nil ? nil : created_at
  @deadline = deadline == nil ? nil : deadline
  @duration = duration == nil ? nil : duration
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @permissions = permissions == nil ? [] : permissions
  @rekeyed = rekeyed == nil ? nil : rekeyed
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#account_typeObject

Corresponds to the type of token, e.g. api or admin-token.



17764
17765
17766
# File 'lib/models/porcelain.rb', line 17764

def 
  @account_type
end

#created_atObject

CreatedAt is the timestamp when the token was created



17766
17767
17768
# File 'lib/models/porcelain.rb', line 17766

def created_at
  @created_at
end

#deadlineObject

The timestamp when the Token will expire.



17768
17769
17770
# File 'lib/models/porcelain.rb', line 17768

def deadline
  @deadline
end

#durationObject

Duration from token creation to expiration.



17770
17771
17772
# File 'lib/models/porcelain.rb', line 17770

def duration
  @duration
end

#idObject

Unique identifier of the Token.



17772
17773
17774
# File 'lib/models/porcelain.rb', line 17772

def id
  @id
end

#nameObject

Unique human-readable name of the Token.



17774
17775
17776
# File 'lib/models/porcelain.rb', line 17774

def name
  @name
end

#permissionsObject

Permissions assigned to the token, e.g. role:create.



17776
17777
17778
# File 'lib/models/porcelain.rb', line 17776

def permissions
  @permissions
end

#rekeyedObject

The timestamp when the Token was last rekeyed.



17778
17779
17780
# File 'lib/models/porcelain.rb', line 17778

def rekeyed
  @rekeyed
end

#suspendedObject

Reserved for future use. Always false for tokens.



17780
17781
17782
# File 'lib/models/porcelain.rb', line 17780

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



17782
17783
17784
# File 'lib/models/porcelain.rb', line 17782

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17808
17809
17810
17811
17812
17813
17814
# File 'lib/models/porcelain.rb', line 17808

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end