Class: SDM::Token
- Inherits:
-
Object
- Object
- SDM::Token
- Defined in:
- lib/models/porcelain.rb
Overview
A Token is an account providing tokenized access for automation or integration use. Tokens include admin tokens, API keys, and SCIM tokens.
Instance Attribute Summary collapse
-
#account_type ⇒ Object
Corresponds to the type of token, e.g.
-
#created_at ⇒ Object
CreatedAt is the timestamp when the token was created.
-
#deadline ⇒ Object
The timestamp when the Token will expire.
-
#duration ⇒ Object
Duration from token creation to expiration.
-
#id ⇒ Object
Unique identifier of the Token.
-
#name ⇒ Object
Unique human-readable name of the Token.
-
#permissions ⇒ Object
Permissions assigned to the token, e.g.
-
#rekeyed ⇒ Object
The timestamp when the Token was last rekeyed.
-
#suspended ⇒ Object
Reserved for future use.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(account_type: nil, created_at: nil, deadline: nil, duration: nil, id: nil, name: nil, permissions: nil, rekeyed: nil, suspended: nil, tags: nil) ⇒ Token
constructor
A new instance of Token.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_type: nil, created_at: nil, deadline: nil, duration: nil, id: nil, name: nil, permissions: nil, rekeyed: nil, suspended: nil, tags: nil) ⇒ Token
Returns a new instance of Token.
17407 17408 17409 17410 17411 17412 17413 17414 17415 17416 17417 17418 17419 17420 17421 17422 17423 17424 17425 17426 17427 17428 17429 |
# File 'lib/models/porcelain.rb', line 17407 def initialize( account_type: nil, created_at: nil, deadline: nil, duration: nil, id: nil, name: nil, permissions: nil, rekeyed: nil, suspended: nil, tags: nil ) @account_type = account_type == nil ? "" : account_type @created_at = created_at == nil ? nil : created_at @deadline = deadline == nil ? nil : deadline @duration = duration == nil ? nil : duration @id = id == nil ? "" : id @name = name == nil ? "" : name @permissions = == nil ? [] : @rekeyed = rekeyed == nil ? nil : rekeyed @suspended = suspended == nil ? false : suspended @tags = == nil ? SDM::() : end |
Instance Attribute Details
#account_type ⇒ Object
Corresponds to the type of token, e.g. api or admin-token.
17387 17388 17389 |
# File 'lib/models/porcelain.rb', line 17387 def account_type @account_type end |
#created_at ⇒ Object
CreatedAt is the timestamp when the token was created
17389 17390 17391 |
# File 'lib/models/porcelain.rb', line 17389 def created_at @created_at end |
#deadline ⇒ Object
The timestamp when the Token will expire.
17391 17392 17393 |
# File 'lib/models/porcelain.rb', line 17391 def deadline @deadline end |
#duration ⇒ Object
Duration from token creation to expiration.
17393 17394 17395 |
# File 'lib/models/porcelain.rb', line 17393 def duration @duration end |
#id ⇒ Object
Unique identifier of the Token.
17395 17396 17397 |
# File 'lib/models/porcelain.rb', line 17395 def id @id end |
#name ⇒ Object
Unique human-readable name of the Token.
17397 17398 17399 |
# File 'lib/models/porcelain.rb', line 17397 def name @name end |
#permissions ⇒ Object
Permissions assigned to the token, e.g. role:create.
17399 17400 17401 |
# File 'lib/models/porcelain.rb', line 17399 def @permissions end |
#rekeyed ⇒ Object
The timestamp when the Token was last rekeyed.
17401 17402 17403 |
# File 'lib/models/porcelain.rb', line 17401 def rekeyed @rekeyed end |
#suspended ⇒ Object
Reserved for future use. Always false for tokens.
17403 17404 17405 |
# File 'lib/models/porcelain.rb', line 17403 def suspended @suspended end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17405 17406 17407 |
# File 'lib/models/porcelain.rb', line 17405 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17431 17432 17433 17434 17435 17436 17437 |
# File 'lib/models/porcelain.rb', line 17431 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |