Class: SDM::Token

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Token is an account providing tokenized access for automation or integration use. Tokens include admin tokens, API keys, and SCIM tokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_type: nil, created_at: nil, deadline: nil, duration: nil, id: nil, name: nil, permissions: nil, rekeyed: nil, suspended: nil, tags: nil) ⇒ Token

Returns a new instance of Token.



17387
17388
17389
17390
17391
17392
17393
17394
17395
17396
17397
17398
17399
17400
17401
17402
17403
17404
17405
17406
17407
17408
17409
# File 'lib/models/porcelain.rb', line 17387

def initialize(
  account_type: nil,
  created_at: nil,
  deadline: nil,
  duration: nil,
  id: nil,
  name: nil,
  permissions: nil,
  rekeyed: nil,
  suspended: nil,
  tags: nil
)
  @account_type =  == nil ? "" : 
  @created_at = created_at == nil ? nil : created_at
  @deadline = deadline == nil ? nil : deadline
  @duration = duration == nil ? nil : duration
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @permissions = permissions == nil ? [] : permissions
  @rekeyed = rekeyed == nil ? nil : rekeyed
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#account_typeObject

Corresponds to the type of token, e.g. api or admin-token.



17367
17368
17369
# File 'lib/models/porcelain.rb', line 17367

def 
  @account_type
end

#created_atObject

CreatedAt is the timestamp when the token was created



17369
17370
17371
# File 'lib/models/porcelain.rb', line 17369

def created_at
  @created_at
end

#deadlineObject

The timestamp when the Token will expire.



17371
17372
17373
# File 'lib/models/porcelain.rb', line 17371

def deadline
  @deadline
end

#durationObject

Duration from token creation to expiration.



17373
17374
17375
# File 'lib/models/porcelain.rb', line 17373

def duration
  @duration
end

#idObject

Unique identifier of the Token.



17375
17376
17377
# File 'lib/models/porcelain.rb', line 17375

def id
  @id
end

#nameObject

Unique human-readable name of the Token.



17377
17378
17379
# File 'lib/models/porcelain.rb', line 17377

def name
  @name
end

#permissionsObject

Permissions assigned to the token, e.g. role:create.



17379
17380
17381
# File 'lib/models/porcelain.rb', line 17379

def permissions
  @permissions
end

#rekeyedObject

The timestamp when the Token was last rekeyed.



17381
17382
17383
# File 'lib/models/porcelain.rb', line 17381

def rekeyed
  @rekeyed
end

#suspendedObject

Reserved for future use. Always false for tokens.



17383
17384
17385
# File 'lib/models/porcelain.rb', line 17383

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



17385
17386
17387
# File 'lib/models/porcelain.rb', line 17385

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17411
17412
17413
17414
17415
17416
17417
# File 'lib/models/porcelain.rb', line 17411

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end