Class: SDM::Token

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Token is an account providing tokenized access for automation or integration use. Tokens include admin tokens, API keys, and SCIM tokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_type: nil, created_at: nil, deadline: nil, duration: nil, id: nil, name: nil, permissions: nil, rekeyed: nil, suspended: nil, tags: nil) ⇒ Token

Returns a new instance of Token.



17880
17881
17882
17883
17884
17885
17886
17887
17888
17889
17890
17891
17892
17893
17894
17895
17896
17897
17898
17899
17900
17901
17902
# File 'lib/models/porcelain.rb', line 17880

def initialize(
  account_type: nil,
  created_at: nil,
  deadline: nil,
  duration: nil,
  id: nil,
  name: nil,
  permissions: nil,
  rekeyed: nil,
  suspended: nil,
  tags: nil
)
  @account_type =  == nil ? "" : 
  @created_at = created_at == nil ? nil : created_at
  @deadline = deadline == nil ? nil : deadline
  @duration = duration == nil ? nil : duration
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @permissions = permissions == nil ? [] : permissions
  @rekeyed = rekeyed == nil ? nil : rekeyed
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#account_typeObject

Corresponds to the type of token, e.g. api or admin-token.



17860
17861
17862
# File 'lib/models/porcelain.rb', line 17860

def 
  @account_type
end

#created_atObject

CreatedAt is the timestamp when the token was created



17862
17863
17864
# File 'lib/models/porcelain.rb', line 17862

def created_at
  @created_at
end

#deadlineObject

The timestamp when the Token will expire.



17864
17865
17866
# File 'lib/models/porcelain.rb', line 17864

def deadline
  @deadline
end

#durationObject

Duration from token creation to expiration.



17866
17867
17868
# File 'lib/models/porcelain.rb', line 17866

def duration
  @duration
end

#idObject

Unique identifier of the Token.



17868
17869
17870
# File 'lib/models/porcelain.rb', line 17868

def id
  @id
end

#nameObject

Unique human-readable name of the Token.



17870
17871
17872
# File 'lib/models/porcelain.rb', line 17870

def name
  @name
end

#permissionsObject

Permissions assigned to the token, e.g. role:create.



17872
17873
17874
# File 'lib/models/porcelain.rb', line 17872

def permissions
  @permissions
end

#rekeyedObject

The timestamp when the Token was last rekeyed.



17874
17875
17876
# File 'lib/models/porcelain.rb', line 17874

def rekeyed
  @rekeyed
end

#suspendedObject

Reserved for future use. Always false for tokens.



17876
17877
17878
# File 'lib/models/porcelain.rb', line 17876

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



17878
17879
17880
# File 'lib/models/porcelain.rb', line 17878

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17904
17905
17906
17907
17908
17909
17910
# File 'lib/models/porcelain.rb', line 17904

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end