Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



18331
18332
18333
18334
18335
18336
18337
18338
18339
18340
18341
18342
18343
18344
18345
18346
18347
18348
18349
18350
18351
18352
18353
18354
18355
18356
18357
18358
18359
18360
18361
18362
18363
# File 'lib/models/porcelain.rb', line 18331

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



18301
18302
18303
# File 'lib/models/porcelain.rb', line 18301

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



18303
18304
18305
# File 'lib/models/porcelain.rb', line 18303

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



18305
18306
18307
# File 'lib/models/porcelain.rb', line 18305

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



18307
18308
18309
# File 'lib/models/porcelain.rb', line 18307

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



18309
18310
18311
# File 'lib/models/porcelain.rb', line 18309

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



18311
18312
18313
# File 'lib/models/porcelain.rb', line 18311

def name
  @name
end

#passwordObject

The password to authenticate with.



18313
18314
18315
# File 'lib/models/porcelain.rb', line 18313

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



18315
18316
18317
# File 'lib/models/porcelain.rb', line 18315

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



18317
18318
18319
# File 'lib/models/porcelain.rb', line 18317

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



18319
18320
18321
# File 'lib/models/porcelain.rb', line 18319

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



18321
18322
18323
# File 'lib/models/porcelain.rb', line 18321

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



18323
18324
18325
# File 'lib/models/porcelain.rb', line 18323

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



18325
18326
18327
# File 'lib/models/porcelain.rb', line 18325

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



18327
18328
18329
# File 'lib/models/porcelain.rb', line 18327

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



18329
18330
18331
# File 'lib/models/porcelain.rb', line 18329

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18365
18366
18367
18368
18369
18370
18371
# File 'lib/models/porcelain.rb', line 18365

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end