Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



18283
18284
18285
18286
18287
18288
18289
18290
18291
18292
18293
18294
18295
18296
18297
18298
18299
18300
18301
18302
18303
18304
18305
18306
18307
18308
18309
18310
18311
18312
18313
18314
18315
# File 'lib/models/porcelain.rb', line 18283

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



18253
18254
18255
# File 'lib/models/porcelain.rb', line 18253

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



18255
18256
18257
# File 'lib/models/porcelain.rb', line 18255

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



18257
18258
18259
# File 'lib/models/porcelain.rb', line 18257

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



18259
18260
18261
# File 'lib/models/porcelain.rb', line 18259

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



18261
18262
18263
# File 'lib/models/porcelain.rb', line 18261

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



18263
18264
18265
# File 'lib/models/porcelain.rb', line 18263

def name
  @name
end

#passwordObject

The password to authenticate with.



18265
18266
18267
# File 'lib/models/porcelain.rb', line 18265

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



18267
18268
18269
# File 'lib/models/porcelain.rb', line 18267

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



18269
18270
18271
# File 'lib/models/porcelain.rb', line 18269

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



18271
18272
18273
# File 'lib/models/porcelain.rb', line 18271

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



18273
18274
18275
# File 'lib/models/porcelain.rb', line 18273

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



18275
18276
18277
# File 'lib/models/porcelain.rb', line 18275

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



18277
18278
18279
# File 'lib/models/porcelain.rb', line 18277

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



18279
18280
18281
# File 'lib/models/porcelain.rb', line 18279

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



18281
18282
18283
# File 'lib/models/porcelain.rb', line 18281

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18317
18318
18319
18320
18321
18322
18323
# File 'lib/models/porcelain.rb', line 18317

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end