Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



18199
18200
18201
18202
18203
18204
18205
18206
18207
18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
18224
18225
18226
18227
18228
18229
18230
18231
# File 'lib/models/porcelain.rb', line 18199

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



18169
18170
18171
# File 'lib/models/porcelain.rb', line 18169

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



18171
18172
18173
# File 'lib/models/porcelain.rb', line 18171

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



18173
18174
18175
# File 'lib/models/porcelain.rb', line 18173

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



18175
18176
18177
# File 'lib/models/porcelain.rb', line 18175

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



18177
18178
18179
# File 'lib/models/porcelain.rb', line 18177

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



18179
18180
18181
# File 'lib/models/porcelain.rb', line 18179

def name
  @name
end

#passwordObject

The password to authenticate with.



18181
18182
18183
# File 'lib/models/porcelain.rb', line 18181

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



18183
18184
18185
# File 'lib/models/porcelain.rb', line 18183

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



18185
18186
18187
# File 'lib/models/porcelain.rb', line 18185

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



18187
18188
18189
# File 'lib/models/porcelain.rb', line 18187

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



18189
18190
18191
# File 'lib/models/porcelain.rb', line 18189

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



18191
18192
18193
# File 'lib/models/porcelain.rb', line 18191

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



18193
18194
18195
# File 'lib/models/porcelain.rb', line 18193

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



18195
18196
18197
# File 'lib/models/porcelain.rb', line 18195

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



18197
18198
18199
# File 'lib/models/porcelain.rb', line 18197

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18233
18234
18235
18236
18237
18238
18239
# File 'lib/models/porcelain.rb', line 18233

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end