Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



17849
17850
17851
17852
17853
17854
17855
17856
17857
17858
17859
17860
17861
17862
17863
17864
17865
17866
17867
17868
17869
17870
17871
17872
17873
17874
17875
17876
17877
17878
17879
17880
17881
# File 'lib/models/porcelain.rb', line 17849

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17819
17820
17821
# File 'lib/models/porcelain.rb', line 17819

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17821
17822
17823
# File 'lib/models/porcelain.rb', line 17821

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17823
17824
17825
# File 'lib/models/porcelain.rb', line 17823

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17825
17826
17827
# File 'lib/models/porcelain.rb', line 17825

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17827
17828
17829
# File 'lib/models/porcelain.rb', line 17827

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17829
17830
17831
# File 'lib/models/porcelain.rb', line 17829

def name
  @name
end

#passwordObject

The password to authenticate with.



17831
17832
17833
# File 'lib/models/porcelain.rb', line 17831

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17833
17834
17835
# File 'lib/models/porcelain.rb', line 17833

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17835
17836
17837
# File 'lib/models/porcelain.rb', line 17835

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17837
17838
17839
# File 'lib/models/porcelain.rb', line 17837

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17839
17840
17841
# File 'lib/models/porcelain.rb', line 17839

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17841
17842
17843
# File 'lib/models/porcelain.rb', line 17841

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17843
17844
17845
# File 'lib/models/porcelain.rb', line 17843

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



17845
17846
17847
# File 'lib/models/porcelain.rb', line 17845

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



17847
17848
17849
# File 'lib/models/porcelain.rb', line 17847

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17883
17884
17885
17886
17887
17888
17889
# File 'lib/models/porcelain.rb', line 17883

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end