Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



17472
17473
17474
17475
17476
17477
17478
17479
17480
17481
17482
17483
17484
17485
17486
17487
17488
17489
17490
17491
17492
17493
17494
17495
17496
17497
17498
17499
17500
17501
17502
17503
17504
# File 'lib/models/porcelain.rb', line 17472

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17442
17443
17444
# File 'lib/models/porcelain.rb', line 17442

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17444
17445
17446
# File 'lib/models/porcelain.rb', line 17444

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17446
17447
17448
# File 'lib/models/porcelain.rb', line 17446

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17448
17449
17450
# File 'lib/models/porcelain.rb', line 17448

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17450
17451
17452
# File 'lib/models/porcelain.rb', line 17450

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17452
17453
17454
# File 'lib/models/porcelain.rb', line 17452

def name
  @name
end

#passwordObject

The password to authenticate with.



17454
17455
17456
# File 'lib/models/porcelain.rb', line 17454

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17456
17457
17458
# File 'lib/models/porcelain.rb', line 17456

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17458
17459
17460
# File 'lib/models/porcelain.rb', line 17458

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17460
17461
17462
# File 'lib/models/porcelain.rb', line 17460

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17462
17463
17464
# File 'lib/models/porcelain.rb', line 17462

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17464
17465
17466
# File 'lib/models/porcelain.rb', line 17464

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17466
17467
17468
# File 'lib/models/porcelain.rb', line 17466

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



17468
17469
17470
# File 'lib/models/porcelain.rb', line 17468

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



17470
17471
17472
# File 'lib/models/porcelain.rb', line 17470

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17506
17507
17508
17509
17510
17511
17512
# File 'lib/models/porcelain.rb', line 17506

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end