Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



17452
17453
17454
17455
17456
17457
17458
17459
17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
17477
17478
17479
17480
17481
17482
17483
17484
# File 'lib/models/porcelain.rb', line 17452

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17422
17423
17424
# File 'lib/models/porcelain.rb', line 17422

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17424
17425
17426
# File 'lib/models/porcelain.rb', line 17424

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17426
17427
17428
# File 'lib/models/porcelain.rb', line 17426

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17428
17429
17430
# File 'lib/models/porcelain.rb', line 17428

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17430
17431
17432
# File 'lib/models/porcelain.rb', line 17430

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17432
17433
17434
# File 'lib/models/porcelain.rb', line 17432

def name
  @name
end

#passwordObject

The password to authenticate with.



17434
17435
17436
# File 'lib/models/porcelain.rb', line 17434

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17436
17437
17438
# File 'lib/models/porcelain.rb', line 17436

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17438
17439
17440
# File 'lib/models/porcelain.rb', line 17438

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17440
17441
17442
# File 'lib/models/porcelain.rb', line 17440

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17442
17443
17444
# File 'lib/models/porcelain.rb', line 17442

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17444
17445
17446
# File 'lib/models/porcelain.rb', line 17444

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17446
17447
17448
# File 'lib/models/porcelain.rb', line 17446

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



17448
17449
17450
# File 'lib/models/porcelain.rb', line 17448

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



17450
17451
17452
# File 'lib/models/porcelain.rb', line 17450

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17486
17487
17488
17489
17490
17491
17492
# File 'lib/models/porcelain.rb', line 17486

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end