Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



17166
17167
17168
17169
17170
17171
17172
17173
17174
17175
17176
17177
17178
17179
17180
17181
17182
17183
17184
17185
17186
17187
17188
17189
17190
17191
17192
17193
17194
17195
17196
17197
17198
# File 'lib/models/porcelain.rb', line 17166

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17136
17137
17138
# File 'lib/models/porcelain.rb', line 17136

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17138
17139
17140
# File 'lib/models/porcelain.rb', line 17138

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17140
17141
17142
# File 'lib/models/porcelain.rb', line 17140

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17142
17143
17144
# File 'lib/models/porcelain.rb', line 17142

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17144
17145
17146
# File 'lib/models/porcelain.rb', line 17144

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17146
17147
17148
# File 'lib/models/porcelain.rb', line 17146

def name
  @name
end

#passwordObject

The password to authenticate with.



17148
17149
17150
# File 'lib/models/porcelain.rb', line 17148

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17150
17151
17152
# File 'lib/models/porcelain.rb', line 17150

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17152
17153
17154
# File 'lib/models/porcelain.rb', line 17152

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17154
17155
17156
# File 'lib/models/porcelain.rb', line 17154

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17156
17157
17158
# File 'lib/models/porcelain.rb', line 17156

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17158
17159
17160
# File 'lib/models/porcelain.rb', line 17158

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17160
17161
17162
# File 'lib/models/porcelain.rb', line 17160

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



17162
17163
17164
# File 'lib/models/porcelain.rb', line 17162

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



17164
17165
17166
# File 'lib/models/porcelain.rb', line 17164

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17200
17201
17202
17203
17204
17205
17206
# File 'lib/models/porcelain.rb', line 17200

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end