Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



17102
17103
17104
17105
17106
17107
17108
17109
17110
17111
17112
17113
17114
17115
17116
17117
17118
17119
17120
17121
17122
17123
17124
17125
17126
17127
17128
17129
17130
17131
17132
17133
17134
# File 'lib/models/porcelain.rb', line 17102

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17072
17073
17074
# File 'lib/models/porcelain.rb', line 17072

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17074
17075
17076
# File 'lib/models/porcelain.rb', line 17074

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17076
17077
17078
# File 'lib/models/porcelain.rb', line 17076

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17078
17079
17080
# File 'lib/models/porcelain.rb', line 17078

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17080
17081
17082
# File 'lib/models/porcelain.rb', line 17080

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17082
17083
17084
# File 'lib/models/porcelain.rb', line 17082

def name
  @name
end

#passwordObject

The password to authenticate with.



17084
17085
17086
# File 'lib/models/porcelain.rb', line 17084

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17086
17087
17088
# File 'lib/models/porcelain.rb', line 17086

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17088
17089
17090
# File 'lib/models/porcelain.rb', line 17088

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17090
17091
17092
# File 'lib/models/porcelain.rb', line 17090

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17092
17093
17094
# File 'lib/models/porcelain.rb', line 17092

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17094
17095
17096
# File 'lib/models/porcelain.rb', line 17094

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17096
17097
17098
# File 'lib/models/porcelain.rb', line 17096

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



17098
17099
17100
# File 'lib/models/porcelain.rb', line 17098

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



17100
17101
17102
# File 'lib/models/porcelain.rb', line 17100

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17136
17137
17138
17139
17140
17141
17142
# File 'lib/models/porcelain.rb', line 17136

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end