Class: SDM::Trino
- Inherits:
-
Object
- Object
- SDM::Trino
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Trino
constructor
A new instance of Trino.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Trino
Returns a new instance of Trino.
16174 16175 16176 16177 16178 16179 16180 16181 16182 16183 16184 16185 16186 16187 16188 16189 16190 16191 16192 16193 16194 16195 16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 |
# File 'lib/models/porcelain.rb', line 16174 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
16144 16145 16146 |
# File 'lib/models/porcelain.rb', line 16144 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
16146 16147 16148 |
# File 'lib/models/porcelain.rb', line 16146 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
16148 16149 16150 |
# File 'lib/models/porcelain.rb', line 16148 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
16150 16151 16152 |
# File 'lib/models/porcelain.rb', line 16150 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
16152 16153 16154 |
# File 'lib/models/porcelain.rb', line 16152 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
16154 16155 16156 |
# File 'lib/models/porcelain.rb', line 16154 def name @name end |
#password ⇒ Object
The password to authenticate with.
16156 16157 16158 |
# File 'lib/models/porcelain.rb', line 16156 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
16158 16159 16160 |
# File 'lib/models/porcelain.rb', line 16158 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
16160 16161 16162 |
# File 'lib/models/porcelain.rb', line 16160 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
16162 16163 16164 |
# File 'lib/models/porcelain.rb', line 16162 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
16164 16165 16166 |
# File 'lib/models/porcelain.rb', line 16164 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
16166 16167 16168 |
# File 'lib/models/porcelain.rb', line 16166 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
16168 16169 16170 |
# File 'lib/models/porcelain.rb', line 16168 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
16170 16171 16172 |
# File 'lib/models/porcelain.rb', line 16170 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
16172 16173 16174 |
# File 'lib/models/porcelain.rb', line 16172 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16208 16209 16210 16211 16212 16213 16214 |
# File 'lib/models/porcelain.rb', line 16208 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |