Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



15122
15123
15124
15125
15126
15127
15128
15129
15130
15131
15132
15133
15134
15135
15136
15137
15138
15139
15140
15141
15142
15143
15144
15145
15146
15147
15148
15149
15150
15151
15152
15153
15154
# File 'lib/models/porcelain.rb', line 15122

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



15092
15093
15094
# File 'lib/models/porcelain.rb', line 15092

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15094
15095
15096
# File 'lib/models/porcelain.rb', line 15094

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15096
15097
15098
# File 'lib/models/porcelain.rb', line 15096

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15098
15099
15100
# File 'lib/models/porcelain.rb', line 15098

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15100
15101
15102
# File 'lib/models/porcelain.rb', line 15100

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15102
15103
15104
# File 'lib/models/porcelain.rb', line 15102

def name
  @name
end

#passwordObject

The password to authenticate with.



15104
15105
15106
# File 'lib/models/porcelain.rb', line 15104

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15106
15107
15108
# File 'lib/models/porcelain.rb', line 15106

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



15108
15109
15110
# File 'lib/models/porcelain.rb', line 15108

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15110
15111
15112
# File 'lib/models/porcelain.rb', line 15110

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15112
15113
15114
# File 'lib/models/porcelain.rb', line 15112

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



15114
15115
15116
# File 'lib/models/porcelain.rb', line 15114

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15116
15117
15118
# File 'lib/models/porcelain.rb', line 15116

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



15118
15119
15120
# File 'lib/models/porcelain.rb', line 15118

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



15120
15121
15122
# File 'lib/models/porcelain.rb', line 15120

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15156
15157
15158
15159
15160
15161
15162
# File 'lib/models/porcelain.rb', line 15156

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end