Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



14848
14849
14850
14851
14852
14853
14854
14855
14856
14857
14858
14859
14860
14861
14862
14863
14864
14865
14866
14867
14868
14869
14870
14871
14872
14873
14874
14875
14876
14877
14878
14879
14880
# File 'lib/models/porcelain.rb', line 14848

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14818
14819
14820
# File 'lib/models/porcelain.rb', line 14818

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14820
14821
14822
# File 'lib/models/porcelain.rb', line 14820

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14822
14823
14824
# File 'lib/models/porcelain.rb', line 14822

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14824
14825
14826
# File 'lib/models/porcelain.rb', line 14824

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14826
14827
14828
# File 'lib/models/porcelain.rb', line 14826

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14828
14829
14830
# File 'lib/models/porcelain.rb', line 14828

def name
  @name
end

#passwordObject

The password to authenticate with.



14830
14831
14832
# File 'lib/models/porcelain.rb', line 14830

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14832
14833
14834
# File 'lib/models/porcelain.rb', line 14832

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14834
14835
14836
# File 'lib/models/porcelain.rb', line 14834

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14836
14837
14838
# File 'lib/models/porcelain.rb', line 14836

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14838
14839
14840
# File 'lib/models/porcelain.rb', line 14838

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14840
14841
14842
# File 'lib/models/porcelain.rb', line 14840

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14842
14843
14844
# File 'lib/models/porcelain.rb', line 14842

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



14844
14845
14846
# File 'lib/models/porcelain.rb', line 14844

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



14846
14847
14848
# File 'lib/models/porcelain.rb', line 14846

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14882
14883
14884
14885
14886
14887
14888
# File 'lib/models/porcelain.rb', line 14882

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end