Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



14665
14666
14667
14668
14669
14670
14671
14672
14673
14674
14675
14676
14677
14678
14679
14680
14681
14682
14683
14684
14685
14686
14687
14688
14689
14690
14691
14692
14693
14694
14695
14696
14697
# File 'lib/models/porcelain.rb', line 14665

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14635
14636
14637
# File 'lib/models/porcelain.rb', line 14635

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14637
14638
14639
# File 'lib/models/porcelain.rb', line 14637

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14639
14640
14641
# File 'lib/models/porcelain.rb', line 14639

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14641
14642
14643
# File 'lib/models/porcelain.rb', line 14641

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14643
14644
14645
# File 'lib/models/porcelain.rb', line 14643

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14645
14646
14647
# File 'lib/models/porcelain.rb', line 14645

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14647
14648
14649
# File 'lib/models/porcelain.rb', line 14647

def name
  @name
end

#passwordObject

The password to authenticate with.



14649
14650
14651
# File 'lib/models/porcelain.rb', line 14649

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14651
14652
14653
# File 'lib/models/porcelain.rb', line 14651

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14653
14654
14655
# File 'lib/models/porcelain.rb', line 14653

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14655
14656
14657
# File 'lib/models/porcelain.rb', line 14655

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14657
14658
14659
# File 'lib/models/porcelain.rb', line 14657

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14659
14660
14661
# File 'lib/models/porcelain.rb', line 14659

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14661
14662
14663
# File 'lib/models/porcelain.rb', line 14661

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14663
14664
14665
# File 'lib/models/porcelain.rb', line 14663

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14699
14700
14701
14702
14703
14704
14705
# File 'lib/models/porcelain.rb', line 14699

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end