Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



14597
14598
14599
14600
14601
14602
14603
14604
14605
14606
14607
14608
14609
14610
14611
14612
14613
14614
14615
14616
14617
14618
14619
14620
14621
14622
14623
14624
14625
14626
14627
14628
14629
# File 'lib/models/porcelain.rb', line 14597

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14567
14568
14569
# File 'lib/models/porcelain.rb', line 14567

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14569
14570
14571
# File 'lib/models/porcelain.rb', line 14569

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14571
14572
14573
# File 'lib/models/porcelain.rb', line 14571

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14573
14574
14575
# File 'lib/models/porcelain.rb', line 14573

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14575
14576
14577
# File 'lib/models/porcelain.rb', line 14575

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14577
14578
14579
# File 'lib/models/porcelain.rb', line 14577

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14579
14580
14581
# File 'lib/models/porcelain.rb', line 14579

def name
  @name
end

#passwordObject

The password to authenticate with.



14581
14582
14583
# File 'lib/models/porcelain.rb', line 14581

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14583
14584
14585
# File 'lib/models/porcelain.rb', line 14583

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14585
14586
14587
# File 'lib/models/porcelain.rb', line 14585

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14587
14588
14589
# File 'lib/models/porcelain.rb', line 14587

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14589
14590
14591
# File 'lib/models/porcelain.rb', line 14589

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14591
14592
14593
# File 'lib/models/porcelain.rb', line 14591

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14593
14594
14595
# File 'lib/models/porcelain.rb', line 14593

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14595
14596
14597
# File 'lib/models/porcelain.rb', line 14595

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14631
14632
14633
14634
14635
14636
14637
# File 'lib/models/porcelain.rb', line 14631

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end