Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
14539
14540
14541
14542
14543
14544
14545
14546
14547
14548
14549
14550
14551
14552
14553
14554
14555
14556
# File 'lib/models/porcelain.rb', line 14524

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



14494
14495
14496
# File 'lib/models/porcelain.rb', line 14494

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14496
14497
14498
# File 'lib/models/porcelain.rb', line 14496

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14498
14499
14500
# File 'lib/models/porcelain.rb', line 14498

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14500
14501
14502
# File 'lib/models/porcelain.rb', line 14500

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14502
14503
14504
# File 'lib/models/porcelain.rb', line 14502

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14504
14505
14506
# File 'lib/models/porcelain.rb', line 14504

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14506
14507
14508
# File 'lib/models/porcelain.rb', line 14506

def name
  @name
end

#passwordObject

The password to authenticate with.



14508
14509
14510
# File 'lib/models/porcelain.rb', line 14508

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14510
14511
14512
# File 'lib/models/porcelain.rb', line 14510

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



14512
14513
14514
# File 'lib/models/porcelain.rb', line 14512

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14514
14515
14516
# File 'lib/models/porcelain.rb', line 14514

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14516
14517
14518
# File 'lib/models/porcelain.rb', line 14516

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



14518
14519
14520
# File 'lib/models/porcelain.rb', line 14518

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14520
14521
14522
# File 'lib/models/porcelain.rb', line 14520

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14522
14523
14524
# File 'lib/models/porcelain.rb', line 14522

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14558
14559
14560
14561
14562
14563
14564
# File 'lib/models/porcelain.rb', line 14558

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end