Class: SDM::Trino
- Inherits:
-
Object
- Object
- SDM::Trino
- Defined in:
- lib/models/porcelain.rb
Overview
Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
constructor
A new instance of Trino.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
Returns a new instance of Trino.
13197 13198 13199 13200 13201 13202 13203 13204 13205 13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 |
# File 'lib/models/porcelain.rb', line 13197 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
13167 13168 13169 |
# File 'lib/models/porcelain.rb', line 13167 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
13169 13170 13171 |
# File 'lib/models/porcelain.rb', line 13169 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
13171 13172 13173 |
# File 'lib/models/porcelain.rb', line 13171 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
13173 13174 13175 |
# File 'lib/models/porcelain.rb', line 13173 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
13175 13176 13177 |
# File 'lib/models/porcelain.rb', line 13175 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
13177 13178 13179 |
# File 'lib/models/porcelain.rb', line 13177 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
13179 13180 13181 |
# File 'lib/models/porcelain.rb', line 13179 def name @name end |
#password ⇒ Object
The password to authenticate with.
13181 13182 13183 |
# File 'lib/models/porcelain.rb', line 13181 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
13183 13184 13185 |
# File 'lib/models/porcelain.rb', line 13183 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
13185 13186 13187 |
# File 'lib/models/porcelain.rb', line 13185 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
13187 13188 13189 |
# File 'lib/models/porcelain.rb', line 13187 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
13189 13190 13191 |
# File 'lib/models/porcelain.rb', line 13189 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
13191 13192 13193 |
# File 'lib/models/porcelain.rb', line 13191 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13193 13194 13195 |
# File 'lib/models/porcelain.rb', line 13193 def @tags end |
#username ⇒ Object
The username to authenticate with.
13195 13196 13197 |
# File 'lib/models/porcelain.rb', line 13195 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13231 13232 13233 13234 13235 13236 13237 |
# File 'lib/models/porcelain.rb', line 13231 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |