Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



13189
13190
13191
13192
13193
13194
13195
13196
13197
13198
13199
13200
13201
13202
13203
13204
13205
13206
13207
13208
13209
13210
13211
13212
13213
13214
13215
13216
13217
13218
13219
13220
13221
# File 'lib/models/porcelain.rb', line 13189

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13159
13160
13161
# File 'lib/models/porcelain.rb', line 13159

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13161
13162
13163
# File 'lib/models/porcelain.rb', line 13161

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13163
13164
13165
# File 'lib/models/porcelain.rb', line 13163

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13165
13166
13167
# File 'lib/models/porcelain.rb', line 13165

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13167
13168
13169
# File 'lib/models/porcelain.rb', line 13167

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13169
13170
13171
# File 'lib/models/porcelain.rb', line 13169

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13171
13172
13173
# File 'lib/models/porcelain.rb', line 13171

def name
  @name
end

#passwordObject

The password to authenticate with.



13173
13174
13175
# File 'lib/models/porcelain.rb', line 13173

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13175
13176
13177
# File 'lib/models/porcelain.rb', line 13175

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



13177
13178
13179
# File 'lib/models/porcelain.rb', line 13177

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13179
13180
13181
# File 'lib/models/porcelain.rb', line 13179

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13181
13182
13183
# File 'lib/models/porcelain.rb', line 13181

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13183
13184
13185
# File 'lib/models/porcelain.rb', line 13183

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13185
13186
13187
# File 'lib/models/porcelain.rb', line 13185

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13187
13188
13189
# File 'lib/models/porcelain.rb', line 13187

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13223
13224
13225
13226
13227
13228
13229
# File 'lib/models/porcelain.rb', line 13223

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end