Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



13021
13022
13023
13024
13025
13026
13027
13028
13029
13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
13049
13050
13051
13052
13053
# File 'lib/models/porcelain.rb', line 13021

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12991
12992
12993
# File 'lib/models/porcelain.rb', line 12991

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12993
12994
12995
# File 'lib/models/porcelain.rb', line 12993

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12995
12996
12997
# File 'lib/models/porcelain.rb', line 12995

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12997
12998
12999
# File 'lib/models/porcelain.rb', line 12997

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12999
13000
13001
# File 'lib/models/porcelain.rb', line 12999

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13001
13002
13003
# File 'lib/models/porcelain.rb', line 13001

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13003
13004
13005
# File 'lib/models/porcelain.rb', line 13003

def name
  @name
end

#passwordObject

The password to authenticate with.



13005
13006
13007
# File 'lib/models/porcelain.rb', line 13005

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13007
13008
13009
# File 'lib/models/porcelain.rb', line 13007

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



13009
13010
13011
# File 'lib/models/porcelain.rb', line 13009

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13011
13012
13013
# File 'lib/models/porcelain.rb', line 13011

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13013
13014
13015
# File 'lib/models/porcelain.rb', line 13013

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13015
13016
13017
# File 'lib/models/porcelain.rb', line 13015

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13017
13018
13019
# File 'lib/models/porcelain.rb', line 13017

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13019
13020
13021
# File 'lib/models/porcelain.rb', line 13019

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13055
13056
13057
13058
13059
13060
13061
# File 'lib/models/porcelain.rb', line 13055

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end