Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



12950
12951
12952
12953
12954
12955
12956
12957
12958
12959
12960
12961
12962
12963
12964
12965
12966
12967
12968
12969
12970
12971
12972
12973
12974
12975
12976
12977
12978
12979
12980
12981
12982
# File 'lib/models/porcelain.rb', line 12950

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12920
12921
12922
# File 'lib/models/porcelain.rb', line 12920

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12922
12923
12924
# File 'lib/models/porcelain.rb', line 12922

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12924
12925
12926
# File 'lib/models/porcelain.rb', line 12924

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12926
12927
12928
# File 'lib/models/porcelain.rb', line 12926

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12928
12929
12930
# File 'lib/models/porcelain.rb', line 12928

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12930
12931
12932
# File 'lib/models/porcelain.rb', line 12930

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12932
12933
12934
# File 'lib/models/porcelain.rb', line 12932

def name
  @name
end

#passwordObject

The password to authenticate with.



12934
12935
12936
# File 'lib/models/porcelain.rb', line 12934

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12936
12937
12938
# File 'lib/models/porcelain.rb', line 12936

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12938
12939
12940
# File 'lib/models/porcelain.rb', line 12938

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12940
12941
12942
# File 'lib/models/porcelain.rb', line 12940

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12942
12943
12944
# File 'lib/models/porcelain.rb', line 12942

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12944
12945
12946
# File 'lib/models/porcelain.rb', line 12944

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12946
12947
12948
# File 'lib/models/porcelain.rb', line 12946

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12948
12949
12950
# File 'lib/models/porcelain.rb', line 12948

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12984
12985
12986
12987
12988
12989
12990
# File 'lib/models/porcelain.rb', line 12984

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end