Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
12886
12887
12888
12889
12890
12891
12892
12893
12894
12895
12896
12897
12898
12899
12900
12901
12902
12903
12904
12905
12906
# File 'lib/models/porcelain.rb', line 12874

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12844
12845
12846
# File 'lib/models/porcelain.rb', line 12844

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12846
12847
12848
# File 'lib/models/porcelain.rb', line 12846

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12848
12849
12850
# File 'lib/models/porcelain.rb', line 12848

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12850
12851
12852
# File 'lib/models/porcelain.rb', line 12850

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12852
12853
12854
# File 'lib/models/porcelain.rb', line 12852

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12854
12855
12856
# File 'lib/models/porcelain.rb', line 12854

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12856
12857
12858
# File 'lib/models/porcelain.rb', line 12856

def name
  @name
end

#passwordObject

The password to authenticate with.



12858
12859
12860
# File 'lib/models/porcelain.rb', line 12858

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12860
12861
12862
# File 'lib/models/porcelain.rb', line 12860

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12862
12863
12864
# File 'lib/models/porcelain.rb', line 12862

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12864
12865
12866
# File 'lib/models/porcelain.rb', line 12864

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12866
12867
12868
# File 'lib/models/porcelain.rb', line 12866

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12868
12869
12870
# File 'lib/models/porcelain.rb', line 12868

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12870
12871
12872
# File 'lib/models/porcelain.rb', line 12870

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12872
12873
12874
# File 'lib/models/porcelain.rb', line 12872

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12908
12909
12910
12911
12912
12913
12914
# File 'lib/models/porcelain.rb', line 12908

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end