Class: SDM::Trino
- Inherits:
-
Object
- Object
- SDM::Trino
- Defined in:
- lib/models/porcelain.rb
Overview
Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
constructor
A new instance of Trino.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
Returns a new instance of Trino.
12733 12734 12735 12736 12737 12738 12739 12740 12741 12742 12743 12744 12745 12746 12747 12748 12749 12750 12751 12752 12753 12754 12755 12756 12757 12758 12759 12760 12761 12762 12763 12764 12765 |
# File 'lib/models/porcelain.rb', line 12733 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12703 12704 12705 |
# File 'lib/models/porcelain.rb', line 12703 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
12705 12706 12707 |
# File 'lib/models/porcelain.rb', line 12705 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12707 12708 12709 |
# File 'lib/models/porcelain.rb', line 12707 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12709 12710 12711 |
# File 'lib/models/porcelain.rb', line 12709 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12711 12712 12713 |
# File 'lib/models/porcelain.rb', line 12711 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12713 12714 12715 |
# File 'lib/models/porcelain.rb', line 12713 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12715 12716 12717 |
# File 'lib/models/porcelain.rb', line 12715 def name @name end |
#password ⇒ Object
The password to authenticate with.
12717 12718 12719 |
# File 'lib/models/porcelain.rb', line 12717 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12719 12720 12721 |
# File 'lib/models/porcelain.rb', line 12719 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
12721 12722 12723 |
# File 'lib/models/porcelain.rb', line 12721 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12723 12724 12725 |
# File 'lib/models/porcelain.rb', line 12723 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12725 12726 12727 |
# File 'lib/models/porcelain.rb', line 12725 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
12727 12728 12729 |
# File 'lib/models/porcelain.rb', line 12727 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12729 12730 12731 |
# File 'lib/models/porcelain.rb', line 12729 def @tags end |
#username ⇒ Object
The username to authenticate with.
12731 12732 12733 |
# File 'lib/models/porcelain.rb', line 12731 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12767 12768 12769 12770 12771 12772 12773 |
# File 'lib/models/porcelain.rb', line 12767 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |