Class: SDM::Trino
- Inherits:
-
Object
- Object
- SDM::Trino
- Defined in:
- lib/models/porcelain.rb
Overview
Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
constructor
A new instance of Trino.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
Returns a new instance of Trino.
12438 12439 12440 12441 12442 12443 12444 12445 12446 12447 12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 12467 12468 12469 12470 |
# File 'lib/models/porcelain.rb', line 12438 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12408 12409 12410 |
# File 'lib/models/porcelain.rb', line 12408 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
12410 12411 12412 |
# File 'lib/models/porcelain.rb', line 12410 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12412 12413 12414 |
# File 'lib/models/porcelain.rb', line 12412 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12414 12415 12416 |
# File 'lib/models/porcelain.rb', line 12414 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12416 12417 12418 |
# File 'lib/models/porcelain.rb', line 12416 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12418 12419 12420 |
# File 'lib/models/porcelain.rb', line 12418 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12420 12421 12422 |
# File 'lib/models/porcelain.rb', line 12420 def name @name end |
#password ⇒ Object
The password to authenticate with.
12422 12423 12424 |
# File 'lib/models/porcelain.rb', line 12422 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12424 12425 12426 |
# File 'lib/models/porcelain.rb', line 12424 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
12426 12427 12428 |
# File 'lib/models/porcelain.rb', line 12426 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12428 12429 12430 |
# File 'lib/models/porcelain.rb', line 12428 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12430 12431 12432 |
# File 'lib/models/porcelain.rb', line 12430 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
12432 12433 12434 |
# File 'lib/models/porcelain.rb', line 12432 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12434 12435 12436 |
# File 'lib/models/porcelain.rb', line 12434 def @tags end |
#username ⇒ Object
The username to authenticate with.
12436 12437 12438 |
# File 'lib/models/porcelain.rb', line 12436 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12472 12473 12474 12475 12476 12477 12478 |
# File 'lib/models/porcelain.rb', line 12472 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |