Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



12181
12182
12183
12184
12185
12186
12187
12188
12189
12190
12191
12192
12193
12194
12195
12196
12197
12198
12199
12200
12201
12202
12203
12204
12205
12206
12207
12208
12209
12210
12211
12212
12213
# File 'lib/models/porcelain.rb', line 12181

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12151
12152
12153
# File 'lib/models/porcelain.rb', line 12151

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12153
12154
12155
# File 'lib/models/porcelain.rb', line 12153

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12155
12156
12157
# File 'lib/models/porcelain.rb', line 12155

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12157
12158
12159
# File 'lib/models/porcelain.rb', line 12157

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12159
12160
12161
# File 'lib/models/porcelain.rb', line 12159

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12161
12162
12163
# File 'lib/models/porcelain.rb', line 12161

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12163
12164
12165
# File 'lib/models/porcelain.rb', line 12163

def name
  @name
end

#passwordObject

The password to authenticate with.



12165
12166
12167
# File 'lib/models/porcelain.rb', line 12165

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12167
12168
12169
# File 'lib/models/porcelain.rb', line 12167

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12169
12170
12171
# File 'lib/models/porcelain.rb', line 12169

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12171
12172
12173
# File 'lib/models/porcelain.rb', line 12171

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12173
12174
12175
# File 'lib/models/porcelain.rb', line 12173

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12175
12176
12177
# File 'lib/models/porcelain.rb', line 12175

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12177
12178
12179
# File 'lib/models/porcelain.rb', line 12177

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12179
12180
12181
# File 'lib/models/porcelain.rb', line 12179

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12215
12216
12217
12218
12219
12220
12221
# File 'lib/models/porcelain.rb', line 12215

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end