Class: SDM::Trino
- Inherits:
-
Object
- Object
- SDM::Trino
- Defined in:
- lib/models/porcelain.rb
Overview
Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
constructor
A new instance of Trino.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
Returns a new instance of Trino.
12041 12042 12043 12044 12045 12046 12047 12048 12049 12050 12051 12052 12053 12054 12055 12056 12057 12058 12059 12060 12061 12062 12063 12064 12065 12066 12067 12068 12069 12070 12071 12072 12073 |
# File 'lib/models/porcelain.rb', line 12041 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12011 12012 12013 |
# File 'lib/models/porcelain.rb', line 12011 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
12013 12014 12015 |
# File 'lib/models/porcelain.rb', line 12013 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12015 12016 12017 |
# File 'lib/models/porcelain.rb', line 12015 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12017 12018 12019 |
# File 'lib/models/porcelain.rb', line 12017 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12019 12020 12021 |
# File 'lib/models/porcelain.rb', line 12019 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12021 12022 12023 |
# File 'lib/models/porcelain.rb', line 12021 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12023 12024 12025 |
# File 'lib/models/porcelain.rb', line 12023 def name @name end |
#password ⇒ Object
The password to authenticate with.
12025 12026 12027 |
# File 'lib/models/porcelain.rb', line 12025 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12027 12028 12029 |
# File 'lib/models/porcelain.rb', line 12027 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
12029 12030 12031 |
# File 'lib/models/porcelain.rb', line 12029 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12031 12032 12033 |
# File 'lib/models/porcelain.rb', line 12031 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12033 12034 12035 |
# File 'lib/models/porcelain.rb', line 12033 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
12035 12036 12037 |
# File 'lib/models/porcelain.rb', line 12035 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12037 12038 12039 |
# File 'lib/models/porcelain.rb', line 12037 def @tags end |
#username ⇒ Object
The username to authenticate with.
12039 12040 12041 |
# File 'lib/models/porcelain.rb', line 12039 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12075 12076 12077 12078 12079 12080 12081 |
# File 'lib/models/porcelain.rb', line 12075 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |