Class: SDM::Trino
- Inherits:
-
Object
- Object
- SDM::Trino
- Defined in:
- lib/models/porcelain.rb
Overview
Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
constructor
A new instance of Trino.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
Returns a new instance of Trino.
11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 11711 11712 11713 11714 11715 11716 11717 11718 |
# File 'lib/models/porcelain.rb', line 11688 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11660 11661 11662 |
# File 'lib/models/porcelain.rb', line 11660 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
11662 11663 11664 |
# File 'lib/models/porcelain.rb', line 11662 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11664 11665 11666 |
# File 'lib/models/porcelain.rb', line 11664 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11666 11667 11668 |
# File 'lib/models/porcelain.rb', line 11666 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11668 11669 11670 |
# File 'lib/models/porcelain.rb', line 11668 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11670 11671 11672 |
# File 'lib/models/porcelain.rb', line 11670 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11672 11673 11674 |
# File 'lib/models/porcelain.rb', line 11672 def name @name end |
#password ⇒ Object
The password to authenticate with.
11674 11675 11676 |
# File 'lib/models/porcelain.rb', line 11674 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11676 11677 11678 |
# File 'lib/models/porcelain.rb', line 11676 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11678 11679 11680 |
# File 'lib/models/porcelain.rb', line 11678 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11680 11681 11682 |
# File 'lib/models/porcelain.rb', line 11680 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11682 11683 11684 |
# File 'lib/models/porcelain.rb', line 11682 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11684 11685 11686 |
# File 'lib/models/porcelain.rb', line 11684 def @tags end |
#username ⇒ Object
The username to authenticate with.
11686 11687 11688 |
# File 'lib/models/porcelain.rb', line 11686 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11720 11721 11722 11723 11724 11725 11726 |
# File 'lib/models/porcelain.rb', line 11720 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |