Class: SDM::Trino
- Inherits:
-
Object
- Object
- SDM::Trino
- Defined in:
- lib/models/porcelain.rb
Overview
Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
constructor
A new instance of Trino.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
Returns a new instance of Trino.
11519 11520 11521 11522 11523 11524 11525 11526 11527 11528 11529 11530 11531 11532 11533 11534 11535 11536 11537 11538 11539 11540 11541 11542 11543 11544 11545 11546 11547 11548 11549 |
# File 'lib/models/porcelain.rb', line 11519 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11491 11492 11493 |
# File 'lib/models/porcelain.rb', line 11491 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
11493 11494 11495 |
# File 'lib/models/porcelain.rb', line 11493 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11495 11496 11497 |
# File 'lib/models/porcelain.rb', line 11495 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11497 11498 11499 |
# File 'lib/models/porcelain.rb', line 11497 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11499 11500 11501 |
# File 'lib/models/porcelain.rb', line 11499 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11501 11502 11503 |
# File 'lib/models/porcelain.rb', line 11501 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11503 11504 11505 |
# File 'lib/models/porcelain.rb', line 11503 def name @name end |
#password ⇒ Object
The password to authenticate with.
11505 11506 11507 |
# File 'lib/models/porcelain.rb', line 11505 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11507 11508 11509 |
# File 'lib/models/porcelain.rb', line 11507 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11509 11510 11511 |
# File 'lib/models/porcelain.rb', line 11509 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11511 11512 11513 |
# File 'lib/models/porcelain.rb', line 11511 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11513 11514 11515 |
# File 'lib/models/porcelain.rb', line 11513 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11515 11516 11517 |
# File 'lib/models/porcelain.rb', line 11515 def @tags end |
#username ⇒ Object
The username to authenticate with.
11517 11518 11519 |
# File 'lib/models/porcelain.rb', line 11517 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11551 11552 11553 11554 11555 11556 11557 |
# File 'lib/models/porcelain.rb', line 11551 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |