Class: SDM::Trino
- Inherits:
-
Object
- Object
- SDM::Trino
- Defined in:
- lib/models/porcelain.rb
Overview
Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
constructor
A new instance of Trino.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
Returns a new instance of Trino.
11348 11349 11350 11351 11352 11353 11354 11355 11356 11357 11358 11359 11360 11361 11362 11363 11364 11365 11366 11367 11368 11369 11370 11371 11372 11373 11374 11375 11376 11377 11378 |
# File 'lib/models/porcelain.rb', line 11348 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11320 11321 11322 |
# File 'lib/models/porcelain.rb', line 11320 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
11322 11323 11324 |
# File 'lib/models/porcelain.rb', line 11322 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11324 11325 11326 |
# File 'lib/models/porcelain.rb', line 11324 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11326 11327 11328 |
# File 'lib/models/porcelain.rb', line 11326 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11328 11329 11330 |
# File 'lib/models/porcelain.rb', line 11328 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11330 11331 11332 |
# File 'lib/models/porcelain.rb', line 11330 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11332 11333 11334 |
# File 'lib/models/porcelain.rb', line 11332 def name @name end |
#password ⇒ Object
The password to authenticate with.
11334 11335 11336 |
# File 'lib/models/porcelain.rb', line 11334 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11336 11337 11338 |
# File 'lib/models/porcelain.rb', line 11336 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11338 11339 11340 |
# File 'lib/models/porcelain.rb', line 11338 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11340 11341 11342 |
# File 'lib/models/porcelain.rb', line 11340 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11342 11343 11344 |
# File 'lib/models/porcelain.rb', line 11342 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11344 11345 11346 |
# File 'lib/models/porcelain.rb', line 11344 def @tags end |
#username ⇒ Object
The username to authenticate with.
11346 11347 11348 |
# File 'lib/models/porcelain.rb', line 11346 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11380 11381 11382 11383 11384 11385 11386 |
# File 'lib/models/porcelain.rb', line 11380 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |