Class: SDM::Trino
- Inherits:
-
Object
- Object
- SDM::Trino
- Defined in:
- lib/models/porcelain.rb
Overview
Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
constructor
A new instance of Trino.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
Returns a new instance of Trino.
11131 11132 11133 11134 11135 11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 11151 11152 11153 11154 11155 11156 11157 11158 11159 11160 11161 |
# File 'lib/models/porcelain.rb', line 11131 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11103 11104 11105 |
# File 'lib/models/porcelain.rb', line 11103 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
11105 11106 11107 |
# File 'lib/models/porcelain.rb', line 11105 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11107 11108 11109 |
# File 'lib/models/porcelain.rb', line 11107 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11109 11110 11111 |
# File 'lib/models/porcelain.rb', line 11109 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11111 11112 11113 |
# File 'lib/models/porcelain.rb', line 11111 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11113 11114 11115 |
# File 'lib/models/porcelain.rb', line 11113 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11115 11116 11117 |
# File 'lib/models/porcelain.rb', line 11115 def name @name end |
#password ⇒ Object
The password to authenticate with.
11117 11118 11119 |
# File 'lib/models/porcelain.rb', line 11117 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11119 11120 11121 |
# File 'lib/models/porcelain.rb', line 11119 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11121 11122 11123 |
# File 'lib/models/porcelain.rb', line 11121 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11123 11124 11125 |
# File 'lib/models/porcelain.rb', line 11123 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11125 11126 11127 |
# File 'lib/models/porcelain.rb', line 11125 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11127 11128 11129 |
# File 'lib/models/porcelain.rb', line 11127 def @tags end |
#username ⇒ Object
The username to authenticate with.
11129 11130 11131 |
# File 'lib/models/porcelain.rb', line 11129 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11163 11164 11165 11166 11167 11168 11169 |
# File 'lib/models/porcelain.rb', line 11163 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |