Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
9287
9288
9289
9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
# File 'lib/models/porcelain.rb', line 9274

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9246
9247
9248
# File 'lib/models/porcelain.rb', line 9246

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



9248
9249
9250
# File 'lib/models/porcelain.rb', line 9248

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9250
9251
9252
# File 'lib/models/porcelain.rb', line 9250

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9252
9253
9254
# File 'lib/models/porcelain.rb', line 9252

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9254
9255
9256
# File 'lib/models/porcelain.rb', line 9254

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9256
9257
9258
# File 'lib/models/porcelain.rb', line 9256

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9258
9259
9260
# File 'lib/models/porcelain.rb', line 9258

def name
  @name
end

#passwordObject

The password to authenticate with.



9260
9261
9262
# File 'lib/models/porcelain.rb', line 9260

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9262
9263
9264
# File 'lib/models/porcelain.rb', line 9262

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9264
9265
9266
# File 'lib/models/porcelain.rb', line 9264

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9266
9267
9268
# File 'lib/models/porcelain.rb', line 9266

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9268
9269
9270
# File 'lib/models/porcelain.rb', line 9268

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9270
9271
9272
# File 'lib/models/porcelain.rb', line 9270

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9272
9273
9274
# File 'lib/models/porcelain.rb', line 9272

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9306
9307
9308
9309
9310
9311
9312
# File 'lib/models/porcelain.rb', line 9306

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end