Class: SDM::Trino
- Inherits:
-
Object
- Object
- SDM::Trino
- Defined in:
- lib/models/porcelain.rb
Overview
Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
constructor
A new instance of Trino.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
Returns a new instance of Trino.
9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 9133 9134 9135 9136 9137 9138 9139 9140 |
# File 'lib/models/porcelain.rb', line 9110 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9082 9083 9084 |
# File 'lib/models/porcelain.rb', line 9082 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
9084 9085 9086 |
# File 'lib/models/porcelain.rb', line 9084 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9086 9087 9088 |
# File 'lib/models/porcelain.rb', line 9086 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9088 9089 9090 |
# File 'lib/models/porcelain.rb', line 9088 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9090 9091 9092 |
# File 'lib/models/porcelain.rb', line 9090 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9092 9093 9094 |
# File 'lib/models/porcelain.rb', line 9092 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9094 9095 9096 |
# File 'lib/models/porcelain.rb', line 9094 def name @name end |
#password ⇒ Object
The password to authenticate with.
9096 9097 9098 |
# File 'lib/models/porcelain.rb', line 9096 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9098 9099 9100 |
# File 'lib/models/porcelain.rb', line 9098 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9100 9101 9102 |
# File 'lib/models/porcelain.rb', line 9100 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9102 9103 9104 |
# File 'lib/models/porcelain.rb', line 9102 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9104 9105 9106 |
# File 'lib/models/porcelain.rb', line 9104 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9106 9107 9108 |
# File 'lib/models/porcelain.rb', line 9106 def @tags end |
#username ⇒ Object
The username to authenticate with.
9108 9109 9110 |
# File 'lib/models/porcelain.rb', line 9108 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9142 9143 9144 9145 9146 9147 9148 |
# File 'lib/models/porcelain.rb', line 9142 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |