Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
8516
8517
8518
8519
8520
8521
8522
8523
8524
8525
8526
8527
# File 'lib/models/porcelain.rb', line 8497

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



8469
8470
8471
# File 'lib/models/porcelain.rb', line 8469

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



8471
8472
8473
# File 'lib/models/porcelain.rb', line 8471

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8473
8474
8475
# File 'lib/models/porcelain.rb', line 8473

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8475
8476
8477
# File 'lib/models/porcelain.rb', line 8475

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



8477
8478
8479
# File 'lib/models/porcelain.rb', line 8477

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8479
8480
8481
# File 'lib/models/porcelain.rb', line 8479

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8481
8482
8483
# File 'lib/models/porcelain.rb', line 8481

def name
  @name
end

#passwordObject

Returns the value of attribute password.



8483
8484
8485
# File 'lib/models/porcelain.rb', line 8483

def password
  @password
end

#portObject

Returns the value of attribute port.



8485
8486
8487
# File 'lib/models/porcelain.rb', line 8485

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



8487
8488
8489
# File 'lib/models/porcelain.rb', line 8487

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8489
8490
8491
# File 'lib/models/porcelain.rb', line 8489

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8491
8492
8493
# File 'lib/models/porcelain.rb', line 8491

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8493
8494
8495
# File 'lib/models/porcelain.rb', line 8493

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



8495
8496
8497
# File 'lib/models/porcelain.rb', line 8495

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8529
8530
8531
8532
8533
8534
8535
# File 'lib/models/porcelain.rb', line 8529

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end