Class: SDM::Trino
- Inherits:
-
Object
- Object
- SDM::Trino
- Defined in:
- lib/models/porcelain.rb
Overview
Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
constructor
A new instance of Trino.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino
Returns a new instance of Trino.
8433 8434 8435 8436 8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/models/porcelain.rb', line 8433 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
8405 8406 8407 |
# File 'lib/models/porcelain.rb', line 8405 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
8407 8408 8409 |
# File 'lib/models/porcelain.rb', line 8407 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8409 8410 8411 |
# File 'lib/models/porcelain.rb', line 8409 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8411 8412 8413 |
# File 'lib/models/porcelain.rb', line 8411 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
8413 8414 8415 |
# File 'lib/models/porcelain.rb', line 8413 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8415 8416 8417 |
# File 'lib/models/porcelain.rb', line 8415 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8417 8418 8419 |
# File 'lib/models/porcelain.rb', line 8417 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
8419 8420 8421 |
# File 'lib/models/porcelain.rb', line 8419 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
8421 8422 8423 |
# File 'lib/models/porcelain.rb', line 8421 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
8423 8424 8425 |
# File 'lib/models/porcelain.rb', line 8423 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8425 8426 8427 |
# File 'lib/models/porcelain.rb', line 8425 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8427 8428 8429 |
# File 'lib/models/porcelain.rb', line 8427 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8429 8430 8431 |
# File 'lib/models/porcelain.rb', line 8429 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
8431 8432 8433 |
# File 'lib/models/porcelain.rb', line 8431 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8465 8466 8467 8468 8469 8470 8471 |
# File 'lib/models/porcelain.rb', line 8465 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |