Class: SDM::Trino

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Trino is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Trino

Returns a new instance of Trino.



8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
8286
8287
8288
8289
# File 'lib/models/porcelain.rb', line 8259

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



8231
8232
8233
# File 'lib/models/porcelain.rb', line 8231

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



8233
8234
8235
# File 'lib/models/porcelain.rb', line 8233

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8235
8236
8237
# File 'lib/models/porcelain.rb', line 8235

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8237
8238
8239
# File 'lib/models/porcelain.rb', line 8237

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



8239
8240
8241
# File 'lib/models/porcelain.rb', line 8239

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8241
8242
8243
# File 'lib/models/porcelain.rb', line 8241

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8243
8244
8245
# File 'lib/models/porcelain.rb', line 8243

def name
  @name
end

#passwordObject

Returns the value of attribute password.



8245
8246
8247
# File 'lib/models/porcelain.rb', line 8245

def password
  @password
end

#portObject

Returns the value of attribute port.



8247
8248
8249
# File 'lib/models/porcelain.rb', line 8247

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



8249
8250
8251
# File 'lib/models/porcelain.rb', line 8249

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8251
8252
8253
# File 'lib/models/porcelain.rb', line 8251

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8253
8254
8255
# File 'lib/models/porcelain.rb', line 8253

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8255
8256
8257
# File 'lib/models/porcelain.rb', line 8255

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



8257
8258
8259
# File 'lib/models/porcelain.rb', line 8257

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8291
8292
8293
8294
8295
8296
8297
# File 'lib/models/porcelain.rb', line 8291

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end