Class: SDM::VaultAWSEC2CertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAWSEC2CertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSEC2CertSSHStore
constructor
A new instance of VaultAWSEC2CertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSEC2CertSSHStore
Returns a new instance of VaultAWSEC2CertSSHStore.
18128 18129 18130 18131 18132 18133 18134 18135 18136 18137 18138 18139 18140 18141 18142 18143 18144 18145 18146 |
# File 'lib/models/porcelain.rb', line 18128 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18112 18113 18114 |
# File 'lib/models/porcelain.rb', line 18112 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
18114 18115 18116 |
# File 'lib/models/porcelain.rb', line 18114 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18116 18117 18118 |
# File 'lib/models/porcelain.rb', line 18116 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18118 18119 18120 |
# File 'lib/models/porcelain.rb', line 18118 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18120 18121 18122 |
# File 'lib/models/porcelain.rb', line 18120 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18122 18123 18124 |
# File 'lib/models/porcelain.rb', line 18122 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
18124 18125 18126 |
# File 'lib/models/porcelain.rb', line 18124 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18126 18127 18128 |
# File 'lib/models/porcelain.rb', line 18126 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18148 18149 18150 18151 18152 18153 18154 |
# File 'lib/models/porcelain.rb', line 18148 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |