Class: SDM::VaultAWSEC2CertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAWSEC2CertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSEC2CertSSHStore
constructor
A new instance of VaultAWSEC2CertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSEC2CertSSHStore
Returns a new instance of VaultAWSEC2CertSSHStore.
18004 18005 18006 18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/models/porcelain.rb', line 18004 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17988 17989 17990 |
# File 'lib/models/porcelain.rb', line 17988 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
17990 17991 17992 |
# File 'lib/models/porcelain.rb', line 17990 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17992 17993 17994 |
# File 'lib/models/porcelain.rb', line 17992 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17994 17995 17996 |
# File 'lib/models/porcelain.rb', line 17994 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
17996 17997 17998 |
# File 'lib/models/porcelain.rb', line 17996 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17998 17999 18000 |
# File 'lib/models/porcelain.rb', line 17998 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
18000 18001 18002 |
# File 'lib/models/porcelain.rb', line 18000 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18002 18003 18004 |
# File 'lib/models/porcelain.rb', line 18002 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18024 18025 18026 18027 18028 18029 18030 |
# File 'lib/models/porcelain.rb', line 18024 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |