Class: SDM::VaultAWSEC2CertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAWSEC2CertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSEC2CertSSHStore
constructor
A new instance of VaultAWSEC2CertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSEC2CertSSHStore
Returns a new instance of VaultAWSEC2CertSSHStore.
17700 17701 17702 17703 17704 17705 17706 17707 17708 17709 17710 17711 17712 17713 17714 17715 17716 17717 17718 |
# File 'lib/models/porcelain.rb', line 17700 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17684 17685 17686 |
# File 'lib/models/porcelain.rb', line 17684 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
17686 17687 17688 |
# File 'lib/models/porcelain.rb', line 17686 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17688 17689 17690 |
# File 'lib/models/porcelain.rb', line 17688 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17690 17691 17692 |
# File 'lib/models/porcelain.rb', line 17690 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
17692 17693 17694 |
# File 'lib/models/porcelain.rb', line 17692 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17694 17695 17696 |
# File 'lib/models/porcelain.rb', line 17694 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
17696 17697 17698 |
# File 'lib/models/porcelain.rb', line 17696 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17698 17699 17700 |
# File 'lib/models/porcelain.rb', line 17698 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17720 17721 17722 17723 17724 17725 17726 |
# File 'lib/models/porcelain.rb', line 17720 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |