Class: SDM::VaultAWSEC2CertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAWSEC2CertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSEC2CertSSHStore
constructor
A new instance of VaultAWSEC2CertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSEC2CertSSHStore
Returns a new instance of VaultAWSEC2CertSSHStore.
17627 17628 17629 17630 17631 17632 17633 17634 17635 17636 17637 17638 17639 17640 17641 17642 17643 17644 17645 |
# File 'lib/models/porcelain.rb', line 17627 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17611 17612 17613 |
# File 'lib/models/porcelain.rb', line 17611 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
17613 17614 17615 |
# File 'lib/models/porcelain.rb', line 17613 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17615 17616 17617 |
# File 'lib/models/porcelain.rb', line 17615 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17617 17618 17619 |
# File 'lib/models/porcelain.rb', line 17617 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
17619 17620 17621 |
# File 'lib/models/porcelain.rb', line 17619 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17621 17622 17623 |
# File 'lib/models/porcelain.rb', line 17621 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
17623 17624 17625 |
# File 'lib/models/porcelain.rb', line 17623 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17625 17626 17627 |
# File 'lib/models/porcelain.rb', line 17625 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17647 17648 17649 17650 17651 17652 17653 |
# File 'lib/models/porcelain.rb', line 17647 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |