Class: SDM::VaultAWSEC2CertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAWSEC2CertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSEC2CertSSHStore
constructor
A new instance of VaultAWSEC2CertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSEC2CertSSHStore
Returns a new instance of VaultAWSEC2CertSSHStore.
17257 17258 17259 17260 17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 |
# File 'lib/models/porcelain.rb', line 17257 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17241 17242 17243 |
# File 'lib/models/porcelain.rb', line 17241 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
17243 17244 17245 |
# File 'lib/models/porcelain.rb', line 17243 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17245 17246 17247 |
# File 'lib/models/porcelain.rb', line 17245 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17247 17248 17249 |
# File 'lib/models/porcelain.rb', line 17247 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
17249 17250 17251 |
# File 'lib/models/porcelain.rb', line 17249 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17251 17252 17253 |
# File 'lib/models/porcelain.rb', line 17251 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
17253 17254 17255 |
# File 'lib/models/porcelain.rb', line 17253 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17255 17256 17257 |
# File 'lib/models/porcelain.rb', line 17255 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17277 17278 17279 17280 17281 17282 17283 |
# File 'lib/models/porcelain.rb', line 17277 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |