Class: SDM::VaultAWSEC2CertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAWSEC2CertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
constructor
A new instance of VaultAWSEC2CertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
Returns a new instance of VaultAWSEC2CertX509Store.
18485 18486 18487 18488 18489 18490 18491 18492 18493 18494 18495 18496 18497 18498 18499 18500 18501 18502 18503 |
# File 'lib/models/porcelain.rb', line 18485 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18469 18470 18471 |
# File 'lib/models/porcelain.rb', line 18469 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18471 18472 18473 |
# File 'lib/models/porcelain.rb', line 18471 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18473 18474 18475 |
# File 'lib/models/porcelain.rb', line 18473 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18475 18476 18477 |
# File 'lib/models/porcelain.rb', line 18475 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18477 18478 18479 |
# File 'lib/models/porcelain.rb', line 18477 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18479 18480 18481 |
# File 'lib/models/porcelain.rb', line 18479 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18481 18482 18483 |
# File 'lib/models/porcelain.rb', line 18481 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18483 18484 18485 |
# File 'lib/models/porcelain.rb', line 18483 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18505 18506 18507 18508 18509 18510 18511 |
# File 'lib/models/porcelain.rb', line 18505 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |