Class: SDM::VaultAWSEC2CertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAWSEC2CertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
constructor
A new instance of VaultAWSEC2CertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
Returns a new instance of VaultAWSEC2CertX509Store.
18167 18168 18169 18170 18171 18172 18173 18174 18175 18176 18177 18178 18179 18180 18181 18182 18183 18184 18185 |
# File 'lib/models/porcelain.rb', line 18167 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18151 18152 18153 |
# File 'lib/models/porcelain.rb', line 18151 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18153 18154 18155 |
# File 'lib/models/porcelain.rb', line 18153 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18155 18156 18157 |
# File 'lib/models/porcelain.rb', line 18155 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18157 18158 18159 |
# File 'lib/models/porcelain.rb', line 18157 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18159 18160 18161 |
# File 'lib/models/porcelain.rb', line 18159 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18161 18162 18163 |
# File 'lib/models/porcelain.rb', line 18161 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18163 18164 18165 |
# File 'lib/models/porcelain.rb', line 18163 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18165 18166 18167 |
# File 'lib/models/porcelain.rb', line 18165 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18187 18188 18189 18190 18191 18192 18193 |
# File 'lib/models/porcelain.rb', line 18187 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |