Class: SDM::VaultAWSEC2CertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAWSEC2CertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
constructor
A new instance of VaultAWSEC2CertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
Returns a new instance of VaultAWSEC2CertX509Store.
18051 18052 18053 18054 18055 18056 18057 18058 18059 18060 18061 18062 18063 18064 18065 18066 18067 18068 18069 |
# File 'lib/models/porcelain.rb', line 18051 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18035 18036 18037 |
# File 'lib/models/porcelain.rb', line 18035 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18037 18038 18039 |
# File 'lib/models/porcelain.rb', line 18037 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18039 18040 18041 |
# File 'lib/models/porcelain.rb', line 18039 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18041 18042 18043 |
# File 'lib/models/porcelain.rb', line 18041 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18043 18044 18045 |
# File 'lib/models/porcelain.rb', line 18043 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18045 18046 18047 |
# File 'lib/models/porcelain.rb', line 18045 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18047 18048 18049 |
# File 'lib/models/porcelain.rb', line 18047 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18049 18050 18051 |
# File 'lib/models/porcelain.rb', line 18049 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18071 18072 18073 18074 18075 18076 18077 |
# File 'lib/models/porcelain.rb', line 18071 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |