Class: SDM::VaultAWSEC2CertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAWSEC2CertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
constructor
A new instance of VaultAWSEC2CertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
Returns a new instance of VaultAWSEC2CertX509Store.
17748 17749 17750 17751 17752 17753 17754 17755 17756 17757 17758 17759 17760 17761 17762 17763 17764 17765 17766 |
# File 'lib/models/porcelain.rb', line 17748 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17732 17733 17734 |
# File 'lib/models/porcelain.rb', line 17732 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
17734 17735 17736 |
# File 'lib/models/porcelain.rb', line 17734 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17736 17737 17738 |
# File 'lib/models/porcelain.rb', line 17736 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17738 17739 17740 |
# File 'lib/models/porcelain.rb', line 17738 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
17740 17741 17742 |
# File 'lib/models/porcelain.rb', line 17740 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
17742 17743 17744 |
# File 'lib/models/porcelain.rb', line 17742 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17744 17745 17746 |
# File 'lib/models/porcelain.rb', line 17744 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17746 17747 17748 |
# File 'lib/models/porcelain.rb', line 17746 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17768 17769 17770 17771 17772 17773 17774 |
# File 'lib/models/porcelain.rb', line 17768 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |