Class: SDM::VaultAWSEC2CertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAWSEC2CertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
constructor
A new instance of VaultAWSEC2CertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
Returns a new instance of VaultAWSEC2CertX509Store.
17674 17675 17676 17677 17678 17679 17680 17681 17682 17683 17684 17685 17686 17687 17688 17689 17690 17691 17692 |
# File 'lib/models/porcelain.rb', line 17674 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17658 17659 17660 |
# File 'lib/models/porcelain.rb', line 17658 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
17660 17661 17662 |
# File 'lib/models/porcelain.rb', line 17660 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17662 17663 17664 |
# File 'lib/models/porcelain.rb', line 17662 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17664 17665 17666 |
# File 'lib/models/porcelain.rb', line 17664 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
17666 17667 17668 |
# File 'lib/models/porcelain.rb', line 17666 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
17668 17669 17670 |
# File 'lib/models/porcelain.rb', line 17668 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17670 17671 17672 |
# File 'lib/models/porcelain.rb', line 17670 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17672 17673 17674 |
# File 'lib/models/porcelain.rb', line 17672 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17694 17695 17696 17697 17698 17699 17700 |
# File 'lib/models/porcelain.rb', line 17694 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |