Class: SDM::VaultAWSEC2CertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAWSEC2CertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
constructor
A new instance of VaultAWSEC2CertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
Returns a new instance of VaultAWSEC2CertX509Store.
17368 17369 17370 17371 17372 17373 17374 17375 17376 17377 17378 17379 17380 17381 17382 17383 17384 17385 17386 |
# File 'lib/models/porcelain.rb', line 17368 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17352 17353 17354 |
# File 'lib/models/porcelain.rb', line 17352 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
17354 17355 17356 |
# File 'lib/models/porcelain.rb', line 17354 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17356 17357 17358 |
# File 'lib/models/porcelain.rb', line 17356 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17358 17359 17360 |
# File 'lib/models/porcelain.rb', line 17358 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
17360 17361 17362 |
# File 'lib/models/porcelain.rb', line 17360 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
17362 17363 17364 |
# File 'lib/models/porcelain.rb', line 17362 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17364 17365 17366 |
# File 'lib/models/porcelain.rb', line 17364 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17366 17367 17368 |
# File 'lib/models/porcelain.rb', line 17366 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17388 17389 17390 17391 17392 17393 17394 |
# File 'lib/models/porcelain.rb', line 17388 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |