Class: SDM::VaultAWSEC2CertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAWSEC2CertX509Store
- Defined in:
- lib/models/porcelain.rb
Overview
VaultAWSEC2CertX509Store is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
constructor
A new instance of VaultAWSEC2CertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSEC2CertX509Store
Returns a new instance of VaultAWSEC2CertX509Store.
16370 16371 16372 16373 16374 16375 16376 16377 16378 16379 16380 16381 16382 16383 16384 16385 16386 16387 16388 |
# File 'lib/models/porcelain.rb', line 16370 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
16354 16355 16356 |
# File 'lib/models/porcelain.rb', line 16354 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
16356 16357 16358 |
# File 'lib/models/porcelain.rb', line 16356 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
16358 16359 16360 |
# File 'lib/models/porcelain.rb', line 16358 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
16360 16361 16362 |
# File 'lib/models/porcelain.rb', line 16360 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
16362 16363 16364 |
# File 'lib/models/porcelain.rb', line 16362 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
16364 16365 16366 |
# File 'lib/models/porcelain.rb', line 16364 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
16366 16367 16368 |
# File 'lib/models/porcelain.rb', line 16366 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
16368 16369 16370 |
# File 'lib/models/porcelain.rb', line 16368 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16390 16391 16392 16393 16394 16395 16396 |
# File 'lib/models/porcelain.rb', line 16390 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |