Class: SDM::VaultAWSIAMCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAWSIAMCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSIAMCertSSHStore
constructor
A new instance of VaultAWSIAMCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSIAMCertSSHStore
Returns a new instance of VaultAWSIAMCertSSHStore.
18567 18568 18569 18570 18571 18572 18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 |
# File 'lib/models/porcelain.rb', line 18567 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18551 18552 18553 |
# File 'lib/models/porcelain.rb', line 18551 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
18553 18554 18555 |
# File 'lib/models/porcelain.rb', line 18553 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18555 18556 18557 |
# File 'lib/models/porcelain.rb', line 18555 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18557 18558 18559 |
# File 'lib/models/porcelain.rb', line 18557 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18559 18560 18561 |
# File 'lib/models/porcelain.rb', line 18559 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18561 18562 18563 |
# File 'lib/models/porcelain.rb', line 18561 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
18563 18564 18565 |
# File 'lib/models/porcelain.rb', line 18563 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18565 18566 18567 |
# File 'lib/models/porcelain.rb', line 18565 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18587 18588 18589 18590 18591 18592 18593 |
# File 'lib/models/porcelain.rb', line 18587 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |