Class: SDM::VaultAWSIAMCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAWSIAMCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSIAMCertSSHStore
constructor
A new instance of VaultAWSIAMCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSIAMCertSSHStore
Returns a new instance of VaultAWSIAMCertSSHStore.
18483 18484 18485 18486 18487 18488 18489 18490 18491 18492 18493 18494 18495 18496 18497 18498 18499 18500 18501 |
# File 'lib/models/porcelain.rb', line 18483 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18467 18468 18469 |
# File 'lib/models/porcelain.rb', line 18467 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
18469 18470 18471 |
# File 'lib/models/porcelain.rb', line 18469 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18471 18472 18473 |
# File 'lib/models/porcelain.rb', line 18471 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18473 18474 18475 |
# File 'lib/models/porcelain.rb', line 18473 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18475 18476 18477 |
# File 'lib/models/porcelain.rb', line 18475 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18477 18478 18479 |
# File 'lib/models/porcelain.rb', line 18477 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
18479 18480 18481 |
# File 'lib/models/porcelain.rb', line 18479 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18481 18482 18483 |
# File 'lib/models/porcelain.rb', line 18481 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18503 18504 18505 18506 18507 18508 18509 |
# File 'lib/models/porcelain.rb', line 18503 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |