Class: SDM::VaultAWSIAMCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAWSIAMCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSIAMCertSSHStore
constructor
A new instance of VaultAWSIAMCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSIAMCertSSHStore
Returns a new instance of VaultAWSIAMCertSSHStore.
17450 17451 17452 17453 17454 17455 17456 17457 17458 17459 17460 17461 17462 17463 17464 17465 17466 17467 17468 |
# File 'lib/models/porcelain.rb', line 17450 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17434 17435 17436 |
# File 'lib/models/porcelain.rb', line 17434 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
17436 17437 17438 |
# File 'lib/models/porcelain.rb', line 17436 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17438 17439 17440 |
# File 'lib/models/porcelain.rb', line 17438 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17440 17441 17442 |
# File 'lib/models/porcelain.rb', line 17440 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
17442 17443 17444 |
# File 'lib/models/porcelain.rb', line 17442 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17444 17445 17446 |
# File 'lib/models/porcelain.rb', line 17444 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
17446 17447 17448 |
# File 'lib/models/porcelain.rb', line 17446 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17448 17449 17450 |
# File 'lib/models/porcelain.rb', line 17448 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17470 17471 17472 17473 17474 17475 17476 |
# File 'lib/models/porcelain.rb', line 17470 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |