Class: SDM::VaultAWSIAMCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAWSIAMCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSIAMCertSSHStore
constructor
A new instance of VaultAWSIAMCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSIAMCertSSHStore
Returns a new instance of VaultAWSIAMCertSSHStore.
17386 17387 17388 17389 17390 17391 17392 17393 17394 17395 17396 17397 17398 17399 17400 17401 17402 17403 17404 |
# File 'lib/models/porcelain.rb', line 17386 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17370 17371 17372 |
# File 'lib/models/porcelain.rb', line 17370 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
17372 17373 17374 |
# File 'lib/models/porcelain.rb', line 17372 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17374 17375 17376 |
# File 'lib/models/porcelain.rb', line 17374 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17376 17377 17378 |
# File 'lib/models/porcelain.rb', line 17376 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
17378 17379 17380 |
# File 'lib/models/porcelain.rb', line 17378 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17380 17381 17382 |
# File 'lib/models/porcelain.rb', line 17380 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
17382 17383 17384 |
# File 'lib/models/porcelain.rb', line 17382 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17384 17385 17386 |
# File 'lib/models/porcelain.rb', line 17384 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17406 17407 17408 17409 17410 17411 17412 |
# File 'lib/models/porcelain.rb', line 17406 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |