Class: SDM::VaultAWSIAMCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

VaultAWSIAMCertSSHStore is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSIAMCertSSHStore

Returns a new instance of VaultAWSIAMCertSSHStore.



16453
16454
16455
16456
16457
16458
16459
16460
16461
16462
16463
16464
16465
16466
16467
16468
16469
16470
16471
# File 'lib/models/porcelain.rb', line 16453

def initialize(
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the SecretStore.



16437
16438
16439
# File 'lib/models/porcelain.rb', line 16437

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA in minutes. Recommended value is 5.



16439
16440
16441
# File 'lib/models/porcelain.rb', line 16439

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



16441
16442
16443
# File 'lib/models/porcelain.rb', line 16441

def name
  @name
end

#namespaceObject

The namespace to make requests within



16443
16444
16445
# File 'lib/models/porcelain.rb', line 16443

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



16445
16446
16447
# File 'lib/models/porcelain.rb', line 16445

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



16447
16448
16449
# File 'lib/models/porcelain.rb', line 16447

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



16449
16450
16451
# File 'lib/models/porcelain.rb', line 16449

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



16451
16452
16453
# File 'lib/models/porcelain.rb', line 16451

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16473
16474
16475
16476
16477
16478
16479
# File 'lib/models/porcelain.rb', line 16473

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end