Class: SDM::VaultAWSIAMCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAWSIAMCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSIAMCertX509Store
constructor
A new instance of VaultAWSIAMCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSIAMCertX509Store
Returns a new instance of VaultAWSIAMCertX509Store.
17876 17877 17878 17879 17880 17881 17882 17883 17884 17885 17886 17887 17888 17889 17890 17891 17892 17893 17894 |
# File 'lib/models/porcelain.rb', line 17876 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17860 17861 17862 |
# File 'lib/models/porcelain.rb', line 17860 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
17862 17863 17864 |
# File 'lib/models/porcelain.rb', line 17862 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17864 17865 17866 |
# File 'lib/models/porcelain.rb', line 17864 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17866 17867 17868 |
# File 'lib/models/porcelain.rb', line 17866 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
17868 17869 17870 |
# File 'lib/models/porcelain.rb', line 17868 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
17870 17871 17872 |
# File 'lib/models/porcelain.rb', line 17870 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17872 17873 17874 |
# File 'lib/models/porcelain.rb', line 17872 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17874 17875 17876 |
# File 'lib/models/porcelain.rb', line 17874 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17896 17897 17898 17899 17900 17901 17902 |
# File 'lib/models/porcelain.rb', line 17896 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |