Class: SDM::VaultAWSIAMCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAWSIAMCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSIAMCertX509Store
constructor
A new instance of VaultAWSIAMCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSIAMCertX509Store
Returns a new instance of VaultAWSIAMCertX509Store.
17497 17498 17499 17500 17501 17502 17503 17504 17505 17506 17507 17508 17509 17510 17511 17512 17513 17514 17515 |
# File 'lib/models/porcelain.rb', line 17497 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17481 17482 17483 |
# File 'lib/models/porcelain.rb', line 17481 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
17483 17484 17485 |
# File 'lib/models/porcelain.rb', line 17483 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17485 17486 17487 |
# File 'lib/models/porcelain.rb', line 17485 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17487 17488 17489 |
# File 'lib/models/porcelain.rb', line 17487 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
17489 17490 17491 |
# File 'lib/models/porcelain.rb', line 17489 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
17491 17492 17493 |
# File 'lib/models/porcelain.rb', line 17491 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17493 17494 17495 |
# File 'lib/models/porcelain.rb', line 17493 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17495 17496 17497 |
# File 'lib/models/porcelain.rb', line 17495 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17517 17518 17519 17520 17521 17522 17523 |
# File 'lib/models/porcelain.rb', line 17517 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |