Class: SDM::VaultAWSIAMCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

VaultAWSIAMCertX509Store is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSIAMCertX509Store

Returns a new instance of VaultAWSIAMCertX509Store.



16501
16502
16503
16504
16505
16506
16507
16508
16509
16510
16511
16512
16513
16514
16515
16516
16517
16518
16519
# File 'lib/models/porcelain.rb', line 16501

def initialize(
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the SecretStore.



16485
16486
16487
# File 'lib/models/porcelain.rb', line 16485

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



16487
16488
16489
# File 'lib/models/porcelain.rb', line 16487

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



16489
16490
16491
# File 'lib/models/porcelain.rb', line 16489

def name
  @name
end

#namespaceObject

The namespace to make requests within



16491
16492
16493
# File 'lib/models/porcelain.rb', line 16491

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



16493
16494
16495
# File 'lib/models/porcelain.rb', line 16493

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



16495
16496
16497
# File 'lib/models/porcelain.rb', line 16495

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



16497
16498
16499
# File 'lib/models/porcelain.rb', line 16497

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



16499
16500
16501
# File 'lib/models/porcelain.rb', line 16499

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16521
16522
16523
16524
16525
16526
16527
# File 'lib/models/porcelain.rb', line 16521

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end