Class: SDM::VaultAppRoleCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAppRoleCertSSHStore
constructor
A new instance of VaultAppRoleCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAppRoleCertSSHStore
Returns a new instance of VaultAppRoleCertSSHStore.
18744 18745 18746 18747 18748 18749 18750 18751 18752 18753 18754 18755 18756 18757 18758 18759 18760 18761 18762 |
# File 'lib/models/porcelain.rb', line 18744 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18728 18729 18730 |
# File 'lib/models/porcelain.rb', line 18728 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18730 18731 18732 |
# File 'lib/models/porcelain.rb', line 18730 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18732 18733 18734 |
# File 'lib/models/porcelain.rb', line 18732 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18734 18735 18736 |
# File 'lib/models/porcelain.rb', line 18734 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18736 18737 18738 |
# File 'lib/models/porcelain.rb', line 18736 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18738 18739 18740 |
# File 'lib/models/porcelain.rb', line 18738 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
18740 18741 18742 |
# File 'lib/models/porcelain.rb', line 18740 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18742 18743 18744 |
# File 'lib/models/porcelain.rb', line 18742 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18764 18765 18766 18767 18768 18769 18770 |
# File 'lib/models/porcelain.rb', line 18764 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |