Class: SDM::VaultAppRoleCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAppRoleCertSSHStore
constructor
A new instance of VaultAppRoleCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAppRoleCertSSHStore
Returns a new instance of VaultAppRoleCertSSHStore.
18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 18272 18273 18274 18275 18276 18277 18278 18279 18280 |
# File 'lib/models/porcelain.rb', line 18262 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18246 18247 18248 |
# File 'lib/models/porcelain.rb', line 18246 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18248 18249 18250 |
# File 'lib/models/porcelain.rb', line 18248 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18250 18251 18252 |
# File 'lib/models/porcelain.rb', line 18250 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18252 18253 18254 |
# File 'lib/models/porcelain.rb', line 18252 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18254 18255 18256 |
# File 'lib/models/porcelain.rb', line 18254 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18256 18257 18258 |
# File 'lib/models/porcelain.rb', line 18256 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
18258 18259 18260 |
# File 'lib/models/porcelain.rb', line 18258 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18260 18261 18262 |
# File 'lib/models/porcelain.rb', line 18260 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18282 18283 18284 18285 18286 18287 18288 |
# File 'lib/models/porcelain.rb', line 18282 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |