Class: SDM::VaultAppRoleCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAppRoleCertSSHStore
constructor
A new instance of VaultAppRoleCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAppRoleCertSSHStore
Returns a new instance of VaultAppRoleCertSSHStore.
14661 14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 |
# File 'lib/models/porcelain.rb', line 14661 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
14645 14646 14647 |
# File 'lib/models/porcelain.rb', line 14645 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
14647 14648 14649 |
# File 'lib/models/porcelain.rb', line 14647 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
14649 14650 14651 |
# File 'lib/models/porcelain.rb', line 14649 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
14651 14652 14653 |
# File 'lib/models/porcelain.rb', line 14651 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
14653 14654 14655 |
# File 'lib/models/porcelain.rb', line 14653 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
14655 14656 14657 |
# File 'lib/models/porcelain.rb', line 14655 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
14657 14658 14659 |
# File 'lib/models/porcelain.rb', line 14657 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14659 14660 14661 |
# File 'lib/models/porcelain.rb', line 14659 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14681 14682 14683 14684 14685 14686 14687 |
# File 'lib/models/porcelain.rb', line 14681 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |