Class: SDM::VaultAppRoleCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAppRoleCertSSHStore
constructor
A new instance of VaultAppRoleCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAppRoleCertSSHStore
Returns a new instance of VaultAppRoleCertSSHStore.
17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 17977 17978 17979 17980 17981 17982 17983 17984 |
# File 'lib/models/porcelain.rb', line 17966 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17950 17951 17952 |
# File 'lib/models/porcelain.rb', line 17950 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
17952 17953 17954 |
# File 'lib/models/porcelain.rb', line 17952 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17954 17955 17956 |
# File 'lib/models/porcelain.rb', line 17954 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17956 17957 17958 |
# File 'lib/models/porcelain.rb', line 17956 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
17958 17959 17960 |
# File 'lib/models/porcelain.rb', line 17958 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17960 17961 17962 |
# File 'lib/models/porcelain.rb', line 17960 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
17962 17963 17964 |
# File 'lib/models/porcelain.rb', line 17962 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17964 17965 17966 |
# File 'lib/models/porcelain.rb', line 17964 def end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17986 17987 17988 17989 17990 17991 17992 |
# File 'lib/models/porcelain.rb', line 17986 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |