Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
18791 18792 18793 18794 18795 18796 18797 18798 18799 18800 18801 18802 18803 18804 18805 18806 18807 18808 18809 |
# File 'lib/models/porcelain.rb', line 18791 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18775 18776 18777 |
# File 'lib/models/porcelain.rb', line 18775 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
18777 18778 18779 |
# File 'lib/models/porcelain.rb', line 18777 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18779 18780 18781 |
# File 'lib/models/porcelain.rb', line 18779 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18781 18782 18783 |
# File 'lib/models/porcelain.rb', line 18781 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18783 18784 18785 |
# File 'lib/models/porcelain.rb', line 18783 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18785 18786 18787 |
# File 'lib/models/porcelain.rb', line 18785 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18787 18788 18789 |
# File 'lib/models/porcelain.rb', line 18787 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18789 18790 18791 |
# File 'lib/models/porcelain.rb', line 18789 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18811 18812 18813 18814 18815 18816 18817 |
# File 'lib/models/porcelain.rb', line 18811 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |