Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
18743 18744 18745 18746 18747 18748 18749 18750 18751 18752 18753 18754 18755 18756 18757 18758 18759 18760 18761 |
# File 'lib/models/porcelain.rb', line 18743 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18727 18728 18729 |
# File 'lib/models/porcelain.rb', line 18727 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
18729 18730 18731 |
# File 'lib/models/porcelain.rb', line 18729 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18731 18732 18733 |
# File 'lib/models/porcelain.rb', line 18731 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18733 18734 18735 |
# File 'lib/models/porcelain.rb', line 18733 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18735 18736 18737 |
# File 'lib/models/porcelain.rb', line 18735 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18737 18738 18739 |
# File 'lib/models/porcelain.rb', line 18737 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18739 18740 18741 |
# File 'lib/models/porcelain.rb', line 18739 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18741 18742 18743 |
# File 'lib/models/porcelain.rb', line 18741 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18763 18764 18765 18766 18767 18768 18769 |
# File 'lib/models/porcelain.rb', line 18763 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |