Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
18433 18434 18435 18436 18437 18438 18439 18440 18441 18442 18443 18444 18445 18446 18447 18448 18449 18450 18451 |
# File 'lib/models/porcelain.rb', line 18433 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18417 18418 18419 |
# File 'lib/models/porcelain.rb', line 18417 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
18419 18420 18421 |
# File 'lib/models/porcelain.rb', line 18419 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18421 18422 18423 |
# File 'lib/models/porcelain.rb', line 18421 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18423 18424 18425 |
# File 'lib/models/porcelain.rb', line 18423 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18425 18426 18427 |
# File 'lib/models/porcelain.rb', line 18425 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18427 18428 18429 |
# File 'lib/models/porcelain.rb', line 18427 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18429 18430 18431 |
# File 'lib/models/porcelain.rb', line 18429 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18431 18432 18433 |
# File 'lib/models/porcelain.rb', line 18431 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18453 18454 18455 18456 18457 18458 18459 |
# File 'lib/models/porcelain.rb', line 18453 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |