Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
18309 18310 18311 18312 18313 18314 18315 18316 18317 18318 18319 18320 18321 18322 18323 18324 18325 18326 18327 |
# File 'lib/models/porcelain.rb', line 18309 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18293 18294 18295 |
# File 'lib/models/porcelain.rb', line 18293 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
18295 18296 18297 |
# File 'lib/models/porcelain.rb', line 18295 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18297 18298 18299 |
# File 'lib/models/porcelain.rb', line 18297 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18299 18300 18301 |
# File 'lib/models/porcelain.rb', line 18299 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18301 18302 18303 |
# File 'lib/models/porcelain.rb', line 18301 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18303 18304 18305 |
# File 'lib/models/porcelain.rb', line 18303 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18305 18306 18307 |
# File 'lib/models/porcelain.rb', line 18305 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18307 18308 18309 |
# File 'lib/models/porcelain.rb', line 18307 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18329 18330 18331 18332 18333 18334 18335 |
# File 'lib/models/porcelain.rb', line 18329 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |