Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 17949 17950 |
# File 'lib/models/porcelain.rb', line 17932 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17916 17917 17918 |
# File 'lib/models/porcelain.rb', line 17916 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
17918 17919 17920 |
# File 'lib/models/porcelain.rb', line 17918 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17920 17921 17922 |
# File 'lib/models/porcelain.rb', line 17920 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17922 17923 17924 |
# File 'lib/models/porcelain.rb', line 17922 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
17924 17925 17926 |
# File 'lib/models/porcelain.rb', line 17924 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
17926 17927 17928 |
# File 'lib/models/porcelain.rb', line 17926 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17928 17929 17930 |
# File 'lib/models/porcelain.rb', line 17928 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17930 17931 17932 |
# File 'lib/models/porcelain.rb', line 17930 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17952 17953 17954 17955 17956 17957 17958 |
# File 'lib/models/porcelain.rb', line 17952 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |