Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
17912 17913 17914 17915 17916 17917 17918 17919 17920 17921 17922 17923 17924 17925 17926 17927 17928 17929 17930 |
# File 'lib/models/porcelain.rb', line 17912 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17896 17897 17898 |
# File 'lib/models/porcelain.rb', line 17896 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
17898 17899 17900 |
# File 'lib/models/porcelain.rb', line 17898 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17900 17901 17902 |
# File 'lib/models/porcelain.rb', line 17900 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17902 17903 17904 |
# File 'lib/models/porcelain.rb', line 17902 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
17904 17905 17906 |
# File 'lib/models/porcelain.rb', line 17904 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
17906 17907 17908 |
# File 'lib/models/porcelain.rb', line 17906 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17908 17909 17910 |
# File 'lib/models/porcelain.rb', line 17908 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17910 17911 17912 |
# File 'lib/models/porcelain.rb', line 17910 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17932 17933 17934 17935 17936 17937 17938 |
# File 'lib/models/porcelain.rb', line 17932 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |