Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
17626 17627 17628 17629 17630 17631 17632 17633 17634 17635 17636 17637 17638 17639 17640 17641 17642 17643 17644 |
# File 'lib/models/porcelain.rb', line 17626 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
17610 17611 17612 |
# File 'lib/models/porcelain.rb', line 17610 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
17612 17613 17614 |
# File 'lib/models/porcelain.rb', line 17612 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
17614 17615 17616 |
# File 'lib/models/porcelain.rb', line 17614 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
17616 17617 17618 |
# File 'lib/models/porcelain.rb', line 17616 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
17618 17619 17620 |
# File 'lib/models/porcelain.rb', line 17618 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
17620 17621 17622 |
# File 'lib/models/porcelain.rb', line 17620 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
17622 17623 17624 |
# File 'lib/models/porcelain.rb', line 17622 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
17624 17625 17626 |
# File 'lib/models/porcelain.rb', line 17624 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17646 17647 17648 17649 17650 17651 17652 |
# File 'lib/models/porcelain.rb', line 17646 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |