Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
16630 16631 16632 16633 16634 16635 16636 16637 16638 16639 16640 16641 16642 16643 16644 16645 16646 16647 16648 |
# File 'lib/models/porcelain.rb', line 16630 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
16614 16615 16616 |
# File 'lib/models/porcelain.rb', line 16614 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
16616 16617 16618 |
# File 'lib/models/porcelain.rb', line 16616 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
16618 16619 16620 |
# File 'lib/models/porcelain.rb', line 16618 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
16620 16621 16622 |
# File 'lib/models/porcelain.rb', line 16620 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
16622 16623 16624 |
# File 'lib/models/porcelain.rb', line 16622 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
16624 16625 16626 |
# File 'lib/models/porcelain.rb', line 16624 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
16626 16627 16628 |
# File 'lib/models/porcelain.rb', line 16626 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
16628 16629 16630 |
# File 'lib/models/porcelain.rb', line 16628 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16650 16651 16652 16653 16654 16655 16656 |
# File 'lib/models/porcelain.rb', line 16650 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |