Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
14928 14929 14930 14931 14932 14933 14934 14935 14936 14937 14938 14939 14940 14941 14942 14943 14944 14945 14946 |
# File 'lib/models/porcelain.rb', line 14928 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
14912 14913 14914 |
# File 'lib/models/porcelain.rb', line 14912 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
14914 14915 14916 |
# File 'lib/models/porcelain.rb', line 14914 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
14916 14917 14918 |
# File 'lib/models/porcelain.rb', line 14916 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
14918 14919 14920 |
# File 'lib/models/porcelain.rb', line 14918 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
14920 14921 14922 |
# File 'lib/models/porcelain.rb', line 14920 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
14922 14923 14924 |
# File 'lib/models/porcelain.rb', line 14922 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
14924 14925 14926 |
# File 'lib/models/porcelain.rb', line 14924 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14926 14927 14928 |
# File 'lib/models/porcelain.rb', line 14926 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14948 14949 14950 14951 14952 14953 14954 |
# File 'lib/models/porcelain.rb', line 14948 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |