Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
13532 13533 13534 13535 13536 13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 |
# File 'lib/models/porcelain.rb', line 13532 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
13516 13517 13518 |
# File 'lib/models/porcelain.rb', line 13516 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
13518 13519 13520 |
# File 'lib/models/porcelain.rb', line 13518 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13520 13521 13522 |
# File 'lib/models/porcelain.rb', line 13520 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13522 13523 13524 |
# File 'lib/models/porcelain.rb', line 13522 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
13524 13525 13526 |
# File 'lib/models/porcelain.rb', line 13524 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
13526 13527 13528 |
# File 'lib/models/porcelain.rb', line 13526 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
13528 13529 13530 |
# File 'lib/models/porcelain.rb', line 13528 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13530 13531 13532 |
# File 'lib/models/porcelain.rb', line 13530 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13552 13553 13554 13555 13556 13557 13558 |
# File 'lib/models/porcelain.rb', line 13552 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |