Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
13449 13450 13451 13452 13453 13454 13455 13456 13457 13458 13459 13460 13461 13462 13463 13464 13465 13466 13467 |
# File 'lib/models/porcelain.rb', line 13449 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
13433 13434 13435 |
# File 'lib/models/porcelain.rb', line 13433 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
13435 13436 13437 |
# File 'lib/models/porcelain.rb', line 13435 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13437 13438 13439 |
# File 'lib/models/porcelain.rb', line 13437 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13439 13440 13441 |
# File 'lib/models/porcelain.rb', line 13439 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
13441 13442 13443 |
# File 'lib/models/porcelain.rb', line 13441 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
13443 13444 13445 |
# File 'lib/models/porcelain.rb', line 13443 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
13445 13446 13447 |
# File 'lib/models/porcelain.rb', line 13445 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13447 13448 13449 |
# File 'lib/models/porcelain.rb', line 13447 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13469 13470 13471 13472 13473 13474 13475 |
# File 'lib/models/porcelain.rb', line 13469 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |