Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
13206 13207 13208 13209 13210 13211 13212 13213 13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 |
# File 'lib/models/porcelain.rb', line 13206 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
13190 13191 13192 |
# File 'lib/models/porcelain.rb', line 13190 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
13192 13193 13194 |
# File 'lib/models/porcelain.rb', line 13192 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13194 13195 13196 |
# File 'lib/models/porcelain.rb', line 13194 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13196 13197 13198 |
# File 'lib/models/porcelain.rb', line 13196 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
13198 13199 13200 |
# File 'lib/models/porcelain.rb', line 13198 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
13200 13201 13202 |
# File 'lib/models/porcelain.rb', line 13200 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
13202 13203 13204 |
# File 'lib/models/porcelain.rb', line 13202 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13204 13205 13206 |
# File 'lib/models/porcelain.rb', line 13204 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/models/porcelain.rb', line 13226 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |