Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
13122 13123 13124 13125 13126 13127 13128 13129 13130 13131 13132 13133 13134 13135 13136 13137 13138 13139 13140 |
# File 'lib/models/porcelain.rb', line 13122 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
13106 13107 13108 |
# File 'lib/models/porcelain.rb', line 13106 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
13108 13109 13110 |
# File 'lib/models/porcelain.rb', line 13108 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13110 13111 13112 |
# File 'lib/models/porcelain.rb', line 13110 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13112 13113 13114 |
# File 'lib/models/porcelain.rb', line 13112 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
13114 13115 13116 |
# File 'lib/models/porcelain.rb', line 13114 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
13116 13117 13118 |
# File 'lib/models/porcelain.rb', line 13116 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
13118 13119 13120 |
# File 'lib/models/porcelain.rb', line 13118 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13120 13121 13122 |
# File 'lib/models/porcelain.rb', line 13120 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13142 13143 13144 13145 13146 13147 13148 |
# File 'lib/models/porcelain.rb', line 13142 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |