Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
13051 13052 13053 13054 13055 13056 13057 13058 13059 13060 13061 13062 13063 13064 13065 13066 13067 13068 13069 |
# File 'lib/models/porcelain.rb', line 13051 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
13035 13036 13037 |
# File 'lib/models/porcelain.rb', line 13035 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
13037 13038 13039 |
# File 'lib/models/porcelain.rb', line 13037 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13039 13040 13041 |
# File 'lib/models/porcelain.rb', line 13039 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13041 13042 13043 |
# File 'lib/models/porcelain.rb', line 13041 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
13043 13044 13045 |
# File 'lib/models/porcelain.rb', line 13043 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
13045 13046 13047 |
# File 'lib/models/porcelain.rb', line 13045 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
13047 13048 13049 |
# File 'lib/models/porcelain.rb', line 13047 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13049 13050 13051 |
# File 'lib/models/porcelain.rb', line 13049 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13071 13072 13073 13074 13075 13076 13077 |
# File 'lib/models/porcelain.rb', line 13071 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |