Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
12688 12689 12690 12691 12692 12693 12694 12695 12696 12697 12698 12699 12700 12701 12702 12703 12704 12705 12706 |
# File 'lib/models/porcelain.rb', line 12688 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
12672 12673 12674 |
# File 'lib/models/porcelain.rb', line 12672 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
12674 12675 12676 |
# File 'lib/models/porcelain.rb', line 12674 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
12676 12677 12678 |
# File 'lib/models/porcelain.rb', line 12676 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
12678 12679 12680 |
# File 'lib/models/porcelain.rb', line 12678 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
12680 12681 12682 |
# File 'lib/models/porcelain.rb', line 12680 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
12682 12683 12684 |
# File 'lib/models/porcelain.rb', line 12682 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
12684 12685 12686 |
# File 'lib/models/porcelain.rb', line 12684 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12686 12687 12688 |
# File 'lib/models/porcelain.rb', line 12686 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12708 12709 12710 12711 12712 12713 12714 |
# File 'lib/models/porcelain.rb', line 12708 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |