Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 12444 12445 12446 12447 12448 12449 12450 12451 |
# File 'lib/models/porcelain.rb', line 12433 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
12417 12418 12419 |
# File 'lib/models/porcelain.rb', line 12417 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
12419 12420 12421 |
# File 'lib/models/porcelain.rb', line 12419 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
12421 12422 12423 |
# File 'lib/models/porcelain.rb', line 12421 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
12423 12424 12425 |
# File 'lib/models/porcelain.rb', line 12423 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
12425 12426 12427 |
# File 'lib/models/porcelain.rb', line 12425 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
12427 12428 12429 |
# File 'lib/models/porcelain.rb', line 12427 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
12429 12430 12431 |
# File 'lib/models/porcelain.rb', line 12429 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12431 12432 12433 |
# File 'lib/models/porcelain.rb', line 12431 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12453 12454 12455 12456 12457 12458 12459 |
# File 'lib/models/porcelain.rb', line 12453 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |