Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
12362 12363 12364 12365 12366 12367 12368 12369 12370 12371 12372 12373 12374 12375 12376 12377 12378 12379 12380 |
# File 'lib/models/porcelain.rb', line 12362 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
12346 12347 12348 |
# File 'lib/models/porcelain.rb', line 12346 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
12348 12349 12350 |
# File 'lib/models/porcelain.rb', line 12348 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
12350 12351 12352 |
# File 'lib/models/porcelain.rb', line 12350 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
12352 12353 12354 |
# File 'lib/models/porcelain.rb', line 12352 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
12354 12355 12356 |
# File 'lib/models/porcelain.rb', line 12354 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
12356 12357 12358 |
# File 'lib/models/porcelain.rb', line 12356 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
12358 12359 12360 |
# File 'lib/models/porcelain.rb', line 12358 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12360 12361 12362 |
# File 'lib/models/porcelain.rb', line 12360 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12382 12383 12384 12385 12386 12387 12388 |
# File 'lib/models/porcelain.rb', line 12382 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |