Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
11769 11770 11771 11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/models/porcelain.rb', line 11769 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
11753 11754 11755 |
# File 'lib/models/porcelain.rb', line 11753 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
11755 11756 11757 |
# File 'lib/models/porcelain.rb', line 11755 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
11757 11758 11759 |
# File 'lib/models/porcelain.rb', line 11757 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
11759 11760 11761 |
# File 'lib/models/porcelain.rb', line 11759 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
11761 11762 11763 |
# File 'lib/models/porcelain.rb', line 11761 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
11763 11764 11765 |
# File 'lib/models/porcelain.rb', line 11763 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
11765 11766 11767 |
# File 'lib/models/porcelain.rb', line 11765 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11767 11768 11769 |
# File 'lib/models/porcelain.rb', line 11767 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11789 11790 11791 11792 11793 11794 11795 |
# File 'lib/models/porcelain.rb', line 11789 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |