Class: SDM::VaultAppRoleCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

VaultAppRoleCertX509Store is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store

Returns a new instance of VaultAppRoleCertX509Store.



10097
10098
10099
10100
10101
10102
10103
10104
10105
10106
10107
10108
10109
10110
10111
10112
10113
# File 'lib/models/porcelain.rb', line 10097

def initialize(
  id: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the SecretStore.



10083
10084
10085
# File 'lib/models/porcelain.rb', line 10083

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



10085
10086
10087
# File 'lib/models/porcelain.rb', line 10085

def name
  @name
end

#namespaceObject

The namespace to make requests within



10087
10088
10089
# File 'lib/models/porcelain.rb', line 10087

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



10089
10090
10091
# File 'lib/models/porcelain.rb', line 10089

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



10091
10092
10093
# File 'lib/models/porcelain.rb', line 10091

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



10093
10094
10095
# File 'lib/models/porcelain.rb', line 10093

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



10095
10096
10097
# File 'lib/models/porcelain.rb', line 10095

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10115
10116
10117
10118
10119
10120
10121
# File 'lib/models/porcelain.rb', line 10115

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end