Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
18849
18850
18851
18852
18853
18854
18855
# File 'lib/models/porcelain.rb', line 18831

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18809
18810
18811
# File 'lib/models/porcelain.rb', line 18809

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18811
18812
18813
# File 'lib/models/porcelain.rb', line 18811

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18813
18814
18815
# File 'lib/models/porcelain.rb', line 18813

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18815
18816
18817
# File 'lib/models/porcelain.rb', line 18815

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



18817
18818
18819
# File 'lib/models/porcelain.rb', line 18817

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



18819
18820
18821
# File 'lib/models/porcelain.rb', line 18819

def name
  @name
end

#namespaceObject

The namespace to make requests within



18821
18822
18823
# File 'lib/models/porcelain.rb', line 18821

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



18823
18824
18825
# File 'lib/models/porcelain.rb', line 18823

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



18825
18826
18827
# File 'lib/models/porcelain.rb', line 18825

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



18827
18828
18829
# File 'lib/models/porcelain.rb', line 18827

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



18829
18830
18831
# File 'lib/models/porcelain.rb', line 18829

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18857
18858
18859
18860
18861
18862
18863
# File 'lib/models/porcelain.rb', line 18857

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end