Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



18747
18748
18749
18750
18751
18752
18753
18754
18755
18756
18757
18758
18759
18760
18761
18762
18763
18764
18765
18766
18767
18768
18769
18770
18771
# File 'lib/models/porcelain.rb', line 18747

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18725
18726
18727
# File 'lib/models/porcelain.rb', line 18725

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18727
18728
18729
# File 'lib/models/porcelain.rb', line 18727

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18729
18730
18731
# File 'lib/models/porcelain.rb', line 18729

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18731
18732
18733
# File 'lib/models/porcelain.rb', line 18731

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



18733
18734
18735
# File 'lib/models/porcelain.rb', line 18733

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



18735
18736
18737
# File 'lib/models/porcelain.rb', line 18735

def name
  @name
end

#namespaceObject

The namespace to make requests within



18737
18738
18739
# File 'lib/models/porcelain.rb', line 18737

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



18739
18740
18741
# File 'lib/models/porcelain.rb', line 18739

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



18741
18742
18743
# File 'lib/models/porcelain.rb', line 18741

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



18743
18744
18745
# File 'lib/models/porcelain.rb', line 18743

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



18745
18746
18747
# File 'lib/models/porcelain.rb', line 18745

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18773
18774
18775
18776
18777
18778
18779
# File 'lib/models/porcelain.rb', line 18773

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end