Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



18513
18514
18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
18531
18532
18533
18534
18535
18536
18537
# File 'lib/models/porcelain.rb', line 18513

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18491
18492
18493
# File 'lib/models/porcelain.rb', line 18491

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18493
18494
18495
# File 'lib/models/porcelain.rb', line 18493

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18495
18496
18497
# File 'lib/models/porcelain.rb', line 18495

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18497
18498
18499
# File 'lib/models/porcelain.rb', line 18497

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



18499
18500
18501
# File 'lib/models/porcelain.rb', line 18499

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



18501
18502
18503
# File 'lib/models/porcelain.rb', line 18501

def name
  @name
end

#namespaceObject

The namespace to make requests within



18503
18504
18505
# File 'lib/models/porcelain.rb', line 18503

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



18505
18506
18507
# File 'lib/models/porcelain.rb', line 18505

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



18507
18508
18509
# File 'lib/models/porcelain.rb', line 18507

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



18509
18510
18511
# File 'lib/models/porcelain.rb', line 18509

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



18511
18512
18513
# File 'lib/models/porcelain.rb', line 18511

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18539
18540
18541
18542
18543
18544
18545
# File 'lib/models/porcelain.rb', line 18539

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end