Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



18397
18398
18399
18400
18401
18402
18403
18404
18405
18406
18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
18418
18419
18420
18421
# File 'lib/models/porcelain.rb', line 18397

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18375
18376
18377
# File 'lib/models/porcelain.rb', line 18375

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18377
18378
18379
# File 'lib/models/porcelain.rb', line 18377

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18379
18380
18381
# File 'lib/models/porcelain.rb', line 18379

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18381
18382
18383
# File 'lib/models/porcelain.rb', line 18381

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



18383
18384
18385
# File 'lib/models/porcelain.rb', line 18383

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



18385
18386
18387
# File 'lib/models/porcelain.rb', line 18385

def name
  @name
end

#namespaceObject

The namespace to make requests within



18387
18388
18389
# File 'lib/models/porcelain.rb', line 18387

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



18389
18390
18391
# File 'lib/models/porcelain.rb', line 18389

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



18391
18392
18393
# File 'lib/models/porcelain.rb', line 18391

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



18393
18394
18395
# File 'lib/models/porcelain.rb', line 18393

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



18395
18396
18397
# File 'lib/models/porcelain.rb', line 18395

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18423
18424
18425
18426
18427
18428
18429
# File 'lib/models/porcelain.rb', line 18423

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end