Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



18020
18021
18022
18023
18024
18025
18026
18027
18028
18029
18030
18031
18032
18033
18034
18035
18036
18037
18038
18039
18040
18041
18042
18043
18044
# File 'lib/models/porcelain.rb', line 18020

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



17998
17999
18000
# File 'lib/models/porcelain.rb', line 17998

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18000
18001
18002
# File 'lib/models/porcelain.rb', line 18000

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18002
18003
18004
# File 'lib/models/porcelain.rb', line 18002

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18004
18005
18006
# File 'lib/models/porcelain.rb', line 18004

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



18006
18007
18008
# File 'lib/models/porcelain.rb', line 18006

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



18008
18009
18010
# File 'lib/models/porcelain.rb', line 18008

def name
  @name
end

#namespaceObject

The namespace to make requests within



18010
18011
18012
# File 'lib/models/porcelain.rb', line 18010

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



18012
18013
18014
# File 'lib/models/porcelain.rb', line 18012

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



18014
18015
18016
# File 'lib/models/porcelain.rb', line 18014

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



18016
18017
18018
# File 'lib/models/porcelain.rb', line 18016

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



18018
18019
18020
# File 'lib/models/porcelain.rb', line 18018

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18046
18047
18048
18049
18050
18051
18052
# File 'lib/models/porcelain.rb', line 18046

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end