Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



17714
17715
17716
17717
17718
17719
17720
17721
17722
17723
17724
17725
17726
17727
17728
17729
17730
17731
17732
17733
17734
17735
17736
17737
17738
# File 'lib/models/porcelain.rb', line 17714

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



17692
17693
17694
# File 'lib/models/porcelain.rb', line 17692

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



17694
17695
17696
# File 'lib/models/porcelain.rb', line 17694

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



17696
17697
17698
# File 'lib/models/porcelain.rb', line 17696

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



17698
17699
17700
# File 'lib/models/porcelain.rb', line 17698

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



17700
17701
17702
# File 'lib/models/porcelain.rb', line 17700

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



17702
17703
17704
# File 'lib/models/porcelain.rb', line 17702

def name
  @name
end

#namespaceObject

The namespace to make requests within



17704
17705
17706
# File 'lib/models/porcelain.rb', line 17704

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



17706
17707
17708
# File 'lib/models/porcelain.rb', line 17706

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



17708
17709
17710
# File 'lib/models/porcelain.rb', line 17708

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



17710
17711
17712
# File 'lib/models/porcelain.rb', line 17710

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



17712
17713
17714
# File 'lib/models/porcelain.rb', line 17712

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17740
17741
17742
17743
17744
17745
17746
# File 'lib/models/porcelain.rb', line 17740

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end