Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



16718
16719
16720
16721
16722
16723
16724
16725
16726
16727
16728
16729
16730
16731
16732
16733
16734
16735
16736
16737
16738
16739
16740
16741
16742
# File 'lib/models/porcelain.rb', line 16718

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



16696
16697
16698
# File 'lib/models/porcelain.rb', line 16696

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



16698
16699
16700
# File 'lib/models/porcelain.rb', line 16698

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



16700
16701
16702
# File 'lib/models/porcelain.rb', line 16700

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



16702
16703
16704
# File 'lib/models/porcelain.rb', line 16702

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



16704
16705
16706
# File 'lib/models/porcelain.rb', line 16704

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



16706
16707
16708
# File 'lib/models/porcelain.rb', line 16706

def name
  @name
end

#namespaceObject

The namespace to make requests within



16708
16709
16710
# File 'lib/models/porcelain.rb', line 16708

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



16710
16711
16712
# File 'lib/models/porcelain.rb', line 16710

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



16712
16713
16714
# File 'lib/models/porcelain.rb', line 16712

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



16714
16715
16716
# File 'lib/models/porcelain.rb', line 16714

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



16716
16717
16718
# File 'lib/models/porcelain.rb', line 16716

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16744
16745
16746
16747
16748
16749
16750
# File 'lib/models/porcelain.rb', line 16744

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end