Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



15005
15006
15007
15008
15009
15010
15011
15012
15013
15014
15015
15016
15017
15018
15019
15020
15021
15022
15023
15024
15025
15026
15027
15028
15029
# File 'lib/models/porcelain.rb', line 15005

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



14983
14984
14985
# File 'lib/models/porcelain.rb', line 14983

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



14985
14986
14987
# File 'lib/models/porcelain.rb', line 14985

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



14987
14988
14989
# File 'lib/models/porcelain.rb', line 14987

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



14989
14990
14991
# File 'lib/models/porcelain.rb', line 14989

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



14991
14992
14993
# File 'lib/models/porcelain.rb', line 14991

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



14993
14994
14995
# File 'lib/models/porcelain.rb', line 14993

def name
  @name
end

#namespaceObject

The namespace to make requests within



14995
14996
14997
# File 'lib/models/porcelain.rb', line 14995

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



14997
14998
14999
# File 'lib/models/porcelain.rb', line 14997

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



14999
15000
15001
# File 'lib/models/porcelain.rb', line 14999

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



15001
15002
15003
# File 'lib/models/porcelain.rb', line 15001

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



15003
15004
15005
# File 'lib/models/porcelain.rb', line 15003

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15031
15032
15033
15034
15035
15036
15037
# File 'lib/models/porcelain.rb', line 15031

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end