Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



14937
14938
14939
14940
14941
14942
14943
14944
14945
14946
14947
14948
14949
14950
14951
14952
14953
14954
14955
14956
14957
14958
14959
14960
14961
# File 'lib/models/porcelain.rb', line 14937

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



14915
14916
14917
# File 'lib/models/porcelain.rb', line 14915

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



14917
14918
14919
# File 'lib/models/porcelain.rb', line 14917

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



14919
14920
14921
# File 'lib/models/porcelain.rb', line 14919

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



14921
14922
14923
# File 'lib/models/porcelain.rb', line 14921

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



14923
14924
14925
# File 'lib/models/porcelain.rb', line 14923

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



14925
14926
14927
# File 'lib/models/porcelain.rb', line 14925

def name
  @name
end

#namespaceObject

The namespace to make requests within



14927
14928
14929
# File 'lib/models/porcelain.rb', line 14927

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



14929
14930
14931
# File 'lib/models/porcelain.rb', line 14929

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



14931
14932
14933
# File 'lib/models/porcelain.rb', line 14931

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



14933
14934
14935
# File 'lib/models/porcelain.rb', line 14933

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



14935
14936
14937
# File 'lib/models/porcelain.rb', line 14935

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14963
14964
14965
14966
14967
14968
14969
# File 'lib/models/porcelain.rb', line 14963

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end