Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



14864
14865
14866
14867
14868
14869
14870
14871
14872
14873
14874
14875
14876
14877
14878
14879
14880
14881
14882
14883
14884
14885
14886
14887
14888
# File 'lib/models/porcelain.rb', line 14864

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



14842
14843
14844
# File 'lib/models/porcelain.rb', line 14842

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



14844
14845
14846
# File 'lib/models/porcelain.rb', line 14844

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



14846
14847
14848
# File 'lib/models/porcelain.rb', line 14846

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



14848
14849
14850
# File 'lib/models/porcelain.rb', line 14848

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



14850
14851
14852
# File 'lib/models/porcelain.rb', line 14850

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



14852
14853
14854
# File 'lib/models/porcelain.rb', line 14852

def name
  @name
end

#namespaceObject

The namespace to make requests within



14854
14855
14856
# File 'lib/models/porcelain.rb', line 14854

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



14856
14857
14858
# File 'lib/models/porcelain.rb', line 14856

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



14858
14859
14860
# File 'lib/models/porcelain.rb', line 14858

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



14860
14861
14862
# File 'lib/models/porcelain.rb', line 14860

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



14862
14863
14864
# File 'lib/models/porcelain.rb', line 14862

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14890
14891
14892
14893
14894
14895
14896
# File 'lib/models/porcelain.rb', line 14890

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end