Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



14796
14797
14798
14799
14800
14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
14820
# File 'lib/models/porcelain.rb', line 14796

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



14774
14775
14776
# File 'lib/models/porcelain.rb', line 14774

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



14776
14777
14778
# File 'lib/models/porcelain.rb', line 14776

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



14778
14779
14780
# File 'lib/models/porcelain.rb', line 14778

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



14780
14781
14782
# File 'lib/models/porcelain.rb', line 14780

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



14782
14783
14784
# File 'lib/models/porcelain.rb', line 14782

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



14784
14785
14786
# File 'lib/models/porcelain.rb', line 14784

def name
  @name
end

#namespaceObject

The namespace to make requests within



14786
14787
14788
# File 'lib/models/porcelain.rb', line 14786

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



14788
14789
14790
# File 'lib/models/porcelain.rb', line 14788

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



14790
14791
14792
# File 'lib/models/porcelain.rb', line 14790

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



14792
14793
14794
# File 'lib/models/porcelain.rb', line 14792

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



14794
14795
14796
# File 'lib/models/porcelain.rb', line 14794

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14822
14823
14824
14825
14826
14827
14828
# File 'lib/models/porcelain.rb', line 14822

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end