Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



13612
13613
13614
13615
13616
13617
13618
13619
13620
13621
13622
13623
13624
13625
13626
13627
13628
13629
13630
13631
13632
13633
13634
13635
13636
# File 'lib/models/porcelain.rb', line 13612

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



13590
13591
13592
# File 'lib/models/porcelain.rb', line 13590

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



13592
13593
13594
# File 'lib/models/porcelain.rb', line 13592

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



13594
13595
13596
# File 'lib/models/porcelain.rb', line 13594

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



13596
13597
13598
# File 'lib/models/porcelain.rb', line 13596

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



13598
13599
13600
# File 'lib/models/porcelain.rb', line 13598

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



13600
13601
13602
# File 'lib/models/porcelain.rb', line 13600

def name
  @name
end

#namespaceObject

The namespace to make requests within



13602
13603
13604
# File 'lib/models/porcelain.rb', line 13602

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



13604
13605
13606
# File 'lib/models/porcelain.rb', line 13604

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



13606
13607
13608
# File 'lib/models/porcelain.rb', line 13606

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



13608
13609
13610
# File 'lib/models/porcelain.rb', line 13608

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



13610
13611
13612
# File 'lib/models/porcelain.rb', line 13610

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13638
13639
13640
13641
13642
13643
13644
# File 'lib/models/porcelain.rb', line 13638

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end