Class: SDM::VaultTLSCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore
constructor
A new instance of VaultTLSCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore
Returns a new instance of VaultTLSCertSSHStore.
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 13557 13558 13559 13560 13561 |
# File 'lib/models/porcelain.rb', line 13537 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
13515 13516 13517 |
# File 'lib/models/porcelain.rb', line 13515 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
13517 13518 13519 |
# File 'lib/models/porcelain.rb', line 13517 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
13519 13520 13521 |
# File 'lib/models/porcelain.rb', line 13519 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
13521 13522 13523 |
# File 'lib/models/porcelain.rb', line 13521 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
13523 13524 13525 |
# File 'lib/models/porcelain.rb', line 13523 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13525 13526 13527 |
# File 'lib/models/porcelain.rb', line 13525 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13527 13528 13529 |
# File 'lib/models/porcelain.rb', line 13527 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
13529 13530 13531 |
# File 'lib/models/porcelain.rb', line 13529 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
13531 13532 13533 |
# File 'lib/models/porcelain.rb', line 13531 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
13533 13534 13535 |
# File 'lib/models/porcelain.rb', line 13533 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13535 13536 13537 |
# File 'lib/models/porcelain.rb', line 13535 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13563 13564 13565 13566 13567 13568 13569 |
# File 'lib/models/porcelain.rb', line 13563 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |