Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



13529
13530
13531
13532
13533
13534
13535
13536
13537
13538
13539
13540
13541
13542
13543
13544
13545
13546
13547
13548
13549
13550
13551
13552
13553
# File 'lib/models/porcelain.rb', line 13529

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



13507
13508
13509
# File 'lib/models/porcelain.rb', line 13507

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



13509
13510
13511
# File 'lib/models/porcelain.rb', line 13509

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



13511
13512
13513
# File 'lib/models/porcelain.rb', line 13511

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



13513
13514
13515
# File 'lib/models/porcelain.rb', line 13513

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



13515
13516
13517
# File 'lib/models/porcelain.rb', line 13515

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



13517
13518
13519
# File 'lib/models/porcelain.rb', line 13517

def name
  @name
end

#namespaceObject

The namespace to make requests within



13519
13520
13521
# File 'lib/models/porcelain.rb', line 13519

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



13521
13522
13523
# File 'lib/models/porcelain.rb', line 13521

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



13523
13524
13525
# File 'lib/models/porcelain.rb', line 13523

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



13525
13526
13527
# File 'lib/models/porcelain.rb', line 13525

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



13527
13528
13529
# File 'lib/models/porcelain.rb', line 13527

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13555
13556
13557
13558
13559
13560
13561
# File 'lib/models/porcelain.rb', line 13555

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end