Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



13361
13362
13363
13364
13365
13366
13367
13368
13369
13370
13371
13372
13373
13374
13375
13376
13377
13378
13379
13380
13381
13382
13383
13384
13385
# File 'lib/models/porcelain.rb', line 13361

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



13339
13340
13341
# File 'lib/models/porcelain.rb', line 13339

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



13341
13342
13343
# File 'lib/models/porcelain.rb', line 13341

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



13343
13344
13345
# File 'lib/models/porcelain.rb', line 13343

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



13345
13346
13347
# File 'lib/models/porcelain.rb', line 13345

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



13347
13348
13349
# File 'lib/models/porcelain.rb', line 13347

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



13349
13350
13351
# File 'lib/models/porcelain.rb', line 13349

def name
  @name
end

#namespaceObject

The namespace to make requests within



13351
13352
13353
# File 'lib/models/porcelain.rb', line 13351

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



13353
13354
13355
# File 'lib/models/porcelain.rb', line 13353

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



13355
13356
13357
# File 'lib/models/porcelain.rb', line 13355

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



13357
13358
13359
# File 'lib/models/porcelain.rb', line 13357

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



13359
13360
13361
# File 'lib/models/porcelain.rb', line 13359

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13387
13388
13389
13390
13391
13392
13393
# File 'lib/models/porcelain.rb', line 13387

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end