Class: SDM::VaultTLSCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore
constructor
A new instance of VaultTLSCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore
Returns a new instance of VaultTLSCertSSHStore.
13294 13295 13296 13297 13298 13299 13300 13301 13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 13313 13314 13315 13316 13317 13318 |
# File 'lib/models/porcelain.rb', line 13294 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
13272 13273 13274 |
# File 'lib/models/porcelain.rb', line 13272 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
13274 13275 13276 |
# File 'lib/models/porcelain.rb', line 13274 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
13276 13277 13278 |
# File 'lib/models/porcelain.rb', line 13276 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
13278 13279 13280 |
# File 'lib/models/porcelain.rb', line 13278 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
13280 13281 13282 |
# File 'lib/models/porcelain.rb', line 13280 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13282 13283 13284 |
# File 'lib/models/porcelain.rb', line 13282 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13284 13285 13286 |
# File 'lib/models/porcelain.rb', line 13284 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
13286 13287 13288 |
# File 'lib/models/porcelain.rb', line 13286 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
13288 13289 13290 |
# File 'lib/models/porcelain.rb', line 13288 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
13290 13291 13292 |
# File 'lib/models/porcelain.rb', line 13290 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13292 13293 13294 |
# File 'lib/models/porcelain.rb', line 13292 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13320 13321 13322 13323 13324 13325 13326 |
# File 'lib/models/porcelain.rb', line 13320 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |