Class: SDM::VaultTLSCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore
constructor
A new instance of VaultTLSCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore
Returns a new instance of VaultTLSCertSSHStore.
13139 13140 13141 13142 13143 13144 13145 13146 13147 13148 13149 13150 13151 13152 13153 13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 |
# File 'lib/models/porcelain.rb', line 13139 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
13117 13118 13119 |
# File 'lib/models/porcelain.rb', line 13117 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
13119 13120 13121 |
# File 'lib/models/porcelain.rb', line 13119 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
13121 13122 13123 |
# File 'lib/models/porcelain.rb', line 13121 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
13123 13124 13125 |
# File 'lib/models/porcelain.rb', line 13123 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
13125 13126 13127 |
# File 'lib/models/porcelain.rb', line 13125 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13127 13128 13129 |
# File 'lib/models/porcelain.rb', line 13127 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13129 13130 13131 |
# File 'lib/models/porcelain.rb', line 13129 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
13131 13132 13133 |
# File 'lib/models/porcelain.rb', line 13131 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
13133 13134 13135 |
# File 'lib/models/porcelain.rb', line 13133 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
13135 13136 13137 |
# File 'lib/models/porcelain.rb', line 13135 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13137 13138 13139 |
# File 'lib/models/porcelain.rb', line 13137 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13165 13166 13167 13168 13169 13170 13171 |
# File 'lib/models/porcelain.rb', line 13165 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |