Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



12778
12779
12780
12781
12782
12783
12784
12785
12786
12787
12788
12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
# File 'lib/models/porcelain.rb', line 12778

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



12756
12757
12758
# File 'lib/models/porcelain.rb', line 12756

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



12758
12759
12760
# File 'lib/models/porcelain.rb', line 12758

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



12760
12761
12762
# File 'lib/models/porcelain.rb', line 12760

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



12762
12763
12764
# File 'lib/models/porcelain.rb', line 12762

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



12764
12765
12766
# File 'lib/models/porcelain.rb', line 12764

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



12766
12767
12768
# File 'lib/models/porcelain.rb', line 12766

def name
  @name
end

#namespaceObject

The namespace to make requests within



12768
12769
12770
# File 'lib/models/porcelain.rb', line 12768

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



12770
12771
12772
# File 'lib/models/porcelain.rb', line 12770

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



12772
12773
12774
# File 'lib/models/porcelain.rb', line 12772

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



12774
12775
12776
# File 'lib/models/porcelain.rb', line 12774

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



12776
12777
12778
# File 'lib/models/porcelain.rb', line 12776

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12804
12805
12806
12807
12808
12809
12810
# File 'lib/models/porcelain.rb', line 12804

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end