Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



12026
12027
12028
12029
12030
12031
12032
12033
12034
12035
12036
12037
12038
12039
12040
12041
12042
12043
12044
12045
12046
12047
12048
12049
12050
# File 'lib/models/porcelain.rb', line 12026

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



12004
12005
12006
# File 'lib/models/porcelain.rb', line 12004

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



12006
12007
12008
# File 'lib/models/porcelain.rb', line 12006

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



12008
12009
12010
# File 'lib/models/porcelain.rb', line 12008

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



12010
12011
12012
# File 'lib/models/porcelain.rb', line 12010

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



12012
12013
12014
# File 'lib/models/porcelain.rb', line 12012

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



12014
12015
12016
# File 'lib/models/porcelain.rb', line 12014

def name
  @name
end

#namespaceObject

The namespace to make requests within



12016
12017
12018
# File 'lib/models/porcelain.rb', line 12016

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



12018
12019
12020
# File 'lib/models/porcelain.rb', line 12018

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



12020
12021
12022
# File 'lib/models/porcelain.rb', line 12020

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



12022
12023
12024
# File 'lib/models/porcelain.rb', line 12022

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



12024
12025
12026
# File 'lib/models/porcelain.rb', line 12024

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12052
12053
12054
12055
12056
12057
12058
# File 'lib/models/porcelain.rb', line 12052

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end