Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



11853
11854
11855
11856
11857
11858
11859
11860
11861
11862
11863
11864
11865
11866
11867
11868
11869
11870
11871
11872
11873
11874
11875
11876
11877
# File 'lib/models/porcelain.rb', line 11853

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



11831
11832
11833
# File 'lib/models/porcelain.rb', line 11831

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



11833
11834
11835
# File 'lib/models/porcelain.rb', line 11833

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



11835
11836
11837
# File 'lib/models/porcelain.rb', line 11835

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



11837
11838
11839
# File 'lib/models/porcelain.rb', line 11837

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



11839
11840
11841
# File 'lib/models/porcelain.rb', line 11839

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



11841
11842
11843
# File 'lib/models/porcelain.rb', line 11841

def name
  @name
end

#namespaceObject

The namespace to make requests within



11843
11844
11845
# File 'lib/models/porcelain.rb', line 11843

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



11845
11846
11847
# File 'lib/models/porcelain.rb', line 11845

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



11847
11848
11849
# File 'lib/models/porcelain.rb', line 11847

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



11849
11850
11851
# File 'lib/models/porcelain.rb', line 11849

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



11851
11852
11853
# File 'lib/models/porcelain.rb', line 11851

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11879
11880
11881
11882
11883
11884
11885
# File 'lib/models/porcelain.rb', line 11879

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end