Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



10903
10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
10920
10921
10922
10923
10924
10925
10926
10927
# File 'lib/models/porcelain.rb', line 10903

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



10881
10882
10883
# File 'lib/models/porcelain.rb', line 10881

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



10883
10884
10885
# File 'lib/models/porcelain.rb', line 10883

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



10885
10886
10887
# File 'lib/models/porcelain.rb', line 10885

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



10887
10888
10889
# File 'lib/models/porcelain.rb', line 10887

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



10889
10890
10891
# File 'lib/models/porcelain.rb', line 10889

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



10891
10892
10893
# File 'lib/models/porcelain.rb', line 10891

def name
  @name
end

#namespaceObject

The namespace to make requests within



10893
10894
10895
# File 'lib/models/porcelain.rb', line 10893

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



10895
10896
10897
# File 'lib/models/porcelain.rb', line 10895

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



10897
10898
10899
# File 'lib/models/porcelain.rb', line 10897

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



10899
10900
10901
# File 'lib/models/porcelain.rb', line 10899

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



10901
10902
10903
# File 'lib/models/porcelain.rb', line 10901

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10929
10930
10931
10932
10933
10934
10935
# File 'lib/models/porcelain.rb', line 10929

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end