Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

VaultTLSCertSSHStore is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



10053
10054
10055
10056
10057
10058
10059
10060
10061
10062
10063
10064
10065
10066
10067
10068
10069
10070
10071
10072
10073
10074
10075
# File 'lib/models/porcelain.rb', line 10053

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



10033
10034
10035
# File 'lib/models/porcelain.rb', line 10033

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



10035
10036
10037
# File 'lib/models/porcelain.rb', line 10035

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



10037
10038
10039
# File 'lib/models/porcelain.rb', line 10037

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



10039
10040
10041
# File 'lib/models/porcelain.rb', line 10039

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



10041
10042
10043
# File 'lib/models/porcelain.rb', line 10041

def name
  @name
end

#namespaceObject

The namespace to make requests within



10043
10044
10045
# File 'lib/models/porcelain.rb', line 10043

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



10045
10046
10047
# File 'lib/models/porcelain.rb', line 10045

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



10047
10048
10049
# File 'lib/models/porcelain.rb', line 10047

def signing_role
  @signing_role
end

#ssh_mount_pointObject

The mount point of the SSH engine configured with the desired CA



10049
10050
10051
# File 'lib/models/porcelain.rb', line 10049

def ssh_mount_point
  @ssh_mount_point
end

#tagsObject

Tags is a map of key, value pairs.



10051
10052
10053
# File 'lib/models/porcelain.rb', line 10051

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10077
10078
10079
10080
10081
10082
10083
# File 'lib/models/porcelain.rb', line 10077

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end