Class: SDM::VaultTLSCertSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTLSCertSSHStore

Returns a new instance of VaultTLSCertSSHStore.



18939
18940
18941
18942
18943
18944
18945
18946
18947
18948
18949
18950
18951
18952
18953
18954
18955
18956
18957
18958
18959
18960
18961
18962
18963
# File 'lib/models/porcelain.rb', line 18939

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  signing_role: nil,
  ssh_mount_point: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_path ⇒ Object

A path to a CA file accessible by a Node



18917
18918
18919
# File 'lib/models/porcelain.rb', line 18917

def ca_cert_path
  @ca_cert_path
end

#client_cert_path ⇒ Object

A path to a client certificate file accessible by a Node



18919
18920
18921
# File 'lib/models/porcelain.rb', line 18919

def client_cert_path
  @client_cert_path
end

#client_key_path ⇒ Object

A path to a client key file accessible by a Node



18921
18922
18923
# File 'lib/models/porcelain.rb', line 18921

def client_key_path
  @client_key_path
end

#id ⇒ Object

Unique identifier of the SecretStore.



18923
18924
18925
# File 'lib/models/porcelain.rb', line 18923

def id
  @id
end

#issuedcertttlminutes ⇒ Object

The lifetime of certificates issued by this CA represented in minutes.



18925
18926
18927
# File 'lib/models/porcelain.rb', line 18925

def issuedcertttlminutes
  @issuedcertttlminutes
end

#name ⇒ Object

Unique human-readable name of the SecretStore.



18927
18928
18929
# File 'lib/models/porcelain.rb', line 18927

def name
  @name
end

#namespace ⇒ Object

The namespace to make requests within



18929
18930
18931
# File 'lib/models/porcelain.rb', line 18929

def namespace
  @namespace
end

#server_address ⇒ Object

The URL of the Vault to target



18931
18932
18933
# File 'lib/models/porcelain.rb', line 18931

def server_address
  @server_address
end

#signing_role ⇒ Object

The signing role to be used for signing certificates



18933
18934
18935
# File 'lib/models/porcelain.rb', line 18933

def signing_role
  @signing_role
end

#ssh_mount_point ⇒ Object

The mount point of the SSH engine configured with the desired CA



18935
18936
18937
# File 'lib/models/porcelain.rb', line 18935

def ssh_mount_point
  @ssh_mount_point
end

#tags ⇒ Object

Tags is a map of key, value pairs.



18937
18938
18939
# File 'lib/models/porcelain.rb', line 18937

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18965
18966
18967
18968
18969
18970
18971
# File 'lib/models/porcelain.rb', line 18965

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end