Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



18938
18939
18940
18941
18942
18943
18944
18945
18946
18947
18948
18949
18950
18951
18952
18953
18954
18955
18956
18957
18958
18959
18960
18961
18962
# File 'lib/models/porcelain.rb', line 18938

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18916
18917
18918
# File 'lib/models/porcelain.rb', line 18916

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18918
18919
18920
# File 'lib/models/porcelain.rb', line 18918

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18920
18921
18922
# File 'lib/models/porcelain.rb', line 18920

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18922
18923
18924
# File 'lib/models/porcelain.rb', line 18922

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



18924
18925
18926
# File 'lib/models/porcelain.rb', line 18924

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



18926
18927
18928
# File 'lib/models/porcelain.rb', line 18926

def name
  @name
end

#namespaceObject

The namespace to make requests within



18928
18929
18930
# File 'lib/models/porcelain.rb', line 18928

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



18930
18931
18932
# File 'lib/models/porcelain.rb', line 18930

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



18932
18933
18934
# File 'lib/models/porcelain.rb', line 18932

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



18934
18935
18936
# File 'lib/models/porcelain.rb', line 18934

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



18936
18937
18938
# File 'lib/models/porcelain.rb', line 18936

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18964
18965
18966
18967
18968
18969
18970
# File 'lib/models/porcelain.rb', line 18964

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end