Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



18890
18891
18892
18893
18894
18895
18896
18897
18898
18899
18900
18901
18902
18903
18904
18905
18906
18907
18908
18909
18910
18911
18912
18913
18914
# File 'lib/models/porcelain.rb', line 18890

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18868
18869
18870
# File 'lib/models/porcelain.rb', line 18868

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18870
18871
18872
# File 'lib/models/porcelain.rb', line 18870

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18872
18873
18874
# File 'lib/models/porcelain.rb', line 18872

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18874
18875
18876
# File 'lib/models/porcelain.rb', line 18874

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



18876
18877
18878
# File 'lib/models/porcelain.rb', line 18876

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



18878
18879
18880
# File 'lib/models/porcelain.rb', line 18878

def name
  @name
end

#namespaceObject

The namespace to make requests within



18880
18881
18882
# File 'lib/models/porcelain.rb', line 18880

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



18882
18883
18884
# File 'lib/models/porcelain.rb', line 18882

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



18884
18885
18886
# File 'lib/models/porcelain.rb', line 18884

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



18886
18887
18888
# File 'lib/models/porcelain.rb', line 18886

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



18888
18889
18890
# File 'lib/models/porcelain.rb', line 18888

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18916
18917
18918
18919
18920
18921
18922
# File 'lib/models/porcelain.rb', line 18916

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end