Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



18806
18807
18808
18809
18810
18811
18812
18813
18814
18815
18816
18817
18818
18819
18820
18821
18822
18823
18824
18825
18826
18827
18828
18829
18830
# File 'lib/models/porcelain.rb', line 18806

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18784
18785
18786
# File 'lib/models/porcelain.rb', line 18784

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18786
18787
18788
# File 'lib/models/porcelain.rb', line 18786

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18788
18789
18790
# File 'lib/models/porcelain.rb', line 18788

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18790
18791
18792
# File 'lib/models/porcelain.rb', line 18790

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



18792
18793
18794
# File 'lib/models/porcelain.rb', line 18792

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



18794
18795
18796
# File 'lib/models/porcelain.rb', line 18794

def name
  @name
end

#namespaceObject

The namespace to make requests within



18796
18797
18798
# File 'lib/models/porcelain.rb', line 18796

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



18798
18799
18800
# File 'lib/models/porcelain.rb', line 18798

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



18800
18801
18802
# File 'lib/models/porcelain.rb', line 18800

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



18802
18803
18804
# File 'lib/models/porcelain.rb', line 18802

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



18804
18805
18806
# File 'lib/models/porcelain.rb', line 18804

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18832
18833
18834
18835
18836
18837
18838
# File 'lib/models/porcelain.rb', line 18832

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end