Class: SDM::VaultTLSCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTLSCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store
constructor
A new instance of VaultTLSCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store
Returns a new instance of VaultTLSCertX509Store.
18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 18600 18601 18602 18603 18604 |
# File 'lib/models/porcelain.rb', line 18580 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
18558 18559 18560 |
# File 'lib/models/porcelain.rb', line 18558 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
18560 18561 18562 |
# File 'lib/models/porcelain.rb', line 18560 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
18562 18563 18564 |
# File 'lib/models/porcelain.rb', line 18562 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
18564 18565 18566 |
# File 'lib/models/porcelain.rb', line 18564 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18566 18567 18568 |
# File 'lib/models/porcelain.rb', line 18566 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18568 18569 18570 |
# File 'lib/models/porcelain.rb', line 18568 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18570 18571 18572 |
# File 'lib/models/porcelain.rb', line 18570 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18572 18573 18574 |
# File 'lib/models/porcelain.rb', line 18572 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18574 18575 18576 |
# File 'lib/models/porcelain.rb', line 18574 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18576 18577 18578 |
# File 'lib/models/porcelain.rb', line 18576 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18578 18579 18580 |
# File 'lib/models/porcelain.rb', line 18578 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18606 18607 18608 18609 18610 18611 18612 |
# File 'lib/models/porcelain.rb', line 18606 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |