Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



18572
18573
18574
18575
18576
18577
18578
18579
18580
18581
18582
18583
18584
18585
18586
18587
18588
18589
18590
18591
18592
18593
18594
18595
18596
# File 'lib/models/porcelain.rb', line 18572

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18550
18551
18552
# File 'lib/models/porcelain.rb', line 18550

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18552
18553
18554
# File 'lib/models/porcelain.rb', line 18552

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18554
18555
18556
# File 'lib/models/porcelain.rb', line 18554

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18556
18557
18558
# File 'lib/models/porcelain.rb', line 18556

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



18558
18559
18560
# File 'lib/models/porcelain.rb', line 18558

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



18560
18561
18562
# File 'lib/models/porcelain.rb', line 18560

def name
  @name
end

#namespaceObject

The namespace to make requests within



18562
18563
18564
# File 'lib/models/porcelain.rb', line 18562

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



18564
18565
18566
# File 'lib/models/porcelain.rb', line 18564

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



18566
18567
18568
# File 'lib/models/porcelain.rb', line 18566

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



18568
18569
18570
# File 'lib/models/porcelain.rb', line 18568

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



18570
18571
18572
# File 'lib/models/porcelain.rb', line 18570

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18598
18599
18600
18601
18602
18603
18604
# File 'lib/models/porcelain.rb', line 18598

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end