Class: SDM::VaultTLSCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTLSCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store
constructor
A new instance of VaultTLSCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store
Returns a new instance of VaultTLSCertX509Store.
18456 18457 18458 18459 18460 18461 18462 18463 18464 18465 18466 18467 18468 18469 18470 18471 18472 18473 18474 18475 18476 18477 18478 18479 18480 |
# File 'lib/models/porcelain.rb', line 18456 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
18434 18435 18436 |
# File 'lib/models/porcelain.rb', line 18434 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
18436 18437 18438 |
# File 'lib/models/porcelain.rb', line 18436 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
18438 18439 18440 |
# File 'lib/models/porcelain.rb', line 18438 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
18440 18441 18442 |
# File 'lib/models/porcelain.rb', line 18440 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18442 18443 18444 |
# File 'lib/models/porcelain.rb', line 18442 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18444 18445 18446 |
# File 'lib/models/porcelain.rb', line 18444 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18446 18447 18448 |
# File 'lib/models/porcelain.rb', line 18446 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18448 18449 18450 |
# File 'lib/models/porcelain.rb', line 18448 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18450 18451 18452 |
# File 'lib/models/porcelain.rb', line 18450 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18452 18453 18454 |
# File 'lib/models/porcelain.rb', line 18452 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18454 18455 18456 |
# File 'lib/models/porcelain.rb', line 18454 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18482 18483 18484 18485 18486 18487 18488 |
# File 'lib/models/porcelain.rb', line 18482 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |