Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



17773
17774
17775
17776
17777
17778
17779
17780
17781
17782
17783
17784
17785
17786
17787
17788
17789
17790
17791
17792
17793
17794
17795
17796
17797
# File 'lib/models/porcelain.rb', line 17773

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



17751
17752
17753
# File 'lib/models/porcelain.rb', line 17751

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



17753
17754
17755
# File 'lib/models/porcelain.rb', line 17753

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



17755
17756
17757
# File 'lib/models/porcelain.rb', line 17755

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



17757
17758
17759
# File 'lib/models/porcelain.rb', line 17757

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



17759
17760
17761
# File 'lib/models/porcelain.rb', line 17759

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



17761
17762
17763
# File 'lib/models/porcelain.rb', line 17761

def name
  @name
end

#namespaceObject

The namespace to make requests within



17763
17764
17765
# File 'lib/models/porcelain.rb', line 17763

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



17765
17766
17767
# File 'lib/models/porcelain.rb', line 17765

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



17767
17768
17769
# File 'lib/models/porcelain.rb', line 17767

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



17769
17770
17771
# File 'lib/models/porcelain.rb', line 17769

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



17771
17772
17773
# File 'lib/models/porcelain.rb', line 17771

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17799
17800
17801
17802
17803
17804
17805
# File 'lib/models/porcelain.rb', line 17799

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end