Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



16777
16778
16779
16780
16781
16782
16783
16784
16785
16786
16787
16788
16789
16790
16791
16792
16793
16794
16795
16796
16797
16798
16799
16800
16801
# File 'lib/models/porcelain.rb', line 16777

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



16755
16756
16757
# File 'lib/models/porcelain.rb', line 16755

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



16757
16758
16759
# File 'lib/models/porcelain.rb', line 16757

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



16759
16760
16761
# File 'lib/models/porcelain.rb', line 16759

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



16761
16762
16763
# File 'lib/models/porcelain.rb', line 16761

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



16763
16764
16765
# File 'lib/models/porcelain.rb', line 16763

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



16765
16766
16767
# File 'lib/models/porcelain.rb', line 16765

def name
  @name
end

#namespaceObject

The namespace to make requests within



16767
16768
16769
# File 'lib/models/porcelain.rb', line 16767

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



16769
16770
16771
# File 'lib/models/porcelain.rb', line 16769

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



16771
16772
16773
# File 'lib/models/porcelain.rb', line 16771

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



16773
16774
16775
# File 'lib/models/porcelain.rb', line 16773

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



16775
16776
16777
# File 'lib/models/porcelain.rb', line 16775

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16803
16804
16805
16806
16807
16808
16809
# File 'lib/models/porcelain.rb', line 16803

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end