Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



15075
15076
15077
15078
15079
15080
15081
15082
15083
15084
15085
15086
15087
15088
15089
15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
# File 'lib/models/porcelain.rb', line 15075

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



15053
15054
15055
# File 'lib/models/porcelain.rb', line 15053

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



15055
15056
15057
# File 'lib/models/porcelain.rb', line 15055

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



15057
15058
15059
# File 'lib/models/porcelain.rb', line 15057

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



15059
15060
15061
# File 'lib/models/porcelain.rb', line 15059

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



15061
15062
15063
# File 'lib/models/porcelain.rb', line 15061

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



15063
15064
15065
# File 'lib/models/porcelain.rb', line 15063

def name
  @name
end

#namespaceObject

The namespace to make requests within



15065
15066
15067
# File 'lib/models/porcelain.rb', line 15065

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



15067
15068
15069
# File 'lib/models/porcelain.rb', line 15067

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



15069
15070
15071
# File 'lib/models/porcelain.rb', line 15069

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



15071
15072
15073
# File 'lib/models/porcelain.rb', line 15071

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



15073
15074
15075
# File 'lib/models/porcelain.rb', line 15073

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15101
15102
15103
15104
15105
15106
15107
# File 'lib/models/porcelain.rb', line 15101

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end