Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
14940
14941
14942
14943
14944
# File 'lib/models/porcelain.rb', line 14920

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



14898
14899
14900
# File 'lib/models/porcelain.rb', line 14898

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



14900
14901
14902
# File 'lib/models/porcelain.rb', line 14900

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



14902
14903
14904
# File 'lib/models/porcelain.rb', line 14902

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



14904
14905
14906
# File 'lib/models/porcelain.rb', line 14904

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



14906
14907
14908
# File 'lib/models/porcelain.rb', line 14906

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



14908
14909
14910
# File 'lib/models/porcelain.rb', line 14908

def name
  @name
end

#namespaceObject

The namespace to make requests within



14910
14911
14912
# File 'lib/models/porcelain.rb', line 14910

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



14912
14913
14914
# File 'lib/models/porcelain.rb', line 14912

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



14914
14915
14916
# File 'lib/models/porcelain.rb', line 14914

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



14916
14917
14918
# File 'lib/models/porcelain.rb', line 14916

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



14918
14919
14920
# File 'lib/models/porcelain.rb', line 14918

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14946
14947
14948
14949
14950
14951
14952
# File 'lib/models/porcelain.rb', line 14946

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end