Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
14940
14941
14942
14943
14944
14945
14946
14947
# File 'lib/models/porcelain.rb', line 14923

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



14901
14902
14903
# File 'lib/models/porcelain.rb', line 14901

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



14903
14904
14905
# File 'lib/models/porcelain.rb', line 14903

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



14905
14906
14907
# File 'lib/models/porcelain.rb', line 14905

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



14907
14908
14909
# File 'lib/models/porcelain.rb', line 14907

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



14909
14910
14911
# File 'lib/models/porcelain.rb', line 14909

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



14911
14912
14913
# File 'lib/models/porcelain.rb', line 14911

def name
  @name
end

#namespaceObject

The namespace to make requests within



14913
14914
14915
# File 'lib/models/porcelain.rb', line 14913

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



14915
14916
14917
# File 'lib/models/porcelain.rb', line 14915

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



14917
14918
14919
# File 'lib/models/porcelain.rb', line 14917

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



14919
14920
14921
# File 'lib/models/porcelain.rb', line 14919

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



14921
14922
14923
# File 'lib/models/porcelain.rb', line 14921

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14949
14950
14951
14952
14953
14954
14955
# File 'lib/models/porcelain.rb', line 14949

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end