Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



13679
13680
13681
13682
13683
13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
13694
13695
13696
13697
13698
13699
13700
13701
13702
13703
# File 'lib/models/porcelain.rb', line 13679

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



13657
13658
13659
# File 'lib/models/porcelain.rb', line 13657

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



13659
13660
13661
# File 'lib/models/porcelain.rb', line 13659

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



13661
13662
13663
# File 'lib/models/porcelain.rb', line 13661

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



13663
13664
13665
# File 'lib/models/porcelain.rb', line 13663

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



13665
13666
13667
# File 'lib/models/porcelain.rb', line 13665

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



13667
13668
13669
# File 'lib/models/porcelain.rb', line 13667

def name
  @name
end

#namespaceObject

The namespace to make requests within



13669
13670
13671
# File 'lib/models/porcelain.rb', line 13669

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



13671
13672
13673
# File 'lib/models/porcelain.rb', line 13671

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



13673
13674
13675
# File 'lib/models/porcelain.rb', line 13673

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



13675
13676
13677
# File 'lib/models/porcelain.rb', line 13675

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



13677
13678
13679
# File 'lib/models/porcelain.rb', line 13677

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13705
13706
13707
13708
13709
13710
13711
# File 'lib/models/porcelain.rb', line 13705

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end