Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



13596
13597
13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
13613
13614
13615
13616
13617
13618
13619
13620
# File 'lib/models/porcelain.rb', line 13596

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



13574
13575
13576
# File 'lib/models/porcelain.rb', line 13574

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



13576
13577
13578
# File 'lib/models/porcelain.rb', line 13576

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



13578
13579
13580
# File 'lib/models/porcelain.rb', line 13578

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



13580
13581
13582
# File 'lib/models/porcelain.rb', line 13580

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



13582
13583
13584
# File 'lib/models/porcelain.rb', line 13582

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



13584
13585
13586
# File 'lib/models/porcelain.rb', line 13584

def name
  @name
end

#namespaceObject

The namespace to make requests within



13586
13587
13588
# File 'lib/models/porcelain.rb', line 13586

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



13588
13589
13590
# File 'lib/models/porcelain.rb', line 13588

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



13590
13591
13592
# File 'lib/models/porcelain.rb', line 13590

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



13592
13593
13594
# File 'lib/models/porcelain.rb', line 13592

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



13594
13595
13596
# File 'lib/models/porcelain.rb', line 13594

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13622
13623
13624
13625
13626
13627
13628
# File 'lib/models/porcelain.rb', line 13622

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end