Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



13420
13421
13422
13423
13424
13425
13426
13427
13428
13429
13430
13431
13432
13433
13434
13435
13436
13437
13438
13439
13440
13441
13442
13443
13444
# File 'lib/models/porcelain.rb', line 13420

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



13398
13399
13400
# File 'lib/models/porcelain.rb', line 13398

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



13400
13401
13402
# File 'lib/models/porcelain.rb', line 13400

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



13402
13403
13404
# File 'lib/models/porcelain.rb', line 13402

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



13404
13405
13406
# File 'lib/models/porcelain.rb', line 13404

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



13406
13407
13408
# File 'lib/models/porcelain.rb', line 13406

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



13408
13409
13410
# File 'lib/models/porcelain.rb', line 13408

def name
  @name
end

#namespaceObject

The namespace to make requests within



13410
13411
13412
# File 'lib/models/porcelain.rb', line 13410

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



13412
13413
13414
# File 'lib/models/porcelain.rb', line 13412

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



13414
13415
13416
# File 'lib/models/porcelain.rb', line 13414

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



13416
13417
13418
# File 'lib/models/porcelain.rb', line 13416

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



13418
13419
13420
# File 'lib/models/porcelain.rb', line 13418

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13446
13447
13448
13449
13450
13451
13452
# File 'lib/models/porcelain.rb', line 13446

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end