Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



13353
13354
13355
13356
13357
13358
13359
13360
13361
13362
13363
13364
13365
13366
13367
13368
13369
13370
13371
13372
13373
13374
13375
13376
13377
# File 'lib/models/porcelain.rb', line 13353

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



13331
13332
13333
# File 'lib/models/porcelain.rb', line 13331

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



13333
13334
13335
# File 'lib/models/porcelain.rb', line 13333

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



13335
13336
13337
# File 'lib/models/porcelain.rb', line 13335

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



13337
13338
13339
# File 'lib/models/porcelain.rb', line 13337

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



13339
13340
13341
# File 'lib/models/porcelain.rb', line 13339

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



13341
13342
13343
# File 'lib/models/porcelain.rb', line 13341

def name
  @name
end

#namespaceObject

The namespace to make requests within



13343
13344
13345
# File 'lib/models/porcelain.rb', line 13343

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



13345
13346
13347
# File 'lib/models/porcelain.rb', line 13345

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



13347
13348
13349
# File 'lib/models/porcelain.rb', line 13347

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



13349
13350
13351
# File 'lib/models/porcelain.rb', line 13349

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



13351
13352
13353
# File 'lib/models/porcelain.rb', line 13351

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13379
13380
13381
13382
13383
13384
13385
# File 'lib/models/porcelain.rb', line 13379

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end