Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



13269
13270
13271
13272
13273
13274
13275
13276
13277
13278
13279
13280
13281
13282
13283
13284
13285
13286
13287
13288
13289
13290
13291
13292
13293
# File 'lib/models/porcelain.rb', line 13269

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



13247
13248
13249
# File 'lib/models/porcelain.rb', line 13247

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



13249
13250
13251
# File 'lib/models/porcelain.rb', line 13249

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



13251
13252
13253
# File 'lib/models/porcelain.rb', line 13251

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



13253
13254
13255
# File 'lib/models/porcelain.rb', line 13253

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



13255
13256
13257
# File 'lib/models/porcelain.rb', line 13255

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



13257
13258
13259
# File 'lib/models/porcelain.rb', line 13257

def name
  @name
end

#namespaceObject

The namespace to make requests within



13259
13260
13261
# File 'lib/models/porcelain.rb', line 13259

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



13261
13262
13263
# File 'lib/models/porcelain.rb', line 13261

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



13263
13264
13265
# File 'lib/models/porcelain.rb', line 13263

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



13265
13266
13267
# File 'lib/models/porcelain.rb', line 13265

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



13267
13268
13269
# File 'lib/models/porcelain.rb', line 13267

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13295
13296
13297
13298
13299
13300
13301
# File 'lib/models/porcelain.rb', line 13295

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end