Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



13199
13200
13201
13202
13203
13204
13205
13206
13207
13208
13209
13210
13211
13212
13213
13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
# File 'lib/models/porcelain.rb', line 13199

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



13177
13178
13179
# File 'lib/models/porcelain.rb', line 13177

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



13179
13180
13181
# File 'lib/models/porcelain.rb', line 13179

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



13181
13182
13183
# File 'lib/models/porcelain.rb', line 13181

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



13183
13184
13185
# File 'lib/models/porcelain.rb', line 13183

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



13185
13186
13187
# File 'lib/models/porcelain.rb', line 13185

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



13187
13188
13189
# File 'lib/models/porcelain.rb', line 13187

def name
  @name
end

#namespaceObject

The namespace to make requests within



13189
13190
13191
# File 'lib/models/porcelain.rb', line 13189

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



13191
13192
13193
# File 'lib/models/porcelain.rb', line 13191

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



13193
13194
13195
# File 'lib/models/porcelain.rb', line 13193

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



13195
13196
13197
# File 'lib/models/porcelain.rb', line 13195

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



13197
13198
13199
# File 'lib/models/porcelain.rb', line 13197

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13225
13226
13227
13228
13229
13230
13231
# File 'lib/models/porcelain.rb', line 13225

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end