Class: SDM::VaultTLSCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTLSCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store
constructor
A new instance of VaultTLSCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store
Returns a new instance of VaultTLSCertX509Store.
12580 12581 12582 12583 12584 12585 12586 12587 12588 12589 12590 12591 12592 12593 12594 12595 12596 12597 12598 12599 12600 12601 12602 12603 12604 |
# File 'lib/models/porcelain.rb', line 12580 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
12558 12559 12560 |
# File 'lib/models/porcelain.rb', line 12558 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
12560 12561 12562 |
# File 'lib/models/porcelain.rb', line 12560 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
12562 12563 12564 |
# File 'lib/models/porcelain.rb', line 12562 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
12564 12565 12566 |
# File 'lib/models/porcelain.rb', line 12564 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
12566 12567 12568 |
# File 'lib/models/porcelain.rb', line 12566 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
12568 12569 12570 |
# File 'lib/models/porcelain.rb', line 12568 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
12570 12571 12572 |
# File 'lib/models/porcelain.rb', line 12570 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
12572 12573 12574 |
# File 'lib/models/porcelain.rb', line 12572 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
12574 12575 12576 |
# File 'lib/models/porcelain.rb', line 12574 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
12576 12577 12578 |
# File 'lib/models/porcelain.rb', line 12576 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12578 12579 12580 |
# File 'lib/models/porcelain.rb', line 12578 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12606 12607 12608 12609 12610 12611 12612 |
# File 'lib/models/porcelain.rb', line 12606 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |