Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



12440
12441
12442
12443
12444
12445
12446
12447
12448
12449
12450
12451
12452
12453
12454
12455
12456
12457
12458
12459
12460
12461
12462
12463
12464
# File 'lib/models/porcelain.rb', line 12440

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



12418
12419
12420
# File 'lib/models/porcelain.rb', line 12418

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



12420
12421
12422
# File 'lib/models/porcelain.rb', line 12420

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



12422
12423
12424
# File 'lib/models/porcelain.rb', line 12422

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



12424
12425
12426
# File 'lib/models/porcelain.rb', line 12424

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



12426
12427
12428
# File 'lib/models/porcelain.rb', line 12426

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



12428
12429
12430
# File 'lib/models/porcelain.rb', line 12428

def name
  @name
end

#namespaceObject

The namespace to make requests within



12430
12431
12432
# File 'lib/models/porcelain.rb', line 12430

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



12432
12433
12434
# File 'lib/models/porcelain.rb', line 12432

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



12434
12435
12436
# File 'lib/models/porcelain.rb', line 12434

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



12436
12437
12438
# File 'lib/models/porcelain.rb', line 12436

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



12438
12439
12440
# File 'lib/models/porcelain.rb', line 12438

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12466
12467
12468
12469
12470
12471
12472
# File 'lib/models/porcelain.rb', line 12466

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end