Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



12085
12086
12087
12088
12089
12090
12091
12092
12093
12094
12095
12096
12097
12098
12099
12100
12101
12102
12103
12104
12105
12106
12107
12108
12109
# File 'lib/models/porcelain.rb', line 12085

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



12063
12064
12065
# File 'lib/models/porcelain.rb', line 12063

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



12065
12066
12067
# File 'lib/models/porcelain.rb', line 12065

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



12067
12068
12069
# File 'lib/models/porcelain.rb', line 12067

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



12069
12070
12071
# File 'lib/models/porcelain.rb', line 12069

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



12071
12072
12073
# File 'lib/models/porcelain.rb', line 12071

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



12073
12074
12075
# File 'lib/models/porcelain.rb', line 12073

def name
  @name
end

#namespaceObject

The namespace to make requests within



12075
12076
12077
# File 'lib/models/porcelain.rb', line 12075

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



12077
12078
12079
# File 'lib/models/porcelain.rb', line 12077

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



12079
12080
12081
# File 'lib/models/porcelain.rb', line 12079

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



12081
12082
12083
# File 'lib/models/porcelain.rb', line 12081

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



12083
12084
12085
# File 'lib/models/porcelain.rb', line 12083

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12111
12112
12113
12114
12115
12116
12117
# File 'lib/models/porcelain.rb', line 12111

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end