Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



11907
11908
11909
11910
11911
11912
11913
11914
11915
11916
11917
11918
11919
11920
11921
11922
11923
11924
11925
11926
11927
11928
11929
11930
11931
# File 'lib/models/porcelain.rb', line 11907

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



11885
11886
11887
# File 'lib/models/porcelain.rb', line 11885

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



11887
11888
11889
# File 'lib/models/porcelain.rb', line 11887

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



11889
11890
11891
# File 'lib/models/porcelain.rb', line 11889

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



11891
11892
11893
# File 'lib/models/porcelain.rb', line 11891

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



11893
11894
11895
# File 'lib/models/porcelain.rb', line 11893

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



11895
11896
11897
# File 'lib/models/porcelain.rb', line 11895

def name
  @name
end

#namespaceObject

The namespace to make requests within



11897
11898
11899
# File 'lib/models/porcelain.rb', line 11897

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



11899
11900
11901
# File 'lib/models/porcelain.rb', line 11899

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



11901
11902
11903
# File 'lib/models/porcelain.rb', line 11901

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



11903
11904
11905
# File 'lib/models/porcelain.rb', line 11903

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



11905
11906
11907
# File 'lib/models/porcelain.rb', line 11905

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11933
11934
11935
11936
11937
11938
11939
# File 'lib/models/porcelain.rb', line 11933

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end