Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



11523
11524
11525
11526
11527
11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
11539
11540
11541
11542
11543
11544
11545
11546
11547
# File 'lib/models/porcelain.rb', line 11523

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



11501
11502
11503
# File 'lib/models/porcelain.rb', line 11501

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



11503
11504
11505
# File 'lib/models/porcelain.rb', line 11503

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



11505
11506
11507
# File 'lib/models/porcelain.rb', line 11505

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



11507
11508
11509
# File 'lib/models/porcelain.rb', line 11507

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



11509
11510
11511
# File 'lib/models/porcelain.rb', line 11509

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



11511
11512
11513
# File 'lib/models/porcelain.rb', line 11511

def name
  @name
end

#namespaceObject

The namespace to make requests within



11513
11514
11515
# File 'lib/models/porcelain.rb', line 11513

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



11515
11516
11517
# File 'lib/models/porcelain.rb', line 11515

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



11517
11518
11519
# File 'lib/models/porcelain.rb', line 11517

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



11519
11520
11521
# File 'lib/models/porcelain.rb', line 11519

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



11521
11522
11523
# File 'lib/models/porcelain.rb', line 11521

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11549
11550
11551
11552
11553
11554
11555
# File 'lib/models/porcelain.rb', line 11549

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end