Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



11034
11035
11036
11037
11038
11039
11040
11041
11042
11043
11044
11045
11046
11047
11048
11049
11050
11051
11052
11053
11054
11055
11056
11057
11058
# File 'lib/models/porcelain.rb', line 11034

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



11012
11013
11014
# File 'lib/models/porcelain.rb', line 11012

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



11014
11015
11016
# File 'lib/models/porcelain.rb', line 11014

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



11016
11017
11018
# File 'lib/models/porcelain.rb', line 11016

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



11018
11019
11020
# File 'lib/models/porcelain.rb', line 11018

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



11020
11021
11022
# File 'lib/models/porcelain.rb', line 11020

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



11022
11023
11024
# File 'lib/models/porcelain.rb', line 11022

def name
  @name
end

#namespaceObject

The namespace to make requests within



11024
11025
11026
# File 'lib/models/porcelain.rb', line 11024

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



11026
11027
11028
# File 'lib/models/porcelain.rb', line 11026

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



11028
11029
11030
# File 'lib/models/porcelain.rb', line 11028

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



11030
11031
11032
# File 'lib/models/porcelain.rb', line 11030

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



11032
11033
11034
# File 'lib/models/porcelain.rb', line 11032

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11060
11061
11062
11063
11064
11065
11066
# File 'lib/models/porcelain.rb', line 11060

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end