Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



10824
10825
10826
10827
10828
10829
10830
10831
10832
10833
10834
10835
10836
10837
10838
10839
10840
10841
10842
10843
10844
10845
10846
10847
10848
# File 'lib/models/porcelain.rb', line 10824

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



10802
10803
10804
# File 'lib/models/porcelain.rb', line 10802

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



10804
10805
10806
# File 'lib/models/porcelain.rb', line 10804

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



10806
10807
10808
# File 'lib/models/porcelain.rb', line 10806

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



10808
10809
10810
# File 'lib/models/porcelain.rb', line 10808

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



10810
10811
10812
# File 'lib/models/porcelain.rb', line 10810

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



10812
10813
10814
# File 'lib/models/porcelain.rb', line 10812

def name
  @name
end

#namespaceObject

The namespace to make requests within



10814
10815
10816
# File 'lib/models/porcelain.rb', line 10814

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



10816
10817
10818
# File 'lib/models/porcelain.rb', line 10816

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



10818
10819
10820
# File 'lib/models/porcelain.rb', line 10818

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



10820
10821
10822
# File 'lib/models/porcelain.rb', line 10820

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



10822
10823
10824
# File 'lib/models/porcelain.rb', line 10822

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10850
10851
10852
10853
10854
10855
10856
# File 'lib/models/porcelain.rb', line 10850

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end