Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

VaultTLSCertX509Store is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
10125
10126
10127
10128
10129
10130
10131
# File 'lib/models/porcelain.rb', line 10109

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



10089
10090
10091
# File 'lib/models/porcelain.rb', line 10089

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



10091
10092
10093
# File 'lib/models/porcelain.rb', line 10091

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



10093
10094
10095
# File 'lib/models/porcelain.rb', line 10093

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



10095
10096
10097
# File 'lib/models/porcelain.rb', line 10095

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



10097
10098
10099
# File 'lib/models/porcelain.rb', line 10097

def name
  @name
end

#namespaceObject

The namespace to make requests within



10099
10100
10101
# File 'lib/models/porcelain.rb', line 10099

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



10101
10102
10103
# File 'lib/models/porcelain.rb', line 10101

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



10103
10104
10105
# File 'lib/models/porcelain.rb', line 10103

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



10105
10106
10107
# File 'lib/models/porcelain.rb', line 10105

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



10107
10108
10109
# File 'lib/models/porcelain.rb', line 10107

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10133
10134
10135
10136
10137
10138
10139
# File 'lib/models/porcelain.rb', line 10133

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end