Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



18304
18305
18306
18307
18308
18309
18310
18311
18312
18313
18314
18315
18316
18317
18318
18319
18320
18321
18322
18323
18324
18325
18326
18327
18328
# File 'lib/models/porcelain.rb', line 18304

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18282
18283
18284
# File 'lib/models/porcelain.rb', line 18282

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18284
18285
18286
# File 'lib/models/porcelain.rb', line 18284

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18286
18287
18288
# File 'lib/models/porcelain.rb', line 18286

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18288
18289
18290
# File 'lib/models/porcelain.rb', line 18288

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



18290
18291
18292
# File 'lib/models/porcelain.rb', line 18290

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



18292
18293
18294
# File 'lib/models/porcelain.rb', line 18292

def name
  @name
end

#namespaceObject

The namespace to make requests within



18294
18295
18296
# File 'lib/models/porcelain.rb', line 18294

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



18296
18297
18298
# File 'lib/models/porcelain.rb', line 18296

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



18298
18299
18300
# File 'lib/models/porcelain.rb', line 18298

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



18300
18301
18302
# File 'lib/models/porcelain.rb', line 18300

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



18302
18303
18304
# File 'lib/models/porcelain.rb', line 18302

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18330
18331
18332
18333
18334
18335
18336
# File 'lib/models/porcelain.rb', line 18330

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end