Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store

Returns a new instance of VaultTLSCertX509Store.



18998
18999
19000
19001
19002
19003
19004
19005
19006
19007
19008
19009
19010
19011
19012
19013
19014
19015
19016
19017
19018
19019
19020
19021
19022
# File 'lib/models/porcelain.rb', line 18998

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_path ⇒ Object

A path to a CA file accessible by a Node



18976
18977
18978
# File 'lib/models/porcelain.rb', line 18976

def ca_cert_path
  @ca_cert_path
end

#client_cert_path ⇒ Object

A path to a client certificate file accessible by a Node



18978
18979
18980
# File 'lib/models/porcelain.rb', line 18978

def client_cert_path
  @client_cert_path
end

#client_key_path ⇒ Object

A path to a client key file accessible by a Node



18980
18981
18982
# File 'lib/models/porcelain.rb', line 18980

def client_key_path
  @client_key_path
end

#id ⇒ Object

Unique identifier of the SecretStore.



18982
18983
18984
# File 'lib/models/porcelain.rb', line 18982

def id
  @id
end

#issuedcertttlminutes ⇒ Object

The lifetime of certificates issued by this CA represented in minutes.



18984
18985
18986
# File 'lib/models/porcelain.rb', line 18984

def issuedcertttlminutes
  @issuedcertttlminutes
end

#name ⇒ Object

Unique human-readable name of the SecretStore.



18986
18987
18988
# File 'lib/models/porcelain.rb', line 18986

def name
  @name
end

#namespace ⇒ Object

The namespace to make requests within



18988
18989
18990
# File 'lib/models/porcelain.rb', line 18988

def namespace
  @namespace
end

#pki_mount_point ⇒ Object

The mount point of the PKI engine configured with the desired CA



18990
18991
18992
# File 'lib/models/porcelain.rb', line 18990

def pki_mount_point
  @pki_mount_point
end

#server_address ⇒ Object

The URL of the Vault to target



18992
18993
18994
# File 'lib/models/porcelain.rb', line 18992

def server_address
  @server_address
end

#signing_role ⇒ Object

The signing role to be used for signing certificates



18994
18995
18996
# File 'lib/models/porcelain.rb', line 18994

def signing_role
  @signing_role
end

#tags ⇒ Object

Tags is a map of key, value pairs.



18996
18997
18998
# File 'lib/models/porcelain.rb', line 18996

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19024
19025
19026
19027
19028
19029
19030
# File 'lib/models/porcelain.rb', line 19024

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end