Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
18991 18992 18993 18994 18995 18996 18997 18998 18999 19000 19001 19002 19003 19004 19005 19006 19007 19008 19009 |
# File 'lib/models/porcelain.rb', line 18991 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
18975 18976 18977 |
# File 'lib/models/porcelain.rb', line 18975 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
18977 18978 18979 |
# File 'lib/models/porcelain.rb', line 18977 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
18979 18980 18981 |
# File 'lib/models/porcelain.rb', line 18979 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
18981 18982 18983 |
# File 'lib/models/porcelain.rb', line 18981 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18983 18984 18985 |
# File 'lib/models/porcelain.rb', line 18983 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18985 18986 18987 |
# File 'lib/models/porcelain.rb', line 18985 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18987 18988 18989 |
# File 'lib/models/porcelain.rb', line 18987 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18989 18990 18991 |
# File 'lib/models/porcelain.rb', line 18989 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
19011 19012 19013 19014 19015 19016 19017 |
# File 'lib/models/porcelain.rb', line 19011 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |