Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



18859
18860
18861
18862
18863
18864
18865
18866
18867
18868
18869
18870
18871
18872
18873
18874
18875
18876
18877
# File 'lib/models/porcelain.rb', line 18859

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18843
18844
18845
# File 'lib/models/porcelain.rb', line 18843

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18845
18846
18847
# File 'lib/models/porcelain.rb', line 18845

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18847
18848
18849
# File 'lib/models/porcelain.rb', line 18847

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18849
18850
18851
# File 'lib/models/porcelain.rb', line 18849

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



18851
18852
18853
# File 'lib/models/porcelain.rb', line 18851

def name
  @name
end

#namespaceObject

The namespace to make requests within



18853
18854
18855
# File 'lib/models/porcelain.rb', line 18853

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



18855
18856
18857
# File 'lib/models/porcelain.rb', line 18855

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



18857
18858
18859
# File 'lib/models/porcelain.rb', line 18857

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18879
18880
18881
18882
18883
18884
18885
# File 'lib/models/porcelain.rb', line 18879

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end