Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
18633 18634 18635 18636 18637 18638 18639 18640 18641 18642 18643 18644 18645 18646 18647 18648 18649 18650 18651 |
# File 'lib/models/porcelain.rb', line 18633 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
18617 18618 18619 |
# File 'lib/models/porcelain.rb', line 18617 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
18619 18620 18621 |
# File 'lib/models/porcelain.rb', line 18619 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
18621 18622 18623 |
# File 'lib/models/porcelain.rb', line 18621 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
18623 18624 18625 |
# File 'lib/models/porcelain.rb', line 18623 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18625 18626 18627 |
# File 'lib/models/porcelain.rb', line 18625 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18627 18628 18629 |
# File 'lib/models/porcelain.rb', line 18627 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18629 18630 18631 |
# File 'lib/models/porcelain.rb', line 18629 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18631 18632 18633 |
# File 'lib/models/porcelain.rb', line 18631 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18653 18654 18655 18656 18657 18658 18659 |
# File 'lib/models/porcelain.rb', line 18653 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |