Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



18625
18626
18627
18628
18629
18630
18631
18632
18633
18634
18635
18636
18637
18638
18639
18640
18641
18642
18643
# File 'lib/models/porcelain.rb', line 18625

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18609
18610
18611
# File 'lib/models/porcelain.rb', line 18609

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18611
18612
18613
# File 'lib/models/porcelain.rb', line 18611

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18613
18614
18615
# File 'lib/models/porcelain.rb', line 18613

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18615
18616
18617
# File 'lib/models/porcelain.rb', line 18615

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



18617
18618
18619
# File 'lib/models/porcelain.rb', line 18617

def name
  @name
end

#namespaceObject

The namespace to make requests within



18619
18620
18621
# File 'lib/models/porcelain.rb', line 18619

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



18621
18622
18623
# File 'lib/models/porcelain.rb', line 18621

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



18623
18624
18625
# File 'lib/models/porcelain.rb', line 18623

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18645
18646
18647
18648
18649
18650
18651
# File 'lib/models/porcelain.rb', line 18645

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end