Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



18509
18510
18511
18512
18513
18514
18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
# File 'lib/models/porcelain.rb', line 18509

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18493
18494
18495
# File 'lib/models/porcelain.rb', line 18493

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18495
18496
18497
# File 'lib/models/porcelain.rb', line 18495

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18497
18498
18499
# File 'lib/models/porcelain.rb', line 18497

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18499
18500
18501
# File 'lib/models/porcelain.rb', line 18499

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



18501
18502
18503
# File 'lib/models/porcelain.rb', line 18501

def name
  @name
end

#namespaceObject

The namespace to make requests within



18503
18504
18505
# File 'lib/models/porcelain.rb', line 18503

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



18505
18506
18507
# File 'lib/models/porcelain.rb', line 18505

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



18507
18508
18509
# File 'lib/models/porcelain.rb', line 18507

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18529
18530
18531
18532
18533
18534
18535
# File 'lib/models/porcelain.rb', line 18529

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end