Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
18132 18133 18134 18135 18136 18137 18138 18139 18140 18141 18142 18143 18144 18145 18146 18147 18148 18149 18150 |
# File 'lib/models/porcelain.rb', line 18132 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
18116 18117 18118 |
# File 'lib/models/porcelain.rb', line 18116 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
18118 18119 18120 |
# File 'lib/models/porcelain.rb', line 18118 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
18120 18121 18122 |
# File 'lib/models/porcelain.rb', line 18120 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
18122 18123 18124 |
# File 'lib/models/porcelain.rb', line 18122 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18124 18125 18126 |
# File 'lib/models/porcelain.rb', line 18124 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18126 18127 18128 |
# File 'lib/models/porcelain.rb', line 18126 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18128 18129 18130 |
# File 'lib/models/porcelain.rb', line 18128 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18130 18131 18132 |
# File 'lib/models/porcelain.rb', line 18130 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18152 18153 18154 18155 18156 18157 18158 |
# File 'lib/models/porcelain.rb', line 18152 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |