Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 18122 18123 18124 18125 18126 18127 18128 18129 18130 |
# File 'lib/models/porcelain.rb', line 18112 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
18096 18097 18098 |
# File 'lib/models/porcelain.rb', line 18096 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
18098 18099 18100 |
# File 'lib/models/porcelain.rb', line 18098 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
18100 18101 18102 |
# File 'lib/models/porcelain.rb', line 18100 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
18102 18103 18104 |
# File 'lib/models/porcelain.rb', line 18102 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18104 18105 18106 |
# File 'lib/models/porcelain.rb', line 18104 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18106 18107 18108 |
# File 'lib/models/porcelain.rb', line 18106 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18108 18109 18110 |
# File 'lib/models/porcelain.rb', line 18108 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18110 18111 18112 |
# File 'lib/models/porcelain.rb', line 18110 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18132 18133 18134 18135 18136 18137 18138 |
# File 'lib/models/porcelain.rb', line 18132 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |