Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



17826
17827
17828
17829
17830
17831
17832
17833
17834
17835
17836
17837
17838
17839
17840
17841
17842
17843
17844
# File 'lib/models/porcelain.rb', line 17826

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



17810
17811
17812
# File 'lib/models/porcelain.rb', line 17810

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



17812
17813
17814
# File 'lib/models/porcelain.rb', line 17812

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



17814
17815
17816
# File 'lib/models/porcelain.rb', line 17814

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



17816
17817
17818
# File 'lib/models/porcelain.rb', line 17816

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



17818
17819
17820
# File 'lib/models/porcelain.rb', line 17818

def name
  @name
end

#namespaceObject

The namespace to make requests within



17820
17821
17822
# File 'lib/models/porcelain.rb', line 17820

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



17822
17823
17824
# File 'lib/models/porcelain.rb', line 17822

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



17824
17825
17826
# File 'lib/models/porcelain.rb', line 17824

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17846
17847
17848
17849
17850
17851
17852
# File 'lib/models/porcelain.rb', line 17846

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end