Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



17762
17763
17764
17765
17766
17767
17768
17769
17770
17771
17772
17773
17774
17775
17776
17777
17778
17779
17780
# File 'lib/models/porcelain.rb', line 17762

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



17746
17747
17748
# File 'lib/models/porcelain.rb', line 17746

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



17748
17749
17750
# File 'lib/models/porcelain.rb', line 17748

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



17750
17751
17752
# File 'lib/models/porcelain.rb', line 17750

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



17752
17753
17754
# File 'lib/models/porcelain.rb', line 17752

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



17754
17755
17756
# File 'lib/models/porcelain.rb', line 17754

def name
  @name
end

#namespaceObject

The namespace to make requests within



17756
17757
17758
# File 'lib/models/porcelain.rb', line 17756

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



17758
17759
17760
# File 'lib/models/porcelain.rb', line 17758

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



17760
17761
17762
# File 'lib/models/porcelain.rb', line 17760

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17782
17783
17784
17785
17786
17787
17788
# File 'lib/models/porcelain.rb', line 17782

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end