Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
16830 16831 16832 16833 16834 16835 16836 16837 16838 16839 16840 16841 16842 16843 16844 16845 16846 16847 16848 |
# File 'lib/models/porcelain.rb', line 16830 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
16814 16815 16816 |
# File 'lib/models/porcelain.rb', line 16814 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
16816 16817 16818 |
# File 'lib/models/porcelain.rb', line 16816 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
16818 16819 16820 |
# File 'lib/models/porcelain.rb', line 16818 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
16820 16821 16822 |
# File 'lib/models/porcelain.rb', line 16820 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
16822 16823 16824 |
# File 'lib/models/porcelain.rb', line 16822 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
16824 16825 16826 |
# File 'lib/models/porcelain.rb', line 16824 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
16826 16827 16828 |
# File 'lib/models/porcelain.rb', line 16826 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
16828 16829 16830 |
# File 'lib/models/porcelain.rb', line 16828 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16850 16851 16852 16853 16854 16855 16856 |
# File 'lib/models/porcelain.rb', line 16850 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |