Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



15312
15313
15314
15315
15316
15317
15318
15319
15320
15321
15322
15323
15324
15325
15326
15327
15328
15329
15330
# File 'lib/models/porcelain.rb', line 15312

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



15296
15297
15298
# File 'lib/models/porcelain.rb', line 15296

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



15298
15299
15300
# File 'lib/models/porcelain.rb', line 15298

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



15300
15301
15302
# File 'lib/models/porcelain.rb', line 15300

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



15302
15303
15304
# File 'lib/models/porcelain.rb', line 15302

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



15304
15305
15306
# File 'lib/models/porcelain.rb', line 15304

def name
  @name
end

#namespaceObject

The namespace to make requests within



15306
15307
15308
# File 'lib/models/porcelain.rb', line 15306

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



15308
15309
15310
# File 'lib/models/porcelain.rb', line 15308

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



15310
15311
15312
# File 'lib/models/porcelain.rb', line 15310

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15332
15333
15334
15335
15336
15337
15338
# File 'lib/models/porcelain.rb', line 15332

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end