Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
15128 15129 15130 15131 15132 15133 15134 15135 15136 15137 15138 15139 15140 15141 15142 15143 15144 15145 15146 |
# File 'lib/models/porcelain.rb', line 15128 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
15112 15113 15114 |
# File 'lib/models/porcelain.rb', line 15112 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
15114 15115 15116 |
# File 'lib/models/porcelain.rb', line 15114 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
15116 15117 15118 |
# File 'lib/models/porcelain.rb', line 15116 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
15118 15119 15120 |
# File 'lib/models/porcelain.rb', line 15118 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
15120 15121 15122 |
# File 'lib/models/porcelain.rb', line 15120 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
15122 15123 15124 |
# File 'lib/models/porcelain.rb', line 15122 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
15124 15125 15126 |
# File 'lib/models/porcelain.rb', line 15124 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
15126 15127 15128 |
# File 'lib/models/porcelain.rb', line 15126 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15148 15149 15150 15151 15152 15153 15154 |
# File 'lib/models/porcelain.rb', line 15148 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |