Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



15049
15050
15051
15052
15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
# File 'lib/models/porcelain.rb', line 15049

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



15033
15034
15035
# File 'lib/models/porcelain.rb', line 15033

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



15035
15036
15037
# File 'lib/models/porcelain.rb', line 15035

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



15037
15038
15039
# File 'lib/models/porcelain.rb', line 15037

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



15039
15040
15041
# File 'lib/models/porcelain.rb', line 15039

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



15041
15042
15043
# File 'lib/models/porcelain.rb', line 15041

def name
  @name
end

#namespaceObject

The namespace to make requests within



15043
15044
15045
# File 'lib/models/porcelain.rb', line 15043

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



15045
15046
15047
# File 'lib/models/porcelain.rb', line 15045

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



15047
15048
15049
# File 'lib/models/porcelain.rb', line 15047

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15069
15070
15071
15072
15073
15074
15075
# File 'lib/models/porcelain.rb', line 15069

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end