Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
14976 14977 14978 14979 14980 14981 14982 14983 14984 14985 14986 14987 14988 14989 14990 14991 14992 14993 14994 |
# File 'lib/models/porcelain.rb', line 14976 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
14960 14961 14962 |
# File 'lib/models/porcelain.rb', line 14960 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
14962 14963 14964 |
# File 'lib/models/porcelain.rb', line 14962 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
14964 14965 14966 |
# File 'lib/models/porcelain.rb', line 14964 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
14966 14967 14968 |
# File 'lib/models/porcelain.rb', line 14966 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
14968 14969 14970 |
# File 'lib/models/porcelain.rb', line 14968 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
14970 14971 14972 |
# File 'lib/models/porcelain.rb', line 14970 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
14972 14973 14974 |
# File 'lib/models/porcelain.rb', line 14972 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14974 14975 14976 |
# File 'lib/models/porcelain.rb', line 14974 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14996 14997 14998 14999 15000 15001 15002 |
# File 'lib/models/porcelain.rb', line 14996 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |