Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
14908 14909 14910 14911 14912 14913 14914 14915 14916 14917 14918 14919 14920 14921 14922 14923 14924 14925 14926 |
# File 'lib/models/porcelain.rb', line 14908 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
14892 14893 14894 |
# File 'lib/models/porcelain.rb', line 14892 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
14894 14895 14896 |
# File 'lib/models/porcelain.rb', line 14894 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
14896 14897 14898 |
# File 'lib/models/porcelain.rb', line 14896 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
14898 14899 14900 |
# File 'lib/models/porcelain.rb', line 14898 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
14900 14901 14902 |
# File 'lib/models/porcelain.rb', line 14900 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
14902 14903 14904 |
# File 'lib/models/porcelain.rb', line 14902 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
14904 14905 14906 |
# File 'lib/models/porcelain.rb', line 14904 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14906 14907 14908 |
# File 'lib/models/porcelain.rb', line 14906 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14928 14929 14930 14931 14932 14933 14934 |
# File 'lib/models/porcelain.rb', line 14928 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |