Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



13732
13733
13734
13735
13736
13737
13738
13739
13740
13741
13742
13743
13744
13745
13746
13747
13748
13749
13750
# File 'lib/models/porcelain.rb', line 13732

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



13716
13717
13718
# File 'lib/models/porcelain.rb', line 13716

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



13718
13719
13720
# File 'lib/models/porcelain.rb', line 13718

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



13720
13721
13722
# File 'lib/models/porcelain.rb', line 13720

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



13722
13723
13724
# File 'lib/models/porcelain.rb', line 13722

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



13724
13725
13726
# File 'lib/models/porcelain.rb', line 13724

def name
  @name
end

#namespaceObject

The namespace to make requests within



13726
13727
13728
# File 'lib/models/porcelain.rb', line 13726

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



13728
13729
13730
# File 'lib/models/porcelain.rb', line 13728

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



13730
13731
13732
# File 'lib/models/porcelain.rb', line 13730

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13752
13753
13754
13755
13756
13757
13758
# File 'lib/models/porcelain.rb', line 13752

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end