Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



13649
13650
13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
# File 'lib/models/porcelain.rb', line 13649

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



13633
13634
13635
# File 'lib/models/porcelain.rb', line 13633

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



13635
13636
13637
# File 'lib/models/porcelain.rb', line 13635

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



13637
13638
13639
# File 'lib/models/porcelain.rb', line 13637

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



13639
13640
13641
# File 'lib/models/porcelain.rb', line 13639

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



13641
13642
13643
# File 'lib/models/porcelain.rb', line 13641

def name
  @name
end

#namespaceObject

The namespace to make requests within



13643
13644
13645
# File 'lib/models/porcelain.rb', line 13643

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



13645
13646
13647
# File 'lib/models/porcelain.rb', line 13645

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



13647
13648
13649
# File 'lib/models/porcelain.rb', line 13647

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13669
13670
13671
13672
13673
13674
13675
# File 'lib/models/porcelain.rb', line 13669

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end