Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
13641 13642 13643 13644 13645 13646 13647 13648 13649 13650 13651 13652 13653 13654 13655 13656 13657 13658 13659 |
# File 'lib/models/porcelain.rb', line 13641 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
13625 13626 13627 |
# File 'lib/models/porcelain.rb', line 13625 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
13627 13628 13629 |
# File 'lib/models/porcelain.rb', line 13627 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
13629 13630 13631 |
# File 'lib/models/porcelain.rb', line 13629 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
13631 13632 13633 |
# File 'lib/models/porcelain.rb', line 13631 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13633 13634 13635 |
# File 'lib/models/porcelain.rb', line 13633 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13635 13636 13637 |
# File 'lib/models/porcelain.rb', line 13635 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
13637 13638 13639 |
# File 'lib/models/porcelain.rb', line 13637 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13639 13640 13641 |
# File 'lib/models/porcelain.rb', line 13639 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13661 13662 13663 13664 13665 13666 13667 |
# File 'lib/models/porcelain.rb', line 13661 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |