Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
13405 13406 13407 13408 13409 13410 13411 13412 13413 13414 13415 13416 13417 13418 13419 13420 13421 13422 13423 |
# File 'lib/models/porcelain.rb', line 13405 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
13389 13390 13391 |
# File 'lib/models/porcelain.rb', line 13389 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
13391 13392 13393 |
# File 'lib/models/porcelain.rb', line 13391 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
13393 13394 13395 |
# File 'lib/models/porcelain.rb', line 13393 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
13395 13396 13397 |
# File 'lib/models/porcelain.rb', line 13395 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13397 13398 13399 |
# File 'lib/models/porcelain.rb', line 13397 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13399 13400 13401 |
# File 'lib/models/porcelain.rb', line 13399 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
13401 13402 13403 |
# File 'lib/models/porcelain.rb', line 13401 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13403 13404 13405 |
# File 'lib/models/porcelain.rb', line 13403 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13425 13426 13427 13428 13429 13430 13431 |
# File 'lib/models/porcelain.rb', line 13425 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |