Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



13322
13323
13324
13325
13326
13327
13328
13329
13330
13331
13332
13333
13334
13335
13336
13337
13338
13339
13340
# File 'lib/models/porcelain.rb', line 13322

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



13306
13307
13308
# File 'lib/models/porcelain.rb', line 13306

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



13308
13309
13310
# File 'lib/models/porcelain.rb', line 13308

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



13310
13311
13312
# File 'lib/models/porcelain.rb', line 13310

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



13312
13313
13314
# File 'lib/models/porcelain.rb', line 13312

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



13314
13315
13316
# File 'lib/models/porcelain.rb', line 13314

def name
  @name
end

#namespaceObject

The namespace to make requests within



13316
13317
13318
# File 'lib/models/porcelain.rb', line 13316

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



13318
13319
13320
# File 'lib/models/porcelain.rb', line 13318

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



13320
13321
13322
# File 'lib/models/porcelain.rb', line 13320

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13342
13343
13344
13345
13346
13347
13348
# File 'lib/models/porcelain.rb', line 13342

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end