Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
12888 12889 12890 12891 12892 12893 12894 12895 12896 12897 12898 12899 12900 12901 12902 12903 12904 12905 12906 |
# File 'lib/models/porcelain.rb', line 12888 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
12872 12873 12874 |
# File 'lib/models/porcelain.rb', line 12872 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
12874 12875 12876 |
# File 'lib/models/porcelain.rb', line 12874 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
12876 12877 12878 |
# File 'lib/models/porcelain.rb', line 12876 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
12878 12879 12880 |
# File 'lib/models/porcelain.rb', line 12878 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
12880 12881 12882 |
# File 'lib/models/porcelain.rb', line 12880 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
12882 12883 12884 |
# File 'lib/models/porcelain.rb', line 12882 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
12884 12885 12886 |
# File 'lib/models/porcelain.rb', line 12884 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12886 12887 12888 |
# File 'lib/models/porcelain.rb', line 12886 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12908 12909 12910 12911 12912 12913 12914 |
# File 'lib/models/porcelain.rb', line 12908 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |