Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



12890
12891
12892
12893
12894
12895
12896
12897
12898
12899
12900
12901
12902
12903
12904
12905
12906
12907
12908
# File 'lib/models/porcelain.rb', line 12890

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



12874
12875
12876
# File 'lib/models/porcelain.rb', line 12874

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



12876
12877
12878
# File 'lib/models/porcelain.rb', line 12876

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



12878
12879
12880
# File 'lib/models/porcelain.rb', line 12878

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



12880
12881
12882
# File 'lib/models/porcelain.rb', line 12880

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



12882
12883
12884
# File 'lib/models/porcelain.rb', line 12882

def name
  @name
end

#namespaceObject

The namespace to make requests within



12884
12885
12886
# File 'lib/models/porcelain.rb', line 12884

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



12886
12887
12888
# File 'lib/models/porcelain.rb', line 12886

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



12888
12889
12890
# File 'lib/models/porcelain.rb', line 12888

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12910
12911
12912
12913
12914
12915
12916
# File 'lib/models/porcelain.rb', line 12910

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end