Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
12633 12634 12635 12636 12637 12638 12639 12640 12641 12642 12643 12644 12645 12646 12647 12648 12649 12650 12651 |
# File 'lib/models/porcelain.rb', line 12633 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
12617 12618 12619 |
# File 'lib/models/porcelain.rb', line 12617 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
12619 12620 12621 |
# File 'lib/models/porcelain.rb', line 12619 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
12621 12622 12623 |
# File 'lib/models/porcelain.rb', line 12621 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
12623 12624 12625 |
# File 'lib/models/porcelain.rb', line 12623 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
12625 12626 12627 |
# File 'lib/models/porcelain.rb', line 12625 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
12627 12628 12629 |
# File 'lib/models/porcelain.rb', line 12627 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
12629 12630 12631 |
# File 'lib/models/porcelain.rb', line 12629 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12631 12632 12633 |
# File 'lib/models/porcelain.rb', line 12631 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12653 12654 12655 12656 12657 12658 12659 |
# File 'lib/models/porcelain.rb', line 12653 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |