Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



12562
12563
12564
12565
12566
12567
12568
12569
12570
12571
12572
12573
12574
12575
12576
12577
12578
12579
12580
# File 'lib/models/porcelain.rb', line 12562

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



12546
12547
12548
# File 'lib/models/porcelain.rb', line 12546

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



12548
12549
12550
# File 'lib/models/porcelain.rb', line 12548

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



12550
12551
12552
# File 'lib/models/porcelain.rb', line 12550

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



12552
12553
12554
# File 'lib/models/porcelain.rb', line 12552

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



12554
12555
12556
# File 'lib/models/porcelain.rb', line 12554

def name
  @name
end

#namespaceObject

The namespace to make requests within



12556
12557
12558
# File 'lib/models/porcelain.rb', line 12556

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



12558
12559
12560
# File 'lib/models/porcelain.rb', line 12558

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



12560
12561
12562
# File 'lib/models/porcelain.rb', line 12560

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12582
12583
12584
12585
12586
12587
12588
# File 'lib/models/porcelain.rb', line 12582

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end