Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
12138 12139 12140 12141 12142 12143 12144 12145 12146 12147 12148 12149 12150 12151 12152 12153 12154 12155 12156 |
# File 'lib/models/porcelain.rb', line 12138 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
12122 12123 12124 |
# File 'lib/models/porcelain.rb', line 12122 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
12124 12125 12126 |
# File 'lib/models/porcelain.rb', line 12124 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
12126 12127 12128 |
# File 'lib/models/porcelain.rb', line 12126 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
12128 12129 12130 |
# File 'lib/models/porcelain.rb', line 12128 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
12130 12131 12132 |
# File 'lib/models/porcelain.rb', line 12130 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
12132 12133 12134 |
# File 'lib/models/porcelain.rb', line 12132 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
12134 12135 12136 |
# File 'lib/models/porcelain.rb', line 12134 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12136 12137 12138 |
# File 'lib/models/porcelain.rb', line 12136 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12158 12159 12160 12161 12162 12163 12164 |
# File 'lib/models/porcelain.rb', line 12158 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |