Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
11965 11966 11967 11968 11969 11970 11971 11972 11973 11974 11975 11976 11977 11978 11979 11980 11981 11982 11983 |
# File 'lib/models/porcelain.rb', line 11965 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
11949 11950 11951 |
# File 'lib/models/porcelain.rb', line 11949 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
11951 11952 11953 |
# File 'lib/models/porcelain.rb', line 11951 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
11953 11954 11955 |
# File 'lib/models/porcelain.rb', line 11953 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
11955 11956 11957 |
# File 'lib/models/porcelain.rb', line 11955 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
11957 11958 11959 |
# File 'lib/models/porcelain.rb', line 11957 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
11959 11960 11961 |
# File 'lib/models/porcelain.rb', line 11959 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
11961 11962 11963 |
# File 'lib/models/porcelain.rb', line 11961 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11963 11964 11965 |
# File 'lib/models/porcelain.rb', line 11963 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11985 11986 11987 11988 11989 11990 11991 |
# File 'lib/models/porcelain.rb', line 11985 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |