Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



10160
10161
10162
10163
10164
10165
10166
10167
10168
10169
10170
10171
10172
10173
10174
10175
10176
10177
10178
# File 'lib/models/porcelain.rb', line 10160

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



10144
10145
10146
# File 'lib/models/porcelain.rb', line 10144

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



10146
10147
10148
# File 'lib/models/porcelain.rb', line 10146

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



10148
10149
10150
# File 'lib/models/porcelain.rb', line 10148

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



10150
10151
10152
# File 'lib/models/porcelain.rb', line 10150

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



10152
10153
10154
# File 'lib/models/porcelain.rb', line 10152

def name
  @name
end

#namespaceObject

The namespace to make requests within



10154
10155
10156
# File 'lib/models/porcelain.rb', line 10154

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



10156
10157
10158
# File 'lib/models/porcelain.rb', line 10156

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



10158
10159
10160
# File 'lib/models/porcelain.rb', line 10158

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10180
10181
10182
10183
10184
10185
10186
# File 'lib/models/porcelain.rb', line 10180

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end