Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
9728 9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 |
# File 'lib/models/porcelain.rb', line 9728 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
9712 9713 9714 |
# File 'lib/models/porcelain.rb', line 9712 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
9714 9715 9716 |
# File 'lib/models/porcelain.rb', line 9714 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
9716 9717 9718 |
# File 'lib/models/porcelain.rb', line 9716 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
9718 9719 9720 |
# File 'lib/models/porcelain.rb', line 9718 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
9720 9721 9722 |
# File 'lib/models/porcelain.rb', line 9720 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
9722 9723 9724 |
# File 'lib/models/porcelain.rb', line 9722 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
9724 9725 9726 |
# File 'lib/models/porcelain.rb', line 9724 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9726 9727 9728 |
# File 'lib/models/porcelain.rb', line 9726 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9748 9749 9750 9751 9752 9753 9754 |
# File 'lib/models/porcelain.rb', line 9748 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |