Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
9510
# File 'lib/models/porcelain.rb', line 9492

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



9476
9477
9478
# File 'lib/models/porcelain.rb', line 9476

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



9478
9479
9480
# File 'lib/models/porcelain.rb', line 9478

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



9480
9481
9482
# File 'lib/models/porcelain.rb', line 9480

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



9482
9483
9484
# File 'lib/models/porcelain.rb', line 9482

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



9484
9485
9486
# File 'lib/models/porcelain.rb', line 9484

def name
  @name
end

#namespaceObject

The namespace to make requests within



9486
9487
9488
# File 'lib/models/porcelain.rb', line 9486

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



9488
9489
9490
# File 'lib/models/porcelain.rb', line 9488

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



9490
9491
9492
# File 'lib/models/porcelain.rb', line 9490

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9512
9513
9514
9515
9516
9517
9518
# File 'lib/models/porcelain.rb', line 9512

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end