Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 |
# File 'lib/models/porcelain.rb', line 9435 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
9419 9420 9421 |
# File 'lib/models/porcelain.rb', line 9419 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
9421 9422 9423 |
# File 'lib/models/porcelain.rb', line 9421 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
9423 9424 9425 |
# File 'lib/models/porcelain.rb', line 9423 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
9425 9426 9427 |
# File 'lib/models/porcelain.rb', line 9425 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
9427 9428 9429 |
# File 'lib/models/porcelain.rb', line 9427 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
9429 9430 9431 |
# File 'lib/models/porcelain.rb', line 9429 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
9431 9432 9433 |
# File 'lib/models/porcelain.rb', line 9431 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9433 9434 9435 |
# File 'lib/models/porcelain.rb', line 9433 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9455 9456 9457 9458 9459 9460 9461 |
# File 'lib/models/porcelain.rb', line 9455 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |