Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
9271 9272 9273 9274 9275 9276 9277 9278 9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 |
# File 'lib/models/porcelain.rb', line 9271 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
9255 9256 9257 |
# File 'lib/models/porcelain.rb', line 9255 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
9257 9258 9259 |
# File 'lib/models/porcelain.rb', line 9257 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
9259 9260 9261 |
# File 'lib/models/porcelain.rb', line 9259 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
9261 9262 9263 |
# File 'lib/models/porcelain.rb', line 9261 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
9263 9264 9265 |
# File 'lib/models/porcelain.rb', line 9263 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
9265 9266 9267 |
# File 'lib/models/porcelain.rb', line 9265 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
9267 9268 9269 |
# File 'lib/models/porcelain.rb', line 9267 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9269 9270 9271 |
# File 'lib/models/porcelain.rb', line 9269 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9291 9292 9293 9294 9295 9296 9297 |
# File 'lib/models/porcelain.rb', line 9291 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |