Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



9263
9264
9265
9266
9267
9268
9269
9270
9271
9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
# File 'lib/models/porcelain.rb', line 9263

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



9247
9248
9249
# File 'lib/models/porcelain.rb', line 9247

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



9249
9250
9251
# File 'lib/models/porcelain.rb', line 9249

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



9251
9252
9253
# File 'lib/models/porcelain.rb', line 9251

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



9253
9254
9255
# File 'lib/models/porcelain.rb', line 9253

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



9255
9256
9257
# File 'lib/models/porcelain.rb', line 9255

def name
  @name
end

#namespaceObject

The namespace to make requests within



9257
9258
9259
# File 'lib/models/porcelain.rb', line 9257

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



9259
9260
9261
# File 'lib/models/porcelain.rb', line 9259

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



9261
9262
9263
# File 'lib/models/porcelain.rb', line 9261

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9283
9284
9285
9286
9287
9288
9289
# File 'lib/models/porcelain.rb', line 9283

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end