Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 8852 |
# File 'lib/models/porcelain.rb', line 8834 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
8818 8819 8820 |
# File 'lib/models/porcelain.rb', line 8818 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
8820 8821 8822 |
# File 'lib/models/porcelain.rb', line 8820 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
8822 8823 8824 |
# File 'lib/models/porcelain.rb', line 8822 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
8824 8825 8826 |
# File 'lib/models/porcelain.rb', line 8824 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
8826 8827 8828 |
# File 'lib/models/porcelain.rb', line 8826 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
8828 8829 8830 |
# File 'lib/models/porcelain.rb', line 8828 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
8830 8831 8832 |
# File 'lib/models/porcelain.rb', line 8830 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8832 8833 8834 |
# File 'lib/models/porcelain.rb', line 8832 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8854 8855 8856 8857 8858 8859 8860 |
# File 'lib/models/porcelain.rb', line 8854 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |