Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
# File 'lib/models/porcelain.rb', line 8844

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



8828
8829
8830
# File 'lib/models/porcelain.rb', line 8828

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



8830
8831
8832
# File 'lib/models/porcelain.rb', line 8830

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



8832
8833
8834
# File 'lib/models/porcelain.rb', line 8832

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



8834
8835
8836
# File 'lib/models/porcelain.rb', line 8834

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



8836
8837
8838
# File 'lib/models/porcelain.rb', line 8836

def name
  @name
end

#namespaceObject

The namespace to make requests within



8838
8839
8840
# File 'lib/models/porcelain.rb', line 8838

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



8840
8841
8842
# File 'lib/models/porcelain.rb', line 8840

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



8842
8843
8844
# File 'lib/models/porcelain.rb', line 8842

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8864
8865
8866
8867
8868
8869
8870
# File 'lib/models/porcelain.rb', line 8864

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end