Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



18205
18206
18207
18208
18209
18210
18211
18212
18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
18223
# File 'lib/models/porcelain.rb', line 18205

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18189
18190
18191
# File 'lib/models/porcelain.rb', line 18189

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18191
18192
18193
# File 'lib/models/porcelain.rb', line 18191

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18193
18194
18195
# File 'lib/models/porcelain.rb', line 18193

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18195
18196
18197
# File 'lib/models/porcelain.rb', line 18195

def id
  @id
end

#nameObject

Unique human-readable name of the SecretStore.



18197
18198
18199
# File 'lib/models/porcelain.rb', line 18197

def name
  @name
end

#namespaceObject

The namespace to make requests within



18199
18200
18201
# File 'lib/models/porcelain.rb', line 18199

def namespace
  @namespace
end

#server_addressObject

The URL of the Vault to target



18201
18202
18203
# File 'lib/models/porcelain.rb', line 18201

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



18203
18204
18205
# File 'lib/models/porcelain.rb', line 18203

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18225
18226
18227
18228
18229
18230
18231
# File 'lib/models/porcelain.rb', line 18225

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end