Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
15117 15118 15119 15120 15121 15122 15123 15124 15125 15126 15127 15128 15129 15130 15131 15132 15133 15134 15135 |
# File 'lib/models/porcelain.rb', line 15117 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
15101 15102 15103 |
# File 'lib/models/porcelain.rb', line 15101 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
15103 15104 15105 |
# File 'lib/models/porcelain.rb', line 15103 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
15105 15106 15107 |
# File 'lib/models/porcelain.rb', line 15105 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
15107 15108 15109 |
# File 'lib/models/porcelain.rb', line 15107 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
15109 15110 15111 |
# File 'lib/models/porcelain.rb', line 15109 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
15111 15112 15113 |
# File 'lib/models/porcelain.rb', line 15111 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
15113 15114 15115 |
# File 'lib/models/porcelain.rb', line 15113 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
15115 15116 15117 |
# File 'lib/models/porcelain.rb', line 15115 def end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15137 15138 15139 15140 15141 15142 15143 |
# File 'lib/models/porcelain.rb', line 15137 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |