Class: SDM::VaultTLSStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore

Returns a new instance of VaultTLSStore.



19051
19052
19053
19054
19055
19056
19057
19058
19059
19060
19061
19062
19063
19064
19065
19066
19067
19068
19069
# File 'lib/models/porcelain.rb', line 19051

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  name: nil,
  namespace: nil,
  server_address: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_path ⇒ Object

A path to a CA file accessible by a Node



19035
19036
19037
# File 'lib/models/porcelain.rb', line 19035

def ca_cert_path
  @ca_cert_path
end

#client_cert_path ⇒ Object

A path to a client certificate file accessible by a Node



19037
19038
19039
# File 'lib/models/porcelain.rb', line 19037

def client_cert_path
  @client_cert_path
end

#client_key_path ⇒ Object

A path to a client key file accessible by a Node



19039
19040
19041
# File 'lib/models/porcelain.rb', line 19039

def client_key_path
  @client_key_path
end

#id ⇒ Object

Unique identifier of the SecretStore.



19041
19042
19043
# File 'lib/models/porcelain.rb', line 19041

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the SecretStore.



19043
19044
19045
# File 'lib/models/porcelain.rb', line 19043

def name
  @name
end

#namespace ⇒ Object

The namespace to make requests within



19045
19046
19047
# File 'lib/models/porcelain.rb', line 19045

def namespace
  @namespace
end

#server_address ⇒ Object

The URL of the Vault to target



19047
19048
19049
# File 'lib/models/porcelain.rb', line 19047

def server_address
  @server_address
end

#tags ⇒ Object

Tags is a map of key, value pairs.



19049
19050
19051
# File 'lib/models/porcelain.rb', line 19049

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19071
19072
19073
19074
19075
19076
19077
# File 'lib/models/porcelain.rb', line 19071

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end