Class: SDM::VaultTokenCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTokenCertSSHStore
constructor
A new instance of VaultTokenCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTokenCertSSHStore
Returns a new instance of VaultTokenCertSSHStore.
18990 18991 18992 18993 18994 18995 18996 18997 18998 18999 19000 19001 19002 19003 19004 19005 19006 19007 19008 |
# File 'lib/models/porcelain.rb', line 18990 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18974 18975 18976 |
# File 'lib/models/porcelain.rb', line 18974 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
18976 18977 18978 |
# File 'lib/models/porcelain.rb', line 18976 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18978 18979 18980 |
# File 'lib/models/porcelain.rb', line 18978 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18980 18981 18982 |
# File 'lib/models/porcelain.rb', line 18980 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18982 18983 18984 |
# File 'lib/models/porcelain.rb', line 18982 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18984 18985 18986 |
# File 'lib/models/porcelain.rb', line 18984 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
18986 18987 18988 |
# File 'lib/models/porcelain.rb', line 18986 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18988 18989 18990 |
# File 'lib/models/porcelain.rb', line 18988 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
19010 19011 19012 19013 19014 19015 19016 |
# File 'lib/models/porcelain.rb', line 19010 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |