Class: SDM::VaultTokenCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTokenCertSSHStore
constructor
A new instance of VaultTokenCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTokenCertSSHStore
Returns a new instance of VaultTokenCertSSHStore.
18672 18673 18674 18675 18676 18677 18678 18679 18680 18681 18682 18683 18684 18685 18686 18687 18688 18689 18690 |
# File 'lib/models/porcelain.rb', line 18672 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18656 18657 18658 |
# File 'lib/models/porcelain.rb', line 18656 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
18658 18659 18660 |
# File 'lib/models/porcelain.rb', line 18658 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18660 18661 18662 |
# File 'lib/models/porcelain.rb', line 18660 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18662 18663 18664 |
# File 'lib/models/porcelain.rb', line 18662 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18664 18665 18666 |
# File 'lib/models/porcelain.rb', line 18664 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18666 18667 18668 |
# File 'lib/models/porcelain.rb', line 18666 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
18668 18669 18670 |
# File 'lib/models/porcelain.rb', line 18668 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18670 18671 18672 |
# File 'lib/models/porcelain.rb', line 18670 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18692 18693 18694 18695 18696 18697 18698 |
# File 'lib/models/porcelain.rb', line 18692 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |