Class: SDM::VaultTokenCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTokenCertSSHStore
constructor
A new instance of VaultTokenCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTokenCertSSHStore
Returns a new instance of VaultTokenCertSSHStore.
12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 |
# File 'lib/models/porcelain.rb', line 12016 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
12000 12001 12002 |
# File 'lib/models/porcelain.rb', line 12000 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
12002 12003 12004 |
# File 'lib/models/porcelain.rb', line 12002 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
12004 12005 12006 |
# File 'lib/models/porcelain.rb', line 12004 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
12006 12007 12008 |
# File 'lib/models/porcelain.rb', line 12006 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
12008 12009 12010 |
# File 'lib/models/porcelain.rb', line 12008 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
12010 12011 12012 |
# File 'lib/models/porcelain.rb', line 12010 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
12012 12013 12014 |
# File 'lib/models/porcelain.rb', line 12012 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12014 12015 12016 |
# File 'lib/models/porcelain.rb', line 12014 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12036 12037 12038 12039 12040 12041 12042 |
# File 'lib/models/porcelain.rb', line 12036 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |