Class: SDM::VaultTokenCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Overview
VaultTokenCertSSHStore is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTokenCertSSHStore
constructor
A new instance of VaultTokenCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultTokenCertSSHStore
Returns a new instance of VaultTokenCertSSHStore.
10206 10207 10208 10209 10210 10211 10212 10213 10214 10215 10216 10217 10218 10219 10220 10221 10222 |
# File 'lib/models/porcelain.rb', line 10206 def initialize( id: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
10192 10193 10194 |
# File 'lib/models/porcelain.rb', line 10192 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
10194 10195 10196 |
# File 'lib/models/porcelain.rb', line 10194 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
10196 10197 10198 |
# File 'lib/models/porcelain.rb', line 10196 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
10198 10199 10200 |
# File 'lib/models/porcelain.rb', line 10198 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
10200 10201 10202 |
# File 'lib/models/porcelain.rb', line 10200 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
10202 10203 10204 |
# File 'lib/models/porcelain.rb', line 10202 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10204 10205 10206 |
# File 'lib/models/porcelain.rb', line 10204 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10224 10225 10226 10227 10228 10229 10230 |
# File 'lib/models/porcelain.rb', line 10224 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |