Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
19037 19038 19039 19040 19041 19042 19043 19044 19045 19046 19047 19048 19049 19050 19051 19052 19053 19054 19055 |
# File 'lib/models/porcelain.rb', line 19037 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
19021 19022 19023 |
# File 'lib/models/porcelain.rb', line 19021 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
19023 19024 19025 |
# File 'lib/models/porcelain.rb', line 19023 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
19025 19026 19027 |
# File 'lib/models/porcelain.rb', line 19025 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
19027 19028 19029 |
# File 'lib/models/porcelain.rb', line 19027 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
19029 19030 19031 |
# File 'lib/models/porcelain.rb', line 19029 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
19031 19032 19033 |
# File 'lib/models/porcelain.rb', line 19031 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
19033 19034 19035 |
# File 'lib/models/porcelain.rb', line 19033 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
19035 19036 19037 |
# File 'lib/models/porcelain.rb', line 19035 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
19057 19058 19059 19060 19061 19062 19063 |
# File 'lib/models/porcelain.rb', line 19057 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |