Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
18953 18954 18955 18956 18957 18958 18959 18960 18961 18962 18963 18964 18965 18966 18967 18968 18969 18970 18971 |
# File 'lib/models/porcelain.rb', line 18953 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18937 18938 18939 |
# File 'lib/models/porcelain.rb', line 18937 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18939 18940 18941 |
# File 'lib/models/porcelain.rb', line 18939 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18941 18942 18943 |
# File 'lib/models/porcelain.rb', line 18941 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18943 18944 18945 |
# File 'lib/models/porcelain.rb', line 18943 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18945 18946 18947 |
# File 'lib/models/porcelain.rb', line 18945 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18947 18948 18949 |
# File 'lib/models/porcelain.rb', line 18947 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18949 18950 18951 |
# File 'lib/models/porcelain.rb', line 18949 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18951 18952 18953 |
# File 'lib/models/porcelain.rb', line 18951 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18973 18974 18975 18976 18977 18978 18979 |
# File 'lib/models/porcelain.rb', line 18973 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |