Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
18719 18720 18721 18722 18723 18724 18725 18726 18727 18728 18729 18730 18731 18732 18733 18734 18735 18736 18737 |
# File 'lib/models/porcelain.rb', line 18719 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18703 18704 18705 |
# File 'lib/models/porcelain.rb', line 18703 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18705 18706 18707 |
# File 'lib/models/porcelain.rb', line 18705 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18707 18708 18709 |
# File 'lib/models/porcelain.rb', line 18707 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18709 18710 18711 |
# File 'lib/models/porcelain.rb', line 18709 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18711 18712 18713 |
# File 'lib/models/porcelain.rb', line 18711 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18713 18714 18715 |
# File 'lib/models/porcelain.rb', line 18713 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18715 18716 18717 |
# File 'lib/models/porcelain.rb', line 18715 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18717 18718 18719 |
# File 'lib/models/porcelain.rb', line 18717 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18739 18740 18741 18742 18743 18744 18745 |
# File 'lib/models/porcelain.rb', line 18739 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |