Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
18603 18604 18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 18616 18617 18618 18619 18620 18621 |
# File 'lib/models/porcelain.rb', line 18603 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18587 18588 18589 |
# File 'lib/models/porcelain.rb', line 18587 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18589 18590 18591 |
# File 'lib/models/porcelain.rb', line 18589 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18591 18592 18593 |
# File 'lib/models/porcelain.rb', line 18591 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18593 18594 18595 |
# File 'lib/models/porcelain.rb', line 18593 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18595 18596 18597 |
# File 'lib/models/porcelain.rb', line 18595 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18597 18598 18599 |
# File 'lib/models/porcelain.rb', line 18597 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18599 18600 18601 |
# File 'lib/models/porcelain.rb', line 18599 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18601 18602 18603 |
# File 'lib/models/porcelain.rb', line 18601 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18623 18624 18625 18626 18627 18628 18629 |
# File 'lib/models/porcelain.rb', line 18623 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |