Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
15222 15223 15224 15225 15226 15227 15228 15229 15230 15231 15232 15233 15234 15235 15236 15237 15238 15239 15240 |
# File 'lib/models/porcelain.rb', line 15222 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
15206 15207 15208 |
# File 'lib/models/porcelain.rb', line 15206 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
15208 15209 15210 |
# File 'lib/models/porcelain.rb', line 15208 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
15210 15211 15212 |
# File 'lib/models/porcelain.rb', line 15210 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
15212 15213 15214 |
# File 'lib/models/porcelain.rb', line 15212 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
15214 15215 15216 |
# File 'lib/models/porcelain.rb', line 15214 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
15216 15217 15218 |
# File 'lib/models/porcelain.rb', line 15216 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
15218 15219 15220 |
# File 'lib/models/porcelain.rb', line 15218 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
15220 15221 15222 |
# File 'lib/models/porcelain.rb', line 15220 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15242 15243 15244 15245 15246 15247 15248 |
# File 'lib/models/porcelain.rb', line 15242 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |