Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
15211 15212 15213 15214 15215 15216 15217 15218 15219 15220 15221 15222 15223 15224 15225 15226 15227 15228 15229 |
# File 'lib/models/porcelain.rb', line 15211 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
15195 15196 15197 |
# File 'lib/models/porcelain.rb', line 15195 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
15197 15198 15199 |
# File 'lib/models/porcelain.rb', line 15197 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
15199 15200 15201 |
# File 'lib/models/porcelain.rb', line 15199 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
15201 15202 15203 |
# File 'lib/models/porcelain.rb', line 15201 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
15203 15204 15205 |
# File 'lib/models/porcelain.rb', line 15203 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
15205 15206 15207 |
# File 'lib/models/porcelain.rb', line 15205 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
15207 15208 15209 |
# File 'lib/models/porcelain.rb', line 15207 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
15209 15210 15211 |
# File 'lib/models/porcelain.rb', line 15209 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15231 15232 15233 15234 15235 15236 15237 |
# File 'lib/models/porcelain.rb', line 15231 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |