Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
13826 13827 13828 13829 13830 13831 13832 13833 13834 13835 13836 13837 13838 13839 13840 13841 13842 13843 13844 |
# File 'lib/models/porcelain.rb', line 13826 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
13810 13811 13812 |
# File 'lib/models/porcelain.rb', line 13810 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
13812 13813 13814 |
# File 'lib/models/porcelain.rb', line 13812 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13814 13815 13816 |
# File 'lib/models/porcelain.rb', line 13814 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13816 13817 13818 |
# File 'lib/models/porcelain.rb', line 13816 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
13818 13819 13820 |
# File 'lib/models/porcelain.rb', line 13818 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
13820 13821 13822 |
# File 'lib/models/porcelain.rb', line 13820 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
13822 13823 13824 |
# File 'lib/models/porcelain.rb', line 13822 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13824 13825 13826 |
# File 'lib/models/porcelain.rb', line 13824 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13846 13847 13848 13849 13850 13851 13852 |
# File 'lib/models/porcelain.rb', line 13846 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |