Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
13735 13736 13737 13738 13739 13740 13741 13742 13743 13744 13745 13746 13747 13748 13749 13750 13751 13752 13753 |
# File 'lib/models/porcelain.rb', line 13735 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
13719 13720 13721 |
# File 'lib/models/porcelain.rb', line 13719 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
13721 13722 13723 |
# File 'lib/models/porcelain.rb', line 13721 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13723 13724 13725 |
# File 'lib/models/porcelain.rb', line 13723 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13725 13726 13727 |
# File 'lib/models/porcelain.rb', line 13725 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
13727 13728 13729 |
# File 'lib/models/porcelain.rb', line 13727 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
13729 13730 13731 |
# File 'lib/models/porcelain.rb', line 13729 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
13731 13732 13733 |
# File 'lib/models/porcelain.rb', line 13731 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13733 13734 13735 |
# File 'lib/models/porcelain.rb', line 13733 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13755 13756 13757 13758 13759 13760 13761 |
# File 'lib/models/porcelain.rb', line 13755 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |