Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
13496 13497 13498 13499 13500 13501 13502 13503 13504 13505 13506 13507 13508 13509 13510 13511 13512 13513 13514 |
# File 'lib/models/porcelain.rb', line 13496 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
13480 13481 13482 |
# File 'lib/models/porcelain.rb', line 13480 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
13482 13483 13484 |
# File 'lib/models/porcelain.rb', line 13482 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
13484 13485 13486 |
# File 'lib/models/porcelain.rb', line 13484 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
13486 13487 13488 |
# File 'lib/models/porcelain.rb', line 13486 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
13488 13489 13490 |
# File 'lib/models/porcelain.rb', line 13488 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
13490 13491 13492 |
# File 'lib/models/porcelain.rb', line 13490 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
13492 13493 13494 |
# File 'lib/models/porcelain.rb', line 13492 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13494 13495 13496 |
# File 'lib/models/porcelain.rb', line 13494 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13516 13517 13518 13519 13520 13521 13522 |
# File 'lib/models/porcelain.rb', line 13516 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |