Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
12984 12985 12986 12987 12988 12989 12990 12991 12992 12993 12994 12995 12996 12997 12998 12999 13000 13001 13002 |
# File 'lib/models/porcelain.rb', line 12984 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
12968 12969 12970 |
# File 'lib/models/porcelain.rb', line 12968 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
12970 12971 12972 |
# File 'lib/models/porcelain.rb', line 12970 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
12972 12973 12974 |
# File 'lib/models/porcelain.rb', line 12972 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
12974 12975 12976 |
# File 'lib/models/porcelain.rb', line 12974 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
12976 12977 12978 |
# File 'lib/models/porcelain.rb', line 12976 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
12978 12979 12980 |
# File 'lib/models/porcelain.rb', line 12978 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
12980 12981 12982 |
# File 'lib/models/porcelain.rb', line 12980 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12982 12983 12984 |
# File 'lib/models/porcelain.rb', line 12982 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13004 13005 13006 13007 13008 13009 13010 |
# File 'lib/models/porcelain.rb', line 13004 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |