Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
12656 12657 12658 12659 12660 12661 12662 12663 12664 12665 12666 12667 12668 12669 12670 12671 12672 12673 12674 |
# File 'lib/models/porcelain.rb', line 12656 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
12640 12641 12642 |
# File 'lib/models/porcelain.rb', line 12640 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
12642 12643 12644 |
# File 'lib/models/porcelain.rb', line 12642 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
12644 12645 12646 |
# File 'lib/models/porcelain.rb', line 12644 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
12646 12647 12648 |
# File 'lib/models/porcelain.rb', line 12646 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
12648 12649 12650 |
# File 'lib/models/porcelain.rb', line 12648 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
12650 12651 12652 |
# File 'lib/models/porcelain.rb', line 12650 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
12652 12653 12654 |
# File 'lib/models/porcelain.rb', line 12652 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12654 12655 12656 |
# File 'lib/models/porcelain.rb', line 12654 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12676 12677 12678 12679 12680 12681 12682 |
# File 'lib/models/porcelain.rb', line 12676 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |