Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
12587 12588 12589 12590 12591 12592 12593 12594 12595 12596 12597 12598 12599 12600 12601 12602 12603 12604 12605 |
# File 'lib/models/porcelain.rb', line 12587 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
12571 12572 12573 |
# File 'lib/models/porcelain.rb', line 12571 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
12573 12574 12575 |
# File 'lib/models/porcelain.rb', line 12573 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
12575 12576 12577 |
# File 'lib/models/porcelain.rb', line 12575 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
12577 12578 12579 |
# File 'lib/models/porcelain.rb', line 12577 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
12579 12580 12581 |
# File 'lib/models/porcelain.rb', line 12579 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
12581 12582 12583 |
# File 'lib/models/porcelain.rb', line 12581 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
12583 12584 12585 |
# File 'lib/models/porcelain.rb', line 12583 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12585 12586 12587 |
# File 'lib/models/porcelain.rb', line 12585 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12607 12608 12609 12610 12611 12612 12613 |
# File 'lib/models/porcelain.rb', line 12607 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |