Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
12054 12055 12056 12057 12058 12059 12060 12061 12062 12063 12064 12065 12066 12067 12068 12069 12070 12071 12072 |
# File 'lib/models/porcelain.rb', line 12054 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
12038 12039 12040 |
# File 'lib/models/porcelain.rb', line 12038 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
12040 12041 12042 |
# File 'lib/models/porcelain.rb', line 12040 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
12042 12043 12044 |
# File 'lib/models/porcelain.rb', line 12042 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
12044 12045 12046 |
# File 'lib/models/porcelain.rb', line 12044 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
12046 12047 12048 |
# File 'lib/models/porcelain.rb', line 12046 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
12048 12049 12050 |
# File 'lib/models/porcelain.rb', line 12048 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
12050 12051 12052 |
# File 'lib/models/porcelain.rb', line 12050 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12052 12053 12054 |
# File 'lib/models/porcelain.rb', line 12052 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12074 12075 12076 12077 12078 12079 12080 |
# File 'lib/models/porcelain.rb', line 12074 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |