Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
11887 11888 11889 11890 11891 11892 11893 11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 |
# File 'lib/models/porcelain.rb', line 11887 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
11871 11872 11873 |
# File 'lib/models/porcelain.rb', line 11871 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
11873 11874 11875 |
# File 'lib/models/porcelain.rb', line 11873 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
11875 11876 11877 |
# File 'lib/models/porcelain.rb', line 11875 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
11877 11878 11879 |
# File 'lib/models/porcelain.rb', line 11877 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
11879 11880 11881 |
# File 'lib/models/porcelain.rb', line 11879 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
11881 11882 11883 |
# File 'lib/models/porcelain.rb', line 11881 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
11883 11884 11885 |
# File 'lib/models/porcelain.rb', line 11883 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11885 11886 11887 |
# File 'lib/models/porcelain.rb', line 11885 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11907 11908 11909 11910 11911 11912 11913 |
# File 'lib/models/porcelain.rb', line 11907 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |