Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
19145 19146 19147 19148 19149 19150 19151 19152 19153 19154 19155 19156 19157 19158 19159 19160 19161 19162 19163 |
# File 'lib/models/porcelain.rb', line 19145 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
19129 19130 19131 |
# File 'lib/models/porcelain.rb', line 19129 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
19131 19132 19133 |
# File 'lib/models/porcelain.rb', line 19131 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
19133 19134 19135 |
# File 'lib/models/porcelain.rb', line 19133 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
19135 19136 19137 |
# File 'lib/models/porcelain.rb', line 19135 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
19137 19138 19139 |
# File 'lib/models/porcelain.rb', line 19137 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
19139 19140 19141 |
# File 'lib/models/porcelain.rb', line 19139 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
19141 19142 19143 |
# File 'lib/models/porcelain.rb', line 19141 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
19143 19144 19145 |
# File 'lib/models/porcelain.rb', line 19143 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
19165 19166 19167 19168 19169 19170 19171 |
# File 'lib/models/porcelain.rb', line 19165 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |