Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



19181
19182
19183
19184
19185
19186
19187
19188
19189
19190
19191
19192
19193
19194
19195
19196
19197
19198
19199
19200
19201
19202
19203
19204
19205
19206
19207
19208
19209
19210
19211
19212
19213
# File 'lib/models/porcelain.rb', line 19181

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



19151
19152
19153
# File 'lib/models/porcelain.rb', line 19151

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



19153
19154
19155
# File 'lib/models/porcelain.rb', line 19153

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



19155
19156
19157
# File 'lib/models/porcelain.rb', line 19155

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



19157
19158
19159
# File 'lib/models/porcelain.rb', line 19157

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



19159
19160
19161
# File 'lib/models/porcelain.rb', line 19159

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



19161
19162
19163
# File 'lib/models/porcelain.rb', line 19161

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



19163
19164
19165
# File 'lib/models/porcelain.rb', line 19163

def name
  @name
end

#passwordObject

The password to authenticate with.



19165
19166
19167
# File 'lib/models/porcelain.rb', line 19165

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



19167
19168
19169
# File 'lib/models/porcelain.rb', line 19167

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



19169
19170
19171
# File 'lib/models/porcelain.rb', line 19169

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



19171
19172
19173
# File 'lib/models/porcelain.rb', line 19171

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



19173
19174
19175
# File 'lib/models/porcelain.rb', line 19173

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



19175
19176
19177
# File 'lib/models/porcelain.rb', line 19175

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



19177
19178
19179
# File 'lib/models/porcelain.rb', line 19177

def tags
  @tags
end

#usernameObject

The username to authenticate with.



19179
19180
19181
# File 'lib/models/porcelain.rb', line 19179

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19215
19216
19217
19218
19219
19220
19221
# File 'lib/models/porcelain.rb', line 19215

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end