Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



19133
19134
19135
19136
19137
19138
19139
19140
19141
19142
19143
19144
19145
19146
19147
19148
19149
19150
19151
19152
19153
19154
19155
19156
19157
19158
19159
19160
19161
19162
19163
19164
19165
# File 'lib/models/porcelain.rb', line 19133

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



19103
19104
19105
# File 'lib/models/porcelain.rb', line 19103

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



19105
19106
19107
# File 'lib/models/porcelain.rb', line 19105

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



19107
19108
19109
# File 'lib/models/porcelain.rb', line 19107

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



19109
19110
19111
# File 'lib/models/porcelain.rb', line 19109

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



19111
19112
19113
# File 'lib/models/porcelain.rb', line 19111

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



19113
19114
19115
# File 'lib/models/porcelain.rb', line 19113

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



19115
19116
19117
# File 'lib/models/porcelain.rb', line 19115

def name
  @name
end

#passwordObject

The password to authenticate with.



19117
19118
19119
# File 'lib/models/porcelain.rb', line 19117

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



19119
19120
19121
# File 'lib/models/porcelain.rb', line 19119

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



19121
19122
19123
# File 'lib/models/porcelain.rb', line 19121

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



19123
19124
19125
# File 'lib/models/porcelain.rb', line 19123

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



19125
19126
19127
# File 'lib/models/porcelain.rb', line 19125

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



19127
19128
19129
# File 'lib/models/porcelain.rb', line 19127

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



19129
19130
19131
# File 'lib/models/porcelain.rb', line 19129

def tags
  @tags
end

#usernameObject

The username to authenticate with.



19131
19132
19133
# File 'lib/models/porcelain.rb', line 19131

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19167
19168
19169
19170
19171
19172
19173
# File 'lib/models/porcelain.rb', line 19167

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end