Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



19049
19050
19051
19052
19053
19054
19055
19056
19057
19058
19059
19060
19061
19062
19063
19064
19065
19066
19067
19068
19069
19070
19071
19072
19073
19074
19075
19076
19077
19078
19079
19080
19081
# File 'lib/models/porcelain.rb', line 19049

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



19019
19020
19021
# File 'lib/models/porcelain.rb', line 19019

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



19021
19022
19023
# File 'lib/models/porcelain.rb', line 19021

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



19023
19024
19025
# File 'lib/models/porcelain.rb', line 19023

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



19025
19026
19027
# File 'lib/models/porcelain.rb', line 19025

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



19027
19028
19029
# File 'lib/models/porcelain.rb', line 19027

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



19029
19030
19031
# File 'lib/models/porcelain.rb', line 19029

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



19031
19032
19033
# File 'lib/models/porcelain.rb', line 19031

def name
  @name
end

#passwordObject

The password to authenticate with.



19033
19034
19035
# File 'lib/models/porcelain.rb', line 19033

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



19035
19036
19037
# File 'lib/models/porcelain.rb', line 19035

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



19037
19038
19039
# File 'lib/models/porcelain.rb', line 19037

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



19039
19040
19041
# File 'lib/models/porcelain.rb', line 19039

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



19041
19042
19043
# File 'lib/models/porcelain.rb', line 19041

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



19043
19044
19045
# File 'lib/models/porcelain.rb', line 19043

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



19045
19046
19047
# File 'lib/models/porcelain.rb', line 19045

def tags
  @tags
end

#usernameObject

The username to authenticate with.



19047
19048
19049
# File 'lib/models/porcelain.rb', line 19047

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19083
19084
19085
19086
19087
19088
19089
# File 'lib/models/porcelain.rb', line 19083

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end