Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



18823
18824
18825
18826
18827
18828
18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
18840
18841
18842
18843
18844
18845
18846
18847
18848
18849
18850
18851
18852
18853
18854
18855
# File 'lib/models/porcelain.rb', line 18823

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



18793
18794
18795
# File 'lib/models/porcelain.rb', line 18793

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



18795
18796
18797
# File 'lib/models/porcelain.rb', line 18795

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



18797
18798
18799
# File 'lib/models/porcelain.rb', line 18797

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



18799
18800
18801
# File 'lib/models/porcelain.rb', line 18799

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



18801
18802
18803
# File 'lib/models/porcelain.rb', line 18801

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



18803
18804
18805
# File 'lib/models/porcelain.rb', line 18803

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



18805
18806
18807
# File 'lib/models/porcelain.rb', line 18805

def name
  @name
end

#passwordObject

The password to authenticate with.



18807
18808
18809
# File 'lib/models/porcelain.rb', line 18807

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



18809
18810
18811
# File 'lib/models/porcelain.rb', line 18809

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



18811
18812
18813
# File 'lib/models/porcelain.rb', line 18811

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



18813
18814
18815
# File 'lib/models/porcelain.rb', line 18813

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



18815
18816
18817
# File 'lib/models/porcelain.rb', line 18815

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



18817
18818
18819
# File 'lib/models/porcelain.rb', line 18817

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



18819
18820
18821
# File 'lib/models/porcelain.rb', line 18819

def tags
  @tags
end

#usernameObject

The username to authenticate with.



18821
18822
18823
# File 'lib/models/porcelain.rb', line 18821

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18857
18858
18859
18860
18861
18862
18863
# File 'lib/models/porcelain.rb', line 18857

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end