Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



18699
18700
18701
18702
18703
18704
18705
18706
18707
18708
18709
18710
18711
18712
18713
18714
18715
18716
18717
18718
18719
18720
18721
18722
18723
18724
18725
18726
18727
18728
18729
18730
18731
# File 'lib/models/porcelain.rb', line 18699

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



18669
18670
18671
# File 'lib/models/porcelain.rb', line 18669

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



18671
18672
18673
# File 'lib/models/porcelain.rb', line 18671

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



18673
18674
18675
# File 'lib/models/porcelain.rb', line 18673

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



18675
18676
18677
# File 'lib/models/porcelain.rb', line 18675

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



18677
18678
18679
# File 'lib/models/porcelain.rb', line 18677

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



18679
18680
18681
# File 'lib/models/porcelain.rb', line 18679

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



18681
18682
18683
# File 'lib/models/porcelain.rb', line 18681

def name
  @name
end

#passwordObject

The password to authenticate with.



18683
18684
18685
# File 'lib/models/porcelain.rb', line 18683

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



18685
18686
18687
# File 'lib/models/porcelain.rb', line 18685

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



18687
18688
18689
# File 'lib/models/porcelain.rb', line 18687

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



18689
18690
18691
# File 'lib/models/porcelain.rb', line 18689

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



18691
18692
18693
# File 'lib/models/porcelain.rb', line 18691

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



18693
18694
18695
# File 'lib/models/porcelain.rb', line 18693

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



18695
18696
18697
# File 'lib/models/porcelain.rb', line 18695

def tags
  @tags
end

#usernameObject

The username to authenticate with.



18697
18698
18699
# File 'lib/models/porcelain.rb', line 18697

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18733
18734
18735
18736
18737
18738
18739
# File 'lib/models/porcelain.rb', line 18733

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end