Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



18396
18397
18398
18399
18400
18401
18402
18403
18404
18405
18406
18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
18418
18419
18420
18421
18422
18423
18424
18425
18426
18427
18428
# File 'lib/models/porcelain.rb', line 18396

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



18366
18367
18368
# File 'lib/models/porcelain.rb', line 18366

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



18368
18369
18370
# File 'lib/models/porcelain.rb', line 18368

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



18370
18371
18372
# File 'lib/models/porcelain.rb', line 18370

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



18372
18373
18374
# File 'lib/models/porcelain.rb', line 18372

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



18374
18375
18376
# File 'lib/models/porcelain.rb', line 18374

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



18376
18377
18378
# File 'lib/models/porcelain.rb', line 18376

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



18378
18379
18380
# File 'lib/models/porcelain.rb', line 18378

def name
  @name
end

#passwordObject

The password to authenticate with.



18380
18381
18382
# File 'lib/models/porcelain.rb', line 18380

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



18382
18383
18384
# File 'lib/models/porcelain.rb', line 18382

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



18384
18385
18386
# File 'lib/models/porcelain.rb', line 18384

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



18386
18387
18388
# File 'lib/models/porcelain.rb', line 18386

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



18388
18389
18390
# File 'lib/models/porcelain.rb', line 18388

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



18390
18391
18392
# File 'lib/models/porcelain.rb', line 18390

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



18392
18393
18394
# File 'lib/models/porcelain.rb', line 18392

def tags
  @tags
end

#usernameObject

The username to authenticate with.



18394
18395
18396
# File 'lib/models/porcelain.rb', line 18394

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18430
18431
18432
18433
18434
18435
18436
# File 'lib/models/porcelain.rb', line 18430

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end