Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



18016
18017
18018
18019
18020
18021
18022
18023
18024
18025
18026
18027
18028
18029
18030
18031
18032
18033
18034
18035
18036
18037
18038
18039
18040
18041
18042
18043
18044
18045
18046
18047
18048
# File 'lib/models/porcelain.rb', line 18016

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17986
17987
17988
# File 'lib/models/porcelain.rb', line 17986

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



17988
17989
17990
# File 'lib/models/porcelain.rb', line 17988

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17990
17991
17992
# File 'lib/models/porcelain.rb', line 17990

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17992
17993
17994
# File 'lib/models/porcelain.rb', line 17992

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17994
17995
17996
# File 'lib/models/porcelain.rb', line 17994

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17996
17997
17998
# File 'lib/models/porcelain.rb', line 17996

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17998
17999
18000
# File 'lib/models/porcelain.rb', line 17998

def name
  @name
end

#passwordObject

The password to authenticate with.



18000
18001
18002
# File 'lib/models/porcelain.rb', line 18000

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



18002
18003
18004
# File 'lib/models/porcelain.rb', line 18002

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



18004
18005
18006
# File 'lib/models/porcelain.rb', line 18004

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



18006
18007
18008
# File 'lib/models/porcelain.rb', line 18006

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



18008
18009
18010
# File 'lib/models/porcelain.rb', line 18008

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



18010
18011
18012
# File 'lib/models/porcelain.rb', line 18010

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



18012
18013
18014
# File 'lib/models/porcelain.rb', line 18012

def tags
  @tags
end

#usernameObject

The username to authenticate with.



18014
18015
18016
# File 'lib/models/porcelain.rb', line 18014

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18050
18051
18052
18053
18054
18055
18056
# File 'lib/models/porcelain.rb', line 18050

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end