Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



17020
17021
17022
17023
17024
17025
17026
17027
17028
17029
17030
17031
17032
17033
17034
17035
17036
17037
17038
17039
17040
17041
17042
17043
17044
17045
17046
17047
17048
17049
17050
17051
17052
# File 'lib/models/porcelain.rb', line 17020

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16990
16991
16992
# File 'lib/models/porcelain.rb', line 16990

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



16992
16993
16994
# File 'lib/models/porcelain.rb', line 16992

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16994
16995
16996
# File 'lib/models/porcelain.rb', line 16994

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16996
16997
16998
# File 'lib/models/porcelain.rb', line 16996

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16998
16999
17000
# File 'lib/models/porcelain.rb', line 16998

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17000
17001
17002
# File 'lib/models/porcelain.rb', line 17000

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17002
17003
17004
# File 'lib/models/porcelain.rb', line 17002

def name
  @name
end

#passwordObject

The password to authenticate with.



17004
17005
17006
# File 'lib/models/porcelain.rb', line 17004

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17006
17007
17008
# File 'lib/models/porcelain.rb', line 17006

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17008
17009
17010
# File 'lib/models/porcelain.rb', line 17008

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17010
17011
17012
# File 'lib/models/porcelain.rb', line 17010

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17012
17013
17014
# File 'lib/models/porcelain.rb', line 17012

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17014
17015
17016
# File 'lib/models/porcelain.rb', line 17014

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17016
17017
17018
# File 'lib/models/porcelain.rb', line 17016

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17018
17019
17020
# File 'lib/models/porcelain.rb', line 17018

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17054
17055
17056
17057
17058
17059
17060
# File 'lib/models/porcelain.rb', line 17054

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end