Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



15776
15777
15778
15779
15780
15781
15782
15783
15784
15785
15786
15787
15788
15789
15790
15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
# File 'lib/models/porcelain.rb', line 15776

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



15746
15747
15748
# File 'lib/models/porcelain.rb', line 15746

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15748
15749
15750
# File 'lib/models/porcelain.rb', line 15748

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15750
15751
15752
# File 'lib/models/porcelain.rb', line 15750

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15752
15753
15754
# File 'lib/models/porcelain.rb', line 15752

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15754
15755
15756
# File 'lib/models/porcelain.rb', line 15754

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15756
15757
15758
# File 'lib/models/porcelain.rb', line 15756

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15758
15759
15760
# File 'lib/models/porcelain.rb', line 15758

def name
  @name
end

#passwordObject

The password to authenticate with.



15760
15761
15762
# File 'lib/models/porcelain.rb', line 15760

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15762
15763
15764
# File 'lib/models/porcelain.rb', line 15762

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



15764
15765
15766
# File 'lib/models/porcelain.rb', line 15764

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15766
15767
15768
# File 'lib/models/porcelain.rb', line 15766

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15768
15769
15770
# File 'lib/models/porcelain.rb', line 15768

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



15770
15771
15772
# File 'lib/models/porcelain.rb', line 15770

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15772
15773
15774
# File 'lib/models/porcelain.rb', line 15772

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15774
15775
15776
# File 'lib/models/porcelain.rb', line 15774

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15810
15811
15812
15813
15814
15815
15816
# File 'lib/models/porcelain.rb', line 15810

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end