Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



15502
15503
15504
15505
15506
15507
15508
15509
15510
15511
15512
15513
15514
15515
15516
15517
15518
15519
15520
15521
15522
15523
15524
15525
15526
15527
15528
15529
15530
15531
15532
15533
15534
# File 'lib/models/porcelain.rb', line 15502

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



15472
15473
15474
# File 'lib/models/porcelain.rb', line 15472

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15474
15475
15476
# File 'lib/models/porcelain.rb', line 15474

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15476
15477
15478
# File 'lib/models/porcelain.rb', line 15476

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15478
15479
15480
# File 'lib/models/porcelain.rb', line 15478

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15480
15481
15482
# File 'lib/models/porcelain.rb', line 15480

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15482
15483
15484
# File 'lib/models/porcelain.rb', line 15482

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15484
15485
15486
# File 'lib/models/porcelain.rb', line 15484

def name
  @name
end

#passwordObject

The password to authenticate with.



15486
15487
15488
# File 'lib/models/porcelain.rb', line 15486

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15488
15489
15490
# File 'lib/models/porcelain.rb', line 15488

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



15490
15491
15492
# File 'lib/models/porcelain.rb', line 15490

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15492
15493
15494
# File 'lib/models/porcelain.rb', line 15492

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15494
15495
15496
# File 'lib/models/porcelain.rb', line 15494

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



15496
15497
15498
# File 'lib/models/porcelain.rb', line 15496

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15498
15499
15500
# File 'lib/models/porcelain.rb', line 15498

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15500
15501
15502
# File 'lib/models/porcelain.rb', line 15500

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15536
15537
15538
15539
15540
15541
15542
# File 'lib/models/porcelain.rb', line 15536

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end