Class: SDM::Vertica
- Inherits:
-
Object
- Object
- SDM::Vertica
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica
constructor
A new instance of Vertica.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica
Returns a new instance of Vertica.
15318 15319 15320 15321 15322 15323 15324 15325 15326 15327 15328 15329 15330 15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 |
# File 'lib/models/porcelain.rb', line 15318 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
15288 15289 15290 |
# File 'lib/models/porcelain.rb', line 15288 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
15290 15291 15292 |
# File 'lib/models/porcelain.rb', line 15290 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
15292 15293 15294 |
# File 'lib/models/porcelain.rb', line 15292 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
15294 15295 15296 |
# File 'lib/models/porcelain.rb', line 15294 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
15296 15297 15298 |
# File 'lib/models/porcelain.rb', line 15296 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
15298 15299 15300 |
# File 'lib/models/porcelain.rb', line 15298 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
15300 15301 15302 |
# File 'lib/models/porcelain.rb', line 15300 def name @name end |
#password ⇒ Object
The password to authenticate with.
15302 15303 15304 |
# File 'lib/models/porcelain.rb', line 15302 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
15304 15305 15306 |
# File 'lib/models/porcelain.rb', line 15304 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
15306 15307 15308 |
# File 'lib/models/porcelain.rb', line 15306 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
15308 15309 15310 |
# File 'lib/models/porcelain.rb', line 15308 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
15310 15311 15312 |
# File 'lib/models/porcelain.rb', line 15310 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
15312 15313 15314 |
# File 'lib/models/porcelain.rb', line 15312 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
15314 15315 15316 |
# File 'lib/models/porcelain.rb', line 15314 def @tags end |
#username ⇒ Object
The username to authenticate with.
15316 15317 15318 |
# File 'lib/models/porcelain.rb', line 15316 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15352 15353 15354 15355 15356 15357 15358 |
# File 'lib/models/porcelain.rb', line 15352 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |