Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Vertica is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



15319
15320
15321
15322
15323
15324
15325
15326
15327
15328
15329
15330
15331
15332
15333
15334
15335
15336
15337
15338
15339
15340
15341
15342
15343
15344
15345
15346
15347
15348
15349
15350
15351
# File 'lib/models/porcelain.rb', line 15319

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



15289
15290
15291
# File 'lib/models/porcelain.rb', line 15289

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15291
15292
15293
# File 'lib/models/porcelain.rb', line 15291

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15293
15294
15295
# File 'lib/models/porcelain.rb', line 15293

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15295
15296
15297
# File 'lib/models/porcelain.rb', line 15295

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15297
15298
15299
# File 'lib/models/porcelain.rb', line 15297

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15299
15300
15301
# File 'lib/models/porcelain.rb', line 15299

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15301
15302
15303
# File 'lib/models/porcelain.rb', line 15301

def name
  @name
end

#passwordObject

The password to authenticate with.



15303
15304
15305
# File 'lib/models/porcelain.rb', line 15303

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15305
15306
15307
# File 'lib/models/porcelain.rb', line 15305

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



15307
15308
15309
# File 'lib/models/porcelain.rb', line 15307

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15309
15310
15311
# File 'lib/models/porcelain.rb', line 15309

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15311
15312
15313
# File 'lib/models/porcelain.rb', line 15311

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



15313
15314
15315
# File 'lib/models/porcelain.rb', line 15313

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15315
15316
15317
# File 'lib/models/porcelain.rb', line 15315

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15317
15318
15319
# File 'lib/models/porcelain.rb', line 15317

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15353
15354
15355
15356
15357
15358
15359
# File 'lib/models/porcelain.rb', line 15353

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end