Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Vertica is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



15308
15309
15310
15311
15312
15313
15314
15315
15316
15317
15318
15319
15320
15321
15322
15323
15324
15325
15326
15327
15328
15329
15330
15331
15332
15333
15334
15335
15336
15337
15338
15339
15340
# File 'lib/models/porcelain.rb', line 15308

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



15278
15279
15280
# File 'lib/models/porcelain.rb', line 15278

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15280
15281
15282
# File 'lib/models/porcelain.rb', line 15280

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15282
15283
15284
# File 'lib/models/porcelain.rb', line 15282

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15284
15285
15286
# File 'lib/models/porcelain.rb', line 15284

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15286
15287
15288
# File 'lib/models/porcelain.rb', line 15286

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15288
15289
15290
# File 'lib/models/porcelain.rb', line 15288

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15290
15291
15292
# File 'lib/models/porcelain.rb', line 15290

def name
  @name
end

#passwordObject

The password to authenticate with.



15292
15293
15294
# File 'lib/models/porcelain.rb', line 15292

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15294
15295
15296
# File 'lib/models/porcelain.rb', line 15294

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



15296
15297
15298
# File 'lib/models/porcelain.rb', line 15296

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15298
15299
15300
# File 'lib/models/porcelain.rb', line 15298

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15300
15301
15302
# File 'lib/models/porcelain.rb', line 15300

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



15302
15303
15304
# File 'lib/models/porcelain.rb', line 15302

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15304
15305
15306
# File 'lib/models/porcelain.rb', line 15304

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15306
15307
15308
# File 'lib/models/porcelain.rb', line 15306

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15342
15343
15344
15345
15346
15347
15348
# File 'lib/models/porcelain.rb', line 15342

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end