Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Vertica is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



15240
15241
15242
15243
15244
15245
15246
15247
15248
15249
15250
15251
15252
15253
15254
15255
15256
15257
15258
15259
15260
15261
15262
15263
15264
15265
15266
15267
15268
15269
15270
15271
15272
# File 'lib/models/porcelain.rb', line 15240

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



15210
15211
15212
# File 'lib/models/porcelain.rb', line 15210

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15212
15213
15214
# File 'lib/models/porcelain.rb', line 15212

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15214
15215
15216
# File 'lib/models/porcelain.rb', line 15214

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15216
15217
15218
# File 'lib/models/porcelain.rb', line 15216

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15218
15219
15220
# File 'lib/models/porcelain.rb', line 15218

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15220
15221
15222
# File 'lib/models/porcelain.rb', line 15220

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15222
15223
15224
# File 'lib/models/porcelain.rb', line 15222

def name
  @name
end

#passwordObject

The password to authenticate with.



15224
15225
15226
# File 'lib/models/porcelain.rb', line 15224

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15226
15227
15228
# File 'lib/models/porcelain.rb', line 15226

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



15228
15229
15230
# File 'lib/models/porcelain.rb', line 15228

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15230
15231
15232
# File 'lib/models/porcelain.rb', line 15230

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15232
15233
15234
# File 'lib/models/porcelain.rb', line 15232

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



15234
15235
15236
# File 'lib/models/porcelain.rb', line 15234

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15236
15237
15238
# File 'lib/models/porcelain.rb', line 15236

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15238
15239
15240
# File 'lib/models/porcelain.rb', line 15238

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15274
15275
15276
15277
15278
15279
15280
# File 'lib/models/porcelain.rb', line 15274

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end