Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Vertica is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



15167
15168
15169
15170
15171
15172
15173
15174
15175
15176
15177
15178
15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
15199
# File 'lib/models/porcelain.rb', line 15167

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



15137
15138
15139
# File 'lib/models/porcelain.rb', line 15137

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15139
15140
15141
# File 'lib/models/porcelain.rb', line 15139

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15141
15142
15143
# File 'lib/models/porcelain.rb', line 15141

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15143
15144
15145
# File 'lib/models/porcelain.rb', line 15143

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15145
15146
15147
# File 'lib/models/porcelain.rb', line 15145

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15147
15148
15149
# File 'lib/models/porcelain.rb', line 15147

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15149
15150
15151
# File 'lib/models/porcelain.rb', line 15149

def name
  @name
end

#passwordObject

The password to authenticate with.



15151
15152
15153
# File 'lib/models/porcelain.rb', line 15151

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15153
15154
15155
# File 'lib/models/porcelain.rb', line 15153

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



15155
15156
15157
# File 'lib/models/porcelain.rb', line 15155

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15157
15158
15159
# File 'lib/models/porcelain.rb', line 15157

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15159
15160
15161
# File 'lib/models/porcelain.rb', line 15159

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



15161
15162
15163
# File 'lib/models/porcelain.rb', line 15161

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15163
15164
15165
# File 'lib/models/porcelain.rb', line 15163

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15165
15166
15167
# File 'lib/models/porcelain.rb', line 15165

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15201
15202
15203
15204
15205
15206
15207
# File 'lib/models/porcelain.rb', line 15201

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end