Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Vertica is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
15124
15125
15126
15127
15128
15129
15130
15131
# File 'lib/models/porcelain.rb', line 15099

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



15069
15070
15071
# File 'lib/models/porcelain.rb', line 15069

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15071
15072
15073
# File 'lib/models/porcelain.rb', line 15071

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15073
15074
15075
# File 'lib/models/porcelain.rb', line 15073

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15075
15076
15077
# File 'lib/models/porcelain.rb', line 15075

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15077
15078
15079
# File 'lib/models/porcelain.rb', line 15077

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15079
15080
15081
# File 'lib/models/porcelain.rb', line 15079

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15081
15082
15083
# File 'lib/models/porcelain.rb', line 15081

def name
  @name
end

#passwordObject

The password to authenticate with.



15083
15084
15085
# File 'lib/models/porcelain.rb', line 15083

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15085
15086
15087
# File 'lib/models/porcelain.rb', line 15085

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



15087
15088
15089
# File 'lib/models/porcelain.rb', line 15087

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15089
15090
15091
# File 'lib/models/porcelain.rb', line 15089

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15091
15092
15093
# File 'lib/models/porcelain.rb', line 15091

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



15093
15094
15095
# File 'lib/models/porcelain.rb', line 15093

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15095
15096
15097
# File 'lib/models/porcelain.rb', line 15095

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15097
15098
15099
# File 'lib/models/porcelain.rb', line 15097

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15133
15134
15135
15136
15137
15138
15139
# File 'lib/models/porcelain.rb', line 15133

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end