Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Vertica is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



13915
13916
13917
13918
13919
13920
13921
13922
13923
13924
13925
13926
13927
13928
13929
13930
13931
13932
13933
13934
13935
13936
13937
13938
13939
13940
13941
13942
13943
13944
13945
13946
13947
# File 'lib/models/porcelain.rb', line 13915

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13885
13886
13887
# File 'lib/models/porcelain.rb', line 13885

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13887
13888
13889
# File 'lib/models/porcelain.rb', line 13887

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13889
13890
13891
# File 'lib/models/porcelain.rb', line 13889

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13891
13892
13893
# File 'lib/models/porcelain.rb', line 13891

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13893
13894
13895
# File 'lib/models/porcelain.rb', line 13893

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13895
13896
13897
# File 'lib/models/porcelain.rb', line 13895

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13897
13898
13899
# File 'lib/models/porcelain.rb', line 13897

def name
  @name
end

#passwordObject

The password to authenticate with.



13899
13900
13901
# File 'lib/models/porcelain.rb', line 13899

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13901
13902
13903
# File 'lib/models/porcelain.rb', line 13901

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



13903
13904
13905
# File 'lib/models/porcelain.rb', line 13903

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13905
13906
13907
# File 'lib/models/porcelain.rb', line 13905

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13907
13908
13909
# File 'lib/models/porcelain.rb', line 13907

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13909
13910
13911
# File 'lib/models/porcelain.rb', line 13909

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13911
13912
13913
# File 'lib/models/porcelain.rb', line 13911

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13913
13914
13915
# File 'lib/models/porcelain.rb', line 13913

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13949
13950
13951
13952
13953
13954
13955
# File 'lib/models/porcelain.rb', line 13949

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end