Class: SDM::Vertica
- Inherits:
-
Object
- Object
- SDM::Vertica
- Defined in:
- lib/models/porcelain.rb
Overview
Vertica is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica
constructor
A new instance of Vertica.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica
Returns a new instance of Vertica.
13915 13916 13917 13918 13919 13920 13921 13922 13923 13924 13925 13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 13945 13946 13947 |
# File 'lib/models/porcelain.rb', line 13915 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
13885 13886 13887 |
# File 'lib/models/porcelain.rb', line 13885 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
13887 13888 13889 |
# File 'lib/models/porcelain.rb', line 13887 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
13889 13890 13891 |
# File 'lib/models/porcelain.rb', line 13889 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
13891 13892 13893 |
# File 'lib/models/porcelain.rb', line 13891 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
13893 13894 13895 |
# File 'lib/models/porcelain.rb', line 13893 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
13895 13896 13897 |
# File 'lib/models/porcelain.rb', line 13895 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
13897 13898 13899 |
# File 'lib/models/porcelain.rb', line 13897 def name @name end |
#password ⇒ Object
The password to authenticate with.
13899 13900 13901 |
# File 'lib/models/porcelain.rb', line 13899 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
13901 13902 13903 |
# File 'lib/models/porcelain.rb', line 13901 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
13903 13904 13905 |
# File 'lib/models/porcelain.rb', line 13903 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
13905 13906 13907 |
# File 'lib/models/porcelain.rb', line 13905 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
13907 13908 13909 |
# File 'lib/models/porcelain.rb', line 13907 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
13909 13910 13911 |
# File 'lib/models/porcelain.rb', line 13909 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13911 13912 13913 |
# File 'lib/models/porcelain.rb', line 13911 def @tags end |
#username ⇒ Object
The username to authenticate with.
13913 13914 13915 |
# File 'lib/models/porcelain.rb', line 13913 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13949 13950 13951 13952 13953 13954 13955 |
# File 'lib/models/porcelain.rb', line 13949 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |