Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Vertica is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



13840
13841
13842
13843
13844
13845
13846
13847
13848
13849
13850
13851
13852
13853
13854
13855
13856
13857
13858
13859
13860
13861
13862
13863
13864
13865
13866
13867
13868
13869
13870
13871
13872
# File 'lib/models/porcelain.rb', line 13840

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13810
13811
13812
# File 'lib/models/porcelain.rb', line 13810

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13812
13813
13814
# File 'lib/models/porcelain.rb', line 13812

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13814
13815
13816
# File 'lib/models/porcelain.rb', line 13814

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13816
13817
13818
# File 'lib/models/porcelain.rb', line 13816

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13818
13819
13820
# File 'lib/models/porcelain.rb', line 13818

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13820
13821
13822
# File 'lib/models/porcelain.rb', line 13820

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13822
13823
13824
# File 'lib/models/porcelain.rb', line 13822

def name
  @name
end

#passwordObject

The password to authenticate with.



13824
13825
13826
# File 'lib/models/porcelain.rb', line 13824

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13826
13827
13828
# File 'lib/models/porcelain.rb', line 13826

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



13828
13829
13830
# File 'lib/models/porcelain.rb', line 13828

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13830
13831
13832
# File 'lib/models/porcelain.rb', line 13830

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13832
13833
13834
# File 'lib/models/porcelain.rb', line 13832

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13834
13835
13836
# File 'lib/models/porcelain.rb', line 13834

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13836
13837
13838
# File 'lib/models/porcelain.rb', line 13836

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13838
13839
13840
# File 'lib/models/porcelain.rb', line 13838

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13874
13875
13876
13877
13878
13879
13880
# File 'lib/models/porcelain.rb', line 13874

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end