Class: SDM::Workflow
- Inherits:
-
Object
- Object
- SDM::Workflow
- Defined in:
- lib/models/porcelain.rb
Overview
Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.
Instance Attribute Summary collapse
-
#access_request_fixed_duration ⇒ Object
Fixed Duration of access requests bound to this workflow.
-
#access_request_max_duration ⇒ Object
Maximum Duration of access requests bound to this workflow.
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
-
#approval_flow_id ⇒ Object
Optional approval flow ID identifies an approval flow that linked to the workflow.
-
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
-
#description ⇒ Object
Optional description of the Workflow.
-
#enabled ⇒ Object
Optional enabled state for workflow.
-
#id ⇒ Object
Unique identifier of the Workflow.
-
#name ⇒ Object
Unique human-readable name of the Workflow.
-
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
Instance Method Summary collapse
-
#initialize(access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
constructor
A new instance of Workflow.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
Returns a new instance of Workflow.
18896 18897 18898 18899 18900 18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 18912 18913 18914 18915 18916 18917 18918 |
# File 'lib/models/porcelain.rb', line 18896 def initialize( access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil ) @access_request_fixed_duration = access_request_fixed_duration == nil ? nil : access_request_fixed_duration @access_request_max_duration = access_request_max_duration == nil ? nil : access_request_max_duration @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id @auto_grant = auto_grant == nil ? false : auto_grant @description = description == nil ? "" : description @enabled = enabled == nil ? false : enabled @id = id == nil ? "" : id @name = name == nil ? "" : name @weight = weight == nil ? 0 : weight end |
Instance Attribute Details
#access_request_fixed_duration ⇒ Object
Fixed Duration of access requests bound to this workflow. If fixed duration is provided, max duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.
18871 18872 18873 |
# File 'lib/models/porcelain.rb', line 18871 def access_request_fixed_duration @access_request_fixed_duration end |
#access_request_max_duration ⇒ Object
Maximum Duration of access requests bound to this workflow. If max duration is provided, fixed duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.
18874 18875 18876 |
# File 'lib/models/porcelain.rb', line 18874 def access_request_max_duration @access_request_max_duration end |
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
18876 18877 18878 |
# File 'lib/models/porcelain.rb', line 18876 def access_rules @access_rules end |
#approval_flow_id ⇒ Object
Optional approval flow ID identifies an approval flow that linked to the workflow
18878 18879 18880 |
# File 'lib/models/porcelain.rb', line 18878 def approval_flow_id @approval_flow_id end |
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
18880 18881 18882 |
# File 'lib/models/porcelain.rb', line 18880 def auto_grant @auto_grant end |
#description ⇒ Object
Optional description of the Workflow.
18882 18883 18884 |
# File 'lib/models/porcelain.rb', line 18882 def description @description end |
#enabled ⇒ Object
Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.
18888 18889 18890 |
# File 'lib/models/porcelain.rb', line 18888 def enabled @enabled end |
#id ⇒ Object
Unique identifier of the Workflow.
18890 18891 18892 |
# File 'lib/models/porcelain.rb', line 18890 def id @id end |
#name ⇒ Object
Unique human-readable name of the Workflow.
18892 18893 18894 |
# File 'lib/models/porcelain.rb', line 18892 def name @name end |
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
18894 18895 18896 |
# File 'lib/models/porcelain.rb', line 18894 def weight @weight end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18920 18921 18922 18923 18924 18925 18926 |
# File 'lib/models/porcelain.rb', line 18920 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |