Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



18889
18890
18891
18892
18893
18894
18895
18896
18897
18898
18899
18900
18901
18902
18903
18904
18905
18906
18907
18908
18909
18910
18911
# File 'lib/models/porcelain.rb', line 18889

def initialize(
  access_request_fixed_duration: nil,
  access_request_max_duration: nil,
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_request_fixed_duration = access_request_fixed_duration == nil ? nil : access_request_fixed_duration
  @access_request_max_duration = access_request_max_duration == nil ? nil : access_request_max_duration
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_request_fixed_durationObject

Fixed Duration of access requests bound to this workflow. If fixed duration is provided, max duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.



18864
18865
18866
# File 'lib/models/porcelain.rb', line 18864

def access_request_fixed_duration
  @access_request_fixed_duration
end

#access_request_max_durationObject

Maximum Duration of access requests bound to this workflow. If max duration is provided, fixed duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.



18867
18868
18869
# File 'lib/models/porcelain.rb', line 18867

def access_request_max_duration
  @access_request_max_duration
end

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



18869
18870
18871
# File 'lib/models/porcelain.rb', line 18869

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



18871
18872
18873
# File 'lib/models/porcelain.rb', line 18871

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



18873
18874
18875
# File 'lib/models/porcelain.rb', line 18873

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



18875
18876
18877
# File 'lib/models/porcelain.rb', line 18875

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



18881
18882
18883
# File 'lib/models/porcelain.rb', line 18881

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



18883
18884
18885
# File 'lib/models/porcelain.rb', line 18883

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



18885
18886
18887
# File 'lib/models/porcelain.rb', line 18885

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



18887
18888
18889
# File 'lib/models/porcelain.rb', line 18887

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18913
18914
18915
18916
18917
18918
18919
# File 'lib/models/porcelain.rb', line 18913

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end