Class: SDM::Workflow
- Inherits:
-
Object
- Object
- SDM::Workflow
- Defined in:
- lib/models/porcelain.rb
Overview
Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.
Instance Attribute Summary collapse
-
#access_request_fixed_duration ⇒ Object
Fixed Duration of access requests bound to this workflow.
-
#access_request_max_duration ⇒ Object
Maximum Duration of access requests bound to this workflow.
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
-
#approval_flow_id ⇒ Object
Optional approval flow ID identifies an approval flow that linked to the workflow.
-
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
-
#description ⇒ Object
Optional description of the Workflow.
-
#enabled ⇒ Object
Optional enabled state for workflow.
-
#id ⇒ Object
Unique identifier of the Workflow.
-
#name ⇒ Object
Unique human-readable name of the Workflow.
-
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
Instance Method Summary collapse
-
#initialize(access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
constructor
A new instance of Workflow.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
Returns a new instance of Workflow.
17394 17395 17396 17397 17398 17399 17400 17401 17402 17403 17404 17405 17406 17407 17408 17409 17410 17411 17412 17413 17414 17415 17416 |
# File 'lib/models/porcelain.rb', line 17394 def initialize( access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil ) @access_request_fixed_duration = access_request_fixed_duration == nil ? nil : access_request_fixed_duration @access_request_max_duration = access_request_max_duration == nil ? nil : access_request_max_duration @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id @auto_grant = auto_grant == nil ? false : auto_grant @description = description == nil ? "" : description @enabled = enabled == nil ? false : enabled @id = id == nil ? "" : id @name = name == nil ? "" : name @weight = weight == nil ? 0 : weight end |
Instance Attribute Details
#access_request_fixed_duration ⇒ Object
Fixed Duration of access requests bound to this workflow. If fixed duration is provided, max duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.
17369 17370 17371 |
# File 'lib/models/porcelain.rb', line 17369 def access_request_fixed_duration @access_request_fixed_duration end |
#access_request_max_duration ⇒ Object
Maximum Duration of access requests bound to this workflow. If max duration is provided, fixed duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.
17372 17373 17374 |
# File 'lib/models/porcelain.rb', line 17372 def access_request_max_duration @access_request_max_duration end |
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
17374 17375 17376 |
# File 'lib/models/porcelain.rb', line 17374 def access_rules @access_rules end |
#approval_flow_id ⇒ Object
Optional approval flow ID identifies an approval flow that linked to the workflow
17376 17377 17378 |
# File 'lib/models/porcelain.rb', line 17376 def approval_flow_id @approval_flow_id end |
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
17378 17379 17380 |
# File 'lib/models/porcelain.rb', line 17378 def auto_grant @auto_grant end |
#description ⇒ Object
Optional description of the Workflow.
17380 17381 17382 |
# File 'lib/models/porcelain.rb', line 17380 def description @description end |
#enabled ⇒ Object
Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.
17386 17387 17388 |
# File 'lib/models/porcelain.rb', line 17386 def enabled @enabled end |
#id ⇒ Object
Unique identifier of the Workflow.
17388 17389 17390 |
# File 'lib/models/porcelain.rb', line 17388 def id @id end |
#name ⇒ Object
Unique human-readable name of the Workflow.
17390 17391 17392 |
# File 'lib/models/porcelain.rb', line 17390 def name @name end |
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
17392 17393 17394 |
# File 'lib/models/porcelain.rb', line 17392 def weight @weight end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17418 17419 17420 17421 17422 17423 17424 |
# File 'lib/models/porcelain.rb', line 17418 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |