Class: SDM::Workflow
- Inherits:
-
Object
- Object
- SDM::Workflow
- Defined in:
- lib/models/porcelain.rb
Overview
Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.
Instance Attribute Summary collapse
-
#access_request_fixed_duration ⇒ Object
Fixed Duration of access requests bound to this workflow.
-
#access_request_max_duration ⇒ Object
Maximum Duration of access requests bound to this workflow.
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
-
#approval_flow_id ⇒ Object
Optional approval flow ID identifies an approval flow that linked to the workflow.
-
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
-
#description ⇒ Object
Optional description of the Workflow.
-
#enabled ⇒ Object
Optional enabled state for workflow.
-
#id ⇒ Object
Unique identifier of the Workflow.
-
#name ⇒ Object
Unique human-readable name of the Workflow.
-
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
Instance Method Summary collapse
-
#initialize(access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
constructor
A new instance of Workflow.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
Returns a new instance of Workflow.
15850 15851 15852 15853 15854 15855 15856 15857 15858 15859 15860 15861 15862 15863 15864 15865 15866 15867 15868 15869 15870 15871 15872 |
# File 'lib/models/porcelain.rb', line 15850 def initialize( access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil ) @access_request_fixed_duration = access_request_fixed_duration == nil ? nil : access_request_fixed_duration @access_request_max_duration = access_request_max_duration == nil ? nil : access_request_max_duration @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id @auto_grant = auto_grant == nil ? false : auto_grant @description = description == nil ? "" : description @enabled = enabled == nil ? false : enabled @id = id == nil ? "" : id @name = name == nil ? "" : name @weight = weight == nil ? 0 : weight end |
Instance Attribute Details
#access_request_fixed_duration ⇒ Object
Fixed Duration of access requests bound to this workflow. If fixed duration is provided, max duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.
15825 15826 15827 |
# File 'lib/models/porcelain.rb', line 15825 def access_request_fixed_duration @access_request_fixed_duration end |
#access_request_max_duration ⇒ Object
Maximum Duration of access requests bound to this workflow. If max duration is provided, fixed duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.
15828 15829 15830 |
# File 'lib/models/porcelain.rb', line 15828 def access_request_max_duration @access_request_max_duration end |
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
15830 15831 15832 |
# File 'lib/models/porcelain.rb', line 15830 def access_rules @access_rules end |
#approval_flow_id ⇒ Object
Optional approval flow ID identifies an approval flow that linked to the workflow
15832 15833 15834 |
# File 'lib/models/porcelain.rb', line 15832 def approval_flow_id @approval_flow_id end |
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
15834 15835 15836 |
# File 'lib/models/porcelain.rb', line 15834 def auto_grant @auto_grant end |
#description ⇒ Object
Optional description of the Workflow.
15836 15837 15838 |
# File 'lib/models/porcelain.rb', line 15836 def description @description end |
#enabled ⇒ Object
Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.
15842 15843 15844 |
# File 'lib/models/porcelain.rb', line 15842 def enabled @enabled end |
#id ⇒ Object
Unique identifier of the Workflow.
15844 15845 15846 |
# File 'lib/models/porcelain.rb', line 15844 def id @id end |
#name ⇒ Object
Unique human-readable name of the Workflow.
15846 15847 15848 |
# File 'lib/models/porcelain.rb', line 15846 def name @name end |
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
15848 15849 15850 |
# File 'lib/models/porcelain.rb', line 15848 def weight @weight end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15874 15875 15876 15877 15878 15879 15880 |
# File 'lib/models/porcelain.rb', line 15874 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |