Class: SDM::Workflow
- Inherits:
-
Object
- Object
- SDM::Workflow
- Defined in:
- lib/models/porcelain.rb
Overview
Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.
Instance Attribute Summary collapse
-
#access_request_fixed_duration ⇒ Object
Fixed Duration of access requests bound to this workflow.
-
#access_request_max_duration ⇒ Object
Maximum Duration of access requests bound to this workflow.
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
-
#approval_flow_id ⇒ Object
Optional approval flow ID identifies an approval flow that linked to the workflow.
-
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
-
#description ⇒ Object
Optional description of the Workflow.
-
#enabled ⇒ Object
Optional enabled state for workflow.
-
#id ⇒ Object
Unique identifier of the Workflow.
-
#name ⇒ Object
Unique human-readable name of the Workflow.
-
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
Instance Method Summary collapse
-
#initialize(access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
constructor
A new instance of Workflow.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
Returns a new instance of Workflow.
13989 13990 13991 13992 13993 13994 13995 13996 13997 13998 13999 14000 14001 14002 14003 14004 14005 14006 14007 14008 14009 14010 14011 |
# File 'lib/models/porcelain.rb', line 13989 def initialize( access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil ) @access_request_fixed_duration = access_request_fixed_duration == nil ? nil : access_request_fixed_duration @access_request_max_duration = access_request_max_duration == nil ? nil : access_request_max_duration @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id @auto_grant = auto_grant == nil ? false : auto_grant @description = description == nil ? "" : description @enabled = enabled == nil ? false : enabled @id = id == nil ? "" : id @name = name == nil ? "" : name @weight = weight == nil ? 0 : weight end |
Instance Attribute Details
#access_request_fixed_duration ⇒ Object
Fixed Duration of access requests bound to this workflow. If fixed duration is provided, max duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.
13964 13965 13966 |
# File 'lib/models/porcelain.rb', line 13964 def access_request_fixed_duration @access_request_fixed_duration end |
#access_request_max_duration ⇒ Object
Maximum Duration of access requests bound to this workflow. If max duration is provided, fixed duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.
13967 13968 13969 |
# File 'lib/models/porcelain.rb', line 13967 def access_request_max_duration @access_request_max_duration end |
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
13969 13970 13971 |
# File 'lib/models/porcelain.rb', line 13969 def access_rules @access_rules end |
#approval_flow_id ⇒ Object
Optional approval flow ID identifies an approval flow that linked to the workflow
13971 13972 13973 |
# File 'lib/models/porcelain.rb', line 13971 def approval_flow_id @approval_flow_id end |
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
13973 13974 13975 |
# File 'lib/models/porcelain.rb', line 13973 def auto_grant @auto_grant end |
#description ⇒ Object
Optional description of the Workflow.
13975 13976 13977 |
# File 'lib/models/porcelain.rb', line 13975 def description @description end |
#enabled ⇒ Object
Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.
13981 13982 13983 |
# File 'lib/models/porcelain.rb', line 13981 def enabled @enabled end |
#id ⇒ Object
Unique identifier of the Workflow.
13983 13984 13985 |
# File 'lib/models/porcelain.rb', line 13983 def id @id end |
#name ⇒ Object
Unique human-readable name of the Workflow.
13985 13986 13987 |
# File 'lib/models/porcelain.rb', line 13985 def name @name end |
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
13987 13988 13989 |
# File 'lib/models/porcelain.rb', line 13987 def weight @weight end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14013 14014 14015 14016 14017 14018 14019 |
# File 'lib/models/porcelain.rb', line 14013 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |