Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



13594
13595
13596
13597
13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
13613
13614
13615
13616
# File 'lib/models/porcelain.rb', line 13594

def initialize(
  access_request_fixed_duration: nil,
  access_request_max_duration: nil,
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_request_fixed_duration = access_request_fixed_duration == nil ? nil : access_request_fixed_duration
  @access_request_max_duration = access_request_max_duration == nil ? nil : access_request_max_duration
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_request_fixed_durationObject

Fixed Duration of access requests bound to this workflow. If fixed duration is provided, max duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.



13569
13570
13571
# File 'lib/models/porcelain.rb', line 13569

def access_request_fixed_duration
  @access_request_fixed_duration
end

#access_request_max_durationObject

Maximum Duration of access requests bound to this workflow. If max duration is provided, fixed duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.



13572
13573
13574
# File 'lib/models/porcelain.rb', line 13572

def access_request_max_duration
  @access_request_max_duration
end

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



13574
13575
13576
# File 'lib/models/porcelain.rb', line 13574

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



13576
13577
13578
# File 'lib/models/porcelain.rb', line 13576

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



13578
13579
13580
# File 'lib/models/porcelain.rb', line 13578

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



13580
13581
13582
# File 'lib/models/porcelain.rb', line 13580

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



13586
13587
13588
# File 'lib/models/porcelain.rb', line 13586

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



13588
13589
13590
# File 'lib/models/porcelain.rb', line 13588

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



13590
13591
13592
# File 'lib/models/porcelain.rb', line 13590

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



13592
13593
13594
# File 'lib/models/porcelain.rb', line 13592

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13618
13619
13620
13621
13622
13623
13624
# File 'lib/models/porcelain.rb', line 13618

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end