Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



13077
13078
13079
13080
13081
13082
13083
13084
13085
13086
13087
13088
13089
13090
13091
13092
13093
13094
13095
13096
13097
13098
13099
# File 'lib/models/porcelain.rb', line 13077

def initialize(
  access_request_fixed_duration: nil,
  access_request_max_duration: nil,
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_request_fixed_duration = access_request_fixed_duration == nil ? nil : access_request_fixed_duration
  @access_request_max_duration = access_request_max_duration == nil ? nil : access_request_max_duration
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_request_fixed_durationObject

Fixed Duration of access requests bound to this workflow. If fixed duration is provided, max duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.



13052
13053
13054
# File 'lib/models/porcelain.rb', line 13052

def access_request_fixed_duration
  @access_request_fixed_duration
end

#access_request_max_durationObject

Maximum Duration of access requests bound to this workflow. If max duration is provided, fixed duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.



13055
13056
13057
# File 'lib/models/porcelain.rb', line 13055

def access_request_max_duration
  @access_request_max_duration
end

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



13057
13058
13059
# File 'lib/models/porcelain.rb', line 13057

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



13059
13060
13061
# File 'lib/models/porcelain.rb', line 13059

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



13061
13062
13063
# File 'lib/models/porcelain.rb', line 13061

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



13063
13064
13065
# File 'lib/models/porcelain.rb', line 13063

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



13069
13070
13071
# File 'lib/models/porcelain.rb', line 13069

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



13071
13072
13073
# File 'lib/models/porcelain.rb', line 13071

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



13073
13074
13075
# File 'lib/models/porcelain.rb', line 13073

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



13075
13076
13077
# File 'lib/models/porcelain.rb', line 13075

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13101
13102
13103
13104
13105
13106
13107
# File 'lib/models/porcelain.rb', line 13101

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end