Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



12993
12994
12995
12996
12997
12998
12999
13000
13001
13002
13003
13004
13005
13006
13007
13008
13009
13010
13011
# File 'lib/models/porcelain.rb', line 12993

def initialize(
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



12973
12974
12975
# File 'lib/models/porcelain.rb', line 12973

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



12975
12976
12977
# File 'lib/models/porcelain.rb', line 12975

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



12977
12978
12979
# File 'lib/models/porcelain.rb', line 12977

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



12979
12980
12981
# File 'lib/models/porcelain.rb', line 12979

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



12985
12986
12987
# File 'lib/models/porcelain.rb', line 12985

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



12987
12988
12989
# File 'lib/models/porcelain.rb', line 12987

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



12989
12990
12991
# File 'lib/models/porcelain.rb', line 12989

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



12991
12992
12993
# File 'lib/models/porcelain.rb', line 12991

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13013
13014
13015
13016
13017
13018
13019
# File 'lib/models/porcelain.rb', line 13013

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end