Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



12985
12986
12987
12988
12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
13002
13003
# File 'lib/models/porcelain.rb', line 12985

def initialize(
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



12965
12966
12967
# File 'lib/models/porcelain.rb', line 12965

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



12967
12968
12969
# File 'lib/models/porcelain.rb', line 12967

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



12969
12970
12971
# File 'lib/models/porcelain.rb', line 12969

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



12971
12972
12973
# File 'lib/models/porcelain.rb', line 12971

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



12977
12978
12979
# File 'lib/models/porcelain.rb', line 12977

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



12979
12980
12981
# File 'lib/models/porcelain.rb', line 12979

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



12981
12982
12983
# File 'lib/models/porcelain.rb', line 12981

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



12983
12984
12985
# File 'lib/models/porcelain.rb', line 12983

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13005
13006
13007
13008
13009
13010
13011
# File 'lib/models/porcelain.rb', line 13005

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end