Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



12816
12817
12818
12819
12820
12821
12822
12823
12824
12825
12826
12827
12828
12829
12830
12831
12832
12833
12834
# File 'lib/models/porcelain.rb', line 12816

def initialize(
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



12796
12797
12798
# File 'lib/models/porcelain.rb', line 12796

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



12798
12799
12800
# File 'lib/models/porcelain.rb', line 12798

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



12800
12801
12802
# File 'lib/models/porcelain.rb', line 12800

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



12802
12803
12804
# File 'lib/models/porcelain.rb', line 12802

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



12808
12809
12810
# File 'lib/models/porcelain.rb', line 12808

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



12810
12811
12812
# File 'lib/models/porcelain.rb', line 12810

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



12812
12813
12814
# File 'lib/models/porcelain.rb', line 12812

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



12814
12815
12816
# File 'lib/models/porcelain.rb', line 12814

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12836
12837
12838
12839
12840
12841
12842
# File 'lib/models/porcelain.rb', line 12836

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end