Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



12676
12677
12678
12679
12680
12681
12682
12683
12684
12685
12686
12687
12688
12689
12690
12691
12692
12693
12694
# File 'lib/models/porcelain.rb', line 12676

def initialize(
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



12656
12657
12658
# File 'lib/models/porcelain.rb', line 12656

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



12658
12659
12660
# File 'lib/models/porcelain.rb', line 12658

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



12660
12661
12662
# File 'lib/models/porcelain.rb', line 12660

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



12662
12663
12664
# File 'lib/models/porcelain.rb', line 12662

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



12668
12669
12670
# File 'lib/models/porcelain.rb', line 12668

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



12670
12671
12672
# File 'lib/models/porcelain.rb', line 12670

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



12672
12673
12674
# File 'lib/models/porcelain.rb', line 12672

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



12674
12675
12676
# File 'lib/models/porcelain.rb', line 12674

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12696
12697
12698
12699
12700
12701
12702
# File 'lib/models/porcelain.rb', line 12696

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end