Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



12669
12670
12671
12672
12673
12674
12675
12676
12677
12678
12679
12680
12681
12682
12683
12684
12685
12686
12687
# File 'lib/models/porcelain.rb', line 12669

def initialize(
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



12649
12650
12651
# File 'lib/models/porcelain.rb', line 12649

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



12651
12652
12653
# File 'lib/models/porcelain.rb', line 12651

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



12653
12654
12655
# File 'lib/models/porcelain.rb', line 12653

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



12655
12656
12657
# File 'lib/models/porcelain.rb', line 12655

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



12661
12662
12663
# File 'lib/models/porcelain.rb', line 12661

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



12663
12664
12665
# File 'lib/models/porcelain.rb', line 12663

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



12665
12666
12667
# File 'lib/models/porcelain.rb', line 12665

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



12667
12668
12669
# File 'lib/models/porcelain.rb', line 12667

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12689
12690
12691
12692
12693
12694
12695
# File 'lib/models/porcelain.rb', line 12689

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end