Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



12321
12322
12323
12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
# File 'lib/models/porcelain.rb', line 12321

def initialize(
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



12301
12302
12303
# File 'lib/models/porcelain.rb', line 12301

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



12303
12304
12305
# File 'lib/models/porcelain.rb', line 12303

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



12305
12306
12307
# File 'lib/models/porcelain.rb', line 12305

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



12307
12308
12309
# File 'lib/models/porcelain.rb', line 12307

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



12313
12314
12315
# File 'lib/models/porcelain.rb', line 12313

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



12315
12316
12317
# File 'lib/models/porcelain.rb', line 12315

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



12317
12318
12319
# File 'lib/models/porcelain.rb', line 12317

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



12319
12320
12321
# File 'lib/models/porcelain.rb', line 12319

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12341
12342
12343
12344
12345
12346
12347
# File 'lib/models/porcelain.rb', line 12341

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end