Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



12152
12153
12154
12155
12156
12157
12158
12159
12160
12161
12162
12163
12164
12165
12166
12167
12168
12169
12170
# File 'lib/models/porcelain.rb', line 12152

def initialize(
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



12132
12133
12134
# File 'lib/models/porcelain.rb', line 12132

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



12134
12135
12136
# File 'lib/models/porcelain.rb', line 12134

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



12136
12137
12138
# File 'lib/models/porcelain.rb', line 12136

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



12138
12139
12140
# File 'lib/models/porcelain.rb', line 12138

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



12144
12145
12146
# File 'lib/models/porcelain.rb', line 12144

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



12146
12147
12148
# File 'lib/models/porcelain.rb', line 12146

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



12148
12149
12150
# File 'lib/models/porcelain.rb', line 12148

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



12150
12151
12152
# File 'lib/models/porcelain.rb', line 12150

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12172
12173
12174
12175
12176
12177
12178
# File 'lib/models/porcelain.rb', line 12172

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end