Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



11986
11987
11988
11989
11990
11991
11992
11993
11994
11995
11996
11997
11998
11999
12000
12001
12002
12003
12004
# File 'lib/models/porcelain.rb', line 11986

def initialize(
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



11966
11967
11968
# File 'lib/models/porcelain.rb', line 11966

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



11968
11969
11970
# File 'lib/models/porcelain.rb', line 11968

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



11970
11971
11972
# File 'lib/models/porcelain.rb', line 11970

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



11972
11973
11974
# File 'lib/models/porcelain.rb', line 11972

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



11978
11979
11980
# File 'lib/models/porcelain.rb', line 11978

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



11980
11981
11982
# File 'lib/models/porcelain.rb', line 11980

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



11982
11983
11984
# File 'lib/models/porcelain.rb', line 11982

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



11984
11985
11986
# File 'lib/models/porcelain.rb', line 11984

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12006
12007
12008
12009
12010
12011
12012
# File 'lib/models/porcelain.rb', line 12006

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end