Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



11759
11760
11761
11762
11763
11764
11765
11766
11767
11768
11769
11770
11771
11772
11773
11774
11775
11776
11777
# File 'lib/models/porcelain.rb', line 11759

def initialize(
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



11739
11740
11741
# File 'lib/models/porcelain.rb', line 11739

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



11741
11742
11743
# File 'lib/models/porcelain.rb', line 11741

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



11743
11744
11745
# File 'lib/models/porcelain.rb', line 11743

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



11745
11746
11747
# File 'lib/models/porcelain.rb', line 11745

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



11751
11752
11753
# File 'lib/models/porcelain.rb', line 11751

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



11753
11754
11755
# File 'lib/models/porcelain.rb', line 11753

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



11755
11756
11757
# File 'lib/models/porcelain.rb', line 11755

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



11757
11758
11759
# File 'lib/models/porcelain.rb', line 11757

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11779
11780
11781
11782
11783
11784
11785
# File 'lib/models/porcelain.rb', line 11779

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end