Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



11526
11527
11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
11539
11540
11541
11542
11543
11544
# File 'lib/models/porcelain.rb', line 11526

def initialize(
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



11506
11507
11508
# File 'lib/models/porcelain.rb', line 11506

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



11508
11509
11510
# File 'lib/models/porcelain.rb', line 11508

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



11510
11511
11512
# File 'lib/models/porcelain.rb', line 11510

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



11512
11513
11514
# File 'lib/models/porcelain.rb', line 11512

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



11518
11519
11520
# File 'lib/models/porcelain.rb', line 11518

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



11520
11521
11522
# File 'lib/models/porcelain.rb', line 11520

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



11522
11523
11524
# File 'lib/models/porcelain.rb', line 11522

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



11524
11525
11526
# File 'lib/models/porcelain.rb', line 11524

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11546
11547
11548
11549
11550
11551
11552
# File 'lib/models/porcelain.rb', line 11546

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end