Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
# File 'lib/models/porcelain.rb', line 10466

def initialize(
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



10446
10447
10448
# File 'lib/models/porcelain.rb', line 10446

def access_rules
  @access_rules
end

#approval_flow_idObject

Optional approval flow ID identifies an approval flow that linked to the workflow



10448
10449
10450
# File 'lib/models/porcelain.rb', line 10448

def approval_flow_id
  @approval_flow_id
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



10450
10451
10452
# File 'lib/models/porcelain.rb', line 10450

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



10452
10453
10454
# File 'lib/models/porcelain.rb', line 10452

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



10458
10459
10460
# File 'lib/models/porcelain.rb', line 10458

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



10460
10461
10462
# File 'lib/models/porcelain.rb', line 10460

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



10462
10463
10464
# File 'lib/models/porcelain.rb', line 10462

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



10464
10465
10466
# File 'lib/models/porcelain.rb', line 10464

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10486
10487
10488
10489
10490
10491
10492
# File 'lib/models/porcelain.rb', line 10486

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end