Class: SDM::Workflow
- Inherits:
-
Object
- Object
- SDM::Workflow
- Defined in:
- lib/models/porcelain.rb
Overview
Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.
Instance Attribute Summary collapse
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
-
#approval_flow_id ⇒ Object
Optional approval flow ID identifies an approval flow that linked to the workflow.
-
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
-
#description ⇒ Object
Optional description of the Workflow.
-
#enabled ⇒ Object
Optional enabled state for workflow.
-
#id ⇒ Object
Unique identifier of the Workflow.
-
#name ⇒ Object
Unique human-readable name of the Workflow.
-
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
Instance Method Summary collapse
-
#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
constructor
A new instance of Workflow.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
Returns a new instance of Workflow.
10381 10382 10383 10384 10385 10386 10387 10388 10389 10390 10391 10392 10393 10394 10395 10396 10397 10398 10399 |
# File 'lib/models/porcelain.rb', line 10381 def initialize( access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil ) @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id @auto_grant = auto_grant == nil ? false : auto_grant @description = description == nil ? "" : description @enabled = enabled == nil ? false : enabled @id = id == nil ? "" : id @name = name == nil ? "" : name @weight = weight == nil ? 0 : weight end |
Instance Attribute Details
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
10361 10362 10363 |
# File 'lib/models/porcelain.rb', line 10361 def access_rules @access_rules end |
#approval_flow_id ⇒ Object
Optional approval flow ID identifies an approval flow that linked to the workflow
10363 10364 10365 |
# File 'lib/models/porcelain.rb', line 10363 def approval_flow_id @approval_flow_id end |
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
10365 10366 10367 |
# File 'lib/models/porcelain.rb', line 10365 def auto_grant @auto_grant end |
#description ⇒ Object
Optional description of the Workflow.
10367 10368 10369 |
# File 'lib/models/porcelain.rb', line 10367 def description @description end |
#enabled ⇒ Object
Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.
10373 10374 10375 |
# File 'lib/models/porcelain.rb', line 10373 def enabled @enabled end |
#id ⇒ Object
Unique identifier of the Workflow.
10375 10376 10377 |
# File 'lib/models/porcelain.rb', line 10375 def id @id end |
#name ⇒ Object
Unique human-readable name of the Workflow.
10377 10378 10379 |
# File 'lib/models/porcelain.rb', line 10377 def name @name end |
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
10379 10380 10381 |
# File 'lib/models/porcelain.rb', line 10379 def weight @weight end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10401 10402 10403 10404 10405 10406 10407 |
# File 'lib/models/porcelain.rb', line 10401 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |