Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



10335
10336
10337
10338
10339
10340
10341
10342
10343
10344
10345
10346
10347
10348
10349
10350
10351
# File 'lib/models/porcelain.rb', line 10335

def initialize(
  access_rules: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Workflow provides access to.



10317
10318
10319
# File 'lib/models/porcelain.rb', line 10317

def access_rules
  @access_rules
end

#auto_grantObject

Optional auto grant setting to automatically approve requests or not, defaults to false.



10319
10320
10321
# File 'lib/models/porcelain.rb', line 10319

def auto_grant
  @auto_grant
end

#descriptionObject

Optional description of the Workflow.



10321
10322
10323
# File 'lib/models/porcelain.rb', line 10321

def description
  @description
end

#enabledObject

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



10327
10328
10329
# File 'lib/models/porcelain.rb', line 10327

def enabled
  @enabled
end

#idObject

Unique identifier of the Workflow.



10329
10330
10331
# File 'lib/models/porcelain.rb', line 10329

def id
  @id
end

#nameObject

Unique human-readable name of the Workflow.



10331
10332
10333
# File 'lib/models/porcelain.rb', line 10331

def name
  @name
end

#weightObject

Optional weight for workflow to specify it's priority in matching a request.



10333
10334
10335
# File 'lib/models/porcelain.rb', line 10333

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10353
10354
10355
10356
10357
10358
10359
# File 'lib/models/porcelain.rb', line 10353

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end