Class: SDM::Workflow
- Inherits:
-
Object
- Object
- SDM::Workflow
- Defined in:
- lib/models/porcelain.rb
Overview
Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.
Instance Attribute Summary collapse
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
-
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
-
#description ⇒ Object
Optional description of the Workflow.
-
#enabled ⇒ Object
Optional enabled state for workflow.
-
#id ⇒ Object
Unique identifier of the Workflow.
-
#name ⇒ Object
Unique human-readable name of the Workflow.
-
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
Instance Method Summary collapse
-
#initialize(access_rules: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
constructor
A new instance of Workflow.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_rules: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
Returns a new instance of Workflow.
9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 |
# File 'lib/models/porcelain.rb', line 9577 def initialize( access_rules: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil ) @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @auto_grant = auto_grant == nil ? false : auto_grant @description = description == nil ? "" : description @enabled = enabled == nil ? false : enabled @id = id == nil ? "" : id @name = name == nil ? "" : name @weight = weight == nil ? 0 : weight end |
Instance Attribute Details
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
9561 9562 9563 |
# File 'lib/models/porcelain.rb', line 9561 def access_rules @access_rules end |
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
9563 9564 9565 |
# File 'lib/models/porcelain.rb', line 9563 def auto_grant @auto_grant end |
#description ⇒ Object
Optional description of the Workflow.
9565 9566 9567 |
# File 'lib/models/porcelain.rb', line 9565 def description @description end |
#enabled ⇒ Object
Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow.
9569 9570 9571 |
# File 'lib/models/porcelain.rb', line 9569 def enabled @enabled end |
#id ⇒ Object
Unique identifier of the Workflow.
9571 9572 9573 |
# File 'lib/models/porcelain.rb', line 9571 def id @id end |
#name ⇒ Object
Unique human-readable name of the Workflow.
9573 9574 9575 |
# File 'lib/models/porcelain.rb', line 9573 def name @name end |
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
9575 9576 9577 |
# File 'lib/models/porcelain.rb', line 9575 def weight @weight end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9595 9596 9597 9598 9599 9600 9601 |
# File 'lib/models/porcelain.rb', line 9595 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |