Class: SDM::Workflow
- Inherits:
-
Object
- Object
- SDM::Workflow
- Defined in:
- lib/models/porcelain.rb
Overview
Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.
Instance Attribute Summary collapse
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
-
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
-
#description ⇒ Object
Optional description of the Workflow.
-
#enabled ⇒ Object
Optional enabled state for workflow.
-
#id ⇒ Object
Unique identifier of the Workflow.
-
#name ⇒ Object
Unique human-readable name of the Workflow.
-
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
Instance Method Summary collapse
-
#initialize(access_rules: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
constructor
A new instance of Workflow.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_rules: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow
Returns a new instance of Workflow.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 |
# File 'lib/models/porcelain.rb', line 9520 def initialize( access_rules: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil ) @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @auto_grant = auto_grant == nil ? false : auto_grant @description = description == nil ? "" : description @enabled = enabled == nil ? false : enabled @id = id == nil ? "" : id @name = name == nil ? "" : name @weight = weight == nil ? 0 : weight end |
Instance Attribute Details
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Workflow provides access to.
9504 9505 9506 |
# File 'lib/models/porcelain.rb', line 9504 def access_rules @access_rules end |
#auto_grant ⇒ Object
Optional auto grant setting to automatically approve requests or not, defaults to false.
9506 9507 9508 |
# File 'lib/models/porcelain.rb', line 9506 def auto_grant @auto_grant end |
#description ⇒ Object
Optional description of the Workflow.
9508 9509 9510 |
# File 'lib/models/porcelain.rb', line 9508 def description @description end |
#enabled ⇒ Object
Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow.
9512 9513 9514 |
# File 'lib/models/porcelain.rb', line 9512 def enabled @enabled end |
#id ⇒ Object
Unique identifier of the Workflow.
9514 9515 9516 |
# File 'lib/models/porcelain.rb', line 9514 def id @id end |
#name ⇒ Object
Unique human-readable name of the Workflow.
9516 9517 9518 |
# File 'lib/models/porcelain.rb', line 9516 def name @name end |
#weight ⇒ Object
Optional weight for workflow to specify it's priority in matching a request.
9518 9519 9520 |
# File 'lib/models/porcelain.rb', line 9518 def weight @weight end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/models/porcelain.rb', line 9538 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |