Class: SDM::Workflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Workflows are the collection of rules that define the resources to which access can be requested, the users that can request that access, and the mechanism for approving those requests which can either but automatic approval or a set of users authorized to approve the requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_request_fixed_duration: nil, access_request_max_duration: nil, access_rules: nil, approval_flow_id: nil, auto_grant: nil, description: nil, enabled: nil, id: nil, name: nil, weight: nil) ⇒ Workflow

Returns a new instance of Workflow.



19315
19316
19317
19318
19319
19320
19321
19322
19323
19324
19325
19326
19327
19328
19329
19330
19331
19332
19333
19334
19335
19336
19337
# File 'lib/models/porcelain.rb', line 19315

def initialize(
  access_request_fixed_duration: nil,
  access_request_max_duration: nil,
  access_rules: nil,
  approval_flow_id: nil,
  auto_grant: nil,
  description: nil,
  enabled: nil,
  id: nil,
  name: nil,
  weight: nil
)
  @access_request_fixed_duration = access_request_fixed_duration == nil ? nil : access_request_fixed_duration
  @access_request_max_duration = access_request_max_duration == nil ? nil : access_request_max_duration
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @auto_grant = auto_grant == nil ? false : auto_grant
  @description = description == nil ? "" : description
  @enabled = enabled == nil ? false : enabled
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @weight = weight == nil ? 0 : weight
end

Instance Attribute Details

#access_request_fixed_duration ⇒ Object

Fixed Duration of access requests bound to this workflow. If fixed duration is provided, max duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.



19290
19291
19292
# File 'lib/models/porcelain.rb', line 19290

def access_request_fixed_duration
  @access_request_fixed_duration
end

#access_request_max_duration ⇒ Object

Maximum Duration of access requests bound to this workflow. If max duration is provided, fixed duration must be empty. If neither max nor fixed duration are provided, requests that bind to this workflow will use the organization-level settings.



19293
19294
19295
# File 'lib/models/porcelain.rb', line 19293

def access_request_max_duration
  @access_request_max_duration
end

#access_rules ⇒ Object

AccessRules is a list of access rules defining the resources this Workflow provides access to.



19295
19296
19297
# File 'lib/models/porcelain.rb', line 19295

def access_rules
  @access_rules
end

#approval_flow_id ⇒ Object

Optional approval flow ID identifies an approval flow that linked to the workflow



19297
19298
19299
# File 'lib/models/porcelain.rb', line 19297

def approval_flow_id
  @approval_flow_id
end

#auto_grant ⇒ Object

Optional auto grant setting to automatically approve requests or not, defaults to false.



19299
19300
19301
# File 'lib/models/porcelain.rb', line 19299

def auto_grant
  @auto_grant
end

#description ⇒ Object

Optional description of the Workflow.



19301
19302
19303
# File 'lib/models/porcelain.rb', line 19301

def description
  @description
end

#enabled ⇒ Object

Optional enabled state for workflow. This setting may be overridden by the system if the workflow doesn't meet the requirements to be enabled or if other conditions prevent enabling the workflow. The requirements to enable a workflow are that the workflow must be either set up for with auto grant enabled or have one or more WorkflowApprovers created for the workflow.



19307
19308
19309
# File 'lib/models/porcelain.rb', line 19307

def enabled
  @enabled
end

#id ⇒ Object

Unique identifier of the Workflow.



19309
19310
19311
# File 'lib/models/porcelain.rb', line 19309

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Workflow.



19311
19312
19313
# File 'lib/models/porcelain.rb', line 19311

def name
  @name
end

#weight ⇒ Object

Optional weight for workflow to specify it's priority in matching a request.



19313
19314
19315
# File 'lib/models/porcelain.rb', line 19313

def weight
  @weight
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19339
19340
19341
19342
19343
19344
19345
# File 'lib/models/porcelain.rb', line 19339

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end