Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow. WorkflowApprover is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
# File 'lib/models/porcelain.rb', line 19300

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



19292
19293
19294
# File 'lib/models/porcelain.rb', line 19292

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



19294
19295
19296
# File 'lib/models/porcelain.rb', line 19294

def id
  @id
end

#role_idObject

The approver role id



19296
19297
19298
# File 'lib/models/porcelain.rb', line 19296

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



19298
19299
19300
# File 'lib/models/porcelain.rb', line 19298

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19312
19313
19314
19315
19316
19317
19318
# File 'lib/models/porcelain.rb', line 19312

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end