Class: SDM::WorkflowApprover
- Inherits:
-
Object
- Object
- SDM::WorkflowApprover
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow. WorkflowApprover is deprecated, see docs for more info.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The approver account id.
-
#id ⇒ Object
Unique identifier of the WorkflowApprover.
-
#role_id ⇒ Object
The approver role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
constructor
A new instance of WorkflowApprover.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
Returns a new instance of WorkflowApprover.
19252 19253 19254 19255 19256 19257 19258 19259 19260 19261 19262 |
# File 'lib/models/porcelain.rb', line 19252 def initialize( account_id: nil, id: nil, role_id: nil, workflow_id: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#account_id ⇒ Object
The approver account id.
19244 19245 19246 |
# File 'lib/models/porcelain.rb', line 19244 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the WorkflowApprover.
19246 19247 19248 |
# File 'lib/models/porcelain.rb', line 19246 def id @id end |
#role_id ⇒ Object
The approver role id
19248 19249 19250 |
# File 'lib/models/porcelain.rb', line 19248 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
19250 19251 19252 |
# File 'lib/models/porcelain.rb', line 19250 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
19264 19265 19266 19267 19268 19269 19270 |
# File 'lib/models/porcelain.rb', line 19264 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |