Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow. WorkflowApprover is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



19168
19169
19170
19171
19172
19173
19174
19175
19176
19177
19178
# File 'lib/models/porcelain.rb', line 19168

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



19160
19161
19162
# File 'lib/models/porcelain.rb', line 19160

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



19162
19163
19164
# File 'lib/models/porcelain.rb', line 19162

def id
  @id
end

#role_idObject

The approver role id



19164
19165
19166
# File 'lib/models/porcelain.rb', line 19164

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



19166
19167
19168
# File 'lib/models/porcelain.rb', line 19166

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19180
19181
19182
19183
19184
19185
19186
# File 'lib/models/porcelain.rb', line 19180

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end