Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow. WorkflowApprover is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



18934
18935
18936
18937
18938
18939
18940
18941
18942
18943
18944
# File 'lib/models/porcelain.rb', line 18934

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



18926
18927
18928
# File 'lib/models/porcelain.rb', line 18926

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



18928
18929
18930
# File 'lib/models/porcelain.rb', line 18928

def id
  @id
end

#role_idObject

The approver role id



18930
18931
18932
# File 'lib/models/porcelain.rb', line 18930

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



18932
18933
18934
# File 'lib/models/porcelain.rb', line 18932

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18946
18947
18948
18949
18950
18951
18952
# File 'lib/models/porcelain.rb', line 18946

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end