Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow. WorkflowApprover is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



18441
18442
18443
18444
18445
18446
18447
18448
18449
18450
18451
# File 'lib/models/porcelain.rb', line 18441

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



18433
18434
18435
# File 'lib/models/porcelain.rb', line 18433

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



18435
18436
18437
# File 'lib/models/porcelain.rb', line 18435

def id
  @id
end

#role_idObject

The approver role id



18437
18438
18439
# File 'lib/models/porcelain.rb', line 18437

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



18439
18440
18441
# File 'lib/models/porcelain.rb', line 18439

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18453
18454
18455
18456
18457
18458
18459
# File 'lib/models/porcelain.rb', line 18453

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end