Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow. WorkflowApprover is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



18421
18422
18423
18424
18425
18426
18427
18428
18429
18430
18431
# File 'lib/models/porcelain.rb', line 18421

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



18413
18414
18415
# File 'lib/models/porcelain.rb', line 18413

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



18415
18416
18417
# File 'lib/models/porcelain.rb', line 18415

def id
  @id
end

#role_idObject

The approver role id



18417
18418
18419
# File 'lib/models/porcelain.rb', line 18417

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



18419
18420
18421
# File 'lib/models/porcelain.rb', line 18419

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18433
18434
18435
18436
18437
18438
18439
# File 'lib/models/porcelain.rb', line 18433

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end