Class: SDM::WorkflowApprover
- Inherits:
-
Object
- Object
- SDM::WorkflowApprover
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow. WorkflowApprover is deprecated, see docs for more info.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The approver account id.
-
#id ⇒ Object
Unique identifier of the WorkflowApprover.
-
#role_id ⇒ Object
The approver role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
constructor
A new instance of WorkflowApprover.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
Returns a new instance of WorkflowApprover.
17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 |
# File 'lib/models/porcelain.rb', line 17139 def initialize( account_id: nil, id: nil, role_id: nil, workflow_id: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#account_id ⇒ Object
The approver account id.
17131 17132 17133 |
# File 'lib/models/porcelain.rb', line 17131 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the WorkflowApprover.
17133 17134 17135 |
# File 'lib/models/porcelain.rb', line 17133 def id @id end |
#role_id ⇒ Object
The approver role id
17135 17136 17137 |
# File 'lib/models/porcelain.rb', line 17135 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
17137 17138 17139 |
# File 'lib/models/porcelain.rb', line 17137 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17151 17152 17153 17154 17155 17156 17157 |
# File 'lib/models/porcelain.rb', line 17151 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |