Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



15620
15621
15622
15623
15624
15625
15626
15627
15628
15629
15630
# File 'lib/models/porcelain.rb', line 15620

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



15612
15613
15614
# File 'lib/models/porcelain.rb', line 15612

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



15614
15615
15616
# File 'lib/models/porcelain.rb', line 15614

def id
  @id
end

#role_idObject

The approver role id



15616
15617
15618
# File 'lib/models/porcelain.rb', line 15616

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



15618
15619
15620
# File 'lib/models/porcelain.rb', line 15618

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15632
15633
15634
15635
15636
15637
15638
# File 'lib/models/porcelain.rb', line 15632

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end