Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



15285
15286
15287
15288
15289
15290
15291
15292
15293
15294
15295
# File 'lib/models/porcelain.rb', line 15285

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



15277
15278
15279
# File 'lib/models/porcelain.rb', line 15277

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



15279
15280
15281
# File 'lib/models/porcelain.rb', line 15279

def id
  @id
end

#role_idObject

The approver role id



15281
15282
15283
# File 'lib/models/porcelain.rb', line 15281

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



15283
15284
15285
# File 'lib/models/porcelain.rb', line 15283

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15297
15298
15299
15300
15301
15302
15303
# File 'lib/models/porcelain.rb', line 15297

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end