Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



15217
15218
15219
15220
15221
15222
15223
15224
15225
15226
15227
# File 'lib/models/porcelain.rb', line 15217

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



15209
15210
15211
# File 'lib/models/porcelain.rb', line 15209

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



15211
15212
15213
# File 'lib/models/porcelain.rb', line 15211

def id
  @id
end

#role_idObject

The approver role id



15213
15214
15215
# File 'lib/models/porcelain.rb', line 15213

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



15215
15216
15217
# File 'lib/models/porcelain.rb', line 15215

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15229
15230
15231
15232
15233
15234
15235
# File 'lib/models/porcelain.rb', line 15229

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end