Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



13639
13640
13641
13642
13643
13644
13645
13646
13647
13648
13649
# File 'lib/models/porcelain.rb', line 13639

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



13631
13632
13633
# File 'lib/models/porcelain.rb', line 13631

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



13633
13634
13635
# File 'lib/models/porcelain.rb', line 13633

def id
  @id
end

#role_idObject

The approver role id



13635
13636
13637
# File 'lib/models/porcelain.rb', line 13635

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



13637
13638
13639
# File 'lib/models/porcelain.rb', line 13637

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13651
13652
13653
13654
13655
13656
13657
# File 'lib/models/porcelain.rb', line 13651

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end