Class: SDM::WorkflowApprover
- Inherits:
-
Object
- Object
- SDM::WorkflowApprover
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The approver account id.
-
#id ⇒ Object
Unique identifier of the WorkflowApprover.
-
#role_id ⇒ Object
The approver role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
constructor
A new instance of WorkflowApprover.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
Returns a new instance of WorkflowApprover.
13485 13486 13487 13488 13489 13490 13491 13492 13493 13494 13495 |
# File 'lib/models/porcelain.rb', line 13485 def initialize( account_id: nil, id: nil, role_id: nil, workflow_id: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#account_id ⇒ Object
The approver account id.
13477 13478 13479 |
# File 'lib/models/porcelain.rb', line 13477 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the WorkflowApprover.
13479 13480 13481 |
# File 'lib/models/porcelain.rb', line 13479 def id @id end |
#role_id ⇒ Object
The approver role id
13481 13482 13483 |
# File 'lib/models/porcelain.rb', line 13481 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
13483 13484 13485 |
# File 'lib/models/porcelain.rb', line 13483 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13497 13498 13499 13500 13501 13502 13503 |
# File 'lib/models/porcelain.rb', line 13497 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |