Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



13043
13044
13045
13046
13047
13048
13049
13050
13051
13052
13053
# File 'lib/models/porcelain.rb', line 13043

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



13035
13036
13037
# File 'lib/models/porcelain.rb', line 13035

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



13037
13038
13039
# File 'lib/models/porcelain.rb', line 13037

def id
  @id
end

#role_idObject

The approver role id



13039
13040
13041
# File 'lib/models/porcelain.rb', line 13039

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



13041
13042
13043
# File 'lib/models/porcelain.rb', line 13041

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13055
13056
13057
13058
13059
13060
13061
# File 'lib/models/porcelain.rb', line 13055

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end