Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



13025
13026
13027
13028
13029
13030
13031
13032
13033
13034
13035
# File 'lib/models/porcelain.rb', line 13025

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



13017
13018
13019
# File 'lib/models/porcelain.rb', line 13017

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



13019
13020
13021
# File 'lib/models/porcelain.rb', line 13019

def id
  @id
end

#role_idObject

The approver role id



13021
13022
13023
# File 'lib/models/porcelain.rb', line 13021

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



13023
13024
13025
# File 'lib/models/porcelain.rb', line 13023

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13037
13038
13039
13040
13041
13042
13043
# File 'lib/models/porcelain.rb', line 13037

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end