Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



12716
12717
12718
12719
12720
12721
12722
12723
12724
12725
12726
# File 'lib/models/porcelain.rb', line 12716

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



12708
12709
12710
# File 'lib/models/porcelain.rb', line 12708

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



12710
12711
12712
# File 'lib/models/porcelain.rb', line 12710

def id
  @id
end

#role_idObject

The approver role id



12712
12713
12714
# File 'lib/models/porcelain.rb', line 12712

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



12714
12715
12716
# File 'lib/models/porcelain.rb', line 12714

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12728
12729
12730
12731
12732
12733
12734
# File 'lib/models/porcelain.rb', line 12728

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end