Class: SDM::WorkflowApprover
- Inherits:
-
Object
- Object
- SDM::WorkflowApprover
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The approver account id.
-
#id ⇒ Object
Unique identifier of the WorkflowApprover.
-
#role_id ⇒ Object
The approver role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
constructor
A new instance of WorkflowApprover.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
Returns a new instance of WorkflowApprover.
12716 12717 12718 12719 12720 12721 12722 12723 12724 12725 12726 |
# File 'lib/models/porcelain.rb', line 12716 def initialize( account_id: nil, id: nil, role_id: nil, workflow_id: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#account_id ⇒ Object
The approver account id.
12708 12709 12710 |
# File 'lib/models/porcelain.rb', line 12708 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the WorkflowApprover.
12710 12711 12712 |
# File 'lib/models/porcelain.rb', line 12710 def id @id end |
#role_id ⇒ Object
The approver role id
12712 12713 12714 |
# File 'lib/models/porcelain.rb', line 12712 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
12714 12715 12716 |
# File 'lib/models/porcelain.rb', line 12714 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12728 12729 12730 12731 12732 12733 12734 |
# File 'lib/models/porcelain.rb', line 12728 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |