Class: SDM::WorkflowApprover
- Inherits:
-
Object
- Object
- SDM::WorkflowApprover
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The approver account id.
-
#id ⇒ Object
Unique identifier of the WorkflowApprover.
-
#role_id ⇒ Object
The approver role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
constructor
A new instance of WorkflowApprover.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
Returns a new instance of WorkflowApprover.
12361 12362 12363 12364 12365 12366 12367 12368 12369 12370 12371 |
# File 'lib/models/porcelain.rb', line 12361 def initialize( account_id: nil, id: nil, role_id: nil, workflow_id: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#account_id ⇒ Object
The approver account id.
12353 12354 12355 |
# File 'lib/models/porcelain.rb', line 12353 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the WorkflowApprover.
12355 12356 12357 |
# File 'lib/models/porcelain.rb', line 12355 def id @id end |
#role_id ⇒ Object
The approver role id
12357 12358 12359 |
# File 'lib/models/porcelain.rb', line 12357 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
12359 12360 12361 |
# File 'lib/models/porcelain.rb', line 12359 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12373 12374 12375 12376 12377 12378 12379 |
# File 'lib/models/porcelain.rb', line 12373 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |