Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



12192
12193
12194
12195
12196
12197
12198
12199
12200
12201
12202
# File 'lib/models/porcelain.rb', line 12192

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



12184
12185
12186
# File 'lib/models/porcelain.rb', line 12184

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



12186
12187
12188
# File 'lib/models/porcelain.rb', line 12186

def id
  @id
end

#role_idObject

The approver role id



12188
12189
12190
# File 'lib/models/porcelain.rb', line 12188

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



12190
12191
12192
# File 'lib/models/porcelain.rb', line 12190

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12204
12205
12206
12207
12208
12209
12210
# File 'lib/models/porcelain.rb', line 12204

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end