Class: SDM::WorkflowApprover
- Inherits:
-
Object
- Object
- SDM::WorkflowApprover
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The approver account id.
-
#id ⇒ Object
Unique identifier of the WorkflowApprover.
-
#role_id ⇒ Object
The approver role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
constructor
A new instance of WorkflowApprover.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
Returns a new instance of WorkflowApprover.
10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 |
# File 'lib/models/porcelain.rb', line 10373 def initialize( account_id: nil, id: nil, role_id: nil, workflow_id: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#account_id ⇒ Object
The approver account id.
10365 10366 10367 |
# File 'lib/models/porcelain.rb', line 10365 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the WorkflowApprover.
10367 10368 10369 |
# File 'lib/models/porcelain.rb', line 10367 def id @id end |
#role_id ⇒ Object
The approver role id
10369 10370 10371 |
# File 'lib/models/porcelain.rb', line 10369 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
10371 10372 10373 |
# File 'lib/models/porcelain.rb', line 10371 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10385 10386 10387 10388 10389 10390 10391 |
# File 'lib/models/porcelain.rb', line 10385 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |