Class: SDM::WorkflowApprover
- Inherits:
-
Object
- Object
- SDM::WorkflowApprover
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow. WorkflowApprover is deprecated, see docs for more info.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The approver account id.
-
#id ⇒ Object
Unique identifier of the WorkflowApprover.
-
#role_id ⇒ Object
The approver role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
constructor
A new instance of WorkflowApprover.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover
Returns a new instance of WorkflowApprover.
18914 18915 18916 18917 18918 18919 18920 18921 18922 18923 18924 |
# File 'lib/models/porcelain.rb', line 18914 def initialize( account_id: nil, id: nil, role_id: nil, workflow_id: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#account_id ⇒ Object
The approver account id.
18906 18907 18908 |
# File 'lib/models/porcelain.rb', line 18906 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the WorkflowApprover.
18908 18909 18910 |
# File 'lib/models/porcelain.rb', line 18908 def id @id end |
#role_id ⇒ Object
The approver role id
18910 18911 18912 |
# File 'lib/models/porcelain.rb', line 18910 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
18912 18913 18914 |
# File 'lib/models/porcelain.rb', line 18912 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18926 18927 18928 18929 18930 18931 18932 |
# File 'lib/models/porcelain.rb', line 18926 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |