Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



15282
15283
15284
15285
15286
15287
15288
15289
15290
15291
15292
# File 'lib/models/porcelain.rb', line 15282

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



15274
15275
15276
# File 'lib/models/porcelain.rb', line 15274

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



15276
15277
15278
# File 'lib/models/porcelain.rb', line 15276

def id
  @id
end

#role_idObject

The approver role id



15278
15279
15280
# File 'lib/models/porcelain.rb', line 15278

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



15280
15281
15282
# File 'lib/models/porcelain.rb', line 15280

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15294
15295
15296
15297
15298
15299
15300
# File 'lib/models/porcelain.rb', line 15294

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end