Class: SDM::WorkflowApproverHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApproverHistory provides records of all changes to the state of a WorkflowApprover.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory

Returns a new instance of WorkflowApproverHistory.



18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
19005
# File 'lib/models/porcelain.rb', line 18995

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_approver: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_approver = workflow_approver == nil ? nil : workflow_approver
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowApprover. May be empty for some system-initiated updates.



18987
18988
18989
# File 'lib/models/porcelain.rb', line 18987

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowApprover was deleted, the time it was deleted.



18989
18990
18991
# File 'lib/models/porcelain.rb', line 18989

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowApprover state was recorded.



18991
18992
18993
# File 'lib/models/porcelain.rb', line 18991

def timestamp
  @timestamp
end

#workflow_approverObject

The complete WorkflowApprover state at this time.



18993
18994
18995
# File 'lib/models/porcelain.rb', line 18993

def workflow_approver
  @workflow_approver
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19007
19008
19009
19010
19011
19012
19013
# File 'lib/models/porcelain.rb', line 19007

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end