Class: SDM::WorkflowApproverHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApproverHistory provides records of all changes to the state of a WorkflowApprover.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory

Returns a new instance of WorkflowApproverHistory.



15419
15420
15421
15422
15423
15424
15425
15426
15427
15428
15429
# File 'lib/models/porcelain.rb', line 15419

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_approver: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_approver = workflow_approver == nil ? nil : workflow_approver
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowApprover. May be empty for some system-initiated updates.



15411
15412
15413
# File 'lib/models/porcelain.rb', line 15411

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowApprover was deleted, the time it was deleted.



15413
15414
15415
# File 'lib/models/porcelain.rb', line 15413

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowApprover state was recorded.



15415
15416
15417
# File 'lib/models/porcelain.rb', line 15415

def timestamp
  @timestamp
end

#workflow_approverObject

The complete WorkflowApprover state at this time.



15417
15418
15419
# File 'lib/models/porcelain.rb', line 15417

def workflow_approver
  @workflow_approver
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15431
15432
15433
15434
15435
15436
15437
# File 'lib/models/porcelain.rb', line 15431

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end