Class: SDM::WorkflowApproverHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowApproverHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowApproverHistory provides records of all changes to the state of a WorkflowApprover.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowApprover.
-
#deleted_at ⇒ Object
If this WorkflowApprover was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the WorkflowApprover state was recorded.
-
#workflow_approver ⇒ Object
The complete WorkflowApprover state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory
constructor
A new instance of WorkflowApproverHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory
Returns a new instance of WorkflowApproverHistory.
15278 15279 15280 15281 15282 15283 15284 15285 15286 15287 15288 |
# File 'lib/models/porcelain.rb', line 15278 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow_approver = workflow_approver == nil ? nil : workflow_approver end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowApprover. May be empty for some system-initiated updates.
15270 15271 15272 |
# File 'lib/models/porcelain.rb', line 15270 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this WorkflowApprover was deleted, the time it was deleted.
15272 15273 15274 |
# File 'lib/models/porcelain.rb', line 15272 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the WorkflowApprover state was recorded.
15274 15275 15276 |
# File 'lib/models/porcelain.rb', line 15274 def @timestamp end |
#workflow_approver ⇒ Object
The complete WorkflowApprover state at this time.
15276 15277 15278 |
# File 'lib/models/porcelain.rb', line 15276 def workflow_approver @workflow_approver end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15290 15291 15292 15293 15294 15295 15296 |
# File 'lib/models/porcelain.rb', line 15290 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |