Class: SDM::WorkflowApproverHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowApproverHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowApproverHistory provides records of all changes to the state of a WorkflowApprover.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowApprover.
-
#deleted_at ⇒ Object
If this WorkflowApprover was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the WorkflowApprover state was recorded.
-
#workflow_approver ⇒ Object
The complete WorkflowApprover state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory
constructor
A new instance of WorkflowApproverHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory
Returns a new instance of WorkflowApproverHistory.
13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 13945 |
# File 'lib/models/porcelain.rb', line 13935 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow_approver = workflow_approver == nil ? nil : workflow_approver end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowApprover. May be empty for some system-initiated updates.
13927 13928 13929 |
# File 'lib/models/porcelain.rb', line 13927 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this WorkflowApprover was deleted, the time it was deleted.
13929 13930 13931 |
# File 'lib/models/porcelain.rb', line 13929 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the WorkflowApprover state was recorded.
13931 13932 13933 |
# File 'lib/models/porcelain.rb', line 13931 def @timestamp end |
#workflow_approver ⇒ Object
The complete WorkflowApprover state at this time.
13933 13934 13935 |
# File 'lib/models/porcelain.rb', line 13933 def workflow_approver @workflow_approver end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13947 13948 13949 13950 13951 13952 13953 |
# File 'lib/models/porcelain.rb', line 13947 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |