Class: SDM::WorkflowApproverHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApproverHistory provides records of all changes to the state of a WorkflowApprover.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory

Returns a new instance of WorkflowApproverHistory.



13545
13546
13547
13548
13549
13550
13551
13552
13553
13554
13555
# File 'lib/models/porcelain.rb', line 13545

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_approver: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_approver = workflow_approver == nil ? nil : workflow_approver
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowApprover. May be empty for some system-initiated updates.



13537
13538
13539
# File 'lib/models/porcelain.rb', line 13537

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowApprover was deleted, the time it was deleted.



13539
13540
13541
# File 'lib/models/porcelain.rb', line 13539

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowApprover state was recorded.



13541
13542
13543
# File 'lib/models/porcelain.rb', line 13541

def timestamp
  @timestamp
end

#workflow_approverObject

The complete WorkflowApprover state at this time.



13543
13544
13545
# File 'lib/models/porcelain.rb', line 13543

def workflow_approver
  @workflow_approver
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13557
13558
13559
13560
13561
13562
13563
# File 'lib/models/porcelain.rb', line 13557

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end