Class: SDM::WorkflowApproverHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowApproverHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowApproverHistory provides records of all changes to the state of a WorkflowApprover.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowApprover.
-
#deleted_at ⇒ Object
If this WorkflowApprover was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the WorkflowApprover state was recorded.
-
#workflow_approver ⇒ Object
The complete WorkflowApprover state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory
constructor
A new instance of WorkflowApproverHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory
Returns a new instance of WorkflowApproverHistory.
13479 13480 13481 13482 13483 13484 13485 13486 13487 13488 13489 |
# File 'lib/models/porcelain.rb', line 13479 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow_approver = workflow_approver == nil ? nil : workflow_approver end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowApprover. May be empty for some system-initiated updates.
13471 13472 13473 |
# File 'lib/models/porcelain.rb', line 13471 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this WorkflowApprover was deleted, the time it was deleted.
13473 13474 13475 |
# File 'lib/models/porcelain.rb', line 13473 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the WorkflowApprover state was recorded.
13475 13476 13477 |
# File 'lib/models/porcelain.rb', line 13475 def @timestamp end |
#workflow_approver ⇒ Object
The complete WorkflowApprover state at this time.
13477 13478 13479 |
# File 'lib/models/porcelain.rb', line 13477 def workflow_approver @workflow_approver end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13491 13492 13493 13494 13495 13496 13497 |
# File 'lib/models/porcelain.rb', line 13491 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |