Class: SDM::WorkflowApproverHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApproverHistory provides records of all changes to the state of a WorkflowApprover.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory

Returns a new instance of WorkflowApproverHistory.



12846
12847
12848
12849
12850
12851
12852
12853
12854
12855
12856
# File 'lib/models/porcelain.rb', line 12846

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_approver: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_approver = workflow_approver == nil ? nil : workflow_approver
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowApprover. May be empty for some system-initiated updates.



12838
12839
12840
# File 'lib/models/porcelain.rb', line 12838

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowApprover was deleted, the time it was deleted.



12840
12841
12842
# File 'lib/models/porcelain.rb', line 12840

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowApprover state was recorded.



12842
12843
12844
# File 'lib/models/porcelain.rb', line 12842

def timestamp
  @timestamp
end

#workflow_approverObject

The complete WorkflowApprover state at this time.



12844
12845
12846
# File 'lib/models/porcelain.rb', line 12844

def workflow_approver
  @workflow_approver
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12858
12859
12860
12861
12862
12863
12864
# File 'lib/models/porcelain.rb', line 12858

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end