Class: SDM::WorkflowApproverHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowApproverHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowApproverHistory provides records of all changes to the state of a WorkflowApprover.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowApprover.
-
#deleted_at ⇒ Object
If this WorkflowApprover was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the WorkflowApprover state was recorded.
-
#workflow_approver ⇒ Object
The complete WorkflowApprover state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory
constructor
A new instance of WorkflowApproverHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory
Returns a new instance of WorkflowApproverHistory.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 |
# File 'lib/models/porcelain.rb', line 12422 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow_approver = workflow_approver == nil ? nil : workflow_approver end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowApprover. May be empty for some system-initiated updates.
12414 12415 12416 |
# File 'lib/models/porcelain.rb', line 12414 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this WorkflowApprover was deleted, the time it was deleted.
12416 12417 12418 |
# File 'lib/models/porcelain.rb', line 12416 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the WorkflowApprover state was recorded.
12418 12419 12420 |
# File 'lib/models/porcelain.rb', line 12418 def @timestamp end |
#workflow_approver ⇒ Object
The complete WorkflowApprover state at this time.
12420 12421 12422 |
# File 'lib/models/porcelain.rb', line 12420 def workflow_approver @workflow_approver end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12434 12435 12436 12437 12438 12439 12440 |
# File 'lib/models/porcelain.rb', line 12434 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |