Class: SDM::WorkflowApproverHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApproverHistory provides records of all changes to the state of a WorkflowApprover.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory

Returns a new instance of WorkflowApproverHistory.



11100
11101
11102
11103
11104
11105
11106
11107
11108
11109
11110
# File 'lib/models/porcelain.rb', line 11100

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_approver: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_approver = workflow_approver == nil ? nil : workflow_approver
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowApprover. May be empty for some system-initiated updates.



11092
11093
11094
# File 'lib/models/porcelain.rb', line 11092

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowApprover was deleted, the time it was deleted.



11094
11095
11096
# File 'lib/models/porcelain.rb', line 11094

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowApprover state was recorded.



11096
11097
11098
# File 'lib/models/porcelain.rb', line 11096

def timestamp
  @timestamp
end

#workflow_approverObject

The complete WorkflowApprover state at this time.



11098
11099
11100
# File 'lib/models/porcelain.rb', line 11098

def workflow_approver
  @workflow_approver
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11112
11113
11114
11115
11116
11117
11118
# File 'lib/models/porcelain.rb', line 11112

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end