Class: SDM::WorkflowApproverHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApproverHistory records the state of a WorkflowApprover at a given point in time, where every change (create, update and delete) to a WorkflowApprover produces an WorkflowApproverHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory

Returns a new instance of WorkflowApproverHistory.



9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
# File 'lib/models/porcelain.rb', line 9585

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_approver: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_approver = workflow_approver == nil ? nil : workflow_approver
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



9577
9578
9579
# File 'lib/models/porcelain.rb', line 9577

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



9579
9580
9581
# File 'lib/models/porcelain.rb', line 9579

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



9581
9582
9583
# File 'lib/models/porcelain.rb', line 9581

def timestamp
  @timestamp
end

#workflow_approverObject

The complete WorkflowApprover state at this time.



9583
9584
9585
# File 'lib/models/porcelain.rb', line 9583

def workflow_approver
  @workflow_approver
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9597
9598
9599
9600
9601
9602
9603
# File 'lib/models/porcelain.rb', line 9597

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end