Class: SDM::WorkflowApproverHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApproverHistory provides records of all changes to the state of a WorkflowApprover.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_approver: nil) ⇒ WorkflowApproverHistory

Returns a new instance of WorkflowApproverHistory.



19421
19422
19423
19424
19425
19426
19427
19428
19429
19430
19431
# File 'lib/models/porcelain.rb', line 19421

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_approver: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_approver = workflow_approver == nil ? nil : workflow_approver
end

Instance Attribute Details

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the WorkflowApprover. May be empty for some system-initiated updates.



19413
19414
19415
# File 'lib/models/porcelain.rb', line 19413

def activity_id
  @activity_id
end

#deleted_at ⇒ Object

If this WorkflowApprover was deleted, the time it was deleted.



19415
19416
19417
# File 'lib/models/porcelain.rb', line 19415

def deleted_at
  @deleted_at
end

#timestamp ⇒ Object

The time at which the WorkflowApprover state was recorded.



19417
19418
19419
# File 'lib/models/porcelain.rb', line 19417

def timestamp
  @timestamp
end

#workflow_approver ⇒ Object

The complete WorkflowApprover state at this time.



19419
19420
19421
# File 'lib/models/porcelain.rb', line 19419

def workflow_approver
  @workflow_approver
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19433
19434
19435
19436
19437
19438
19439
# File 'lib/models/porcelain.rb', line 19433

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end