Class: SDM::WorkflowAssignmentHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowAssignmentsHistory provides records of all changes to the state of a WorkflowAssignment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil) ⇒ WorkflowAssignmentHistory

Returns a new instance of WorkflowAssignmentHistory.



15604
15605
15606
15607
15608
15609
15610
15611
15612
15613
15614
# File 'lib/models/porcelain.rb', line 15604

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_assignment: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_assignment = workflow_assignment == nil ? nil : workflow_assignment
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowAssignment. May be empty for some system-initiated updates.



15596
15597
15598
# File 'lib/models/porcelain.rb', line 15596

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowAssignment was deleted, the time it was deleted.



15598
15599
15600
# File 'lib/models/porcelain.rb', line 15598

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowAssignment state was recorded.



15600
15601
15602
# File 'lib/models/porcelain.rb', line 15600

def timestamp
  @timestamp
end

#workflow_assignmentObject

The complete WorkflowAssignment state at this time.



15602
15603
15604
# File 'lib/models/porcelain.rb', line 15602

def workflow_assignment
  @workflow_assignment
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15616
15617
15618
15619
15620
15621
15622
# File 'lib/models/porcelain.rb', line 15616

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end