Class: SDM::WorkflowAssignmentHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowAssignmentsHistory provides records of all changes to the state of a WorkflowAssignment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil) ⇒ WorkflowAssignmentHistory

Returns a new instance of WorkflowAssignmentHistory.



15463
15464
15465
15466
15467
15468
15469
15470
15471
15472
15473
# File 'lib/models/porcelain.rb', line 15463

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_assignment: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_assignment = workflow_assignment == nil ? nil : workflow_assignment
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowAssignment. May be empty for some system-initiated updates.



15455
15456
15457
# File 'lib/models/porcelain.rb', line 15455

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowAssignment was deleted, the time it was deleted.



15457
15458
15459
# File 'lib/models/porcelain.rb', line 15457

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowAssignment state was recorded.



15459
15460
15461
# File 'lib/models/porcelain.rb', line 15459

def timestamp
  @timestamp
end

#workflow_assignmentObject

The complete WorkflowAssignment state at this time.



15461
15462
15463
# File 'lib/models/porcelain.rb', line 15461

def workflow_assignment
  @workflow_assignment
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15475
15476
15477
15478
15479
15480
15481
# File 'lib/models/porcelain.rb', line 15475

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end