Class: SDM::WorkflowAssignmentHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowAssignmentsHistory provides records of all changes to the state of a WorkflowAssignment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil) ⇒ WorkflowAssignmentHistory

Returns a new instance of WorkflowAssignmentHistory.



14287
14288
14289
14290
14291
14292
14293
14294
14295
14296
14297
# File 'lib/models/porcelain.rb', line 14287

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_assignment: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_assignment = workflow_assignment == nil ? nil : workflow_assignment
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowAssignment. May be empty for some system-initiated updates.



14279
14280
14281
# File 'lib/models/porcelain.rb', line 14279

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowAssignment was deleted, the time it was deleted.



14281
14282
14283
# File 'lib/models/porcelain.rb', line 14281

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowAssignment state was recorded.



14283
14284
14285
# File 'lib/models/porcelain.rb', line 14283

def timestamp
  @timestamp
end

#workflow_assignmentObject

The complete WorkflowAssignment state at this time.



14285
14286
14287
# File 'lib/models/porcelain.rb', line 14285

def workflow_assignment
  @workflow_assignment
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14299
14300
14301
14302
14303
14304
14305
# File 'lib/models/porcelain.rb', line 14299

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end