Class: SDM::WorkflowAssignmentHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowAssignmentHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowAssignmentsHistory provides records of all changes to the state of a WorkflowAssignment.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowAssignment.
-
#deleted_at ⇒ Object
If this WorkflowAssignment was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the WorkflowAssignment state was recorded.
-
#workflow_assignment ⇒ Object
The complete WorkflowAssignment state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil) ⇒ WorkflowAssignmentHistory
constructor
A new instance of WorkflowAssignmentHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil) ⇒ WorkflowAssignmentHistory
Returns a new instance of WorkflowAssignmentHistory.
14120 14121 14122 14123 14124 14125 14126 14127 14128 14129 14130 |
# File 'lib/models/porcelain.rb', line 14120 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow_assignment = workflow_assignment == nil ? nil : workflow_assignment end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowAssignment. May be empty for some system-initiated updates.
14112 14113 14114 |
# File 'lib/models/porcelain.rb', line 14112 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this WorkflowAssignment was deleted, the time it was deleted.
14114 14115 14116 |
# File 'lib/models/porcelain.rb', line 14114 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the WorkflowAssignment state was recorded.
14116 14117 14118 |
# File 'lib/models/porcelain.rb', line 14116 def @timestamp end |
#workflow_assignment ⇒ Object
The complete WorkflowAssignment state at this time.
14118 14119 14120 |
# File 'lib/models/porcelain.rb', line 14118 def workflow_assignment @workflow_assignment end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14132 14133 14134 14135 14136 14137 14138 |
# File 'lib/models/porcelain.rb', line 14132 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |