Class: SDM::WorkflowAssignmentHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowAssignmentsHistory provides records of all changes to the state of a WorkflowAssignment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil) ⇒ WorkflowAssignmentHistory

Returns a new instance of WorkflowAssignmentHistory.



13801
13802
13803
13804
13805
13806
13807
13808
13809
13810
13811
# File 'lib/models/porcelain.rb', line 13801

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_assignment: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_assignment = workflow_assignment == nil ? nil : workflow_assignment
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowAssignment. May be empty for some system-initiated updates.



13793
13794
13795
# File 'lib/models/porcelain.rb', line 13793

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowAssignment was deleted, the time it was deleted.



13795
13796
13797
# File 'lib/models/porcelain.rb', line 13795

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowAssignment state was recorded.



13797
13798
13799
# File 'lib/models/porcelain.rb', line 13797

def timestamp
  @timestamp
end

#workflow_assignmentObject

The complete WorkflowAssignment state at this time.



13799
13800
13801
# File 'lib/models/porcelain.rb', line 13799

def workflow_assignment
  @workflow_assignment
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13813
13814
13815
13816
13817
13818
13819
# File 'lib/models/porcelain.rb', line 13813

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end