Class: SDM::WorkflowAssignmentHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowAssignmentHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowAssignmentsHistory provides records of all changes to the state of a WorkflowAssignment.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowAssignment.
-
#deleted_at ⇒ Object
If this WorkflowAssignment was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the WorkflowAssignment state was recorded.
-
#workflow_assignment ⇒ Object
The complete WorkflowAssignment state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil) ⇒ WorkflowAssignmentHistory
constructor
A new instance of WorkflowAssignmentHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil) ⇒ WorkflowAssignmentHistory
Returns a new instance of WorkflowAssignmentHistory.
13031 13032 13033 13034 13035 13036 13037 13038 13039 13040 13041 |
# File 'lib/models/porcelain.rb', line 13031 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow_assignment = workflow_assignment == nil ? nil : workflow_assignment end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowAssignment. May be empty for some system-initiated updates.
13023 13024 13025 |
# File 'lib/models/porcelain.rb', line 13023 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this WorkflowAssignment was deleted, the time it was deleted.
13025 13026 13027 |
# File 'lib/models/porcelain.rb', line 13025 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the WorkflowAssignment state was recorded.
13027 13028 13029 |
# File 'lib/models/porcelain.rb', line 13027 def @timestamp end |
#workflow_assignment ⇒ Object
The complete WorkflowAssignment state at this time.
13029 13030 13031 |
# File 'lib/models/porcelain.rb', line 13029 def workflow_assignment @workflow_assignment end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13043 13044 13045 13046 13047 13048 13049 |
# File 'lib/models/porcelain.rb', line 13043 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |