Class: SDM::WorkflowAssignmentHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowAssignmentHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowAssignmentsHistory provides records of all changes to the state of a WorkflowAssignment.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowAssignment.
-
#deleted_at ⇒ Object
If this WorkflowAssignment was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the WorkflowAssignment state was recorded.
-
#workflow_assignment ⇒ Object
The complete WorkflowAssignment state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil) ⇒ WorkflowAssignmentHistory
constructor
A new instance of WorkflowAssignmentHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil) ⇒ WorkflowAssignmentHistory
Returns a new instance of WorkflowAssignmentHistory.
12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 12444 |
# File 'lib/models/porcelain.rb', line 12434 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow_assignment = workflow_assignment == nil ? nil : workflow_assignment end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowAssignment. May be empty for some system-initiated updates.
12426 12427 12428 |
# File 'lib/models/porcelain.rb', line 12426 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this WorkflowAssignment was deleted, the time it was deleted.
12428 12429 12430 |
# File 'lib/models/porcelain.rb', line 12428 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the WorkflowAssignment state was recorded.
12430 12431 12432 |
# File 'lib/models/porcelain.rb', line 12430 def @timestamp end |
#workflow_assignment ⇒ Object
The complete WorkflowAssignment state at this time.
12432 12433 12434 |
# File 'lib/models/porcelain.rb', line 12432 def workflow_assignment @workflow_assignment end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12446 12447 12448 12449 12450 12451 12452 |
# File 'lib/models/porcelain.rb', line 12446 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |