Class: SDM::WorkflowAssignmentHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowAssignmentHistory records the state of a WorkflowAssignment at a given point in time, where every change (create, update and delete) to a WorkflowAssignment produces an WorkflowAssignmentHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_assignment: nil) ⇒ WorkflowAssignmentHistory

Returns a new instance of WorkflowAssignmentHistory.



9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
# File 'lib/models/porcelain.rb', line 9644

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_assignment: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_assignment = workflow_assignment == nil ? nil : workflow_assignment
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



9636
9637
9638
# File 'lib/models/porcelain.rb', line 9636

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



9638
9639
9640
# File 'lib/models/porcelain.rb', line 9638

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



9640
9641
9642
# File 'lib/models/porcelain.rb', line 9640

def timestamp
  @timestamp
end

#workflow_assignmentObject

The complete WorkflowAssignment state at this time.



9642
9643
9644
# File 'lib/models/porcelain.rb', line 9642

def workflow_assignment
  @workflow_assignment
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9656
9657
9658
9659
9660
9661
9662
# File 'lib/models/porcelain.rb', line 9656

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end