Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
# File 'lib/models/porcelain.rb', line 19115

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



19107
19108
19109
# File 'lib/models/porcelain.rb', line 19107

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



19109
19110
19111
# File 'lib/models/porcelain.rb', line 19109

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



19111
19112
19113
# File 'lib/models/porcelain.rb', line 19111

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



19113
19114
19115
# File 'lib/models/porcelain.rb', line 19113

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19127
19128
19129
19130
19131
19132
19133
# File 'lib/models/porcelain.rb', line 19127

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end