Class: SDM::WorkflowHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowsHistory provides records of all changes to the state of a Workflow.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Workflow.
-
#deleted_at ⇒ Object
If this Workflow was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the Workflow state was recorded.
-
#workflow ⇒ Object
The complete Workflow state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory
constructor
A new instance of WorkflowHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory
Returns a new instance of WorkflowHistory.
18812 18813 18814 18815 18816 18817 18818 18819 18820 18821 18822 |
# File 'lib/models/porcelain.rb', line 18812 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow = workflow == nil ? nil : workflow end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.
18804 18805 18806 |
# File 'lib/models/porcelain.rb', line 18804 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Workflow was deleted, the time it was deleted.
18806 18807 18808 |
# File 'lib/models/porcelain.rb', line 18806 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the Workflow state was recorded.
18808 18809 18810 |
# File 'lib/models/porcelain.rb', line 18808 def @timestamp end |
#workflow ⇒ Object
The complete Workflow state at this time.
18810 18811 18812 |
# File 'lib/models/porcelain.rb', line 18810 def workflow @workflow end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18824 18825 18826 18827 18828 18829 18830 |
# File 'lib/models/porcelain.rb', line 18824 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |