Class: SDM::WorkflowHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowsHistory provides records of all changes to the state of a Workflow.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Workflow.
-
#deleted_at ⇒ Object
If this Workflow was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the Workflow state was recorded.
-
#workflow ⇒ Object
The complete Workflow state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory
constructor
A new instance of WorkflowHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory
Returns a new instance of WorkflowHistory.
18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 18728 |
# File 'lib/models/porcelain.rb', line 18718 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow = workflow == nil ? nil : workflow end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.
18710 18711 18712 |
# File 'lib/models/porcelain.rb', line 18710 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Workflow was deleted, the time it was deleted.
18712 18713 18714 |
# File 'lib/models/porcelain.rb', line 18712 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the Workflow state was recorded.
18714 18715 18716 |
# File 'lib/models/porcelain.rb', line 18714 def @timestamp end |
#workflow ⇒ Object
The complete Workflow state at this time.
18716 18717 18718 |
# File 'lib/models/porcelain.rb', line 18716 def workflow @workflow end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18730 18731 18732 18733 18734 18735 18736 |
# File 'lib/models/porcelain.rb', line 18730 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |