Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



17436
17437
17438
17439
17440
17441
17442
17443
17444
17445
17446
# File 'lib/models/porcelain.rb', line 17436

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



17428
17429
17430
# File 'lib/models/porcelain.rb', line 17428

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



17430
17431
17432
# File 'lib/models/porcelain.rb', line 17430

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



17432
17433
17434
# File 'lib/models/porcelain.rb', line 17432

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



17434
17435
17436
# File 'lib/models/porcelain.rb', line 17434

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17448
17449
17450
17451
17452
17453
17454
# File 'lib/models/porcelain.rb', line 17448

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end