Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



15901
15902
15903
15904
15905
15906
15907
15908
15909
15910
15911
# File 'lib/models/porcelain.rb', line 15901

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



15893
15894
15895
# File 'lib/models/porcelain.rb', line 15893

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



15895
15896
15897
# File 'lib/models/porcelain.rb', line 15895

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



15897
15898
15899
# File 'lib/models/porcelain.rb', line 15897

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



15899
15900
15901
# File 'lib/models/porcelain.rb', line 15899

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15913
15914
15915
15916
15917
15918
15919
# File 'lib/models/porcelain.rb', line 15913

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end