Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



15614
15615
15616
15617
15618
15619
15620
15621
15622
15623
15624
# File 'lib/models/porcelain.rb', line 15614

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



15606
15607
15608
# File 'lib/models/porcelain.rb', line 15606

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



15608
15609
15610
# File 'lib/models/porcelain.rb', line 15608

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



15610
15611
15612
# File 'lib/models/porcelain.rb', line 15610

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



15612
15613
15614
# File 'lib/models/porcelain.rb', line 15612

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15626
15627
15628
15629
15630
15631
15632
# File 'lib/models/porcelain.rb', line 15626

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end