Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



14438
14439
14440
14441
14442
14443
14444
14445
14446
14447
14448
# File 'lib/models/porcelain.rb', line 14438

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



14430
14431
14432
# File 'lib/models/porcelain.rb', line 14430

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



14432
14433
14434
# File 'lib/models/porcelain.rb', line 14432

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



14434
14435
14436
# File 'lib/models/porcelain.rb', line 14434

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



14436
14437
14438
# File 'lib/models/porcelain.rb', line 14436

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14450
14451
14452
14453
14454
14455
14456
# File 'lib/models/porcelain.rb', line 14450

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end