Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



14271
14272
14273
14274
14275
14276
14277
14278
14279
14280
14281
# File 'lib/models/porcelain.rb', line 14271

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



14263
14264
14265
# File 'lib/models/porcelain.rb', line 14263

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



14265
14266
14267
# File 'lib/models/porcelain.rb', line 14265

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



14267
14268
14269
# File 'lib/models/porcelain.rb', line 14267

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



14269
14270
14271
# File 'lib/models/porcelain.rb', line 14269

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14283
14284
14285
14286
14287
14288
14289
# File 'lib/models/porcelain.rb', line 14283

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end