Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



14035
14036
14037
14038
14039
14040
14041
14042
14043
14044
14045
# File 'lib/models/porcelain.rb', line 14035

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



14027
14028
14029
# File 'lib/models/porcelain.rb', line 14027

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



14029
14030
14031
# File 'lib/models/porcelain.rb', line 14029

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



14031
14032
14033
# File 'lib/models/porcelain.rb', line 14031

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



14033
14034
14035
# File 'lib/models/porcelain.rb', line 14033

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14047
14048
14049
14050
14051
14052
14053
# File 'lib/models/porcelain.rb', line 14047

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end