Class: SDM::WorkflowHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowsHistory provides records of all changes to the state of a Workflow.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Workflow.
-
#deleted_at ⇒ Object
If this Workflow was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the Workflow state was recorded.
-
#workflow ⇒ Object
The complete Workflow state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory
constructor
A new instance of WorkflowHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory
Returns a new instance of WorkflowHistory.
14036 14037 14038 14039 14040 14041 14042 14043 14044 14045 14046 |
# File 'lib/models/porcelain.rb', line 14036 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow = workflow == nil ? nil : workflow end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.
14028 14029 14030 |
# File 'lib/models/porcelain.rb', line 14028 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Workflow was deleted, the time it was deleted.
14030 14031 14032 |
# File 'lib/models/porcelain.rb', line 14030 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the Workflow state was recorded.
14032 14033 14034 |
# File 'lib/models/porcelain.rb', line 14032 def @timestamp end |
#workflow ⇒ Object
The complete Workflow state at this time.
14034 14035 14036 |
# File 'lib/models/porcelain.rb', line 14034 def workflow @workflow end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14048 14049 14050 14051 14052 14053 14054 |
# File 'lib/models/porcelain.rb', line 14048 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |