Class: SDM::WorkflowHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowsHistory provides records of all changes to the state of a Workflow.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Workflow.
-
#deleted_at ⇒ Object
If this Workflow was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the Workflow state was recorded.
-
#workflow ⇒ Object
The complete Workflow state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory
constructor
A new instance of WorkflowHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory
Returns a new instance of WorkflowHistory.
13440 13441 13442 13443 13444 13445 13446 13447 13448 13449 13450 |
# File 'lib/models/porcelain.rb', line 13440 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow = workflow == nil ? nil : workflow end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.
13432 13433 13434 |
# File 'lib/models/porcelain.rb', line 13432 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Workflow was deleted, the time it was deleted.
13434 13435 13436 |
# File 'lib/models/porcelain.rb', line 13434 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the Workflow state was recorded.
13436 13437 13438 |
# File 'lib/models/porcelain.rb', line 13436 def @timestamp end |
#workflow ⇒ Object
The complete Workflow state at this time.
13438 13439 13440 |
# File 'lib/models/porcelain.rb', line 13438 def workflow @workflow end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13452 13453 13454 13455 13456 13457 13458 |
# File 'lib/models/porcelain.rb', line 13452 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |