Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



13422
13423
13424
13425
13426
13427
13428
13429
13430
13431
13432
# File 'lib/models/porcelain.rb', line 13422

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



13414
13415
13416
# File 'lib/models/porcelain.rb', line 13414

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



13416
13417
13418
# File 'lib/models/porcelain.rb', line 13416

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



13418
13419
13420
# File 'lib/models/porcelain.rb', line 13418

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



13420
13421
13422
# File 'lib/models/porcelain.rb', line 13420

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13434
13435
13436
13437
13438
13439
13440
# File 'lib/models/porcelain.rb', line 13434

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end