Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



13253
13254
13255
13256
13257
13258
13259
13260
13261
13262
13263
# File 'lib/models/porcelain.rb', line 13253

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



13245
13246
13247
# File 'lib/models/porcelain.rb', line 13245

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



13247
13248
13249
# File 'lib/models/porcelain.rb', line 13247

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



13249
13250
13251
# File 'lib/models/porcelain.rb', line 13249

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



13251
13252
13253
# File 'lib/models/porcelain.rb', line 13251

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13265
13266
13267
13268
13269
13270
13271
# File 'lib/models/porcelain.rb', line 13265

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end