Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



12758
12759
12760
12761
12762
12763
12764
12765
12766
12767
12768
# File 'lib/models/porcelain.rb', line 12758

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



12750
12751
12752
# File 'lib/models/porcelain.rb', line 12750

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



12752
12753
12754
# File 'lib/models/porcelain.rb', line 12752

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



12754
12755
12756
# File 'lib/models/porcelain.rb', line 12754

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



12756
12757
12758
# File 'lib/models/porcelain.rb', line 12756

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12770
12771
12772
12773
12774
12775
12776
# File 'lib/models/porcelain.rb', line 12770

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end