Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



12580
12581
12582
12583
12584
12585
12586
12587
12588
12589
12590
# File 'lib/models/porcelain.rb', line 12580

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



12572
12573
12574
# File 'lib/models/porcelain.rb', line 12572

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



12574
12575
12576
# File 'lib/models/porcelain.rb', line 12574

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



12576
12577
12578
# File 'lib/models/porcelain.rb', line 12576

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



12578
12579
12580
# File 'lib/models/porcelain.rb', line 12578

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12592
12593
12594
12595
12596
12597
12598
# File 'lib/models/porcelain.rb', line 12592

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end