Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
# File 'lib/models/porcelain.rb', line 12413

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



12405
12406
12407
# File 'lib/models/porcelain.rb', line 12405

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



12407
12408
12409
# File 'lib/models/porcelain.rb', line 12407

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



12409
12410
12411
# File 'lib/models/porcelain.rb', line 12409

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



12411
12412
12413
# File 'lib/models/porcelain.rb', line 12411

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12425
12426
12427
12428
12429
12430
12431
# File 'lib/models/porcelain.rb', line 12425

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end