Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



10866
10867
10868
10869
10870
10871
10872
10873
10874
10875
10876
# File 'lib/models/porcelain.rb', line 10866

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



10858
10859
10860
# File 'lib/models/porcelain.rb', line 10858

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



10860
10861
10862
# File 'lib/models/porcelain.rb', line 10860

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



10862
10863
10864
# File 'lib/models/porcelain.rb', line 10862

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



10864
10865
10866
# File 'lib/models/porcelain.rb', line 10864

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10878
10879
10880
10881
10882
10883
10884
# File 'lib/models/porcelain.rb', line 10878

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end