Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
10780
# File 'lib/models/porcelain.rb', line 10770

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



10762
10763
10764
# File 'lib/models/porcelain.rb', line 10762

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



10764
10765
10766
# File 'lib/models/porcelain.rb', line 10764

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



10766
10767
10768
# File 'lib/models/porcelain.rb', line 10766

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



10768
10769
10770
# File 'lib/models/porcelain.rb', line 10768

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10782
10783
10784
10785
10786
10787
10788
# File 'lib/models/porcelain.rb', line 10782

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end