Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowHistory records the state of a Workflow at a given point in time, where every change (create, update and delete) to a Workflow produces an WorkflowHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



9679
9680
9681
9682
9683
9684
9685
9686
9687
9688
9689
# File 'lib/models/porcelain.rb', line 9679

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



9671
9672
9673
# File 'lib/models/porcelain.rb', line 9671

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



9673
9674
9675
# File 'lib/models/porcelain.rb', line 9673

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



9675
9676
9677
# File 'lib/models/porcelain.rb', line 9675

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



9677
9678
9679
# File 'lib/models/porcelain.rb', line 9677

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9691
9692
9693
9694
9695
9696
9697
# File 'lib/models/porcelain.rb', line 9691

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end