Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



15823
15824
15825
15826
15827
15828
15829
15830
15831
15832
15833
# File 'lib/models/porcelain.rb', line 15823

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



15815
15816
15817
# File 'lib/models/porcelain.rb', line 15815

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



15817
15818
15819
# File 'lib/models/porcelain.rb', line 15817

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Workflow state was recorded.



15819
15820
15821
# File 'lib/models/porcelain.rb', line 15819

def timestamp
  @timestamp
end

#workflowObject

The complete Workflow state at this time.



15821
15822
15823
# File 'lib/models/porcelain.rb', line 15821

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15835
15836
15837
15838
15839
15840
15841
# File 'lib/models/porcelain.rb', line 15835

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end