Class: SDM::WorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowsHistory provides records of all changes to the state of a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow: nil) ⇒ WorkflowHistory

Returns a new instance of WorkflowHistory.



19657
19658
19659
19660
19661
19662
19663
19664
19665
19666
19667
# File 'lib/models/porcelain.rb', line 19657

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow = workflow == nil ? nil : workflow
end

Instance Attribute Details

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.



19649
19650
19651
# File 'lib/models/porcelain.rb', line 19649

def activity_id
  @activity_id
end

#deleted_at ⇒ Object

If this Workflow was deleted, the time it was deleted.



19651
19652
19653
# File 'lib/models/porcelain.rb', line 19651

def deleted_at
  @deleted_at
end

#timestamp ⇒ Object

The time at which the Workflow state was recorded.



19653
19654
19655
# File 'lib/models/porcelain.rb', line 19653

def timestamp
  @timestamp
end

#workflow ⇒ Object

The complete Workflow state at this time.



19655
19656
19657
# File 'lib/models/porcelain.rb', line 19655

def workflow
  @workflow
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19669
19670
19671
19672
19673
19674
19675
# File 'lib/models/porcelain.rb', line 19669

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end