Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



19283
19284
19285
19286
19287
19288
19289
19290
19291
# File 'lib/models/porcelain.rb', line 19283

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



19277
19278
19279
# File 'lib/models/porcelain.rb', line 19277

def id
  @id
end

#role_idObject

The role id.



19279
19280
19281
# File 'lib/models/porcelain.rb', line 19279

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



19281
19282
19283
# File 'lib/models/porcelain.rb', line 19281

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19293
19294
19295
19296
19297
19298
19299
# File 'lib/models/porcelain.rb', line 19293

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end