Class: SDM::WorkflowRole
- Inherits:
-
Object
- Object
- SDM::WorkflowRole
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the WorkflowRole.
-
#role_id ⇒ Object
The role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole
constructor
A new instance of WorkflowRole.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole
Returns a new instance of WorkflowRole.
18790 18791 18792 18793 18794 18795 18796 18797 18798 |
# File 'lib/models/porcelain.rb', line 18790 def initialize( id: nil, role_id: nil, workflow_id: nil ) @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the WorkflowRole.
18784 18785 18786 |
# File 'lib/models/porcelain.rb', line 18784 def id @id end |
#role_id ⇒ Object
The role id.
18786 18787 18788 |
# File 'lib/models/porcelain.rb', line 18786 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
18788 18789 18790 |
# File 'lib/models/porcelain.rb', line 18788 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18800 18801 18802 18803 18804 18805 18806 |
# File 'lib/models/porcelain.rb', line 18800 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |