Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



18484
18485
18486
18487
18488
18489
18490
18491
18492
# File 'lib/models/porcelain.rb', line 18484

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



18478
18479
18480
# File 'lib/models/porcelain.rb', line 18478

def id
  @id
end

#role_idObject

The role id.



18480
18481
18482
# File 'lib/models/porcelain.rb', line 18480

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



18482
18483
18484
# File 'lib/models/porcelain.rb', line 18482

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18494
18495
18496
18497
18498
18499
18500
# File 'lib/models/porcelain.rb', line 18494

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end