Class: SDM::WorkflowRole
- Inherits:
-
Object
- Object
- SDM::WorkflowRole
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the WorkflowRole.
-
#role_id ⇒ Object
The role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole
constructor
A new instance of WorkflowRole.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole
Returns a new instance of WorkflowRole.
17488 17489 17490 17491 17492 17493 17494 17495 17496 |
# File 'lib/models/porcelain.rb', line 17488 def initialize( id: nil, role_id: nil, workflow_id: nil ) @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the WorkflowRole.
17482 17483 17484 |
# File 'lib/models/porcelain.rb', line 17482 def id @id end |
#role_id ⇒ Object
The role id.
17484 17485 17486 |
# File 'lib/models/porcelain.rb', line 17484 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
17486 17487 17488 |
# File 'lib/models/porcelain.rb', line 17486 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17498 17499 17500 17501 17502 17503 17504 |
# File 'lib/models/porcelain.rb', line 17498 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |