Class: SDM::WorkflowRole
- Inherits:
-
Object
- Object
- SDM::WorkflowRole
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the WorkflowRole.
-
#role_id ⇒ Object
The role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole
constructor
A new instance of WorkflowRole.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole
Returns a new instance of WorkflowRole.
16061 16062 16063 16064 16065 16066 16067 16068 16069 |
# File 'lib/models/porcelain.rb', line 16061 def initialize( id: nil, role_id: nil, workflow_id: nil ) @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the WorkflowRole.
16055 16056 16057 |
# File 'lib/models/porcelain.rb', line 16055 def id @id end |
#role_id ⇒ Object
The role id.
16057 16058 16059 |
# File 'lib/models/porcelain.rb', line 16057 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
16059 16060 16061 |
# File 'lib/models/porcelain.rb', line 16059 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16071 16072 16073 16074 16075 16076 16077 |
# File 'lib/models/porcelain.rb', line 16071 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |