Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



16069
16070
16071
16072
16073
16074
16075
16076
16077
# File 'lib/models/porcelain.rb', line 16069

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



16063
16064
16065
# File 'lib/models/porcelain.rb', line 16063

def id
  @id
end

#role_idObject

The role id.



16065
16066
16067
# File 'lib/models/porcelain.rb', line 16065

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



16067
16068
16069
# File 'lib/models/porcelain.rb', line 16067

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16079
16080
16081
16082
16083
16084
16085
# File 'lib/models/porcelain.rb', line 16079

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end