Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



15886
15887
15888
15889
15890
15891
15892
15893
15894
# File 'lib/models/porcelain.rb', line 15886

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



15880
15881
15882
# File 'lib/models/porcelain.rb', line 15880

def id
  @id
end

#role_idObject

The role id.



15882
15883
15884
# File 'lib/models/porcelain.rb', line 15882

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



15884
15885
15886
# File 'lib/models/porcelain.rb', line 15884

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15896
15897
15898
15899
15900
15901
15902
# File 'lib/models/porcelain.rb', line 15896

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end