Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



15807
15808
15809
15810
15811
15812
15813
15814
15815
# File 'lib/models/porcelain.rb', line 15807

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



15801
15802
15803
# File 'lib/models/porcelain.rb', line 15801

def id
  @id
end

#role_idObject

The role id.



15803
15804
15805
# File 'lib/models/porcelain.rb', line 15803

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



15805
15806
15807
# File 'lib/models/porcelain.rb', line 15805

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15817
15818
15819
15820
15821
15822
15823
# File 'lib/models/porcelain.rb', line 15817

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end