Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



15734
15735
15736
15737
15738
15739
15740
15741
15742
# File 'lib/models/porcelain.rb', line 15734

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



15728
15729
15730
# File 'lib/models/porcelain.rb', line 15728

def id
  @id
end

#role_idObject

The role id.



15730
15731
15732
# File 'lib/models/porcelain.rb', line 15730

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



15732
15733
15734
# File 'lib/models/porcelain.rb', line 15732

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15744
15745
15746
15747
15748
15749
15750
# File 'lib/models/porcelain.rb', line 15744

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end