Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



15666
15667
15668
15669
15670
15671
15672
15673
15674
# File 'lib/models/porcelain.rb', line 15666

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



15660
15661
15662
# File 'lib/models/porcelain.rb', line 15660

def id
  @id
end

#role_idObject

The role id.



15662
15663
15664
# File 'lib/models/porcelain.rb', line 15662

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



15664
15665
15666
# File 'lib/models/porcelain.rb', line 15664

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15676
15677
15678
15679
15680
15681
15682
# File 'lib/models/porcelain.rb', line 15676

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end