Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



14490
14491
14492
14493
14494
14495
14496
14497
14498
# File 'lib/models/porcelain.rb', line 14490

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



14484
14485
14486
# File 'lib/models/porcelain.rb', line 14484

def id
  @id
end

#role_idObject

The role id.



14486
14487
14488
# File 'lib/models/porcelain.rb', line 14486

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



14488
14489
14490
# File 'lib/models/porcelain.rb', line 14488

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14500
14501
14502
14503
14504
14505
14506
# File 'lib/models/porcelain.rb', line 14500

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end