Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



14482
14483
14484
14485
14486
14487
14488
14489
14490
# File 'lib/models/porcelain.rb', line 14482

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



14476
14477
14478
# File 'lib/models/porcelain.rb', line 14476

def id
  @id
end

#role_idObject

The role id.



14478
14479
14480
# File 'lib/models/porcelain.rb', line 14478

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



14480
14481
14482
# File 'lib/models/porcelain.rb', line 14480

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14492
14493
14494
14495
14496
14497
14498
# File 'lib/models/porcelain.rb', line 14492

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end