Class: SDM::WorkflowRole
- Inherits:
-
Object
- Object
- SDM::WorkflowRole
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the WorkflowRole.
-
#role_id ⇒ Object
The role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole
constructor
A new instance of WorkflowRole.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole
Returns a new instance of WorkflowRole.
14407 14408 14409 14410 14411 14412 14413 14414 14415 |
# File 'lib/models/porcelain.rb', line 14407 def initialize( id: nil, role_id: nil, workflow_id: nil ) @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the WorkflowRole.
14401 14402 14403 |
# File 'lib/models/porcelain.rb', line 14401 def id @id end |
#role_id ⇒ Object
The role id.
14403 14404 14405 |
# File 'lib/models/porcelain.rb', line 14403 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
14405 14406 14407 |
# File 'lib/models/porcelain.rb', line 14405 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14417 14418 14419 14420 14421 14422 14423 |
# File 'lib/models/porcelain.rb', line 14417 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |