Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



14323
14324
14325
14326
14327
14328
14329
14330
14331
# File 'lib/models/porcelain.rb', line 14323

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



14317
14318
14319
# File 'lib/models/porcelain.rb', line 14317

def id
  @id
end

#role_idObject

The role id.



14319
14320
14321
# File 'lib/models/porcelain.rb', line 14319

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



14321
14322
14323
# File 'lib/models/porcelain.rb', line 14321

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14333
14334
14335
14336
14337
14338
14339
# File 'lib/models/porcelain.rb', line 14333

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end