Class: SDM::WorkflowRole
- Inherits:
-
Object
- Object
- SDM::WorkflowRole
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the WorkflowRole.
-
#role_id ⇒ Object
The role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole
constructor
A new instance of WorkflowRole.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole
Returns a new instance of WorkflowRole.
14088 14089 14090 14091 14092 14093 14094 14095 14096 |
# File 'lib/models/porcelain.rb', line 14088 def initialize( id: nil, role_id: nil, workflow_id: nil ) @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the WorkflowRole.
14082 14083 14084 |
# File 'lib/models/porcelain.rb', line 14082 def id @id end |
#role_id ⇒ Object
The role id.
14084 14085 14086 |
# File 'lib/models/porcelain.rb', line 14084 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
14086 14087 14088 |
# File 'lib/models/porcelain.rb', line 14086 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14098 14099 14100 14101 14102 14103 14104 |
# File 'lib/models/porcelain.rb', line 14098 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |