Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



14084
14085
14086
14087
14088
14089
14090
14091
14092
# File 'lib/models/porcelain.rb', line 14084

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



14078
14079
14080
# File 'lib/models/porcelain.rb', line 14078

def id
  @id
end

#role_idObject

The role id.



14080
14081
14082
# File 'lib/models/porcelain.rb', line 14080

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



14082
14083
14084
# File 'lib/models/porcelain.rb', line 14082

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14094
14095
14096
14097
14098
14099
14100
# File 'lib/models/porcelain.rb', line 14094

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end