Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



14008
14009
14010
14011
14012
14013
14014
14015
14016
# File 'lib/models/porcelain.rb', line 14008

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



14002
14003
14004
# File 'lib/models/porcelain.rb', line 14002

def id
  @id
end

#role_idObject

The role id.



14004
14005
14006
# File 'lib/models/porcelain.rb', line 14004

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



14006
14007
14008
# File 'lib/models/porcelain.rb', line 14006

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14018
14019
14020
14021
14022
14023
14024
# File 'lib/models/porcelain.rb', line 14018

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end