Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



13572
13573
13574
13575
13576
13577
13578
13579
13580
# File 'lib/models/porcelain.rb', line 13572

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



13566
13567
13568
# File 'lib/models/porcelain.rb', line 13566

def id
  @id
end

#role_idObject

The role id.



13568
13569
13570
# File 'lib/models/porcelain.rb', line 13568

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



13570
13571
13572
# File 'lib/models/porcelain.rb', line 13570

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13582
13583
13584
13585
13586
13587
13588
# File 'lib/models/porcelain.rb', line 13582

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end