Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



13234
13235
13236
13237
13238
13239
13240
13241
13242
# File 'lib/models/porcelain.rb', line 13234

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



13228
13229
13230
# File 'lib/models/porcelain.rb', line 13228

def id
  @id
end

#role_idObject

The role id.



13230
13231
13232
# File 'lib/models/porcelain.rb', line 13230

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



13232
13233
13234
# File 'lib/models/porcelain.rb', line 13232

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13244
13245
13246
13247
13248
13249
13250
# File 'lib/models/porcelain.rb', line 13244

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end