Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



12641
12642
12643
12644
12645
12646
12647
12648
12649
# File 'lib/models/porcelain.rb', line 12641

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



12635
12636
12637
# File 'lib/models/porcelain.rb', line 12635

def id
  @id
end

#role_idObject

The role id.



12637
12638
12639
# File 'lib/models/porcelain.rb', line 12637

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



12639
12640
12641
# File 'lib/models/porcelain.rb', line 12639

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12651
12652
12653
12654
12655
12656
12657
# File 'lib/models/porcelain.rb', line 12651

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end