Class: SDM::WorkflowRole
- Inherits:
-
Object
- Object
- SDM::WorkflowRole
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the WorkflowRole.
-
#role_id ⇒ Object
The role id.
-
#workflow_id ⇒ Object
The workflow id.
Instance Method Summary collapse
-
#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole
constructor
A new instance of WorkflowRole.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole
Returns a new instance of WorkflowRole.
12637 12638 12639 12640 12641 12642 12643 12644 12645 |
# File 'lib/models/porcelain.rb', line 12637 def initialize( id: nil, role_id: nil, workflow_id: nil ) @id = id == nil ? "" : id @role_id = role_id == nil ? "" : role_id @workflow_id = workflow_id == nil ? "" : workflow_id end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the WorkflowRole.
12631 12632 12633 |
# File 'lib/models/porcelain.rb', line 12631 def id @id end |
#role_id ⇒ Object
The role id.
12633 12634 12635 |
# File 'lib/models/porcelain.rb', line 12633 def role_id @role_id end |
#workflow_id ⇒ Object
The workflow id.
12635 12636 12637 |
# File 'lib/models/porcelain.rb', line 12635 def workflow_id @workflow_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12647 12648 12649 12650 12651 12652 12653 |
# File 'lib/models/porcelain.rb', line 12647 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |