Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



12248
12249
12250
12251
12252
12253
12254
12255
12256
# File 'lib/models/porcelain.rb', line 12248

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



12242
12243
12244
# File 'lib/models/porcelain.rb', line 12242

def id
  @id
end

#role_idObject

The role id.



12244
12245
12246
# File 'lib/models/porcelain.rb', line 12244

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



12246
12247
12248
# File 'lib/models/porcelain.rb', line 12246

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12258
12259
12260
12261
12262
12263
12264
# File 'lib/models/porcelain.rb', line 12258

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end