Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



11549
11550
11551
11552
11553
11554
11555
11556
11557
# File 'lib/models/porcelain.rb', line 11549

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



11543
11544
11545
# File 'lib/models/porcelain.rb', line 11543

def id
  @id
end

#role_idObject

The role id.



11545
11546
11547
# File 'lib/models/porcelain.rb', line 11545

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



11547
11548
11549
# File 'lib/models/porcelain.rb', line 11547

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11559
11560
11561
11562
11563
11564
11565
# File 'lib/models/porcelain.rb', line 11559

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end