Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



10918
10919
10920
10921
10922
10923
10924
10925
10926
# File 'lib/models/porcelain.rb', line 10918

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



10912
10913
10914
# File 'lib/models/porcelain.rb', line 10912

def id
  @id
end

#role_idObject

The role id.



10914
10915
10916
# File 'lib/models/porcelain.rb', line 10914

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



10916
10917
10918
# File 'lib/models/porcelain.rb', line 10916

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10928
10929
10930
10931
10932
10933
10934
# File 'lib/models/porcelain.rb', line 10928

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end