Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



15875
15876
15877
15878
15879
15880
15881
15882
15883
# File 'lib/models/porcelain.rb', line 15875

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



15869
15870
15871
# File 'lib/models/porcelain.rb', line 15869

def id
  @id
end

#role_idObject

The role id.



15871
15872
15873
# File 'lib/models/porcelain.rb', line 15871

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



15873
15874
15875
# File 'lib/models/porcelain.rb', line 15873

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15885
15886
15887
15888
15889
15890
15891
# File 'lib/models/porcelain.rb', line 15885

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end