Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



19660
19661
19662
19663
19664
19665
19666
19667
19668
19669
19670
# File 'lib/models/porcelain.rb', line 19660

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



19652
19653
19654
# File 'lib/models/porcelain.rb', line 19652

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



19654
19655
19656
# File 'lib/models/porcelain.rb', line 19654

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



19656
19657
19658
# File 'lib/models/porcelain.rb', line 19656

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



19658
19659
19660
# File 'lib/models/porcelain.rb', line 19658

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19672
19673
19674
19675
19676
19677
19678
# File 'lib/models/porcelain.rb', line 19672

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end