Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



19576
19577
19578
19579
19580
19581
19582
19583
19584
19585
19586
# File 'lib/models/porcelain.rb', line 19576

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



19568
19569
19570
# File 'lib/models/porcelain.rb', line 19568

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



19570
19571
19572
# File 'lib/models/porcelain.rb', line 19570

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



19572
19573
19574
# File 'lib/models/porcelain.rb', line 19572

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



19574
19575
19576
# File 'lib/models/porcelain.rb', line 19574

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19588
19589
19590
19591
19592
19593
19594
# File 'lib/models/porcelain.rb', line 19588

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end