Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



19342
19343
19344
19345
19346
19347
19348
19349
19350
19351
19352
# File 'lib/models/porcelain.rb', line 19342

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



19334
19335
19336
# File 'lib/models/porcelain.rb', line 19334

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



19336
19337
19338
# File 'lib/models/porcelain.rb', line 19336

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



19338
19339
19340
# File 'lib/models/porcelain.rb', line 19338

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



19340
19341
19342
# File 'lib/models/porcelain.rb', line 19340

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19354
19355
19356
19357
19358
19359
19360
# File 'lib/models/porcelain.rb', line 19354

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end