Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



19226
19227
19228
19229
19230
19231
19232
19233
19234
19235
19236
# File 'lib/models/porcelain.rb', line 19226

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



19218
19219
19220
# File 'lib/models/porcelain.rb', line 19218

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



19220
19221
19222
# File 'lib/models/porcelain.rb', line 19220

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



19222
19223
19224
# File 'lib/models/porcelain.rb', line 19222

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



19224
19225
19226
# File 'lib/models/porcelain.rb', line 19224

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19238
19239
19240
19241
19242
19243
19244
# File 'lib/models/porcelain.rb', line 19238

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end