Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



18829
18830
18831
18832
18833
18834
18835
18836
18837
18838
18839
# File 'lib/models/porcelain.rb', line 18829

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



18821
18822
18823
# File 'lib/models/porcelain.rb', line 18821

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



18823
18824
18825
# File 'lib/models/porcelain.rb', line 18823

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



18825
18826
18827
# File 'lib/models/porcelain.rb', line 18825

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



18827
18828
18829
# File 'lib/models/porcelain.rb', line 18827

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18841
18842
18843
18844
18845
18846
18847
# File 'lib/models/porcelain.rb', line 18841

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end