Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



17547
17548
17549
17550
17551
17552
17553
17554
17555
17556
17557
# File 'lib/models/porcelain.rb', line 17547

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



17539
17540
17541
# File 'lib/models/porcelain.rb', line 17539

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



17541
17542
17543
# File 'lib/models/porcelain.rb', line 17541

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



17543
17544
17545
# File 'lib/models/porcelain.rb', line 17543

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



17545
17546
17547
# File 'lib/models/porcelain.rb', line 17545

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17559
17560
17561
17562
17563
17564
17565
# File 'lib/models/porcelain.rb', line 17559

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end