Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



16012
16013
16014
16015
16016
16017
16018
16019
16020
16021
16022
# File 'lib/models/porcelain.rb', line 16012

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



16004
16005
16006
# File 'lib/models/porcelain.rb', line 16004

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



16006
16007
16008
# File 'lib/models/porcelain.rb', line 16006

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



16008
16009
16010
# File 'lib/models/porcelain.rb', line 16008

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



16010
16011
16012
# File 'lib/models/porcelain.rb', line 16010

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16024
16025
16026
16027
16028
16029
16030
# File 'lib/models/porcelain.rb', line 16024

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end