Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



15945
15946
15947
15948
15949
15950
15951
15952
15953
15954
15955
# File 'lib/models/porcelain.rb', line 15945

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



15937
15938
15939
# File 'lib/models/porcelain.rb', line 15937

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



15939
15940
15941
# File 'lib/models/porcelain.rb', line 15939

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



15941
15942
15943
# File 'lib/models/porcelain.rb', line 15941

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



15943
15944
15945
# File 'lib/models/porcelain.rb', line 15943

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15957
15958
15959
15960
15961
15962
15963
# File 'lib/models/porcelain.rb', line 15957

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end