Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



15725
15726
15727
15728
15729
15730
15731
15732
15733
15734
15735
# File 'lib/models/porcelain.rb', line 15725

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



15717
15718
15719
# File 'lib/models/porcelain.rb', line 15717

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



15719
15720
15721
# File 'lib/models/porcelain.rb', line 15719

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



15721
15722
15723
# File 'lib/models/porcelain.rb', line 15721

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



15723
15724
15725
# File 'lib/models/porcelain.rb', line 15723

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15737
15738
15739
15740
15741
15742
15743
# File 'lib/models/porcelain.rb', line 15737

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end