Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



14466
14467
14468
14469
14470
14471
14472
14473
14474
14475
14476
# File 'lib/models/porcelain.rb', line 14466

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



14458
14459
14460
# File 'lib/models/porcelain.rb', line 14458

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



14460
14461
14462
# File 'lib/models/porcelain.rb', line 14460

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



14462
14463
14464
# File 'lib/models/porcelain.rb', line 14462

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



14464
14465
14466
# File 'lib/models/porcelain.rb', line 14464

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14478
14479
14480
14481
14482
14483
14484
# File 'lib/models/porcelain.rb', line 14478

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end