Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



14146
14147
14148
14149
14150
14151
14152
14153
14154
14155
14156
# File 'lib/models/porcelain.rb', line 14146

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



14138
14139
14140
# File 'lib/models/porcelain.rb', line 14138

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



14140
14141
14142
# File 'lib/models/porcelain.rb', line 14140

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



14142
14143
14144
# File 'lib/models/porcelain.rb', line 14142

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



14144
14145
14146
# File 'lib/models/porcelain.rb', line 14144

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14158
14159
14160
14161
14162
14163
14164
# File 'lib/models/porcelain.rb', line 14158

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end