Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



13992
13993
13994
13995
13996
13997
13998
13999
14000
14001
14002
# File 'lib/models/porcelain.rb', line 13992

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



13984
13985
13986
# File 'lib/models/porcelain.rb', line 13984

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



13986
13987
13988
# File 'lib/models/porcelain.rb', line 13986

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



13988
13989
13990
# File 'lib/models/porcelain.rb', line 13988

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



13990
13991
13992
# File 'lib/models/porcelain.rb', line 13990

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14004
14005
14006
14007
14008
14009
14010
# File 'lib/models/porcelain.rb', line 14004

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end