Class: SDM::WorkflowRoleHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowRoleHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowRole.
-
#deleted_at ⇒ Object
If this WorkflowRole was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the WorkflowRole state was recorded.
-
#workflow_role ⇒ Object
The complete WorkflowRole state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory
constructor
A new instance of WorkflowRoleHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory
Returns a new instance of WorkflowRoleHistory.
13926 13927 13928 13929 13930 13931 13932 13933 13934 13935 13936 |
# File 'lib/models/porcelain.rb', line 13926 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow_role = workflow_role == nil ? nil : workflow_role end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.
13918 13919 13920 |
# File 'lib/models/porcelain.rb', line 13918 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this WorkflowRole was deleted, the time it was deleted.
13920 13921 13922 |
# File 'lib/models/porcelain.rb', line 13920 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the WorkflowRole state was recorded.
13922 13923 13924 |
# File 'lib/models/porcelain.rb', line 13922 def @timestamp end |
#workflow_role ⇒ Object
The complete WorkflowRole state at this time.
13924 13925 13926 |
# File 'lib/models/porcelain.rb', line 13924 def workflow_role @workflow_role end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/models/porcelain.rb', line 13938 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |