Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



13631
13632
13633
13634
13635
13636
13637
13638
13639
13640
13641
# File 'lib/models/porcelain.rb', line 13631

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



13623
13624
13625
# File 'lib/models/porcelain.rb', line 13623

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



13625
13626
13627
# File 'lib/models/porcelain.rb', line 13625

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



13627
13628
13629
# File 'lib/models/porcelain.rb', line 13627

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



13629
13630
13631
# File 'lib/models/porcelain.rb', line 13629

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13643
13644
13645
13646
13647
13648
13649
# File 'lib/models/porcelain.rb', line 13643

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end