Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



13541
13542
13543
13544
13545
13546
13547
13548
13549
13550
13551
# File 'lib/models/porcelain.rb', line 13541

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



13533
13534
13535
# File 'lib/models/porcelain.rb', line 13533

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



13535
13536
13537
# File 'lib/models/porcelain.rb', line 13535

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



13537
13538
13539
# File 'lib/models/porcelain.rb', line 13537

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



13539
13540
13541
# File 'lib/models/porcelain.rb', line 13539

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13553
13554
13555
13556
13557
13558
13559
# File 'lib/models/porcelain.rb', line 13553

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end