Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



13364
13365
13366
13367
13368
13369
13370
13371
13372
13373
13374
# File 'lib/models/porcelain.rb', line 13364

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



13356
13357
13358
# File 'lib/models/porcelain.rb', line 13356

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



13358
13359
13360
# File 'lib/models/porcelain.rb', line 13358

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



13360
13361
13362
# File 'lib/models/porcelain.rb', line 13360

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



13362
13363
13364
# File 'lib/models/porcelain.rb', line 13362

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13376
13377
13378
13379
13380
13381
13382
# File 'lib/models/porcelain.rb', line 13376

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end