Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
# File 'lib/models/porcelain.rb', line 13293

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



13285
13286
13287
# File 'lib/models/porcelain.rb', line 13285

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



13287
13288
13289
# File 'lib/models/porcelain.rb', line 13287

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



13289
13290
13291
# File 'lib/models/porcelain.rb', line 13289

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



13291
13292
13293
# File 'lib/models/porcelain.rb', line 13291

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13305
13306
13307
13308
13309
13310
13311
# File 'lib/models/porcelain.rb', line 13305

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end