Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
# File 'lib/models/porcelain.rb', line 13217

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



13209
13210
13211
# File 'lib/models/porcelain.rb', line 13209

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



13211
13212
13213
# File 'lib/models/porcelain.rb', line 13211

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



13213
13214
13215
# File 'lib/models/porcelain.rb', line 13213

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



13215
13216
13217
# File 'lib/models/porcelain.rb', line 13215

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13229
13230
13231
13232
13233
13234
13235
# File 'lib/models/porcelain.rb', line 13229

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end