Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
# File 'lib/models/porcelain.rb', line 12869

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



12861
12862
12863
# File 'lib/models/porcelain.rb', line 12861

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



12863
12864
12865
# File 'lib/models/porcelain.rb', line 12863

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



12865
12866
12867
# File 'lib/models/porcelain.rb', line 12865

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



12867
12868
12869
# File 'lib/models/porcelain.rb', line 12867

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12881
12882
12883
12884
12885
12886
12887
# File 'lib/models/porcelain.rb', line 12881

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end