Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



12526
12527
12528
12529
12530
12531
12532
12533
12534
12535
12536
# File 'lib/models/porcelain.rb', line 12526

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



12518
12519
12520
# File 'lib/models/porcelain.rb', line 12518

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



12520
12521
12522
# File 'lib/models/porcelain.rb', line 12520

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



12522
12523
12524
# File 'lib/models/porcelain.rb', line 12522

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



12524
12525
12526
# File 'lib/models/porcelain.rb', line 12524

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12538
12539
12540
12541
12542
12543
12544
# File 'lib/models/porcelain.rb', line 12538

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end