Class: SDM::WorkflowRoleHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowRoleHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowRole.
-
#deleted_at ⇒ Object
If this WorkflowRole was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the WorkflowRole state was recorded.
-
#workflow_role ⇒ Object
The complete WorkflowRole state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory
constructor
A new instance of WorkflowRoleHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory
Returns a new instance of WorkflowRoleHistory.
12524 12525 12526 12527 12528 12529 12530 12531 12532 12533 12534 |
# File 'lib/models/porcelain.rb', line 12524 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow_role = workflow_role == nil ? nil : workflow_role end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.
12516 12517 12518 |
# File 'lib/models/porcelain.rb', line 12516 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this WorkflowRole was deleted, the time it was deleted.
12518 12519 12520 |
# File 'lib/models/porcelain.rb', line 12518 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the WorkflowRole state was recorded.
12520 12521 12522 |
# File 'lib/models/porcelain.rb', line 12520 def @timestamp end |
#workflow_role ⇒ Object
The complete WorkflowRole state at this time.
12522 12523 12524 |
# File 'lib/models/porcelain.rb', line 12522 def workflow_role @workflow_role end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12536 12537 12538 12539 12540 12541 12542 |
# File 'lib/models/porcelain.rb', line 12536 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |