Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



11746
11747
11748
11749
11750
11751
11752
11753
11754
11755
11756
# File 'lib/models/porcelain.rb', line 11746

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



11738
11739
11740
# File 'lib/models/porcelain.rb', line 11738

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



11740
11741
11742
# File 'lib/models/porcelain.rb', line 11740

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



11742
11743
11744
# File 'lib/models/porcelain.rb', line 11742

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



11744
11745
11746
# File 'lib/models/porcelain.rb', line 11744

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11758
11759
11760
11761
11762
11763
11764
# File 'lib/models/porcelain.rb', line 11758

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end