Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



11608
11609
11610
11611
11612
11613
11614
11615
11616
11617
11618
# File 'lib/models/porcelain.rb', line 11608

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



11600
11601
11602
# File 'lib/models/porcelain.rb', line 11600

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



11602
11603
11604
# File 'lib/models/porcelain.rb', line 11602

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



11604
11605
11606
# File 'lib/models/porcelain.rb', line 11604

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



11606
11607
11608
# File 'lib/models/porcelain.rb', line 11606

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11620
11621
11622
11623
11624
11625
11626
# File 'lib/models/porcelain.rb', line 11620

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end