Class: SDM::WorkflowRoleHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowRoleHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowRole.
-
#deleted_at ⇒ Object
If this WorkflowRole was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the WorkflowRole state was recorded.
-
#workflow_role ⇒ Object
The complete WorkflowRole state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory
constructor
A new instance of WorkflowRoleHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory
Returns a new instance of WorkflowRoleHistory.
10977 10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 |
# File 'lib/models/porcelain.rb', line 10977 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow_role = workflow_role == nil ? nil : workflow_role end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.
10969 10970 10971 |
# File 'lib/models/porcelain.rb', line 10969 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this WorkflowRole was deleted, the time it was deleted.
10971 10972 10973 |
# File 'lib/models/porcelain.rb', line 10971 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the WorkflowRole state was recorded.
10973 10974 10975 |
# File 'lib/models/porcelain.rb', line 10973 def @timestamp end |
#workflow_role ⇒ Object
The complete WorkflowRole state at this time.
10975 10976 10977 |
# File 'lib/models/porcelain.rb', line 10975 def workflow_role @workflow_role end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10989 10990 10991 10992 10993 10994 10995 |
# File 'lib/models/porcelain.rb', line 10989 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |