Class: SDM::WorkflowRoleHistory
- Inherits:
-
Object
- Object
- SDM::WorkflowRoleHistory
- Defined in:
- lib/models/porcelain.rb
Overview
WorkflowRolesHistory records the state of a Workflow at a given point in time, where every change (create, update and delete) to a WorkflowRole produces a WorkflowRoleHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Workflow.
-
#deleted_at ⇒ Object
If this WorkflowRole was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the Workflow state was recorded.
-
#workflow_role ⇒ Object
The complete WorkflowRole state at this time.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory
constructor
A new instance of WorkflowRoleHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory
Returns a new instance of WorkflowRoleHistory.
9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 |
# File 'lib/models/porcelain.rb', line 9738 def initialize( activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : @workflow_role = workflow_role == nil ? nil : workflow_role end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Workflow. May be empty for some system-initiated updates.
9730 9731 9732 |
# File 'lib/models/porcelain.rb', line 9730 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this WorkflowRole was deleted, the time it was deleted.
9732 9733 9734 |
# File 'lib/models/porcelain.rb', line 9732 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the Workflow state was recorded.
9734 9735 9736 |
# File 'lib/models/porcelain.rb', line 9734 def @timestamp end |
#workflow_role ⇒ Object
The complete WorkflowRole state at this time.
9736 9737 9738 |
# File 'lib/models/porcelain.rb', line 9736 def workflow_role @workflow_role end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9750 9751 9752 9753 9754 9755 9756 |
# File 'lib/models/porcelain.rb', line 9750 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |