Class: SDM::WorkflowRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, timestamp: nil, workflow_role: nil) ⇒ WorkflowRoleHistory

Returns a new instance of WorkflowRoleHistory.



18922
18923
18924
18925
18926
18927
18928
18929
18930
18931
18932
# File 'lib/models/porcelain.rb', line 18922

def initialize(
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil,
  workflow_role: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
  @workflow_role = workflow_role == nil ? nil : workflow_role
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the WorkflowRole. May be empty for some system-initiated updates.



18914
18915
18916
# File 'lib/models/porcelain.rb', line 18914

def activity_id
  @activity_id
end

#deleted_atObject

If this WorkflowRole was deleted, the time it was deleted.



18916
18917
18918
# File 'lib/models/porcelain.rb', line 18916

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the WorkflowRole state was recorded.



18918
18919
18920
# File 'lib/models/porcelain.rb', line 18918

def timestamp
  @timestamp
end

#workflow_roleObject

The complete WorkflowRole state at this time.



18920
18921
18922
# File 'lib/models/porcelain.rb', line 18920

def workflow_role
  @workflow_role
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18934
18935
18936
18937
18938
18939
18940
# File 'lib/models/porcelain.rb', line 18934

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end